------------------------------------------------------------------------------
--  This file is a part of the GRLIB VHDL IP LIBRARY
--  Copyright (C) 2020, Cobham Gaisler AB - all rights reserved.
--
-- ANY USE OR REDISTRIBUTION IN PART OR IN WHOLE MUST BE HANDLED IN 
-- ACCORDANCE WITH THE GAISLER LICENSE AGREEMENT AND MUST BE APPROVED 
-- IN ADVANCE IN WRITING.
-----------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
library UNISIM;
use UNISIM.VCOMPONENTS.all;

entity grlfpw_p2_unisim is
port(
  rst :  in std_logic;
  clk :  in std_logic;
  holdn :  in std_logic;
  cpi_flush :  in std_logic;
  cpi_exack :  in std_logic;
  cpi_a_rs1 : in std_logic_vector(4 downto 0);
  cpi_d_pc : in std_logic_vector(31 downto 0);
  cpi_d_inst : in std_logic_vector(31 downto 0);
  cpi_d_cnt : in std_logic_vector(1 downto 0);
  cpi_d_trap :  in std_logic;
  cpi_d_annul :  in std_logic;
  cpi_d_pv :  in std_logic;
  cpi_a_pc : in std_logic_vector(31 downto 0);
  cpi_a_inst : in std_logic_vector(31 downto 0);
  cpi_a_cnt : in std_logic_vector(1 downto 0);
  cpi_a_trap :  in std_logic;
  cpi_a_annul :  in std_logic;
  cpi_a_pv :  in std_logic;
  cpi_e_pc : in std_logic_vector(31 downto 0);
  cpi_e_inst : in std_logic_vector(31 downto 0);
  cpi_e_cnt : in std_logic_vector(1 downto 0);
  cpi_e_trap :  in std_logic;
  cpi_e_annul :  in std_logic;
  cpi_e_pv :  in std_logic;
  cpi_m_pc : in std_logic_vector(31 downto 0);
  cpi_m_inst : in std_logic_vector(31 downto 0);
  cpi_m_cnt : in std_logic_vector(1 downto 0);
  cpi_m_trap :  in std_logic;
  cpi_m_annul :  in std_logic;
  cpi_m_pv :  in std_logic;
  cpi_x_pc : in std_logic_vector(31 downto 0);
  cpi_x_inst : in std_logic_vector(31 downto 0);
  cpi_x_cnt : in std_logic_vector(1 downto 0);
  cpi_x_trap :  in std_logic;
  cpi_x_annul :  in std_logic;
  cpi_x_pv :  in std_logic;
  cpi_lddata : in std_logic_vector(31 downto 0);
  cpi_dbg_enable :  in std_logic;
  cpi_dbg_write :  in std_logic;
  cpi_dbg_fsr :  in std_logic;
  cpi_dbg_addr : in std_logic_vector(4 downto 0);
  cpi_dbg_data : in std_logic_vector(31 downto 0);
  cpi_ft_dis :  in std_logic;
  cpi_ft_ten :  in std_logic;
  cpi_ft_cb : in std_logic_vector(7 downto 0);
  cpi_ft_dpsel :  in std_logic;
  cpo_data : out std_logic_vector(31 downto 0);
  cpo_exc :  out std_logic;
  cpo_cc : out std_logic_vector(1 downto 0);
  cpo_ccv :  out std_logic;
  cpo_ldlock :  out std_logic;
  cpo_holdn :  out std_logic;
  cpo_restart :  out std_logic;
  cpo_dbg_data : out std_logic_vector(31 downto 0);
  cpo_dbg_par : out std_logic_vector(7 downto 0);
  rfi1_rd1addr : out std_logic_vector(3 downto 0);
  rfi1_rd2addr : out std_logic_vector(3 downto 0);
  rfi1_wraddr : out std_logic_vector(3 downto 0);
  rfi1_wrdata : out std_logic_vector(31 downto 0);
  rfi1_wecb : out std_logic_vector(7 downto 0);
  rfi1_ren1 :  out std_logic;
  rfi1_ren2 :  out std_logic;
  rfi1_wren :  out std_logic;
  rfi1_inhw1 :  out std_logic;
  rfi1_inhw2 :  out std_logic;
  rfi1_einj1 :  out std_logic;
  rfi1_einj2 :  out std_logic;
  rfi2_rd1addr : out std_logic_vector(3 downto 0);
  rfi2_rd2addr : out std_logic_vector(3 downto 0);
  rfi2_wraddr : out std_logic_vector(3 downto 0);
  rfi2_wrdata : out std_logic_vector(31 downto 0);
  rfi2_wecb : out std_logic_vector(7 downto 0);
  rfi2_ren1 :  out std_logic;
  rfi2_ren2 :  out std_logic;
  rfi2_wren :  out std_logic;
  rfi2_inhw1 :  out std_logic;
  rfi2_inhw2 :  out std_logic;
  rfi2_einj1 :  out std_logic;
  rfi2_einj2 :  out std_logic;
  rfo1_data1 : in std_logic_vector(31 downto 0);
  rfo1_data2 : in std_logic_vector(31 downto 0);
  rfo1_decb1 : in std_logic_vector(7 downto 0);
  rfo1_decb2 : in std_logic_vector(7 downto 0);
  rfo2_data1 : in std_logic_vector(31 downto 0);
  rfo2_data2 : in std_logic_vector(31 downto 0);
  rfo2_decb1 : in std_logic_vector(7 downto 0);
  rfo2_decb2 : in std_logic_vector(7 downto 0));
end grlfpw_p2_unisim;

architecture beh of grlfpw_p2_unisim is
  signal GRLFPC20_R_FSR_RD : std_logic_vector(1 downto 0);
  signal GRLFPC20_R_STATE : std_logic_vector(1 downto 0);
  signal GRLFPC20_R_I_INST : std_logic_vector(31 downto 0);
  signal GRLFPC20_R_FSR_TEM : std_logic_vector(4 downto 0);
  signal GRLFPC20_R_I_EXC : std_logic_vector(5 downto 0);
  signal GRLFPC20_R_FSR_AEXC : std_logic_vector(4 downto 0);
  signal GRLFPC20_R_A_RS1 : std_logic_vector(4 downto 0);
  signal GRLFPC20_R_A_RS2 : std_logic_vector(4 downto 0);
  signal GRLFPC20_V_I_EXC_1 : std_logic_vector(4 downto 0);
  signal GRLFPC20_R_I_CC : std_logic_vector(1 downto 0);
  signal GRLFPC20_R_I_RES : std_logic_vector(63 downto 0);
  signal GRLFPC20_R_I_PC : std_logic_vector(31 downto 2);
  signal GRLFPC20_R_FSR_CEXC : std_logic_vector(4 downto 0);
  signal GRLFPC20_R_FSR_FTT : std_logic_vector(2 downto 0);
  signal GRLFPC20_R_A_RF1REN : std_logic_vector(2 downto 1);
  signal GRLFPC20_R_A_RF2REN : std_logic_vector(2 downto 1);
  signal GRLFPC20_RS2_1 : std_logic_vector(0 to 0);
  signal GRLFPC20_RS1_1 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL : std_logic_vector(16 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SCTRL_NEW : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_DIVMULTV : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL : std_logic_vector(85 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH : std_logic_vector(377 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_MIXOIN : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3 : std_logic_vector(57 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS : std_logic_vector(56 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP : std_logic_vector(1 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS : std_logic_vector(11 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14 : std_logic_vector(77 to 77);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW : std_logic_vector(9 downto 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_10 : std_logic_vector(10 to 10);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT : std_logic_vector(3 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH : std_logic_vector(375 downto 374);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_13 : std_logic_vector(3 to 3);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12 : std_logic_vector(75 to 75);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_14 : std_logic_vector(4 to 4);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19 : std_logic_vector(63 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_50 : std_logic_vector(316 to 316);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_117 : std_logic_vector(52 to 52);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8 : std_logic_vector(57 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23 : std_logic_vector(113 downto 58);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1 : std_logic_vector(57 downto 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1 : std_logic_vector(7 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL : std_logic_vector(3 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4 : std_logic_vector(57 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS : std_logic_vector(9 downto 4);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP : std_logic_vector(3 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP : std_logic_vector(18 downto 0);
  signal GRLFPC20_V_STATE_1 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_15 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP : std_logic_vector(8 downto 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1 : std_logic_vector(1 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33 : std_logic_vector(244 downto 234);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M : std_logic_vector(47 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1 : std_logic_vector(48 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2 : std_logic_vector(57 downto 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1 : std_logic_vector(3 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0 : std_logic_vector(45 downto 1);
  signal GRLFPC20_FPI_OP2 : std_logic_vector(63 downto 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M : std_logic_vector(27 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_M_0 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SELECTQUOBITS_QUOBITS : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_T_3 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4 : std_logic_vector(56 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE : std_logic_vector(37 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M : std_logic_vector(52 downto 10);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M_0 : std_logic_vector(40 to 40);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I : std_logic_vector(3 to 3);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL : std_logic_vector(67 to 67);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_11 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_2 : std_logic_vector(57 to 57);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_2 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_CI_113 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_57 : std_logic_vector(0 to 0);
  signal GRLFPC20_FPI_OP1 : std_logic_vector(62 downto 32);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8 : std_logic_vector(57 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1 : std_logic_vector(4 downto 3);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT : std_logic_vector(4 downto 0);
  signal GRLFPC20_COMB_V_STATE_9 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3 : std_logic_vector(2 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17 : std_logic_vector(3 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2 : std_logic_vector(3 downto 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M13 : std_logic_vector(2 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M12 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19 : std_logic_vector(80 downto 63);
  signal GRLFPC20_V_FSR_FTT_CNST : std_logic_vector(2 downto 0);
  signal GRLFPC20_R_I_EXC_M : std_logic_vector(4 downto 0);
  signal GRLFPC20_MEXC_1_M : std_logic_vector(4 downto 0);
  signal GRLFPC20_FPCI_M : std_logic_vector(356 downto 352);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_WQSTSETS : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2 : std_logic_vector(2 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8 : std_logic_vector(57 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_M : std_logic_vector(57 to 57);
  signal GRLFPC20_WRADDR_1 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41 : std_logic_vector(257 downto 251);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4 : std_logic_vector(56 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2 : std_logic_vector(55 downto 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_TOPBITSIN : std_logic_vector(8 to 8);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSRRES : std_logic_vector(55 to 55);
  signal GRLFPC20_FPO_EXP : std_logic_vector(10 downto 0);
  signal GRLFPC20_FPO_FRAC : std_logic_vector(54 downto 3);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_SI_10 : std_logic_vector(47 to 47);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_67 : std_logic_vector(46 to 46);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_124 : std_logic_vector(45 to 45);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_9 : std_logic_vector(48 to 48);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_123 : std_logic_vector(46 to 46);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_SI_8 : std_logic_vector(49 to 49);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_65 : std_logic_vector(48 to 48);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_SI_7 : std_logic_vector(50 to 50);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_5 : std_logic_vector(52 to 52);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_SI_62 : std_logic_vector(51 to 51);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_SI_25 : std_logic_vector(32 to 32);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_82 : std_logic_vector(31 to 31);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_SI_139 : std_logic_vector(30 to 30);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_24 : std_logic_vector(33 to 33);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_138 : std_logic_vector(31 to 31);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_SI_23 : std_logic_vector(34 to 34);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_80 : std_logic_vector(33 to 33);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_22 : std_logic_vector(35 to 35);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_21 : std_logic_vector(36 to 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_78 : std_logic_vector(35 to 35);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_20 : std_logic_vector(37 to 37);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_77 : std_logic_vector(36 to 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_76 : std_logic_vector(37 to 37);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_133 : std_logic_vector(36 to 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_SI_18 : std_logic_vector(39 to 39);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_132 : std_logic_vector(37 to 37);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_17 : std_logic_vector(40 to 40);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_16 : std_logic_vector(41 to 41);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_73 : std_logic_vector(40 to 40);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_SI_15 : std_logic_vector(42 to 42);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_72 : std_logic_vector(41 to 41);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_129 : std_logic_vector(40 to 40);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_SI_14 : std_logic_vector(43 to 43);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_128 : std_logic_vector(41 to 41);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_13 : std_logic_vector(44 to 44);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_SI_127 : std_logic_vector(42 to 42);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_12 : std_logic_vector(45 to 45);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_125 : std_logic_vector(44 to 44);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_40 : std_logic_vector(17 to 17);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_97 : std_logic_vector(16 to 16);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_39 : std_logic_vector(18 to 18);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_96 : std_logic_vector(17 to 17);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_153 : std_logic_vector(16 to 16);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_SI_38 : std_logic_vector(19 to 19);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_95 : std_logic_vector(18 to 18);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_SI_37 : std_logic_vector(20 to 20);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_151 : std_logic_vector(18 to 18);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_35 : std_logic_vector(22 to 22);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_SI_92 : std_logic_vector(21 to 21);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_SI_149 : std_logic_vector(20 to 20);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_34 : std_logic_vector(23 to 23);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_91 : std_logic_vector(22 to 22);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_90 : std_logic_vector(23 to 23);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_SI_89 : std_logic_vector(24 to 24);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_146 : std_logic_vector(23 to 23);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_31 : std_logic_vector(26 to 26);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_30 : std_logic_vector(27 to 27);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_87 : std_logic_vector(26 to 26);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_86 : std_logic_vector(27 to 27);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_143 : std_logic_vector(26 to 26);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_28 : std_logic_vector(29 to 29);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_SI_141 : std_logic_vector(28 to 28);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_140 : std_logic_vector(29 to 29);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_112 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_SI_54 : std_logic_vector(3 to 3);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_111 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_168 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_167 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52 : std_logic_vector(5 to 5);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_SI_109 : std_logic_vector(4 to 4);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_108 : std_logic_vector(5 to 5);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_SI_50 : std_logic_vector(7 to 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_SI_107 : std_logic_vector(6 to 6);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_164 : std_logic_vector(5 to 5);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_49 : std_logic_vector(8 to 8);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_105 : std_logic_vector(8 to 8);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_46 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_SI_103 : std_logic_vector(10 to 10);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_102 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_101 : std_logic_vector(12 to 12);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_SI_43 : std_logic_vector(14 to 14);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_100 : std_logic_vector(13 to 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_157 : std_logic_vector(12 to 12);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_42 : std_logic_vector(15 to 15);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_156 : std_logic_vector(13 to 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_41 : std_logic_vector(16 to 16);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_98 : std_logic_vector(15 to 15);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE : std_logic_vector(12 downto 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_56 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_113 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SCLSBS_1 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14_4_0 : std_logic_vector(34 to 34);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_24_0 : std_logic_vector(58 to 58);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_18_0 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_2_0 : std_logic_vector(62 to 62);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_0 : std_logic_vector(63 to 63);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0 : std_logic_vector(75 to 75);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_5 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_6 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_5 : std_logic_vector(56 to 56);
  signal CPI_D_INST_I : std_logic_vector(6 to 6);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_I : std_logic_vector(69 downto 42);
  signal GRLFPC20_V_STATE_1_IV_I : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_SCTRL_I : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_I : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_13_0 : std_logic_vector(60 to 60);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_2 : std_logic_vector(6 to 6);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3 : std_logic_vector(6 downto 5);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_18_0 : std_logic_vector(60 to 60);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_11_1 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_6_0 : std_logic_vector(13 to 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_0_0 : std_logic_vector(61 to 61);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_4_0 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2_1 : std_logic_vector(45 to 45);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_14_1 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_21_1 : std_logic_vector(60 to 60);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_17_1 : std_logic_vector(60 to 60);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_12_1 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_23_0 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_19_1 : std_logic_vector(60 to 60);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_15_1 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_0 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_1 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_4_0 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2_4 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3_4 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_3_1 : std_logic_vector(61 to 61);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_6_0 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_22_1 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_9_0 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_9_1 : std_logic_vector(36 downto 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_0_1 : std_logic_vector(39 to 39);
  signal GRLFPC20_V_A_RF1REN_1_0 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_8_0 : std_logic_vector(7 to 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_23_1 : std_logic_vector(61 to 61);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_3_1 : std_logic_vector(12 to 12);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_11_2 : std_logic_vector(60 to 60);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1 : std_logic_vector(63 downto 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0 : std_logic_vector(62 downto 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_1 : std_logic_vector(49 downto 34);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0 : std_logic_vector(60 downto 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0 : std_logic_vector(60 downto 34);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4 : std_logic_vector(60 downto 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2 : std_logic_vector(62 downto 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3 : std_logic_vector(62 downto 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0 : std_logic_vector(60 downto 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_1 : std_logic_vector(36 to 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_8 : std_logic_vector(36 to 36);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0 : std_logic_vector(62 downto 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0 : std_logic_vector(62 downto 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_0 : std_logic_vector(56 downto 49);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_1 : std_logic_vector(49 to 49);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7 : std_logic_vector(49 downto 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0 : std_logic_vector(48 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2 : std_logic_vector(61 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3 : std_logic_vector(61 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4 : std_logic_vector(61 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5 : std_logic_vector(61 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0_0 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_0 : std_logic_vector(61 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_0 : std_logic_vector(48 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_7_0 : std_logic_vector(48 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_8_1 : std_logic_vector(11 to 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1 : std_logic_vector(61 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_1 : std_logic_vector(61 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_1 : std_logic_vector(13 to 13);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6 : std_logic_vector(61 downto 48);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_0 : std_logic_vector(48 to 48);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_1 : std_logic_vector(48 to 48);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4_0 : std_logic_vector(61 downto 48);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_1 : std_logic_vector(48 to 48);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_0 : std_logic_vector(61 to 61);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6_1 : std_logic_vector(61 to 61);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_2 : std_logic_vector(61 to 61);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5 : std_logic_vector(60 downto 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_6_0 : std_logic_vector(60 downto 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_0 : std_logic_vector(60 downto 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_9 : std_logic_vector(60 downto 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1 : std_logic_vector(50 downto 12);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_1 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_2 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_10 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0 : std_logic_vector(12 to 12);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0 : std_logic_vector(50 downto 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_1 : std_logic_vector(12 to 12);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0 : std_logic_vector(50 downto 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4 : std_logic_vector(50 to 50);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_0 : std_logic_vector(50 to 50);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_1 : std_logic_vector(50 to 50);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4_0 : std_logic_vector(50 to 50);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2 : std_logic_vector(7 to 7);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1 : std_logic_vector(16 to 16);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_0_0 : std_logic_vector(16 to 16);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1_0 : std_logic_vector(16 to 16);
  signal GRLFPC20_R_FSR_AEXCCE_0_0 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT_IV_0 : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_0_0 : std_logic_vector(57 to 57);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_0 : std_logic_vector(57 to 57);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_1 : std_logic_vector(57 to 57);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0 : std_logic_vector(57 downto 6);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4_0 : std_logic_vector(56 to 56);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_0 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_0 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_2_0 : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_1 : std_logic_vector(2 to 2);
  signal GRLFPC20_R_X_RDD_0_DOUT : std_logic_vector(0 to 0);
  signal GRLFPC20_R_X_SEQERR_0_DOUT : std_logic_vector(0 to 0);
  signal GRLFPC20_R_X_SEQERR_0_TMP_D_ARRAY_0 : std_logic_vector(0 to 0);
  signal GRLFPC20_R_X_RDD_0_TMP_D_ARRAY_0 : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO : std_logic_vector(53 downto 5);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_RETO : std_logic_vector(19 to 19);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_0 : std_logic_vector(23 downto 21);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_0 : std_logic_vector(23 downto 22);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_1 : std_logic_vector(23 to 23);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1 : std_logic_vector(22 to 22);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_0 : std_logic_vector(21 downto 11);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0 : std_logic_vector(54 downto 8);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14_0 : std_logic_vector(77 to 77);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_18_0 : std_logic_vector(74 to 74);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_0 : std_logic_vector(75 to 75);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_2_0_E : std_logic_vector(65 to 65);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_E_0_E : std_logic_vector(69 to 69);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_4_0_E : std_logic_vector(2 to 2);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_5_0_E : std_logic_vector(1 to 1);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_6_0_E : std_logic_vector(0 to 0);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_16_0_E : std_logic_vector(6 to 6);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_0_E : std_logic_vector(9 downto 8);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_I : std_logic_vector(53 downto 19);
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_I : std_logic_vector(9 to 9);
  signal NN_1 : std_logic ;
  signal CPO_CC_2 : std_logic ;
  signal RFI1_REN1_64 : std_logic ;
  signal RFI1_REN2_65 : std_logic ;
  signal RFI2_REN1_90 : std_logic ;
  signal RFI2_REN2_91 : std_logic ;
  signal NN_2 : std_logic ;
  signal GRLFPC20_UN1_HOLDN_1 : std_logic ;
  signal GRLFPC20_FPI_START : std_logic ;
  signal GRLFPC20_R_I_EXEC : std_logic ;
  signal GRLFPC20_R_MK_BUSY : std_logic ;
  signal GRLFPC20_R_X_LD : std_logic ;
  signal GRLFPC20_R_X_AFSR : std_logic ;
  signal GRLFPC20_R_X_SEQERR : std_logic ;
  signal GRLFPC20_R_X_FPOP : std_logic ;
  signal GRLFPC20_R_A_RS1D : std_logic ;
  signal GRLFPC20_R_A_RS2D : std_logic ;
  signal GRLFPC20_R_A_AFQ : std_logic ;
  signal GRLFPC20_R_MK_RST : std_logic ;
  signal GRLFPC20_R_MK_RST2 : std_logic ;
  signal GRLFPC20_R_MK_HOLDN1 : std_logic ;
  signal GRLFPC20_R_E_FPOP : std_logic ;
  signal GRLFPC20_R_M_FPOP : std_logic ;
  signal GRLFPC20_R_A_ST : std_logic ;
  signal GRLFPC20_R_A_AFSR : std_logic ;
  signal GRLFPC20_R_MK_HOLDN2 : std_logic ;
  signal GRLFPC20_R_I_V : std_logic ;
  signal GRLFPC20_R_M_LD : std_logic ;
  signal GRLFPC20_R_E_LD : std_logic ;
  signal GRLFPC20_R_A_LD : std_logic ;
  signal GRLFPC20_R_A_FPOP : std_logic ;
  signal GRLFPC20_R_A_RDD : std_logic ;
  signal GRLFPC20_R_A_SEQERR : std_logic ;
  signal GRLFPC20_R_MK_LDOP : std_logic ;
  signal GRLFPC20_R_M_AFQ : std_logic ;
  signal GRLFPC20_R_M_AFSR : std_logic ;
  signal GRLFPC20_R_E_AFQ : std_logic ;
  signal GRLFPC20_R_E_AFSR : std_logic ;
  signal GRLFPC20_V_E_AFSR_1 : std_logic ;
  signal GRLFPC20_R_X_RDD : std_logic ;
  signal GRLFPC20_R_X_AFQ : std_logic ;
  signal GRLFPC20_R_A_MOV : std_logic ;
  signal GRLFPC20_R_I_RDD : std_logic ;
  signal GRLFPC20_COMB_UN19_IUEXEC : std_logic ;
  signal GRLFPC20_R_MK_BUSY2 : std_logic ;
  signal GRLFPC20_R_FSR_NONSTD : std_logic ;
  signal GRLFPC20_COMB_V_MK_BUSY2_2 : std_logic ;
  signal GRLFPC20_V_MK_RST_1 : std_logic ;
  signal GRLFPC20_COMB_V_MK_BUSY_2 : std_logic ;
  signal GRLFPC20_RS1D_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1 : std_logic ;
  signal I2_I_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2778 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2812 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_18 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_25 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_18 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_25 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_32 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_39 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_46 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_53 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_60 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_67 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_74 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_81 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_88 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_95 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_102 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_109 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_116 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_123 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_130 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6303 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6321_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1008 : std_logic ;
  signal GRLFPC20_V_M_AFSR_1 : std_logic ;
  signal GRLFPC20_V_X_AFQ_1 : std_logic ;
  signal GRLFPC20_V_X_AFSR_1 : std_logic ;
  signal GRLFPC20_V_E_FPOP_1 : std_logic ;
  signal GRLFPC20_V_M_FPOP_1 : std_logic ;
  signal GRLFPC20_V_X_FPOP_1 : std_logic ;
  signal GRLFPC20_V_X_LD_1 : std_logic ;
  signal GRLFPC20_V_E_AFQ_1 : std_logic ;
  signal GRLFPC20_V_A_SEQERR_1 : std_logic ;
  signal GRLFPC20_V_A_AFSR_1 : std_logic ;
  signal GRLFPC20_FPOP_1 : std_logic ;
  signal GRLFPC20_V_A_LD_1 : std_logic ;
  signal GRLFPC20_RDD_1 : std_logic ;
  signal GRLFPC20_V_E_LD_1 : std_logic ;
  signal GRLFPC20_V_A_ST_1 : std_logic ;
  signal GRLFPC20_V_M_AFQ_1 : std_logic ;
  signal GRLFPC20_V_M_LD_1 : std_logic ;
  signal GRLFPC20_MOV_5_SQMUXA : std_logic ;
  signal GRLFPC20_AFQ_3_SQMUXA : std_logic ;
  signal GRLFPC20_RS2D_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6263 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2491 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2551 : std_logic ;
  signal GRLFPC20_FPI_LDOP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN10_NOTPROP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6132 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6133 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_SS0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2499 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2559 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6242 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6228 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2586 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA : std_logic ;
  signal GRLFPC20_WRADDR_0_SQMUXA : std_logic ;
  signal GRLFPC20_COMB_RDD_2 : std_logic ;
  signal GRLFPC20_COMB_UN2_HOLDN : std_logic ;
  signal GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2816 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2829 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6272 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2253 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN33_ZERO_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6314 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2818 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2815 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2828 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2493 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2553 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_MIXOOUT0_1_M : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2533 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN16_NOTPROP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN19_NOTPROP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN18_STKGEN_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2472 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2325 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2327 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2332 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN21_LOCOV : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_AREGXORBREG_M_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6312 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6073 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2194 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2190 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2187 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2186 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2179 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN3_LOCUV_M : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2180 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2176 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN8_NOTBINFNAN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2317 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2835 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2496 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2556 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZYBUS24_SN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN26_XZYBUSLSBS : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_128 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MAPMULXFF_UN4_UNIMPMAP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2207 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2216 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX : std_logic ;
  signal GRLFPC20_COMB_SEQERR_UN11_OP : std_logic ;
  signal GRLFPC20_RS1_1_SN_N_3 : std_logic ;
  signal GRLFPC20_RS1V_0_SQMUXA : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2205 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2214 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3077_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2200 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXCSHFT_UN13_EXMIPTRLSBS : std_logic ;
  signal GRLFPC20_COMB_LOCKGEN_LOCKI : std_logic ;
  signal GRLFPC20_RDD_1_N_20_2 : std_logic ;
  signal GRLFPC20_COMB_RSDECODE_UN1_FPCI : std_logic ;
  signal GRLFPC20_RS1V_0_SQMUXA_1 : std_logic ;
  signal GRLFPC20_MOV_1_SQMUXA : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RDD5 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RDD4 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_UN1_FPCI_1 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RS1D5_3 : std_logic ;
  signal GRLFPC20_UN1_RDD3 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RS1D5 : std_logic ;
  signal GRLFPC20_RS2_0_SQMUXA : std_logic ;
  signal GRLFPC20_V_A_AFSR_1_4 : std_logic ;
  signal GRLFPC20_MOV_0_SQMUXA_4 : std_logic ;
  signal GRLFPC20_RS1V12 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_UN1_FPCI_3 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RDD4_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP : std_logic ;
  signal GRLFPC20_ANNULFPU_1_IV : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC : std_logic ;
  signal GRLFPC20_COMB_UN1_FPCI_2 : std_logic ;
  signal GRLFPC20_COMB_LOCKGEN_DEPCHECK : std_logic ;
  signal GRLFPC20_COMB_UN3_HOLDN : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_ST : std_logic ;
  signal GRLFPC20_COMB_UN4_LOCK : std_logic ;
  signal GRLFPC20_UN1_DEPCHECK_1 : std_logic ;
  signal GRLFPC20_RDD_1_N_20 : std_logic ;
  signal GRLFPC20_RDD_1_I9_MUX : std_logic ;
  signal GRLFPC20_COMB_SEQERR_UN7_OP : std_logic ;
  signal GRLFPC20_COMB_UN1_R_A_RS1_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2576 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2694 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6116 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6117 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6115 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2487 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2547 : std_logic ;
  signal GRLFPC20_COMB_UN1_FPCI : std_logic ;
  signal GRLFPC20_COMB_V_E_STDATA2 : std_logic ;
  signal GRLFPC20_N_565 : std_logic ;
  signal GRLFPC20_N_598 : std_logic ;
  signal GRLFPC20_V_STATE_2_SQMUXA : std_logic ;
  signal GRLFPC20_N_329_2 : std_logic ;
  signal GRLFPC20_N_608 : std_logic ;
  signal GRLFPC20_N_575 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2206 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2215 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4150_1 : std_logic ;
  signal GRLFPC20_V_I_V_1_SQMUXA : std_logic ;
  signal GRLFPC20_COMB_UN1_R_I_EXC : std_logic ;
  signal GRLFPC20_COMB_V_FSR_FCC10 : std_logic ;
  signal GRLFPC20_COMB_UN1_V_STATE : std_logic ;
  signal GRLFPC20_COMB_LOCK : std_logic ;
  signal GRLFPC20_V_FSR_FTT_1_SQMUXA : std_logic ;
  signal GRLFPC20_V_I_EXEC_0_SQMUXA : std_logic ;
  signal GRLFPC20_N_593 : std_logic ;
  signal GRLFPC20_N_626 : std_logic ;
  signal GRLFPC20_COMB_V_STATE14 : std_logic ;
  signal GRLFPC20_N_826 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN1_AREGSIGN_SEL : std_logic ;
  signal GRLFPC20_ANNULFPU_1_SQMUXA : std_logic ;
  signal GRLFPC20_COMB_UN1_FPCI_1 : std_logic ;
  signal GRLFPC20_N_824_3 : std_logic ;
  signal GRLFPC20_V_FSR_AEXC_1_SM0 : std_logic ;
  signal GRLFPC20_N_824_1 : std_logic ;
  signal GRLFPC20_COMB_V_I_EXEC_5 : std_logic ;
  signal GRLFPC20_ANNULRES_1 : std_logic ;
  signal GRLFPC20_WREN2_1_SQMUXA_1 : std_logic ;
  signal GRLFPC20_COMB_WREN129 : std_logic ;
  signal GRLFPC20_COMB_UN1_R_I_V_1 : std_logic ;
  signal GRLFPC20_COMB_WRADDR_0_SQMUXA : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2581 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2699 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2827 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2814 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2255 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2164_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12_3_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2166 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_COMPUTECONST_UN25_RESVEC : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6308 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2790 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2826 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2813 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN10_S_MOV : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN3_S_SQRT : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_699 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1271_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1270_MUX : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_804_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_694 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3175_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3601_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2509 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2564 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2569 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2682 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_RNDMODESELECT_UN1_TEMP : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2772 : std_logic ;
  signal GRLFPC20_FPO_SIGN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN10_AREGSIGN_SEL : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2330 : std_logic ;
  signal GRLFPC20_N_592 : std_logic ;
  signal GRLFPC20_N_612 : std_logic ;
  signal GRLFPC20_N_625 : std_logic ;
  signal GRLFPC20_N_566 : std_logic ;
  signal GRLFPC20_N_599 : std_logic ;
  signal GRLFPC20_WRRES_1 : std_logic ;
  signal GRLFPC20_N_569 : std_logic ;
  signal GRLFPC20_N_602 : std_logic ;
  signal I2_I : std_logic ;
  signal GRLFPC20_COMB_UN1_FPCI_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6162 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6141 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2486 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2546 : std_logic ;
  signal GRLFPC20_N_571 : std_logic ;
  signal GRLFPC20_N_604 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2514 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2574 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2580 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2698 : std_logic ;
  signal GRLFPC20_N_576 : std_logic ;
  signal GRLFPC20_N_609 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2478 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2538 : std_logic ;
  signal GRLFPC20_V_FSR_CEXC_3_SQMUXA : std_logic ;
  signal GRLFPC20_N_596 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2500 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2560 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2833 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2834 : std_logic ;
  signal GRLFPC20_N_588 : std_logic ;
  signal GRLFPC20_N_595 : std_logic ;
  signal GRLFPC20_N_621 : std_logic ;
  signal GRLFPC20_COMB_UN1_MEXC : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2584 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2702 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2830 : std_logic ;
  signal GRLFPC20_N_586 : std_logic ;
  signal GRLFPC20_N_616 : std_logic ;
  signal GRLFPC20_N_619 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1367 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3734 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3731 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3732 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3425_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3347_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3031_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3712 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3029_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3727_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3177_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3296_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3225_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1707 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3207_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3222_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3672 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3078_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3794 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3343_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3654 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3661 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3667 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3671 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3753_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3791_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3664_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1277_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3026_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3179_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3801 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4431_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3793 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_MUX : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1274_MUX : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1095 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_766_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6365 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1725 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1831 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXC : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2202 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2203 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN11_WQSTSETS : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2201 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2210 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3127_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1343 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1602 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1967 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1708 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_788 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_773 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1603 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1462 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_836 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3246_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_828 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_739_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3231_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4269_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_148_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_749 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1067 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1072 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_343 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_57_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_38_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_54_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1057 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1059 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_743 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_745_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_746_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_201_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_691 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1631 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1630 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3340_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6223 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2474 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2534 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2587 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2515 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2575 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN3_XZYBUSLSBS : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6306 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1341 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1360 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1766 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1702 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1634 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1705 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_873 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1735 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4310_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4139_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3827_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1922 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1731 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3786 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3124_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3034_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3488_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3923_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4479_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1289 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1877 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1286 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_943 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3096_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3199 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1259_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4182_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4176 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4153 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4490 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4635_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4566_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1699_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6065_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN3_NOTAZERODENORM : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3130_1 : std_logic ;
  signal GRLFPC20_COMB_UN1_R_I_V : std_logic ;
  signal GRLFPC20_N_624 : std_logic ;
  signal GRLFPC20_N_623 : std_logic ;
  signal GRLFPC20_N_622 : std_logic ;
  signal GRLFPC20_N_620 : std_logic ;
  signal GRLFPC20_N_618 : std_logic ;
  signal GRLFPC20_N_617 : std_logic ;
  signal GRLFPC20_N_615 : std_logic ;
  signal GRLFPC20_N_614 : std_logic ;
  signal GRLFPC20_N_611 : std_logic ;
  signal GRLFPC20_N_610 : std_logic ;
  signal GRLFPC20_N_601 : std_logic ;
  signal GRLFPC20_N_600 : std_logic ;
  signal GRLFPC20_N_597 : std_logic ;
  signal GRLFPC20_N_589 : std_logic ;
  signal GRLFPC20_N_587 : std_logic ;
  signal GRLFPC20_N_585 : std_logic ;
  signal GRLFPC20_N_584 : std_logic ;
  signal GRLFPC20_N_578 : std_logic ;
  signal GRLFPC20_N_577 : std_logic ;
  signal GRLFPC20_N_568 : std_logic ;
  signal GRLFPC20_N_567 : std_logic ;
  signal GRLFPC20_N_564 : std_logic ;
  signal GRLFPC20_N_613 : std_logic ;
  signal GRLFPC20_N_607 : std_logic ;
  signal GRLFPC20_N_606 : std_logic ;
  signal GRLFPC20_N_605 : std_logic ;
  signal GRLFPC20_N_603 : std_logic ;
  signal GRLFPC20_N_573 : std_logic ;
  signal GRLFPC20_N_572 : std_logic ;
  signal GRLFPC20_N_570 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_7_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_8_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_12_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_844 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_24_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_MUX : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_55_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_56_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_59_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_72_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_73_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_74_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_875 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3186_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3327_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_110_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_119_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_120_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_123_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_901 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1243_MUX : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1820 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3234_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_141_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3667_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3294_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3828_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3129_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3071_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3421_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3853_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3795_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_748_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3644_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_714_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4630 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3277_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3384_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_330 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_334 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_340 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_346 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_348 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_353 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_359 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_365 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_368 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_370 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_378 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_384 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_390 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_399 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_406 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_I3_MUX_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_414 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_419 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_421 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_424 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_429 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_436 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_441 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_443 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_448 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_451 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_455 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_458 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_460 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_466 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_470 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6367 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_480 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_482 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_488 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_495 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_500 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_504 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_507 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_511 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_513 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_520 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_526 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_531 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_536 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_540 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_544 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_546 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_550 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_552 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_556 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_559 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_561 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_569 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_579 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_583 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_584 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_588 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_591 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_593 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_597 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_600 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_604 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_609 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_611 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_616 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_618 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_623 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_626 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_628 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_632 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_635 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_641_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_646 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_648 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_652 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_655 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_659 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_661 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_663 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_666 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_669 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_675_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_678 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_680 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_690 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_709 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3858_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_714 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_715 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_719 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_722 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_725 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_729 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_731 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_733 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_761 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1254_MUX : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3016_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4564 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_774 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_776 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_777 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_784 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_788_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_792 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_797 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_799 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_805 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_808_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_810 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_818 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_824 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_833 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_836_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_838 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_840 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_841 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_846_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1241_MUX : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_853 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_856 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_860 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_862 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_866 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_870 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_875_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_878 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_883 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_891 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_901_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_905 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_907 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_912 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_915 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_917 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_922 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_928 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_936 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6370 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_952 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_957 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_962 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_965 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_969 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_973 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_975 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_980 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_982 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_986 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_989 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_991 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_995 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_997 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1002 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1005 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1007 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1011 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1012 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1016 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1018 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1020 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1026 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1031 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1036 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1039 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1042 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1044 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1047 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1050 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1052 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_717 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1076 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1079 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1085 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1089 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1102 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1105 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1112 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1113 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1116 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1119 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1123 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1126 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1130 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1133 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1134 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1139 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1143 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1145 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1146 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1148 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1153 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1155 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1158 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1160 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1163 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1165 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1168 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1170 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1172 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1176 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1183 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1192 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1195 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1197 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1200 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1202 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1205 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1213 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1214 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1217 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_I6_MUX_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1357 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_I8_MUX_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3035_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1771 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1280_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_775 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1762 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3803 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6345 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTDIVISORBIT : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1335 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4527 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3014 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3013 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3012 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3021 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3021_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3036 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3178 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3173 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3172 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3188 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3185 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3713 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3795_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3790 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3789 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3799 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4462_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4134 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4138_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4151 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3201 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4522 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4520 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4534 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4529 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4614 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4624 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4623 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4617 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4627 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4628 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3866 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1288 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4518 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3180 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3176 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3015 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3842_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3782 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3858 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3855 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3854 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3853 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3852 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3851 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3860 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4142 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4452 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4448 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4444 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4590 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4581 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4579 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4585 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4449 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4580 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4453 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4637 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2832 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2831 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2588 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6300 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4140 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_105 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_110 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_111 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_112 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_114 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_115 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_116 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2328 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2312 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN17_SHDVAR : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN40_SHDVAR : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2780 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2809 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2700 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2582 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2319 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2315 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2258 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2257 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2256 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2254 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2252 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2251 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_XZYBUSLSBS : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6083 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2697 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2579 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2566 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2506 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2324 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2309 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2572 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2512 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6236 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2562 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2502 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2544 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2484 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2535 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2475 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6214 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6220 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6229 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6230 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6234 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6295 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6126 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6127 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6183 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6192 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6251 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6087 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6199 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6257 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6088 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6089 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6147 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6148 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6205 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6206 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6207 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6266 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6098 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6156 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6102 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6103 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6104 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6105 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6106 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6164 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6278 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6282 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6114 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6172 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6175 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6289 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6235 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6291 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6292 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2703 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2696 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2691 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2689 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2688 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2686 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2585 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2583 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2523 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2578 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2577 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2517 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2573 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2571 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2570 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2568 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2561 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2501 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2558 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2498 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2557 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2497 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2555 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2495 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2554 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2494 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2552 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2492 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2550 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2490 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2549 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2489 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2545 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2485 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2543 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2483 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2542 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2482 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2541 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2481 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2540 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2480 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2539 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2479 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2537 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2477 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2536 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2476 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2471 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2685 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2683 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2681 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2567 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2565 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2563 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2548 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2488 : std_logic ;
  signal N_331 : std_logic ;
  signal N_333 : std_logic ;
  signal N_342 : std_logic ;
  signal N_453 : std_logic ;
  signal N_683 : std_logic ;
  signal N_689 : std_logic ;
  signal N_3_39 : std_logic ;
  signal N_5_MUX : std_logic ;
  signal N_5_MUX_0 : std_logic ;
  signal N_9_MUX_6 : std_logic ;
  signal N_9_MUX_7 : std_logic ;
  signal N_4_58 : std_logic ;
  signal N_4_59 : std_logic ;
  signal N_4_60 : std_logic ;
  signal N_5_MUX_1 : std_logic ;
  signal N_5_MUX_2 : std_logic ;
  signal N_5_MUX_3 : std_logic ;
  signal N_5_MUX_4 : std_logic ;
  signal N_5_MUX_5 : std_logic ;
  signal N_5_MUX_6 : std_logic ;
  signal N_1198 : std_logic ;
  signal N_1199 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_7 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_7 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_10 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_10 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_12 : std_logic ;
  signal N_1210 : std_logic ;
  signal N_1211 : std_logic ;
  signal N_1212 : std_logic ;
  signal N_1265 : std_logic ;
  signal N_1266 : std_logic ;
  signal N_1267 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_7 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_7 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_10 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_10 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_12 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_12 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_13 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_13 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_14 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_14 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_15 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_15 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_16 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_16 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_17 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_17 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_18 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_18 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_19 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_19 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_20 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_20 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_21 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_21 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_22 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_22 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_23 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_23 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_24 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_24 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_25 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_25 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_26 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_26 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_27 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_27 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_28 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_28 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_29 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_29 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_30 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_30 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_31 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_31 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_32 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_32 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_33 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_33 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_34 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_34 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_35 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_35 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_36 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_36 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_37 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_37 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_38 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_38 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_39 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_39 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_40 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_40 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_41 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_41 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_42 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_42 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_43 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_43 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_44 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_44 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_45 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_45 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_46 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_46 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_47 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_47 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_48 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_48 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_49 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_49 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_50 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_50 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_51 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_51 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_52 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_52 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_53 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_53 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_54 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_54 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_55 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_55 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_56 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_56 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_57 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_C2 : std_logic ;
  signal N_1379_I : std_logic ;
  signal N_1381_I : std_logic ;
  signal N_1383_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_CI_37_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_CI_34_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_AXB0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AC0_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_AXB2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_AXB1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_7 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_7 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_10 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_10 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_12 : std_logic ;
  signal N_1628 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4274_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3281_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3132_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_13_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3297_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3548_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3702_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1739 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1244_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_2 : std_logic ;
  signal GRLFPC20_AFQ_3_SQMUXA_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0 : std_logic ;
  signal M5_0_1 : std_logic ;
  signal M8_0_4 : std_logic ;
  signal M8_0_1 : std_logic ;
  signal M9_3_1 : std_logic ;
  signal M9_3_2 : std_logic ;
  signal M9_5_1 : std_logic ;
  signal M9_5_3 : std_logic ;
  signal M9_22_1 : std_logic ;
  signal M9_22_2 : std_logic ;
  signal M9_22_3 : std_logic ;
  signal M9_7_3 : std_logic ;
  signal M9_8_1 : std_logic ;
  signal M9_8_2 : std_logic ;
  signal M9_8_3 : std_logic ;
  signal M9_9_1 : std_logic ;
  signal M9_9_2 : std_logic ;
  signal M9_9_3 : std_logic ;
  signal M9_1 : std_logic ;
  signal M9_3 : std_logic ;
  signal M9_0_1 : std_logic ;
  signal M9_0_2 : std_logic ;
  signal M9_0_3 : std_logic ;
  signal M9_1_1 : std_logic ;
  signal M9_1_3 : std_logic ;
  signal M9_2_1 : std_logic ;
  signal M9_2_2 : std_logic ;
  signal M9_2_3 : std_logic ;
  signal M9_21_2 : std_logic ;
  signal M9_21_3 : std_logic ;
  signal M9_42_1 : std_logic ;
  signal M9_23_1 : std_logic ;
  signal M9_23_2 : std_logic ;
  signal M9_23_3 : std_logic ;
  signal M9_24_1 : std_logic ;
  signal M9_25_1 : std_logic ;
  signal M9_26_1 : std_logic ;
  signal M9_27_1 : std_logic ;
  signal M9_27_2 : std_logic ;
  signal M9_27_3 : std_logic ;
  signal M9_28_1 : std_logic ;
  signal M9_28_2 : std_logic ;
  signal M9_28_3 : std_logic ;
  signal M9_29_1 : std_logic ;
  signal M9_29_2 : std_logic ;
  signal M9_29_3 : std_logic ;
  signal M9_10_1 : std_logic ;
  signal M9_10_3 : std_logic ;
  signal M9_11_1 : std_logic ;
  signal M9_11_3 : std_logic ;
  signal M9_12_1 : std_logic ;
  signal M9_12_2 : std_logic ;
  signal M9_12_3 : std_logic ;
  signal M9_13_3 : std_logic ;
  signal M9_14_1 : std_logic ;
  signal M9_14_2 : std_logic ;
  signal M9_14_3 : std_logic ;
  signal M9_15_1 : std_logic ;
  signal M9_15_2 : std_logic ;
  signal M9_15_3 : std_logic ;
  signal M9_16_1 : std_logic ;
  signal M9_16_3 : std_logic ;
  signal M9_17_2 : std_logic ;
  signal M9_17_3 : std_logic ;
  signal M9_18_1 : std_logic ;
  signal M9_19_1 : std_logic ;
  signal M9_19_2 : std_logic ;
  signal M9_19_3 : std_logic ;
  signal M9_41_3 : std_logic ;
  signal M9_43_1 : std_logic ;
  signal M9_43_2 : std_logic ;
  signal M9_43_3 : std_logic ;
  signal M9_49_1 : std_logic ;
  signal M9_49_2 : std_logic ;
  signal M9_49_3 : std_logic ;
  signal M9_46_1 : std_logic ;
  signal M9_46_2 : std_logic ;
  signal M9_44_1 : std_logic ;
  signal M9_45_1 : std_logic ;
  signal M9_30_1 : std_logic ;
  signal M9_30_2 : std_logic ;
  signal M9_30_3 : std_logic ;
  signal M9_47_1 : std_logic ;
  signal M9_47_2 : std_logic ;
  signal M9_47_3 : std_logic ;
  signal M9_32_2 : std_logic ;
  signal M9_31_1 : std_logic ;
  signal M9_31_2 : std_logic ;
  signal M9_33_1 : std_logic ;
  signal M9_33_2 : std_logic ;
  signal M9_34_1 : std_logic ;
  signal M9_34_2 : std_logic ;
  signal M9_34_3 : std_logic ;
  signal M9_20_2 : std_logic ;
  signal M9_48_2 : std_logic ;
  signal M8_0 : std_logic ;
  signal M8_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0 : std_logic ;
  signal N_1641 : std_logic ;
  signal RST_I : std_logic ;
  signal N_3_31_I : std_logic ;
  signal N_6_MUX_I : std_logic ;
  signal N_3_30_I : std_logic ;
  signal N_3_29_I : std_logic ;
  signal N_3_28_I : std_logic ;
  signal N_3_27_I : std_logic ;
  signal N_3_26_I : std_logic ;
  signal N_3_25_I : std_logic ;
  signal N_3_24_I : std_logic ;
  signal N_3_23_I : std_logic ;
  signal N_3_22_I : std_logic ;
  signal N_3_21_I : std_logic ;
  signal N_3_20_I : std_logic ;
  signal N_3_19_I : std_logic ;
  signal N_3_18_I : std_logic ;
  signal N_3_17_I : std_logic ;
  signal N_3_16_I : std_logic ;
  signal N_3_15_I : std_logic ;
  signal N_3_14_I : std_logic ;
  signal N_3_13_I : std_logic ;
  signal N_3_12_I : std_logic ;
  signal N_3_11_I : std_logic ;
  signal N_3_10_I : std_logic ;
  signal N_3_9_I : std_logic ;
  signal N_3_8_I : std_logic ;
  signal N_3_7_I : std_logic ;
  signal N_3_6_I : std_logic ;
  signal N_3_5_I : std_logic ;
  signal N_3_4_I : std_logic ;
  signal N_3_3_I : std_logic ;
  signal N_3_2_I : std_logic ;
  signal N_3_1_I : std_logic ;
  signal N_3_0_I : std_logic ;
  signal GRLFPC20_N_824_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4485_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3752_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_736_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1179_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1054_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2985_I : std_logic ;
  signal N_5_I : std_logic ;
  signal N_9_MUX_8_I : std_logic ;
  signal N_6_MUX_39_I : std_logic ;
  signal N_3_43_I : std_logic ;
  signal N_3_44_I : std_logic ;
  signal N_3_45_I : std_logic ;
  signal N_3_46_I : std_logic ;
  signal N_3_47_I : std_logic ;
  signal N_3_48_I : std_logic ;
  signal N_3_49_I : std_logic ;
  signal N_3_50_I : std_logic ;
  signal N_3_51_I : std_logic ;
  signal N_3_52_I : std_logic ;
  signal N_3_53_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6322_I : std_logic ;
  signal N_10_MUX_6_I : std_logic ;
  signal N_5_3_I : std_logic ;
  signal N_5_4_I : std_logic ;
  signal N_5_5_I : std_logic ;
  signal N_5_6_I : std_logic ;
  signal N_5_7_I : std_logic ;
  signal N_5_8_I : std_logic ;
  signal N_5_9_I : std_logic ;
  signal N_3_64_I : std_logic ;
  signal N_6_MUX_52_I : std_logic ;
  signal N_3_65_I : std_logic ;
  signal N_3_66_I : std_logic ;
  signal N_6_MUX_54_I : std_logic ;
  signal N_3_67_I : std_logic ;
  signal N_3_69_I : std_logic ;
  signal N_3_70_I : std_logic ;
  signal N_3_71_I : std_logic ;
  signal N_3_72_I : std_logic ;
  signal N_3_73_I : std_logic ;
  signal N_3_74_I : std_logic ;
  signal N_3_75_I : std_logic ;
  signal N_3_76_I : std_logic ;
  signal N_3_77_I : std_logic ;
  signal N_3_78_I : std_logic ;
  signal N_3_79_I : std_logic ;
  signal N_3_80_I : std_logic ;
  signal N_3_81_I : std_logic ;
  signal N_3_82_I : std_logic ;
  signal N_3_83_I : std_logic ;
  signal N_3_84_I : std_logic ;
  signal N_3_85_I : std_logic ;
  signal N_3_86_I : std_logic ;
  signal N_3_87_I : std_logic ;
  signal N_3_88_I : std_logic ;
  signal N_3_89_I : std_logic ;
  signal N_3_90_I : std_logic ;
  signal N_3_91_I : std_logic ;
  signal N_3_92_I : std_logic ;
  signal N_3_93_I : std_logic ;
  signal N_3_94_I : std_logic ;
  signal N_3_95_I : std_logic ;
  signal N_3_96_I : std_logic ;
  signal N_3_97_I : std_logic ;
  signal N_3_98_I : std_logic ;
  signal N_3_99_I : std_logic ;
  signal N_3_100_I : std_logic ;
  signal N_3_101_I : std_logic ;
  signal N_3_102_I : std_logic ;
  signal N_3_103_I : std_logic ;
  signal N_3_104_I : std_logic ;
  signal N_3_105_I : std_logic ;
  signal N_3_106_I : std_logic ;
  signal N_3_107_I : std_logic ;
  signal N_3_108_I : std_logic ;
  signal N_3_109_I : std_logic ;
  signal N_3_110_I : std_logic ;
  signal N_3_111_I : std_logic ;
  signal N_3_112_I : std_logic ;
  signal N_3_113_I : std_logic ;
  signal N_3_114_I : std_logic ;
  signal N_6_MUX_102_I : std_logic ;
  signal N_3_115_I : std_logic ;
  signal N_3_116_I : std_logic ;
  signal N_3_117_I : std_logic ;
  signal N_6_MUX_106_I : std_logic ;
  signal N_3_121_I : std_logic ;
  signal N_3_122_I : std_logic ;
  signal N_3_123_I : std_logic ;
  signal N_3_124_I : std_logic ;
  signal N_3_125_I : std_logic ;
  signal N_3_126_I : std_logic ;
  signal N_3_127_I : std_logic ;
  signal N_3_128_I : std_logic ;
  signal N_3_129_I : std_logic ;
  signal N_3_130_I : std_logic ;
  signal N_3_131_I : std_logic ;
  signal N_3_132_I : std_logic ;
  signal N_3_133_I : std_logic ;
  signal N_3_134_I : std_logic ;
  signal N_3_135_I : std_logic ;
  signal N_3_136_I : std_logic ;
  signal N_3_137_I : std_logic ;
  signal N_3_138_I : std_logic ;
  signal N_3_139_I : std_logic ;
  signal N_3_140_I : std_logic ;
  signal N_3_141_I : std_logic ;
  signal N_3_142_I : std_logic ;
  signal N_3_143_I : std_logic ;
  signal N_3_144_I : std_logic ;
  signal N_3_145_I : std_logic ;
  signal N_3_146_I : std_logic ;
  signal N_3_147_I : std_logic ;
  signal N_3_148_I : std_logic ;
  signal N_3_149_I : std_logic ;
  signal N_3_150_I : std_logic ;
  signal N_3_151_I : std_logic ;
  signal N_3_152_I : std_logic ;
  signal N_3_153_I : std_logic ;
  signal N_3_154_I : std_logic ;
  signal N_3_155_I : std_logic ;
  signal N_3_156_I : std_logic ;
  signal N_3_157_I : std_logic ;
  signal N_3_158_I : std_logic ;
  signal N_3_159_I : std_logic ;
  signal N_3_160_I : std_logic ;
  signal N_3_161_I : std_logic ;
  signal N_3_162_I : std_logic ;
  signal N_3_163_I : std_logic ;
  signal N_3_164_I : std_logic ;
  signal N_3_165_I : std_logic ;
  signal N_3_166_I : std_logic ;
  signal N_3_167_I : std_logic ;
  signal N_3_168_I : std_logic ;
  signal N_3_169_I : std_logic ;
  signal N_3_170_I : std_logic ;
  signal N_3_171_I : std_logic ;
  signal N_3_172_I : std_logic ;
  signal N_3_173_I : std_logic ;
  signal N_5_MUX_7_I : std_logic ;
  signal N_3_177_I : std_logic ;
  signal N_3_178_I : std_logic ;
  signal N_3_179_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_3_I : std_logic ;
  signal GRLFPC20_RS1D_CNST_M10_1 : std_logic ;
  signal GRLFPC20_COMB_UN9_CCV_2 : std_logic ;
  signal GRLFPC20_WREN1_0_SQMUXA_0 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_0 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_1 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_2 : std_logic ;
  signal GRLFPC20_MOV_1_SQMUXA_2 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RDD2_1 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RDD2_2 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_4 : std_logic ;
  signal GRLFPC20_AFQ_3_SQMUXA_0_0 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RDD6_3_0 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_RS1D5_4 : std_logic ;
  signal GRLFPC20_COMB_FPDECODE_UN1_FPCI_1_2_0 : std_logic ;
  signal GRLFPC20_COMB_WREN2_11_IV_0 : std_logic ;
  signal GRLFPC20_COMB_WREN1_11_IV_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN8_NOTAINFNAN_0 : std_logic ;
  signal GRLFPC20_ANNULRES_0_SQMUXA_2_1 : std_logic ;
  signal GRLFPC20_COMB_UN1_MEXC_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN38_SHDVAR_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN12_SRTOSTICKY_2 : std_logic ;
  signal GRLFPC20_V_A_AFSR_1_0_A2_2 : std_logic ;
  signal GRLFPC20_V_FSR_FTT_2_SQMUXA_1_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_EXPAREGLOADEN_274_0 : std_logic ;
  signal GRLFPC20_ANNULRES_1_IV_1_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_2 : std_logic ;
  signal GRLFPC20_V_I_V_3_SQMUXA_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSTICKYINFORSR_2_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_STKGEN_3_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_O0_A3_1_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_O0_A3_1_2 : std_logic ;
  signal M8_3 : std_logic ;
  signal M9_17_0_0 : std_logic ;
  signal M9_18_0_1 : std_logic ;
  signal M9_18_1_0 : std_logic ;
  signal M9_43_0 : std_logic ;
  signal M9_43_1_0 : std_logic ;
  signal M9_44_0_1 : std_logic ;
  signal M9_44_1_0 : std_logic ;
  signal M9_7_0_1 : std_logic ;
  signal M9_6_0_1 : std_logic ;
  signal M9_0_1_0 : std_logic ;
  signal M9_45_0_1 : std_logic ;
  signal M9_45_1_0 : std_logic ;
  signal M9_24_0_1 : std_logic ;
  signal M9_24_1_0 : std_logic ;
  signal M9_42_0_1 : std_logic ;
  signal M9_42_1_0 : std_logic ;
  signal M9_32_2_0 : std_logic ;
  signal M9_12_1_0 : std_logic ;
  signal M9_25_0_1 : std_logic ;
  signal M9_25_1_0 : std_logic ;
  signal M9_21_1_0 : std_logic ;
  signal M9_2_1_0 : std_logic ;
  signal M9_26_0_1 : std_logic ;
  signal M9_26_1_0 : std_logic ;
  signal M9_13_0_1 : std_logic ;
  signal M9_22_0 : std_logic ;
  signal M9_22_1_0 : std_logic ;
  signal M9_20_0_0 : std_logic ;
  signal M9_20_2_0 : std_logic ;
  signal M9_48_0_0 : std_logic ;
  signal M9_48_2_0 : std_logic ;
  signal M9_50_0 : std_logic ;
  signal M9_50_0_0 : std_logic ;
  signal M9_50_0_2 : std_logic ;
  signal M9_37_0 : std_logic ;
  signal M9_37_0_1 : std_logic ;
  signal M9_37_0_2 : std_logic ;
  signal M9_37_0_4 : std_logic ;
  signal M20_E_36_1 : std_logic ;
  signal M9_36_0 : std_logic ;
  signal M9_36_0_1 : std_logic ;
  signal M9_36_0_2 : std_logic ;
  signal M9_36_0_4 : std_logic ;
  signal M9_38_0_1 : std_logic ;
  signal M9_38_0_2 : std_logic ;
  signal M9_38_0_4 : std_logic ;
  signal M9_35_0 : std_logic ;
  signal M9_35_0_0 : std_logic ;
  signal M9_35_0_2 : std_logic ;
  signal M9_35_0_4 : std_logic ;
  signal M9_40_0 : std_logic ;
  signal M9_40_0_0 : std_logic ;
  signal M9_40_0_2 : std_logic ;
  signal M20_E_39_1 : std_logic ;
  signal M20_E_39_2 : std_logic ;
  signal M9_39_0_1 : std_logic ;
  signal M9_39_0_2 : std_logic ;
  signal M9_39_0_3 : std_logic ;
  signal M20_E_38_2 : std_logic ;
  signal M9_4_0_0 : std_logic ;
  signal M9_4_0_1 : std_logic ;
  signal M9_4_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP_1 : std_logic ;
  signal GRLFPC20_V_MK_RST_1_0 : std_logic ;
  signal GRLFPC20_R_I_RDD_0 : std_logic ;
  signal NN_7 : std_logic ;
  signal GRLFPC20_R_FSR_AEXC_0 : std_logic ;
  signal GRLFPC20_R_FSR_AEXC_1 : std_logic ;
  signal GRLFPC20_R_FSR_AEXC_2 : std_logic ;
  signal GRLFPC20_R_FSR_AEXC_3 : std_logic ;
  signal NN_8 : std_logic ;
  signal GRLFPC20_R_FSR_CEXC_0 : std_logic ;
  signal GRLFPC20_R_FSR_CEXC_1 : std_logic ;
  signal GRLFPC20_R_FSR_CEXC_2 : std_logic ;
  signal GRLFPC20_R_FSR_CEXC_3 : std_logic ;
  signal GRLFPC20_R_I_V_0 : std_logic ;
  signal NN_9 : std_logic ;
  signal NN_10 : std_logic ;
  signal NN_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_7 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_9 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_10 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_13 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_14 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_16 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_19 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_24 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_25 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_38 : std_logic ;
  signal NN_3 : std_logic ;
  signal NN_4 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_41 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_42 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_43 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_46 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_53 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_54 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_55 : std_logic ;
  signal RqXzXRDDY_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0_CY : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0_CY : std_logic ;
  signal M20_E_0_RETO : std_logic ;
  signal M9_41_2 : std_logic ;
  signal M9_41_2_RETO : std_logic ;
  signal M9_41_1 : std_logic ;
  signal M9_41_1_RETO : std_logic ;
  signal M20_E_41_3 : std_logic ;
  signal M20_E_41_3_RETO : std_logic ;
  signal N_38_MUX_41 : std_logic ;
  signal R_DPATH_RET_3 : std_logic ;
  signal N_2486 : std_logic ;
  signal M9_32_3 : std_logic ;
  signal M9_32_3_RETO : std_logic ;
  signal N_38_MUX_32 : std_logic ;
  signal R_DPATH_RET_5 : std_logic ;
  signal N_2487 : std_logic ;
  signal N_38_MUX_27 : std_logic ;
  signal R_DPATH_RET_6 : std_logic ;
  signal N_2488 : std_logic ;
  signal N_38_MUX_15 : std_logic ;
  signal R_DPATH_RET_7 : std_logic ;
  signal N_2489 : std_logic ;
  signal N_38_MUX_34 : std_logic ;
  signal R_DPATH_RET_8 : std_logic ;
  signal N_2490 : std_logic ;
  signal M20_E_0_RETO_0 : std_logic ;
  signal N_38_MUX_49 : std_logic ;
  signal R_DPATH_RET_9 : std_logic ;
  signal N_2491 : std_logic ;
  signal N_38_MUX_8 : std_logic ;
  signal R_DPATH_RET_10 : std_logic ;
  signal N_2492 : std_logic ;
  signal N_38_MUX_23 : std_logic ;
  signal R_DPATH_RET_11 : std_logic ;
  signal N_2493 : std_logic ;
  signal N_38_MUX_46 : std_logic ;
  signal R_DPATH_RET_12 : std_logic ;
  signal N_2494 : std_logic ;
  signal N_38_MUX_14 : std_logic ;
  signal R_DPATH_RET_13 : std_logic ;
  signal N_2495 : std_logic ;
  signal N_38_MUX_9 : std_logic ;
  signal R_DPATH_RET_14 : std_logic ;
  signal N_2496 : std_logic ;
  signal N_38_MUX_17 : std_logic ;
  signal R_DPATH_RET_15 : std_logic ;
  signal N_2497 : std_logic ;
  signal N_38_MUX_28 : std_logic ;
  signal R_DPATH_RET_16 : std_logic ;
  signal N_2498 : std_logic ;
  signal N_38_MUX_33 : std_logic ;
  signal R_DPATH_RET_17 : std_logic ;
  signal N_2499 : std_logic ;
  signal N_38_MUX_30 : std_logic ;
  signal R_DPATH_RET_18 : std_logic ;
  signal N_2500 : std_logic ;
  signal N_38_MUX_19 : std_logic ;
  signal R_DPATH_RET_19 : std_logic ;
  signal N_2501 : std_logic ;
  signal N_38_MUX_47 : std_logic ;
  signal R_DPATH_RET_20 : std_logic ;
  signal N_2502 : std_logic ;
  signal N_38_MUX_31 : std_logic ;
  signal R_DPATH_RET_21 : std_logic ;
  signal N_2503 : std_logic ;
  signal N_38_MUX_29 : std_logic ;
  signal R_DPATH_RET_22 : std_logic ;
  signal N_2504 : std_logic ;
  signal N_38_MUX_3 : std_logic ;
  signal R_DPATH_RET_23 : std_logic ;
  signal N_2505 : std_logic ;
  signal N_38_MUX_2 : std_logic ;
  signal R_DPATH_RET_24 : std_logic ;
  signal N_2506 : std_logic ;
  signal N_38_MUX_12 : std_logic ;
  signal R_DPATH_RET_25 : std_logic ;
  signal N_2507 : std_logic ;
  signal N_38_MUX_0 : std_logic ;
  signal R_DPATH_RET_26 : std_logic ;
  signal N_2508 : std_logic ;
  signal M20_E_0_RETO_22 : std_logic ;
  signal M9_42_3 : std_logic ;
  signal M9_42_3_RETO : std_logic ;
  signal M20_E_42_0_1 : std_logic ;
  signal M20_E_42_0_1_RETO : std_logic ;
  signal N_38_MUX_42 : std_logic ;
  signal R_DPATH_RET_29 : std_logic ;
  signal N_2509 : std_logic ;
  signal M9_25_3 : std_logic ;
  signal M9_25_3_RETO : std_logic ;
  signal M20_E_25_0_1 : std_logic ;
  signal M20_E_25_0_1_RETO : std_logic ;
  signal N_38_MUX_25 : std_logic ;
  signal R_DPATH_RET_32 : std_logic ;
  signal N_2510 : std_logic ;
  signal M20_E_0_RETO_24 : std_logic ;
  signal M9_45_3 : std_logic ;
  signal M9_45_3_RETO : std_logic ;
  signal M20_E_45_0_1 : std_logic ;
  signal M20_E_45_0_1_RETO : std_logic ;
  signal N_38_MUX_45 : std_logic ;
  signal R_DPATH_RET_35 : std_logic ;
  signal N_2511 : std_logic ;
  signal M9_18_3 : std_logic ;
  signal M9_18_3_RETO : std_logic ;
  signal M20_E_18_0_1 : std_logic ;
  signal M20_E_18_0_1_RETO : std_logic ;
  signal N_38_MUX_18 : std_logic ;
  signal R_DPATH_RET_38 : std_logic ;
  signal N_2512 : std_logic ;
  signal M9_26_3 : std_logic ;
  signal M9_26_3_RETO : std_logic ;
  signal M20_E_26_0_1 : std_logic ;
  signal M20_E_26_0_1_RETO : std_logic ;
  signal N_38_MUX_26 : std_logic ;
  signal R_DPATH_RET_41 : std_logic ;
  signal N_2513 : std_logic ;
  signal M9_24_3 : std_logic ;
  signal M9_24_3_RETO : std_logic ;
  signal M20_E_24_0_1 : std_logic ;
  signal M20_E_24_0_1_RETO : std_logic ;
  signal N_38_MUX_24 : std_logic ;
  signal R_DPATH_RET_44 : std_logic ;
  signal N_2514 : std_logic ;
  signal M20_E_0_RETO_28 : std_logic ;
  signal M9_44_3 : std_logic ;
  signal M9_44_3_RETO : std_logic ;
  signal M20_E_44_0_1 : std_logic ;
  signal M20_E_44_0_1_RETO : std_logic ;
  signal N_38_MUX_44 : std_logic ;
  signal R_DPATH_RET_47 : std_logic ;
  signal N_2515 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_RETO : std_logic ;
  signal M20_E_20_0_2 : std_logic ;
  signal M20_E_20_0_2_RETO : std_logic ;
  signal N_38_MUX_20 : std_logic ;
  signal R_DPATH_RET_49 : std_logic ;
  signal N_2516 : std_logic ;
  signal N_38_MUX_37 : std_logic ;
  signal R_DPATH_RET_50 : std_logic ;
  signal N_2517 : std_logic ;
  signal M20_E_48_2 : std_logic ;
  signal M20_E_48_2_RETO : std_logic ;
  signal N_38_MUX_48 : std_logic ;
  signal R_DPATH_RET_52 : std_logic ;
  signal N_2518 : std_logic ;
  signal M20_E_0 : std_logic ;
  signal M20_E_36_3 : std_logic ;
  signal M20_E_36_3_RETO : std_logic ;
  signal N_38_MUX_36 : std_logic ;
  signal R_DPATH_RET_54 : std_logic ;
  signal N_2519 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_9_3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_8_3 : std_logic ;
  signal N_2523 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_16 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_7_7 : std_logic ;
  signal N_2526 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_19 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_24 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_29 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_34 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_39 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_44 : std_logic ;
  signal N_2528 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_46 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_51 : std_logic ;
  signal M9_41_N_3_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_12 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_7_8 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G6_0 : std_logic ;
  signal N_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_I_M2_0_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_1 : std_logic ;
  signal G3 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_2 : std_logic ;
  signal N_29 : std_logic ;
  signal N_30 : std_logic ;
  signal M41_I_1 : std_logic ;
  signal M41_I_2 : std_logic ;
  signal N_29_0 : std_logic ;
  signal N_30_0 : std_logic ;
  signal M41_I_1_0 : std_logic ;
  signal M41_I_2_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0_0 : std_logic ;
  signal N_6_169 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2_0 : std_logic ;
  signal G0_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0_1 : std_logic ;
  signal N_30_1 : std_logic ;
  signal N_6_170 : std_logic ;
  signal N_7 : std_logic ;
  signal N_12_I_I_0 : std_logic ;
  signal N_30_2 : std_logic ;
  signal N_6_171 : std_logic ;
  signal N_7_0 : std_logic ;
  signal N_12_I_I_0_0 : std_logic ;
  signal N_15 : std_logic ;
  signal N_7_1 : std_logic ;
  signal N_5_I_I_0 : std_logic ;
  signal N_5_I_I_1 : std_logic ;
  signal N_139 : std_logic ;
  signal N_6_172 : std_logic ;
  signal N_7_2 : std_logic ;
  signal N_12_I_I_0_1 : std_logic ;
  signal N_131 : std_logic ;
  signal N_7_3 : std_logic ;
  signal N_5_I_I_0_0 : std_logic ;
  signal N_5_I_I_1_0 : std_logic ;
  signal N_131_0 : std_logic ;
  signal N_7_4 : std_logic ;
  signal N_5_I_I_0_1 : std_logic ;
  signal N_5_I_I_1_1 : std_logic ;
  signal G5_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0 : std_logic ;
  signal G0_0_0 : std_logic ;
  signal G0_1 : std_logic ;
  signal N_139_0 : std_logic ;
  signal N_6_173 : std_logic ;
  signal N_7_5 : std_logic ;
  signal N_12_I_I_0_2 : std_logic ;
  signal N_139_1 : std_logic ;
  signal N_6_174 : std_logic ;
  signal N_7_6 : std_logic ;
  signal N_12_I_I_0_3 : std_logic ;
  signal N_139_2 : std_logic ;
  signal N_6_175 : std_logic ;
  signal N_7_7 : std_logic ;
  signal N_12_I_I_0_4 : std_logic ;
  signal N_30_3 : std_logic ;
  signal N_6_176 : std_logic ;
  signal N_7_8 : std_logic ;
  signal N_12_I_I_0_5 : std_logic ;
  signal N_139_3 : std_logic ;
  signal N_6_177 : std_logic ;
  signal N_7_9 : std_logic ;
  signal N_12_I_I_0_6 : std_logic ;
  signal G5 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1_0_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_2 : std_logic ;
  signal G0_1_0 : std_logic ;
  signal G5_0_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0_0 : std_logic ;
  signal G0_0_1 : std_logic ;
  signal G0_1_1 : std_logic ;
  signal N_139_4 : std_logic ;
  signal N_6_178 : std_logic ;
  signal N_7_10 : std_logic ;
  signal N_12_I_I_0_7 : std_logic ;
  signal G5_0_1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0_1 : std_logic ;
  signal G0_0_2 : std_logic ;
  signal G0_1_2 : std_logic ;
  signal N_139_5 : std_logic ;
  signal N_6_179 : std_logic ;
  signal N_7_11 : std_logic ;
  signal N_12_I_I_0_8 : std_logic ;
  signal N_131_1 : std_logic ;
  signal N_7_12 : std_logic ;
  signal N_5_I_I_0_2 : std_logic ;
  signal N_5_I_I_1_2 : std_logic ;
  signal N_134 : std_logic ;
  signal N_14 : std_logic ;
  signal N_28 : std_logic ;
  signal M80_I_3 : std_logic ;
  signal G1 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_1_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_2_0 : std_logic ;
  signal N_30_4 : std_logic ;
  signal N_13 : std_logic ;
  signal N_148 : std_logic ;
  signal M96_I_A3_0 : std_logic ;
  signal M96_I_3 : std_logic ;
  signal N_122 : std_logic ;
  signal N_10 : std_logic ;
  signal N_32 : std_logic ;
  signal M74_I_A3_0 : std_logic ;
  signal M74_I_3 : std_logic ;
  signal N_122_0 : std_logic ;
  signal N_13_0 : std_logic ;
  signal N_32_0 : std_logic ;
  signal M74_I_A3_0_0 : std_logic ;
  signal M74_I_3_0 : std_logic ;
  signal N_112 : std_logic ;
  signal N_12 : std_logic ;
  signal N_37 : std_logic ;
  signal M64_I_3 : std_logic ;
  signal RqXzXRDDY : std_logic ;
  signal RqXzXRDDY_0 : std_logic ;
  signal RFI2_RD1ADDR_70 : std_logic ;
  signal RFI2_RD1ADDR_71 : std_logic ;
  signal RFI2_RD1ADDR_72 : std_logic ;
  signal RFI2_RD1ADDR_73 : std_logic ;
  signal RFI2_RD2ADDR_74 : std_logic ;
  signal RFI2_RD2ADDR_75 : std_logic ;
  signal RFI2_RD2ADDR_76 : std_logic ;
  signal RFI2_RD2ADDR_77 : std_logic ;
  signal RFI2_WRADDR_78 : std_logic ;
  signal RFI2_WRADDR_79 : std_logic ;
  signal RFI2_WRADDR_80 : std_logic ;
  signal RFI2_WRADDR_81 : std_logic ;
  signal NN_5 : std_logic ;
  signal M20_E_0_0 : std_logic ;
  signal GRLFPC20_FPI_START_0 : std_logic ;
  signal GRLFPC20_RIN_MK_LDOP_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_UN31_PCTRL_NEW_I_0 : std_logic ;
  signal GRLFPC20_FPI_RST_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37_0 : std_logic ;
  signal NN_6 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52_0 : std_logic ;
  signal M9_41_2_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_UN36_PCTRL_NEW_I_0 : std_logic ;
  signal N_3_32_I_0 : std_logic ;
  signal N_3_33_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_99_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_101_I_0 : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN2_NOTDECODEDUNIMP_I_0_E : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTRESETORUNIMP_I_0_E : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_0_E : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_UN53_SCTRL_NEW_I_0_E : std_logic ;
  signal GRLFPC20_R_MK_RST2_I_E : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_76_0_I : std_logic ;
  signal GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1255_MUX_I : std_logic ;
begin
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_1: MUXCY_L port map (
    DI => NN_5,
    CI => NN_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_130,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_11: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(0),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_123,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_19: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(1),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_116,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_27: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(7),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_109,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_35: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(2),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_102,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_43: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(8),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_95,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_51: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(3),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_88,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_59: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(9),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_81,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_67: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(17),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_74,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_75: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(4),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_67,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_83: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(12),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_60,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_91: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(5),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_53,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_99: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(11),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_46,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_107: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(13),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_39,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_115: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(6),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_32,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_123: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(15),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_25,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_131: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(14),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_18,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_139: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(16),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_11,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_147: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(10),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_4,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_1: MUXCY_L port map (
    DI => NN_5,
    CI => NN_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_25,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_11: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(2),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_18,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_19: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(1),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_11,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_27: MUXCY_L port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(0),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_4,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(1));
GRLFPC20_R_MK_BUSY_Z5504: FDR port map (
    Q => GRLFPC20_R_MK_BUSY,
    D => GRLFPC20_COMB_V_MK_BUSY_2,
    C => clk,
    R => RST_I);
GRLFPC20_R_MK_BUSY2_Z5505: FDR port map (
    Q => GRLFPC20_R_MK_BUSY2,
    D => GRLFPC20_COMB_V_MK_BUSY2_2,
    C => clk,
    R => RST_I);
GRLFPC20_R_MK_HOLDN2_Z5506: FDS port map (
    Q => GRLFPC20_R_MK_HOLDN2,
    D => GRLFPC20_R_MK_HOLDN1,
    C => clk,
    S => RST_I);
GRLFPC20_R_I_PCq2z_Z5507: FDRE port map (
    Q => GRLFPC20_R_I_PC(2),
    D => cpi_x_pc(2),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq3z_Z5508: FDRE port map (
    Q => GRLFPC20_R_I_PC(3),
    D => cpi_x_pc(3),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq4z_Z5509: FDRE port map (
    Q => GRLFPC20_R_I_PC(4),
    D => cpi_x_pc(4),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq5z_Z5510: FDRE port map (
    Q => GRLFPC20_R_I_PC(5),
    D => cpi_x_pc(5),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq6z_Z5511: FDRE port map (
    Q => GRLFPC20_R_I_PC(6),
    D => cpi_x_pc(6),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq7z_Z5512: FDRE port map (
    Q => GRLFPC20_R_I_PC(7),
    D => cpi_x_pc(7),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq8z_Z5513: FDRE port map (
    Q => GRLFPC20_R_I_PC(8),
    D => cpi_x_pc(8),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq9z_Z5514: FDRE port map (
    Q => GRLFPC20_R_I_PC(9),
    D => cpi_x_pc(9),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq10z_Z5515: FDRE port map (
    Q => GRLFPC20_R_I_PC(10),
    D => cpi_x_pc(10),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq11z_Z5516: FDRE port map (
    Q => GRLFPC20_R_I_PC(11),
    D => cpi_x_pc(11),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq12z_Z5517: FDRE port map (
    Q => GRLFPC20_R_I_PC(12),
    D => cpi_x_pc(12),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq13z_Z5518: FDRE port map (
    Q => GRLFPC20_R_I_PC(13),
    D => cpi_x_pc(13),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq14z_Z5519: FDRE port map (
    Q => GRLFPC20_R_I_PC(14),
    D => cpi_x_pc(14),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq15z_Z5520: FDRE port map (
    Q => GRLFPC20_R_I_PC(15),
    D => cpi_x_pc(15),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq16z_Z5521: FDRE port map (
    Q => GRLFPC20_R_I_PC(16),
    D => cpi_x_pc(16),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq17z_Z5522: FDRE port map (
    Q => GRLFPC20_R_I_PC(17),
    D => cpi_x_pc(17),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq18z_Z5523: FDRE port map (
    Q => GRLFPC20_R_I_PC(18),
    D => cpi_x_pc(18),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq19z_Z5524: FDRE port map (
    Q => GRLFPC20_R_I_PC(19),
    D => cpi_x_pc(19),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq20z_Z5525: FDRE port map (
    Q => GRLFPC20_R_I_PC(20),
    D => cpi_x_pc(20),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq21z_Z5526: FDRE port map (
    Q => GRLFPC20_R_I_PC(21),
    D => cpi_x_pc(21),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq22z_Z5527: FDRE port map (
    Q => GRLFPC20_R_I_PC(22),
    D => cpi_x_pc(22),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq23z_Z5528: FDRE port map (
    Q => GRLFPC20_R_I_PC(23),
    D => cpi_x_pc(23),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq24z_Z5529: FDRE port map (
    Q => GRLFPC20_R_I_PC(24),
    D => cpi_x_pc(24),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq25z_Z5530: FDRE port map (
    Q => GRLFPC20_R_I_PC(25),
    D => cpi_x_pc(25),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq26z_Z5531: FDRE port map (
    Q => GRLFPC20_R_I_PC(26),
    D => cpi_x_pc(26),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq27z_Z5532: FDRE port map (
    Q => GRLFPC20_R_I_PC(27),
    D => cpi_x_pc(27),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq28z_Z5533: FDRE port map (
    Q => GRLFPC20_R_I_PC(28),
    D => cpi_x_pc(28),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq29z_Z5534: FDRE port map (
    Q => GRLFPC20_R_I_PC(29),
    D => cpi_x_pc(29),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq30z_Z5535: FDRE port map (
    Q => GRLFPC20_R_I_PC(30),
    D => cpi_x_pc(30),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_PCq31z_Z5536: FDRE port map (
    Q => GRLFPC20_R_I_PC(31),
    D => cpi_x_pc(31),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq0z_Z5537: FDRE port map (
    Q => GRLFPC20_R_I_INST(0),
    D => cpi_x_inst(0),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq1z_Z5538: FDRE port map (
    Q => GRLFPC20_R_I_INST(1),
    D => cpi_x_inst(1),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq2z_Z5539: FDRE port map (
    Q => GRLFPC20_R_I_INST(2),
    D => cpi_x_inst(2),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq3z_Z5540: FDRE port map (
    Q => GRLFPC20_R_I_INST(3),
    D => cpi_x_inst(3),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq4z_Z5541: FDRE port map (
    Q => GRLFPC20_R_I_INST(4),
    D => cpi_x_inst(4),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq5z_Z5542: FDRE port map (
    Q => GRLFPC20_R_I_INST(5),
    D => cpi_x_inst(5),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq6z_Z5543: FDRE port map (
    Q => GRLFPC20_R_I_INST(6),
    D => cpi_x_inst(6),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq7z_Z5544: FDRE port map (
    Q => GRLFPC20_R_I_INST(7),
    D => cpi_x_inst(7),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq8z_Z5545: FDRE port map (
    Q => GRLFPC20_R_I_INST(8),
    D => cpi_x_inst(8),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq9z_Z5546: FDRE port map (
    Q => GRLFPC20_R_I_INST(9),
    D => cpi_x_inst(9),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq10z_Z5547: FDRE port map (
    Q => GRLFPC20_R_I_INST(10),
    D => cpi_x_inst(10),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq11z_Z5548: FDRE port map (
    Q => GRLFPC20_R_I_INST(11),
    D => cpi_x_inst(11),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq12z_Z5549: FDRE port map (
    Q => GRLFPC20_R_I_INST(12),
    D => cpi_x_inst(12),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq13z_Z5550: FDRE port map (
    Q => GRLFPC20_R_I_INST(13),
    D => cpi_x_inst(13),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq14z_Z5551: FDRE port map (
    Q => GRLFPC20_R_I_INST(14),
    D => cpi_x_inst(14),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq15z_Z5552: FDRE port map (
    Q => GRLFPC20_R_I_INST(15),
    D => cpi_x_inst(15),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq16z_Z5553: FDRE port map (
    Q => GRLFPC20_R_I_INST(16),
    D => cpi_x_inst(16),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq17z_Z5554: FDRE port map (
    Q => GRLFPC20_R_I_INST(17),
    D => cpi_x_inst(17),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq18z_Z5555: FDRE port map (
    Q => GRLFPC20_R_I_INST(18),
    D => cpi_x_inst(18),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq19z_Z5556: FDRE port map (
    Q => GRLFPC20_R_I_INST(19),
    D => cpi_x_inst(19),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq20z_Z5557: FDRE port map (
    Q => GRLFPC20_R_I_INST(20),
    D => cpi_x_inst(20),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq21z_Z5558: FDRE port map (
    Q => GRLFPC20_R_I_INST(21),
    D => cpi_x_inst(21),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq22z_Z5559: FDRE port map (
    Q => GRLFPC20_R_I_INST(22),
    D => cpi_x_inst(22),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq23z_Z5560: FDRE port map (
    Q => GRLFPC20_R_I_INST(23),
    D => cpi_x_inst(23),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq24z_Z5561: FDRE port map (
    Q => GRLFPC20_R_I_INST(24),
    D => cpi_x_inst(24),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq25z_Z5562: FDRE port map (
    Q => GRLFPC20_R_I_INST(25),
    D => cpi_x_inst(25),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq26z_Z5563: FDRE port map (
    Q => GRLFPC20_R_I_INST(26),
    D => cpi_x_inst(26),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq27z_Z5564: FDRE port map (
    Q => GRLFPC20_R_I_INST(27),
    D => cpi_x_inst(27),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq28z_Z5565: FDRE port map (
    Q => GRLFPC20_R_I_INST(28),
    D => cpi_x_inst(28),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq29z_Z5566: FDRE port map (
    Q => GRLFPC20_R_I_INST(29),
    D => cpi_x_inst(29),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq30z_Z5567: FDRE port map (
    Q => GRLFPC20_R_I_INST(30),
    D => cpi_x_inst(30),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_I_INSTq31z_Z5568: FDRE port map (
    Q => GRLFPC20_R_I_INST(31),
    D => cpi_x_inst(31),
    C => clk,
    R => N_331,
    CE => N_453);
GRLFPC20_R_FSR_TEMq0z_Z5569: FDRE port map (
    Q => GRLFPC20_R_FSR_TEM(0),
    D => cpi_lddata(23),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_FSR_TEMq1z_Z5570: FDRE port map (
    Q => GRLFPC20_R_FSR_TEM(1),
    D => cpi_lddata(24),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_FSR_TEMq2z_Z5571: FDRE port map (
    Q => GRLFPC20_R_FSR_TEM(2),
    D => cpi_lddata(25),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_FSR_TEMq3z_Z5572: FDRE port map (
    Q => GRLFPC20_R_FSR_TEM(3),
    D => cpi_lddata(26),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_FSR_TEMq4z_Z5573: FDRE port map (
    Q => GRLFPC20_R_FSR_TEM(4),
    D => cpi_lddata(27),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_FSR_RDq0z_Z5574: FDRE port map (
    Q => GRLFPC20_R_FSR_RD(0),
    D => cpi_lddata(30),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_FSR_RDq1z_Z5575: FDRE port map (
    Q => GRLFPC20_R_FSR_RD(1),
    D => cpi_lddata(31),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_FSR_NONSTD_Z5576: FDRE port map (
    Q => GRLFPC20_R_FSR_NONSTD,
    D => cpi_lddata(22),
    C => clk,
    R => N_331,
    CE => N_342);
GRLFPC20_R_E_STDATAq0z: FDRE port map (
    Q => cpo_data(0),
    D => GRLFPC20_N_595,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq1z: FDRE port map (
    Q => cpo_data(1),
    D => GRLFPC20_N_596,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq2z: FDRE port map (
    Q => cpo_data(2),
    D => GRLFPC20_N_597,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq3z: FDRE port map (
    Q => cpo_data(3),
    D => GRLFPC20_N_598,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq4z: FDRE port map (
    Q => cpo_data(4),
    D => GRLFPC20_N_599,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq5z: FDRE port map (
    Q => cpo_data(5),
    D => GRLFPC20_N_600,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq6z: FDRE port map (
    Q => cpo_data(6),
    D => GRLFPC20_N_601,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq7z: FDRE port map (
    Q => cpo_data(7),
    D => GRLFPC20_N_602,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq8z: FDRE port map (
    Q => cpo_data(8),
    D => GRLFPC20_N_603,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq9z: FDRE port map (
    Q => cpo_data(9),
    D => GRLFPC20_N_604,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq10z: FDRE port map (
    Q => cpo_data(10),
    D => GRLFPC20_N_605,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq11z: FDRE port map (
    Q => cpo_data(11),
    D => GRLFPC20_N_606,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq12z: FDRE port map (
    Q => cpo_data(12),
    D => GRLFPC20_N_607,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq13z: FDRE port map (
    Q => cpo_data(13),
    D => GRLFPC20_N_608,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq14z: FDRE port map (
    Q => cpo_data(14),
    D => GRLFPC20_N_609,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq15z: FDRE port map (
    Q => cpo_data(15),
    D => GRLFPC20_N_610,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq16z: FDRE port map (
    Q => cpo_data(16),
    D => GRLFPC20_N_611,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq17z: FDRE port map (
    Q => cpo_data(17),
    D => GRLFPC20_N_612,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq18z: FDRE port map (
    Q => cpo_data(18),
    D => GRLFPC20_N_613,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq19z: FDRE port map (
    Q => cpo_data(19),
    D => GRLFPC20_N_614,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq20z: FDRE port map (
    Q => cpo_data(20),
    D => GRLFPC20_N_615,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq21z: FDRE port map (
    Q => cpo_data(21),
    D => GRLFPC20_N_616,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq22z: FDRE port map (
    Q => cpo_data(22),
    D => GRLFPC20_N_617,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq23z: FDRE port map (
    Q => cpo_data(23),
    D => GRLFPC20_N_618,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq24z: FDRE port map (
    Q => cpo_data(24),
    D => GRLFPC20_N_619,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq25z: FDRE port map (
    Q => cpo_data(25),
    D => GRLFPC20_N_620,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq26z: FDRE port map (
    Q => cpo_data(26),
    D => GRLFPC20_N_621,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq27z: FDRE port map (
    Q => cpo_data(27),
    D => GRLFPC20_N_622,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq28z: FDRE port map (
    Q => cpo_data(28),
    D => GRLFPC20_N_623,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq29z: FDRE port map (
    Q => cpo_data(29),
    D => GRLFPC20_N_624,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq30z: FDRE port map (
    Q => cpo_data(30),
    D => GRLFPC20_N_625,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_E_STDATAq31z: FDRE port map (
    Q => cpo_data(31),
    D => GRLFPC20_N_626,
    C => clk,
    R => N_331,
    CE => holdn);
GRLFPC20_R_I_EXCq0z_Z5609: FDRE port map (
    Q => GRLFPC20_R_I_EXC(0),
    D => GRLFPC20_V_I_EXC_1(0),
    C => clk,
    R => N_333,
    CE => GRLFPC20_UN1_HOLDN_1);
GRLFPC20_R_I_EXCq1z_Z5610: FDRE port map (
    Q => GRLFPC20_R_I_EXC(1),
    D => GRLFPC20_V_I_EXC_1(1),
    C => clk,
    R => N_333,
    CE => GRLFPC20_UN1_HOLDN_1);
GRLFPC20_R_I_EXCq2z_Z5611: FDRE port map (
    Q => GRLFPC20_R_I_EXC(2),
    D => GRLFPC20_V_I_EXC_1(2),
    C => clk,
    R => N_333,
    CE => GRLFPC20_UN1_HOLDN_1);
GRLFPC20_R_I_EXCq3z_Z5612: FDRE port map (
    Q => GRLFPC20_R_I_EXC(3),
    D => GRLFPC20_V_I_EXC_1(3),
    C => clk,
    R => N_333,
    CE => GRLFPC20_UN1_HOLDN_1);
GRLFPC20_R_I_EXCq4z_Z5613: FDRE port map (
    Q => GRLFPC20_R_I_EXC(4),
    D => GRLFPC20_V_I_EXC_1(4),
    C => clk,
    R => N_333,
    CE => GRLFPC20_UN1_HOLDN_1);
GRLFPC20_R_I_EXCq5z_Z5614: FDRE port map (
    Q => GRLFPC20_R_I_EXC(5),
    D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_I(69),
    C => clk,
    R => N_333,
    CE => GRLFPC20_UN1_HOLDN_1);
GRLFPC20_R_I_RESq63z_Z5615: FDRE port map (
    Q => GRLFPC20_R_I_RES(63),
    D => N_3_0_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq62z_Z5616: FDRE port map (
    Q => GRLFPC20_R_I_RES(62),
    D => GRLFPC20_FPO_EXP(10),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq61z_Z5617: FDRE port map (
    Q => GRLFPC20_R_I_RES(61),
    D => GRLFPC20_FPO_EXP(9),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq60z_Z5618: FDRE port map (
    Q => GRLFPC20_R_I_RES(60),
    D => GRLFPC20_FPO_EXP(8),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq59z_Z5619: FDRE port map (
    Q => GRLFPC20_R_I_RES(59),
    D => N_3_1_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq58z_Z5620: FDRE port map (
    Q => GRLFPC20_R_I_RES(58),
    D => N_3_2_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq57z_Z5621: FDRE port map (
    Q => GRLFPC20_R_I_RES(57),
    D => N_3_3_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq56z_Z5622: FDRE port map (
    Q => GRLFPC20_R_I_RES(56),
    D => N_3_4_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq55z_Z5623: FDRE port map (
    Q => GRLFPC20_R_I_RES(55),
    D => N_3_5_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq54z_Z5624: FDRE port map (
    Q => GRLFPC20_R_I_RES(54),
    D => N_3_6_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq53z_Z5625: FDRE port map (
    Q => GRLFPC20_R_I_RES(53),
    D => N_3_7_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq52z_Z5626: FDRE port map (
    Q => GRLFPC20_R_I_RES(52),
    D => N_3_8_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq51z_Z5627: FDRE port map (
    Q => GRLFPC20_R_I_RES(51),
    D => N_3_9_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq50z_Z5628: FDRE port map (
    Q => GRLFPC20_R_I_RES(50),
    D => N_3_10_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq49z_Z5629: FDRE port map (
    Q => GRLFPC20_R_I_RES(49),
    D => N_3_11_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq48z_Z5630: FDRE port map (
    Q => GRLFPC20_R_I_RES(48),
    D => N_3_12_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq47z_Z5631: FDRE port map (
    Q => GRLFPC20_R_I_RES(47),
    D => N_3_13_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq46z_Z5632: FDRE port map (
    Q => GRLFPC20_R_I_RES(46),
    D => N_3_14_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq45z_Z5633: FDRE port map (
    Q => GRLFPC20_R_I_RES(45),
    D => N_3_15_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq44z_Z5634: FDRE port map (
    Q => GRLFPC20_R_I_RES(44),
    D => N_3_16_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq43z_Z5635: FDRE port map (
    Q => GRLFPC20_R_I_RES(43),
    D => N_3_17_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq42z_Z5636: FDRE port map (
    Q => GRLFPC20_R_I_RES(42),
    D => N_3_18_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq41z_Z5637: FDRE port map (
    Q => GRLFPC20_R_I_RES(41),
    D => N_3_19_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq40z_Z5638: FDRE port map (
    Q => GRLFPC20_R_I_RES(40),
    D => N_3_20_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq39z_Z5639: FDRE port map (
    Q => GRLFPC20_R_I_RES(39),
    D => N_3_21_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq38z_Z5640: FDRE port map (
    Q => GRLFPC20_R_I_RES(38),
    D => N_3_22_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq37z_Z5641: FDRE port map (
    Q => GRLFPC20_R_I_RES(37),
    D => N_3_23_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq36z_Z5642: FDRE port map (
    Q => GRLFPC20_R_I_RES(36),
    D => N_3_24_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq35z_Z5643: FDRE port map (
    Q => GRLFPC20_R_I_RES(35),
    D => N_3_25_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq34z_Z5644: FDRE port map (
    Q => GRLFPC20_R_I_RES(34),
    D => N_3_26_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq33z_Z5645: FDRE port map (
    Q => GRLFPC20_R_I_RES(33),
    D => N_3_27_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq32z_Z5646: FDRE port map (
    Q => GRLFPC20_R_I_RES(32),
    D => N_3_28_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq31z_Z5647: FDRE port map (
    Q => GRLFPC20_R_I_RES(31),
    D => N_3_29_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq30z_Z5648: FDRE port map (
    Q => GRLFPC20_R_I_RES(30),
    D => N_3_30_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq29z_Z5649: FDRE port map (
    Q => GRLFPC20_R_I_RES(29),
    D => N_3_31_I,
    C => clk,
    R => RST_I,
    CE => N_6_MUX_I);
GRLFPC20_R_I_RESq28z_Z5650: FDRE port map (
    Q => GRLFPC20_R_I_RES(28),
    D => GRLFPC20_FPO_FRAC(31),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq27z_Z5651: FDRE port map (
    Q => GRLFPC20_R_I_RES(27),
    D => GRLFPC20_FPO_FRAC(30),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq26z_Z5652: FDRE port map (
    Q => GRLFPC20_R_I_RES(26),
    D => GRLFPC20_FPO_FRAC(29),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq25z_Z5653: FDRE port map (
    Q => GRLFPC20_R_I_RES(25),
    D => GRLFPC20_FPO_FRAC(28),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq24z_Z5654: FDRE port map (
    Q => GRLFPC20_R_I_RES(24),
    D => GRLFPC20_FPO_FRAC(27),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq23z_Z5655: FDRE port map (
    Q => GRLFPC20_R_I_RES(23),
    D => GRLFPC20_FPO_FRAC(26),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq22z_Z5656: FDRE port map (
    Q => GRLFPC20_R_I_RES(22),
    D => GRLFPC20_FPO_FRAC(25),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq21z_Z5657: FDRE port map (
    Q => GRLFPC20_R_I_RES(21),
    D => GRLFPC20_FPO_FRAC(24),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq20z_Z5658: FDRE port map (
    Q => GRLFPC20_R_I_RES(20),
    D => GRLFPC20_FPO_FRAC(23),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq19z_Z5659: FDRE port map (
    Q => GRLFPC20_R_I_RES(19),
    D => GRLFPC20_FPO_FRAC(22),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq18z_Z5660: FDRE port map (
    Q => GRLFPC20_R_I_RES(18),
    D => GRLFPC20_FPO_FRAC(21),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq17z_Z5661: FDRE port map (
    Q => GRLFPC20_R_I_RES(17),
    D => GRLFPC20_FPO_FRAC(20),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq16z_Z5662: FDRE port map (
    Q => GRLFPC20_R_I_RES(16),
    D => GRLFPC20_FPO_FRAC(19),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq15z_Z5663: FDRE port map (
    Q => GRLFPC20_R_I_RES(15),
    D => GRLFPC20_FPO_FRAC(18),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq14z_Z5664: FDRE port map (
    Q => GRLFPC20_R_I_RES(14),
    D => GRLFPC20_FPO_FRAC(17),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq13z_Z5665: FDRE port map (
    Q => GRLFPC20_R_I_RES(13),
    D => GRLFPC20_FPO_FRAC(16),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq12z_Z5666: FDRE port map (
    Q => GRLFPC20_R_I_RES(12),
    D => GRLFPC20_FPO_FRAC(15),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq11z_Z5667: FDRE port map (
    Q => GRLFPC20_R_I_RES(11),
    D => GRLFPC20_FPO_FRAC(14),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq10z_Z5668: FDRE port map (
    Q => GRLFPC20_R_I_RES(10),
    D => GRLFPC20_FPO_FRAC(13),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq9z_Z5669: FDRE port map (
    Q => GRLFPC20_R_I_RES(9),
    D => GRLFPC20_FPO_FRAC(12),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq8z_Z5670: FDRE port map (
    Q => GRLFPC20_R_I_RES(8),
    D => GRLFPC20_FPO_FRAC(11),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq7z_Z5671: FDRE port map (
    Q => GRLFPC20_R_I_RES(7),
    D => GRLFPC20_FPO_FRAC(10),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq6z_Z5672: FDRE port map (
    Q => GRLFPC20_R_I_RES(6),
    D => GRLFPC20_FPO_FRAC(9),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq5z_Z5673: FDRE port map (
    Q => GRLFPC20_R_I_RES(5),
    D => GRLFPC20_FPO_FRAC(8),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq4z_Z5674: FDRE port map (
    Q => GRLFPC20_R_I_RES(4),
    D => GRLFPC20_FPO_FRAC(7),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq3z_Z5675: FDRE port map (
    Q => GRLFPC20_R_I_RES(3),
    D => GRLFPC20_FPO_FRAC(6),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq2z_Z5676: FDRE port map (
    Q => GRLFPC20_R_I_RES(2),
    D => GRLFPC20_FPO_FRAC(5),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq1z_Z5677: FDRE port map (
    Q => GRLFPC20_R_I_RES(1),
    D => GRLFPC20_FPO_FRAC(4),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_R_I_RESq0z_Z5678: FDRE port map (
    Q => GRLFPC20_R_I_RES(0),
    D => GRLFPC20_FPO_FRAC(3),
    C => clk,
    R => RST_I,
    CE => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0_Z5679: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(0),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0_CY,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_0,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_0: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_0,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0_CY,
    O => GRLFPC20_FPO_EXP(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_1_Z5681: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(1),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_1,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_1: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_1,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0,
    O => GRLFPC20_FPO_EXP(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_2_Z5683: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(2),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_1,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_2,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_2: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_2,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_1,
    O => GRLFPC20_FPO_EXP(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_3_Z5685: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(3),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_3,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_3: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_3,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_2,
    O => GRLFPC20_FPO_EXP(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_4_Z5687: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(4),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_3,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_4,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_4: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_4,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_3,
    O => GRLFPC20_FPO_EXP(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_5_Z5689: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(5),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_4,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_5,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_5: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_4,
    O => GRLFPC20_FPO_EXP(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_6_Z5691: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(6),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_5,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_6,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_6: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_6,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_5,
    O => GRLFPC20_FPO_EXP(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_7_Z5693: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(7),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_6,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_7,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_7: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_7,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_6,
    O => GRLFPC20_FPO_EXP(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_8_Z5695: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(8),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_7,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_8,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_8: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_8,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_7,
    O => GRLFPC20_FPO_EXP(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_9_Z5697: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(9),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_8,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_9,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_9: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_9,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_8,
    O => GRLFPC20_FPO_EXP(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_10_Z5699: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(10),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_9,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_10,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_10: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_10,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_9,
    O => GRLFPC20_FPO_EXP(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_11_Z5701: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(11),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_10,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_11,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_11: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_11,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_10,
    O => N_1198);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_S_12: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_12,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_11,
    O => N_1199);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0_Z5704: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(0),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0_CY,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_0,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_0: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_0,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0_CY,
    O => N_1210);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_1_Z5706: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(1),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_1,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_1: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_1,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0,
    O => N_1211);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_2_Z5708: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(2),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_1,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_2,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_2: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_2,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_1,
    O => N_1212);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_3_Z5710: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(3),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_3,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_3: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_3,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_2,
    O => GRLFPC20_FPO_FRAC(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_4_Z5712: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(4),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_3,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_4,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_4: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_4,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_3,
    O => GRLFPC20_FPO_FRAC(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_5_Z5714: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(5),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_4,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_5,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_5: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_4,
    O => GRLFPC20_FPO_FRAC(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_6_Z5716: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(6),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_5,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_6,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_6: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_6,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_5,
    O => GRLFPC20_FPO_FRAC(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_7_Z5718: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(7),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_6,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_7,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_7: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_7,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_6,
    O => GRLFPC20_FPO_FRAC(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_8_Z5720: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(8),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_7,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_8,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_8: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_8,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_7,
    O => GRLFPC20_FPO_FRAC(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_9_Z5722: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(9),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_8,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_9,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_9: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_9,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_8,
    O => GRLFPC20_FPO_FRAC(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_10_Z5724: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(10),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_9,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_10,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_10: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_10,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_9,
    O => GRLFPC20_FPO_FRAC(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_11_Z5726: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(11),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_10,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_11,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_11: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_11,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_10,
    O => GRLFPC20_FPO_FRAC(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_12_Z5728: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(12),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_11,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_12,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_12: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_12,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_11,
    O => GRLFPC20_FPO_FRAC(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_13_Z5730: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(13),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_12,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_13,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_13);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_13: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_13,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_12,
    O => GRLFPC20_FPO_FRAC(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_14_Z5732: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(14),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_13,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_14,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_14);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_14: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_14,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_13,
    O => GRLFPC20_FPO_FRAC(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_15_Z5734: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(15),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_14,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_15,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_15);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_15: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_15,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_14,
    O => GRLFPC20_FPO_FRAC(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_16_Z5736: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(16),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_15,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_16,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_16);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_16: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_16,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_15,
    O => GRLFPC20_FPO_FRAC(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_17_Z5738: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(17),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_16,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_17,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_17);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_17: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_17,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_16,
    O => GRLFPC20_FPO_FRAC(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_18_Z5740: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(18),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_17,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_18,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_18);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_18: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_18,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_17,
    O => GRLFPC20_FPO_FRAC(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_19_Z5742: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(19),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_18,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_19,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_19);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_19: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_19,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_18,
    O => GRLFPC20_FPO_FRAC(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_20_Z5744: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(20),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_19,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_20,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_20);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_20: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_20,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_19,
    O => GRLFPC20_FPO_FRAC(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_21_Z5746: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(21),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_20,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_21,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_21);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_21: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_21,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_20,
    O => GRLFPC20_FPO_FRAC(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_22_Z5748: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(22),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_21,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_22,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_22);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_22: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_22,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_21,
    O => GRLFPC20_FPO_FRAC(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_23_Z5750: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(23),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_22,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_23,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_23);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_23: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_23,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_22,
    O => GRLFPC20_FPO_FRAC(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_24_Z5752: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(24),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_23,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_24,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_24);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_24: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_24,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_23,
    O => GRLFPC20_FPO_FRAC(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_25_Z5754: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(25),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_24,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_25,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_25);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_25: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_25,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_24,
    O => GRLFPC20_FPO_FRAC(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_26_Z5756: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(26),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_25,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_26,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_26);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_26: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_26,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_25,
    O => GRLFPC20_FPO_FRAC(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_27_Z5758: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(27),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_26,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_27,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_27);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_27: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_27,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_26,
    O => GRLFPC20_FPO_FRAC(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_28_Z5760: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(28),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_27,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_28,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_28);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_28: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_28,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_27,
    O => GRLFPC20_FPO_FRAC(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_29_Z5762: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(29),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_28,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_29,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_29);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_29: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_29,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_28,
    O => GRLFPC20_FPO_FRAC(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_30_Z5764: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(30),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_29,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_30,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_30);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_30: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_30,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_29,
    O => GRLFPC20_FPO_FRAC(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_31_Z5766: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(31),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_30,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_31,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_31);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_31: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_31,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_30,
    O => GRLFPC20_FPO_FRAC(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_32_Z5768: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(32),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_31,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_32,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_32);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_32: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_32,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_31,
    O => GRLFPC20_FPO_FRAC(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_33_Z5770: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(33),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_32,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_33,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_33);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_33: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_33,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_32,
    O => GRLFPC20_FPO_FRAC(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_34_Z5772: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(34),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_33,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_34,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_34);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_34: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_34,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_33,
    O => GRLFPC20_FPO_FRAC(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_35_Z5774: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(35),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_34,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_35,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_35);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_35: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_35,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_34,
    O => GRLFPC20_FPO_FRAC(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_36_Z5776: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(36),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_35,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_36,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_36);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_36: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_36,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_35,
    O => GRLFPC20_FPO_FRAC(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_37_Z5778: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(37),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_36,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_37,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_37);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_37: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_37,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_36,
    O => GRLFPC20_FPO_FRAC(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_38_Z5780: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(38),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_37,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_38,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_38);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_38: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_38,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_37,
    O => GRLFPC20_FPO_FRAC(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_39_Z5782: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(39),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_38,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_39,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_39);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_39: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_39,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_38,
    O => GRLFPC20_FPO_FRAC(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_40_Z5784: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(40),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_39,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_40,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_40);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_40: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_40,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_39,
    O => GRLFPC20_FPO_FRAC(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_41_Z5786: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(41),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_40,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_41,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_41);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_41: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_41,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_40,
    O => GRLFPC20_FPO_FRAC(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_42_Z5788: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(42),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_41,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_42,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_42);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_42: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_42,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_41,
    O => GRLFPC20_FPO_FRAC(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_43_Z5790: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(43),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_42,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_43,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_43);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_43: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_43,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_42,
    O => GRLFPC20_FPO_FRAC(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_44_Z5792: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(44),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_43,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_44,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_44);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_44: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_44,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_43,
    O => GRLFPC20_FPO_FRAC(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_45_Z5794: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(45),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_44,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_45,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_45);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_45: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_45,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_44,
    O => GRLFPC20_FPO_FRAC(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_46_Z5796: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(46),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_45,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_46,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_46);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_46: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_46,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_45,
    O => GRLFPC20_FPO_FRAC(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_47_Z5798: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(47),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_46,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_47,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_47);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_47: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_47,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_46,
    O => GRLFPC20_FPO_FRAC(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_48_Z5800: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(48),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_47,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_48,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_48);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_48: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_48,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_47,
    O => GRLFPC20_FPO_FRAC(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_49_Z5802: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(49),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_48,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_49,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_49);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_49: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_49,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_48,
    O => GRLFPC20_FPO_FRAC(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_50_Z5804: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(50),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_49,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_50,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_50);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_50: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_50,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_49,
    O => GRLFPC20_FPO_FRAC(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_51_Z5806: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(51),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_50,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_51,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_51);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_51: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_51,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_50,
    O => GRLFPC20_FPO_FRAC(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_52_Z5808: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(52),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_51,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_52,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_52);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_52: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_52,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_51,
    O => GRLFPC20_FPO_FRAC(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_53_Z5810: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(53),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_52,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_53,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_53);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_53: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_53,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_52,
    O => GRLFPC20_FPO_FRAC(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_54_Z5812: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(54),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_53,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_54,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_54);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_54: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_54,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_53,
    O => GRLFPC20_FPO_FRAC(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_55_Z5814: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(55),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_54,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_55,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_55);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_55: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_55,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_54,
    O => N_1265);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_56_Z5816: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(56),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_55,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_56,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_56);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_56: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_56,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_55,
    O => N_1266);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_S_57: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_57,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_56,
    O => N_1267);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_0_Z5819: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
    CI => NN_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_0,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_1_Z5820: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_0,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_1,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_1: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_1,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_0,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_2_Z5822: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_1,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_2,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_2: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_2,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_1,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_3_Z5824: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_3,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_3: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_3,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_2,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_4_Z5826: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_3,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_4,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_4: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_4,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_3,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_5_Z5828: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_4,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_5,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_5: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_4,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_6_Z5830: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_5,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_6,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_6: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_6,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_5,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_7_Z5832: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_6,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_7,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_7: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_7,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_6,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_8_Z5834: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_7,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_8,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_8: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_8,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_7,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_9_Z5836: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_8,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_9,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_9: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_9,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_8,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_10_Z5838: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_9,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_10,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_10: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_10,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_9,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_11_Z5840: MUXCY_L port map (
    DI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_10,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_11,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_11: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_11,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_10,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_12: XORCY port map (
    LI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_12,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_CRY_11,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2RCQq59z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI3SJ51q18z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(18),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI6GGE1q55z: LUT5 
generic map(
  INIT => X"35CACA35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(18),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(55),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_55);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRKDQq61z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISLDQq62z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITMDQq63z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUNDQq64z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVODQq65z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0QDQq66z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1RDQq67z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2SDQq68z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3TDQq69z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRLEQq70z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISMEQq71z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITNEQq72z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUOEQq73z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVPEQq74z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0REQq75z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1SEQq76z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2TEQq77z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3UEQq78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4VEQq79z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISNFQq80z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITOFQq81z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUPFQq82z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVQFQq83z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2_LUT6_2_RNIU2751q1z: LUT5 
generic map(
  INIT => X"47B8B847"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP_RNI49J51q1z: LUT5 
generic map(
  INIT => X"47B8B847"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP_RNI49J51q0z: LUT5 
generic map(
  INIT => X"47B8B847"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(115),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_11_RNO: LUT4 
generic map(
  INIT => X"C0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRM4Rq234z: LUT4 
generic map(
  INIT => X"C0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_RNIG78J1q9z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2835,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(9),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS_RNIF68J1q8z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2834,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS_RNIC38J1q7z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2833,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_RNI908J1q7z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2832,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2818,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_RNI5S7J1q4z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2831,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2818,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_RNIJD8E1q7z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2829,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2816,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_RNIB58E1q1z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2828,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2815,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_RNIA48E1q1z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2827,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2814,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_RNIBLAA1q0z: LUT5 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2826,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2813,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq57z: LUT6_L 
generic map(
  INIT => X"FFFFFFF2FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I1 => M20_E_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_M(57),
  I5 => M5_0_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq56z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => M20_E_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_M_0(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_MIXOOUT0_1_M,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_5(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_6);
GRLFPC20_R_FSR_AEXC_RNOq4z: LUT6_L 
generic map(
  INIT => X"3030B8B8FCF0F0F0"
)
port map (
  I0 => cpi_lddata(9),
  I1 => holdn,
  I2 => GRLFPC20_R_FSR_AEXC(4),
  I3 => GRLFPC20_R_I_EXC(4),
  I4 => GRLFPC20_V_FSR_AEXC_1_SM0,
  I5 => I2_I,
  LO => NN_7);
GRLFPC20_R_FSR_AEXC_RNOq3z: LUT6_L 
generic map(
  INIT => X"3030B8B8FCF0F0F0"
)
port map (
  I0 => cpi_lddata(8),
  I1 => holdn,
  I2 => GRLFPC20_R_FSR_AEXC(3),
  I3 => GRLFPC20_R_I_EXC(3),
  I4 => GRLFPC20_V_FSR_AEXC_1_SM0,
  I5 => I2_I,
  LO => GRLFPC20_R_FSR_AEXC_0);
GRLFPC20_R_FSR_AEXC_RNOq1z: LUT6_L 
generic map(
  INIT => X"3030B8B8FCF0F0F0"
)
port map (
  I0 => cpi_lddata(6),
  I1 => holdn,
  I2 => GRLFPC20_R_FSR_AEXC(1),
  I3 => GRLFPC20_R_I_EXC(1),
  I4 => GRLFPC20_V_FSR_AEXC_1_SM0,
  I5 => I2_I,
  LO => GRLFPC20_R_FSR_AEXC_2);
GRLFPC20_R_FSR_AEXC_RNOq0z: LUT6_L 
generic map(
  INIT => X"3030B8B8FCF0F0F0"
)
port map (
  I0 => cpi_lddata(5),
  I1 => holdn,
  I2 => GRLFPC20_R_FSR_AEXC(0),
  I3 => GRLFPC20_R_I_EXC(0),
  I4 => GRLFPC20_V_FSR_AEXC_1_SM0,
  I5 => I2_I,
  LO => GRLFPC20_R_FSR_AEXC_3);
GRLFPC20_R_FSR_CEXC_RNOq4z: LUT6_L 
generic map(
  INIT => X"EEEEEEECEEEEEEE4"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_FSR_CEXC(4),
  I2 => GRLFPC20_MEXC_1_M(4),
  I3 => GRLFPC20_R_I_EXC_M(4),
  I4 => GRLFPC20_FPCI_M(356),
  I5 => GRLFPC20_V_FSR_CEXC_3_SQMUXA,
  LO => NN_8);
GRLFPC20_R_FSR_CEXC_RNOq3z: LUT6_L 
generic map(
  INIT => X"EEEEEEECEEEEEEE4"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_FSR_CEXC(3),
  I2 => GRLFPC20_MEXC_1_M(3),
  I3 => GRLFPC20_R_I_EXC_M(3),
  I4 => GRLFPC20_FPCI_M(355),
  I5 => GRLFPC20_V_FSR_CEXC_3_SQMUXA,
  LO => GRLFPC20_R_FSR_CEXC_0);
GRLFPC20_R_FSR_CEXC_RNOq2z: LUT6_L 
generic map(
  INIT => X"EEEEEEECEEEEEEE4"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_FSR_CEXC(2),
  I2 => GRLFPC20_MEXC_1_M(2),
  I3 => GRLFPC20_R_I_EXC_M(2),
  I4 => GRLFPC20_FPCI_M(354),
  I5 => GRLFPC20_V_FSR_CEXC_3_SQMUXA,
  LO => GRLFPC20_R_FSR_CEXC_1);
GRLFPC20_R_FSR_CEXC_RNOq1z: LUT6_L 
generic map(
  INIT => X"EEEEEEECEEEEEEE4"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_FSR_CEXC(1),
  I2 => GRLFPC20_MEXC_1_M(1),
  I3 => GRLFPC20_R_I_EXC_M(1),
  I4 => GRLFPC20_FPCI_M(353),
  I5 => GRLFPC20_V_FSR_CEXC_3_SQMUXA,
  LO => GRLFPC20_R_FSR_CEXC_2);
GRLFPC20_R_FSR_CEXC_RNOq0z: LUT6_L 
generic map(
  INIT => X"EEEEEEECEEEEEEE4"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_FSR_CEXC(0),
  I2 => GRLFPC20_MEXC_1_M(0),
  I3 => GRLFPC20_R_I_EXC_M(0),
  I4 => GRLFPC20_FPCI_M(352),
  I5 => GRLFPC20_V_FSR_CEXC_3_SQMUXA,
  LO => GRLFPC20_R_FSR_CEXC_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq114z: LUT6_L 
generic map(
  INIT => X"FE32CE0200000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2472,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_15(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_5_MUX_3);
GRLFPC20_R_FSR_AEXC_RNOq2z: LUT6_L 
generic map(
  INIT => X"00CCAACCFCCCAACC"
)
port map (
  I0 => cpi_lddata(7),
  I1 => GRLFPC20_R_FSR_AEXC(2),
  I2 => GRLFPC20_R_I_EXC(2),
  I3 => GRLFPC20_R_FSR_AEXCCE_0_0(2),
  I4 => GRLFPC20_V_FSR_AEXC_1_SM0,
  I5 => I2_I,
  LO => GRLFPC20_R_FSR_AEXC_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq60z: LUT6_L 
generic map(
  INIT => X"F7B3C480FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(53),
  I3 => N_1265,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2586,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_5_MUX_7_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_60_RNIO7RK: LUT6_L 
generic map(
  INIT => X"0000FFFF7000F8FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_RETO(19),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_RETO,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(19),
  I3 => M20_E_20_0_2_RETO,
  I4 => R_DPATH_RET_49,
  I5 => M20_E_0_RETO_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_68_RNIFDJB: LUT4_L 
generic map(
  INIT => X"0F8B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(5),
  I1 => M20_E_36_3_RETO,
  I2 => R_DPATH_RET_54,
  I3 => M20_E_0_RETO_0,
  LO => NN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_RNIB3DF1: LUT6_L 
generic map(
  INIT => X"00800000FFBFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(10),
  I1 => M9_41_1_RETO,
  I2 => M9_41_2_RETO,
  I3 => M20_E_0_RETO,
  I4 => M20_E_41_3_RETO,
  I5 => R_DPATH_RET_3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq0z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I1 => M20_E_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_5(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_6(0),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_53);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq2z: LUT4_L 
generic map(
  INIT => X"000B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_1(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_2_0(2),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_I(2));
GRLFPC20_COMB_WREN2_12: LUT5 
generic map(
  INIT => X"FCEC0000"
)
port map (
  I0 => GRLFPC20_COMB_RDD_2,
  I1 => GRLFPC20_COMB_WREN2_11_IV_0,
  I2 => GRLFPC20_COMB_WREN129,
  I3 => GRLFPC20_WRADDR_1(0),
  I4 => holdn,
  O => rfi2_wren);
GRLFPC20_COMB_WREN1_12: LUT5 
generic map(
  INIT => X"ECFC0000"
)
port map (
  I0 => GRLFPC20_COMB_RDD_2,
  I1 => GRLFPC20_COMB_WREN1_11_IV_0,
  I2 => GRLFPC20_COMB_WREN129,
  I3 => GRLFPC20_WRADDR_1(0),
  I4 => holdn,
  O => rfi1_wren);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq63z: LUT5_L 
generic map(
  INIT => X"FA50CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2583,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2523,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_179_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq62z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(50),
  I2 => GRLFPC20_FPI_OP1(53),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2702,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_178_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq61z: LUT5_L 
generic map(
  INIT => X"FF00D8D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(54),
  I2 => GRLFPC20_FPI_OP1(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2703,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_177_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq78z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(34),
  I2 => GRLFPC20_FPI_OP1(37),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2686,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_173_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq77z: LUT5_L 
generic map(
  INIT => X"F5A0CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(77),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2509,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2569,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_172_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq76z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(36),
  I2 => GRLFPC20_FPI_OP1(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2688,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_171_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq75z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(37),
  I2 => GRLFPC20_FPI_OP1(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2689,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_170_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq74z: LUT5_L 
generic map(
  INIT => X"F5A0CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(74),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2512,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2572,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_169_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq73z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(39),
  I2 => GRLFPC20_FPI_OP1(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2691,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_168_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq72z: LUT5_L 
generic map(
  INIT => X"F5A0CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2514,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2574,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_167_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq71z: LUT5_L 
generic map(
  INIT => X"F5A0CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(71),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2515,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2575,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_166_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq70z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(42),
  I2 => GRLFPC20_FPI_OP1(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2694,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_165_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq69z: LUT5_L 
generic map(
  INIT => X"FA50CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(69),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2577,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2517,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_164_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq68z: LUT5_L 
generic map(
  INIT => X"FF00D8D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(47),
  I2 => GRLFPC20_FPI_OP1(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2696,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_163_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq67z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(45),
  I2 => GRLFPC20_FPI_OP1(48),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2697,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_162_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq65z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(47),
  I2 => GRLFPC20_FPI_OP1(50),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2699,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_160_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq64z: LUT5_L 
generic map(
  INIT => X"FF00E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(48),
  I2 => GRLFPC20_FPI_OP1(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2700,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_159_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq93z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(19),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2493,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2553,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_158_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq92z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2494,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2554,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_157_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq91z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2495,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2555,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_156_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq90z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(22),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2496,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2556,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_155_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq89z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(23),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2497,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2557,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_154_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq88z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(24),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2498,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2558,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_153_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq87z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(25),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2499,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2559,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_152_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq86z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(26),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2500,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2560,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_151_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq85z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(27),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2501,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2561,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_150_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq84z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(28),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2502,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2562,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_149_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq83z: LUT5_L 
generic map(
  INIT => X"FF00E2E2"
)
port map (
  I0 => rfo2_data1(29),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_OP1(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2681,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_148_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq82z: LUT5_L 
generic map(
  INIT => X"FF00E2E2"
)
port map (
  I0 => rfo2_data1(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_OP1(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2682,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_147_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq81z: LUT5_L 
generic map(
  INIT => X"FF00E2E2"
)
port map (
  I0 => rfo2_data1(31),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_OP1(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2683,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_146_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq80z: LUT5_L 
generic map(
  INIT => X"FA50CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2566,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2506,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_145_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq79z: LUT5_L 
generic map(
  INIT => X"FF00D8D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(36),
  I2 => GRLFPC20_FPI_OP1(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2685,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_144_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq108z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2478,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2538,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_143_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq107z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2479,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2539,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_142_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq106z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2480,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2540,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_141_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq105z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2481,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2541,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_140_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq104z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2482,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2542,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_139_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq103z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2483,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2543,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_138_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq102z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(10),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2484,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2544,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_137_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq101z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(11),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2485,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2545,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_136_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq100z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2486,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2546,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_135_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq99z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(13),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2487,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2547,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_134_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq98z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(14),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2488,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2548,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_133_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq97z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2489,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2549,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_132_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq96z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(16),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2490,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2550,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_131_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq95z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(17),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2491,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2551,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_130_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq94z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(18),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2492,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2552,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_129_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq112z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2474,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2534,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_117_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq111z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2475,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2535,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_116_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq110z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2476,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2536,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_115_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq109z: LUT6_L 
generic map(
  INIT => X"FF0FF00022222222"
)
port map (
  I0 => rfo2_data1(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2477,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2537,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_3_114_I);
R_DPATH_RET_26_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(50),
  I1 => GRLFPC20_FPO_FRAC(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_0_3,
  I4 => M9_0_1,
  I5 => M9_0_1_0,
  LO => N_38_MUX_0);
R_DPATH_RET_24_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(52),
  I1 => GRLFPC20_FPO_FRAC(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_2_3,
  I4 => M9_2_1,
  I5 => M9_2_1_0,
  LO => N_38_MUX_2);
R_DPATH_RET_25_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(41),
  I1 => GRLFPC20_FPO_FRAC(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_12_3,
  I4 => M9_12_1,
  I5 => M9_12_1_0,
  LO => N_38_MUX_12);
R_DPATH_RET_38_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(47),
  I1 => GRLFPC20_FPO_FRAC(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_18_3,
  I4 => M9_18_1,
  I5 => M9_18_1_0,
  LO => N_38_MUX_18);
R_DPATH_RET_49_RNO: LUT6_L 
generic map(
  INIT => X"2030A0F000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(38),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(38),
  I2 => M9_20_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_20_2_0,
  LO => N_38_MUX_20);
R_DPATH_RET_44_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(23),
  I1 => GRLFPC20_FPO_FRAC(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_24_3,
  I4 => M9_24_1,
  I5 => M9_24_1_0,
  LO => N_38_MUX_24);
R_DPATH_RET_32_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(24),
  I1 => GRLFPC20_FPO_FRAC(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_25_3,
  I4 => M9_25_1,
  I5 => M9_25_1_0,
  LO => N_38_MUX_25);
R_DPATH_RET_41_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(25),
  I1 => GRLFPC20_FPO_FRAC(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_26_3,
  I4 => M9_26_1,
  I5 => M9_26_1_0,
  LO => N_38_MUX_26);
R_DPATH_RET_54_RNO: LUT6_L 
generic map(
  INIT => X"153F000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(52),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I4 => M9_36_0_4,
  I5 => M9_36_0,
  LO => N_38_MUX_36);
R_DPATH_RET_50_RNO: LUT6_L 
generic map(
  INIT => X"153F000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I4 => M9_37_0_4,
  I5 => M9_37_0,
  LO => N_38_MUX_37);
R_DPATH_RET_29_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(11),
  I1 => GRLFPC20_FPO_FRAC(45),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_42_3,
  I4 => M9_42_1,
  I5 => M9_42_1_0,
  LO => N_38_MUX_42);
R_DPATH_RET_47_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(13),
  I1 => GRLFPC20_FPO_FRAC(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_44_3,
  I4 => M9_44_1,
  I5 => M9_44_1_0,
  LO => N_38_MUX_44);
R_DPATH_RET_35_RNO: LUT6_L 
generic map(
  INIT => X"1500000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(14),
  I1 => GRLFPC20_FPO_FRAC(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_45_3,
  I4 => M9_45_1,
  I5 => M9_45_1_0,
  LO => N_38_MUX_45);
R_DPATH_RET_52_RNO: LUT6_L 
generic map(
  INIT => X"2030A0F000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(40),
  I2 => M9_48_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_48_2_0,
  LO => N_38_MUX_48);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1q0z_Z5969: LUT6_L 
generic map(
  INIT => X"F5F5FF00FCFCCCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXCSHFT_UN13_EXMIPTRLSBS,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2200,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12(75),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1q2z_Z5970: LUT6_L 
generic map(
  INIT => X"EEEEFF00FCFCF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2202,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12(75),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq58z: LUT6_L 
generic map(
  INIT => X"F7B3C48000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => N_1265,
  I3 => N_1267,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2588,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_5_MUX_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq59z: LUT6_L 
generic map(
  INIT => X"FB73C84000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => N_1266,
  I3 => GRLFPC20_FPO_FRAC(54),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2587,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_5_MUX_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq81z: LUT6_L 
generic map(
  INIT => X"DDF0DDF0FFFF0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3077_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12(75),
  I4 => N_1641,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq80z: LUT6_L 
generic map(
  INIT => X"FFFFCC88FCF8FCF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2205,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2214,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8q57z_Z5975: LUT6 
generic map(
  INIT => X"FFEFFFFFFFFFFFEE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_1(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_0(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_STKGEN_3_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_2(57),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_11(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(57));
GRLFPC20_R_I_V_RNO: LUT6_L 
generic map(
  INIT => X"00F5CCCC00F500F5"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_I_V,
  I2 => GRLFPC20_UN1_HOLDN_1,
  I3 => GRLFPC20_ANNULRES_1,
  I4 => GRLFPC20_COMB_V_FSR_FCC10,
  I5 => GRLFPC20_V_I_V_3_SQMUXA_3,
  LO => GRLFPC20_R_I_V_0);
GRLFPC20_R_I_EXEC_RNO: LUT6_L 
generic map(
  INIT => X"0000000000000004"
)
port map (
  I0 => GRLFPC20_N_826,
  I1 => GRLFPC20_COMB_V_I_EXEC_5,
  I2 => GRLFPC20_COMB_V_STATE14,
  I3 => GRLFPC20_N_824_1,
  I4 => GRLFPC20_N_824_3,
  I5 => GRLFPC20_V_FSR_AEXC_1_SM0,
  LO => GRLFPC20_N_824_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_15q0z_Z5978: LUT5 
generic map(
  INIT => X"E800E8FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SCLSBS_1(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_11(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_15(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_1q2z_Z5979: LUT6 
generic map(
  INIT => X"FFFFFFBAFFFFFF30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_0(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_0(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_1(2));
R_DPATH_RET_49_RNO_0: LUT6_L 
generic map(
  INIT => X"0111033300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(19),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I5 => M9_20_0_0,
  LO => M9_20_2_0);
R_DPATH_RET_52_RNO_0: LUT6_L 
generic map(
  INIT => X"0111033300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I5 => M9_48_0_0,
  LO => M9_48_2_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq67z: LUT6_L 
generic map(
  INIT => X"141414141414FF00"
)
port map (
  I0 => cpi_d_inst(13),
  I1 => cpi_d_inst(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MAPMULXFF_UN4_UNIMPMAP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(67),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I5 => GRLFPC20_FPI_START,
  LO => NN_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_13q3z_Z5983: LUT3_L 
generic map(
  INIT => X"84"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2778,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_13(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_6q0z_Z5984: LUT6 
generic map(
  INIT => X"FEEEFCCCFAAAF000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(116),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6321_I,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_6(0));
GRLFPC20_V_FSR_CEXC_3_SQMUXA_Z5985: LUT5 
generic map(
  INIT => X"00000002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I2 => GRLFPC20_COMB_V_STATE14,
  I3 => GRLFPC20_COMB_WREN129,
  I4 => GRLFPC20_COMB_V_FSR_FCC10,
  O => GRLFPC20_V_FSR_CEXC_3_SQMUXA);
R_DPATH_RET_51_RNO: LUT6_L 
generic map(
  INIT => X"0000153F00000000"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M_0(40),
  I5 => M9_48_2,
  LO => M20_E_48_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q12z: LUT4 
generic map(
  INIT => X"1500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(12),
  I1 => GRLFPC20_FPO_FRAC(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_43_1,
  O => M9_43_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q21z: LUT4 
generic map(
  INIT => X"1500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(21),
  I1 => GRLFPC20_FPO_FRAC(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_22_1,
  O => M9_22_0);
R_DPATH_RET_2_RNO: LUT4_L 
generic map(
  INIT => X"008C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(47),
  I1 => M9_41_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(47),
  LO => M20_E_41_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q3z: LUT6 
generic map(
  INIT => X"2A0000003F000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(53),
  I1 => GRLFPC20_FPO_FRAC(53),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_50_0_2,
  I4 => M9_50_0_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_50_0);
R_DPATH_RET_50_RNO_1: LUT6_L 
generic map(
  INIT => X"135F000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(122),
  I1 => GRLFPC20_FPO_FRAC(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I4 => M9_37_0_2,
  I5 => M9_37_0_1,
  LO => M9_37_0);
R_DPATH_RET_54_RNO_1: LUT6_L 
generic map(
  INIT => X"135F000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(121),
  I1 => GRLFPC20_FPO_FRAC(52),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I4 => M9_36_0_2,
  I5 => M9_36_0_1,
  LO => M9_36_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q4z: LUT6_L 
generic map(
  INIT => X"2A0000003F000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(52),
  I1 => GRLFPC20_FPO_FRAC(52),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_35_0_2,
  I4 => M9_35_0_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_35_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q9z: LUT6 
generic map(
  INIT => X"2A0000003F000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(47),
  I1 => GRLFPC20_FPO_FRAC(47),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_40_0_2,
  I4 => M9_40_0_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_40_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q70z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(43),
  I3 => GRLFPC20_FPO_FRAC(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2576,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2694);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q65z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(48),
  I3 => GRLFPC20_FPO_FRAC(50),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2581,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2699);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q82z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(31),
  I3 => GRLFPC20_FPO_FRAC(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2564,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2682);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q66z: LUT5 
generic map(
  INIT => X"F7C4B380"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2580,
  I4 => GRLFPC20_FPO_FRAC(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2698);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q62z: LUT5 
generic map(
  INIT => X"FC74B830"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2584,
  I3 => GRLFPC20_FPO_FRAC(51),
  I4 => GRLFPC20_FPO_FRAC(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2702);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q64z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(49),
  I3 => GRLFPC20_FPO_FRAC(51),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2582,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2700);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q67z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(46),
  I3 => GRLFPC20_FPO_FRAC(48),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2579,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2697);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q61z: LUT5 
generic map(
  INIT => X"FC74B830"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2585,
  I3 => GRLFPC20_FPO_FRAC(52),
  I4 => GRLFPC20_FPO_FRAC(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2703);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q68z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(45),
  I3 => GRLFPC20_FPO_FRAC(47),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2578,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2696);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q73z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(40),
  I3 => GRLFPC20_FPO_FRAC(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2573,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2691);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q75z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(38),
  I3 => GRLFPC20_FPO_FRAC(40),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2571,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2689);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q76z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(37),
  I3 => GRLFPC20_FPO_FRAC(39),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2570,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2688);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q78z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(35),
  I3 => GRLFPC20_FPO_FRAC(37),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2568,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2686);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q79z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(34),
  I3 => GRLFPC20_FPO_FRAC(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2567,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2685);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q81z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(32),
  I3 => GRLFPC20_FPO_FRAC(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2565,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2683);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_3q83z: LUT5 
generic map(
  INIT => X"F7B3C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_FPO_FRAC(30),
  I3 => GRLFPC20_FPO_FRAC(32),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2563,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2681);
GRLFPC20_V_MK_RST_1_Z6011: LUT6_L 
generic map(
  INIT => X"0000000000000008"
)
port map (
  I0 => GRLFPC20_R_MK_HOLDN1,
  I1 => GRLFPC20_V_MK_RST_1_0,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  I4 => GRLFPC20_ANNULFPU_1_IV,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP,
  LO => GRLFPC20_V_MK_RST_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq243z: LUT5_L 
generic map(
  INIT => X"AAFCAA0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(243),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2252,
  LO => N_5_9_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq242z: LUT5_L 
generic map(
  INIT => X"AAFCAA0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(242),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2253,
  LO => N_5_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq241z: LUT5_L 
generic map(
  INIT => X"AAFCAA0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(241),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2254,
  LO => N_5_7_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq240z: LUT5_L 
generic map(
  INIT => X"AAFCAA0C"
)
port map (
  I0 => NN_4,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(240),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2255,
  LO => N_5_6_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq239z: LUT5_L 
generic map(
  INIT => X"AAFCAA0C"
)
port map (
  I0 => NN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(239),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2256,
  LO => N_5_5_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq238z: LUT5_L 
generic map(
  INIT => X"AAFCAA0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(238),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2257,
  LO => N_5_4_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq237z: LUT5_L 
generic map(
  INIT => X"AAFCAA0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(237),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2258,
  LO => N_5_3_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq244z: LUT5_L 
generic map(
  INIT => X"AAAAF0CC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2251,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  LO => N_5_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_0q7z: LUT5 
generic map(
  INIT => X"AA3CAACC"
)
port map (
  I0 => cpi_d_inst(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C6,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2207);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_5q56z_Z6021: LUT6 
generic map(
  INIT => X"3075005530300000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_5(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4q56z_Z6022: LUT5_L 
generic map(
  INIT => X"FFFFECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(172),
  I1 => N_1211,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4_0(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_5q0z_Z6023: LUT6 
generic map(
  INIT => X"FBF3BB33FAF0AA00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(57),
  I2 => N_1267,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_5(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q1z: LUT6 
generic map(
  INIT => X"040C44CC050F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(117),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(56),
  I2 => N_1266,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M8_0_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q57z: LUT6 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(173),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(115),
  I2 => N_1210,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M5_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_0q2z_Z6026: LUT6 
generic map(
  INIT => X"3F0F33007F5F7755"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => GRLFPC20_FPO_FRAC(54),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_0(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_2_0q2z_Z6027: LUT6_L 
generic map(
  INIT => X"FF27FF0027270000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(53),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(55),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSRRES(55),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_2_0(2));
R_DPATH_RET_48_RNO: LUT5_L 
generic map(
  INIT => X"2A003F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(37),
  I1 => GRLFPC20_FPO_FRAC(37),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_20_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M20_E_20_0_2);
R_DPATH_RET_15_RNO_1: LUT6_L 
generic map(
  INIT => X"020A22AA030F33FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(10),
  I1 => GRLFPC20_FPO_FRAC(10),
  I2 => GRLFPC20_FPO_FRAC(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_17_0_0);
R_DPATH_RET_38_RNO_1: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(163),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_18_0_1);
R_DPATH_RET_47_RNO_1: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(129),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_44_0_1);
R_DPATH_RET_35_RNO_1: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(130),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_45_0_1);
R_DPATH_RET_44_RNO_1: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(139),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_24_0_1);
R_DPATH_RET_29_RNO_1: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(127),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(46),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_42_0_1);
R_DPATH_RET_32_RNO_1: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(140),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_25_0_1);
R_DPATH_RET_41_RNO_1: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(141),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_26_0_1);
R_DPATH_RET_28_RNO: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(127),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => M9_42_1,
  LO => M20_E_42_0_1);
R_DPATH_RET_34_RNO: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(130),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => M9_45_1,
  LO => M20_E_45_0_1);
R_DPATH_RET_46_RNO: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(129),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => M9_44_1,
  LO => M20_E_44_0_1);
R_DPATH_RET_43_RNO: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(139),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => M9_24_1,
  LO => M20_E_24_0_1);
R_DPATH_RET_37_RNO: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(163),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => M9_18_1,
  LO => M20_E_18_0_1);
R_DPATH_RET_40_RNO: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(141),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => M9_26_1,
  LO => M20_E_26_0_1);
R_DPATH_RET_31_RNO: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(140),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => M9_25_1,
  LO => M20_E_25_0_1);
R_DPATH_RET_49_RNO_1: LUT6_L 
generic map(
  INIT => X"040C44CC050F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(37),
  I2 => GRLFPC20_FPO_FRAC(37),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_20_0_0);
R_DPATH_RET_50_RNO_0: LUT4 
generic map(
  INIT => X"4C5F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M9_37_0_4);
R_DPATH_RET_53_RNO_0: LUT6_L 
generic map(
  INIT => X"01031133050F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(52),
  I2 => GRLFPC20_FPO_FRAC(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M20_E_36_1);
R_DPATH_RET_54_RNO_0: LUT4 
generic map(
  INIT => X"4C5F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(52),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M9_36_0_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q7z: LUT4 
generic map(
  INIT => X"4C5F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(50),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M9_38_0_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q4z: LUT4 
generic map(
  INIT => X"4C5F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(53),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M9_35_0_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q8z: LUT6 
generic map(
  INIT => X"01031133050F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(49),
  I2 => GRLFPC20_FPO_FRAC(49),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => M20_E_39_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q8z: LUT5_L 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(124),
  I1 => GRLFPC20_FPO_FRAC(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I4 => M9_39_0_1,
  LO => M9_39_0_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq249z: LUT6_L 
generic map(
  INIT => X"FFAA550030303030"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_OP1(60),
  I3 => GRLFPC20_FPO_EXP(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2317,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_0,
  LO => N_3_45_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq247z: LUT6_L 
generic map(
  INIT => X"FFAA550030303030"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_OP1(62),
  I3 => GRLFPC20_FPO_EXP(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2319,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_0,
  LO => N_3_43_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_3_Z6054: LUT6 
generic map(
  INIT => X"FFF2F22D2DDFDFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN33_ZERO_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_113(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_CI_113(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SCLSBS_1(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_4: LUT6 
generic map(
  INIT => X"FFFFAAF0EEFCAAF0"
)
port map (
  I0 => cpi_d_inst(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I2 => N_1628,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  O => N_1641);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_27_RNICEH11q75z: LUT4 
generic map(
  INIT => X"0C0D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP_Z6057: LUT6 
generic map(
  INIT => X"FB00000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(66),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12(75),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_STKGEN_3_0_Z6058: LUT6 
generic map(
  INIT => X"0DD2D2202000000D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN33_ZERO_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_113(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_CI_113(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SCLSBS_1(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_STKGEN_3_0);
GRLFPC20_R_STATE_RNOq1z: LUT5_L 
generic map(
  INIT => X"CC800080"
)
port map (
  I0 => cpi_exack,
  I1 => rst,
  I2 => GRLFPC20_R_STATE(0),
  I3 => GRLFPC20_R_STATE(1),
  I4 => GRLFPC20_V_STATE_2_SQMUXA,
  LO => GRLFPC20_V_STATE_1_IV_I(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_0q6z: LUT4 
generic map(
  INIT => X"A3AC"
)
port map (
  I0 => cpi_d_inst(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C6,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2206);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_SCTRL_26_Uq0z: LUT6 
generic map(
  INIT => X"FFFFFD0D0000F808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(22),
  I1 => GRLFPC20_FPO_SIGN,
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN10_AREGSIGN_SEL,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN1_AREGSIGN_SEL,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2772,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2778);
GRLFPC20_COMB_UN1_R_I_V_RNIL1EJ1: LUT6 
generic map(
  INIT => X"AFCF000000000000"
)
port map (
  I0 => cpi_x_inst(19),
  I1 => GRLFPC20_R_I_INST(19),
  I2 => GRLFPC20_R_X_LD,
  I3 => GRLFPC20_COMB_UN1_R_I_V,
  I4 => GRLFPC20_COMB_UN1_R_I_V_1,
  I5 => GRLFPC20_COMB_UN1_V_STATE,
  O => GRLFPC20_WRRES_1);
GRLFPC20_COMB_V_FSR_FCC10_Z6063: LUT5 
generic map(
  INIT => X"AC000000"
)
port map (
  I0 => cpi_x_inst(19),
  I1 => GRLFPC20_R_I_INST(19),
  I2 => GRLFPC20_COMB_UN1_R_I_V,
  I3 => GRLFPC20_COMB_UN1_R_I_V_1,
  I4 => GRLFPC20_COMB_UN1_V_STATE,
  O => GRLFPC20_COMB_V_FSR_FCC10);
GRLFPC20_COMB_WREN129_Z6064: LUT6 
generic map(
  INIT => X"0503000000000000"
)
port map (
  I0 => cpi_x_inst(19),
  I1 => GRLFPC20_R_I_INST(19),
  I2 => GRLFPC20_R_X_LD,
  I3 => GRLFPC20_COMB_UN1_R_I_V,
  I4 => GRLFPC20_COMB_UN1_R_I_V_1,
  I5 => GRLFPC20_COMB_UN1_V_STATE,
  O => GRLFPC20_COMB_WREN129);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_RNIBU4A1q24z: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(24),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq233z: LUT5_L 
generic map(
  INIT => X"0000B800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => N_1198,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  LO => N_9_MUX_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq232z: LUT5_L 
generic map(
  INIT => X"00B00080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(245),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  I4 => N_1199,
  LO => N_9_MUX_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q1z: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(53),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(55),
  I3 => N_1265,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M8_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q34z: LUT6_L 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(20),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(22),
  I3 => GRLFPC20_FPO_FRAC(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_5_1);
R_DPATH_RET_10_RNO_5: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(19),
  I3 => GRLFPC20_FPO_FRAC(20),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_8_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q49z: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(7),
  I3 => GRLFPC20_FPO_FRAC(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_1);
R_DPATH_RET_26_RNO_1: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(6),
  I1 => GRLFPC20_FPO_FRAC(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q51z: LUT6_L 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(5),
  I3 => GRLFPC20_FPO_FRAC(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_1_1);
R_DPATH_RET_24_RNO_1: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(4),
  I1 => GRLFPC20_FPO_FRAC(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_2_1);
R_DPATH_RET_11_RNO_5: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(34),
  I1 => GRLFPC20_FPO_FRAC(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_23_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_RNII49P1q29z: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(31),
  I3 => GRLFPC20_FPO_FRAC(32),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_26_1);
R_DPATH_RET_6_RNO_5: LUT6 
generic map(
  INIT => X"001B1B1B00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_116,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(28),
  I3 => GRLFPC20_FPO_FRAC(31),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_27_1);
R_DPATH_RET_16_RNO_5: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(27),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(29),
  I3 => GRLFPC20_FPO_FRAC(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_28_1);
R_DPATH_RET_22_RNO_5: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(26),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(28),
  I3 => GRLFPC20_FPO_FRAC(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_29_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q40z: LUT6_L 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(14),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(16),
  I3 => GRLFPC20_FPO_FRAC(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_11_1);
R_DPATH_RET_25_RNO_1: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(13),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(15),
  I3 => GRLFPC20_FPO_FRAC(16),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_12_1);
R_DPATH_RET_13_RNO_5: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(13),
  I3 => GRLFPC20_FPO_FRAC(14),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_14_1);
R_DPATH_RET_7_RNO_2: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(12),
  I1 => GRLFPC20_FPO_FRAC(13),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_15_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q45z: LUT6_L 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(11),
  I3 => GRLFPC20_FPO_FRAC(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_16_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNIGCKG1q9z: LUT6 
generic map(
  INIT => X"001B1B1B00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(7),
  I3 => GRLFPC20_FPO_FRAC(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_18_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_RNI6T6Sq46z: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(46),
  I1 => GRLFPC20_FPO_FRAC(47),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_41_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q12z: LUT4_L 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(44),
  I1 => GRLFPC20_FPO_FRAC(45),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_43_1);
R_DPATH_RET_9_RNO_5: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(38),
  I1 => GRLFPC20_FPO_FRAC(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_49_1);
R_DPATH_RET_12_RNO_3: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(41),
  I3 => GRLFPC20_FPO_FRAC(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_46_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_RNIUO6Sq42z: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(42),
  I1 => GRLFPC20_FPO_FRAC(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_45_1);
R_DPATH_RET_18_RNO_2: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(27),
  I1 => GRLFPC20_FPO_FRAC(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_30_1);
R_DPATH_RET_20_RNO_5: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(40),
  I1 => GRLFPC20_FPO_FRAC(41),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_47_1);
R_DPATH_RET_21_RNO_3: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(24),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(26),
  I3 => GRLFPC20_FPO_FRAC(27),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_31_1);
R_DPATH_RET_17_RNO_3: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(22),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(24),
  I3 => GRLFPC20_FPO_FRAC(25),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_33_1);
R_DPATH_RET_8_RNO_5: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(23),
  I1 => GRLFPC20_FPO_FRAC(24),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_34_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4FEVq135z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(135),
  I1 => GRLFPC20_FPO_FRAC(38),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M9_20_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRDEVq133z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(133),
  I1 => GRLFPC20_FPO_FRAC(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M9_48_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q55z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(171),
  I1 => N_1212,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M8_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_10q10z_Z6099: LUT6 
generic map(
  INIT => X"F0F01122F0F03300"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_FPI_LDOP,
  I5 => I2_I_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_10(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_0q2z_Z6100: LUT4 
generic map(
  INIT => X"7350"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(118),
  I1 => N_1265,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1_0(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q3z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(119),
  I1 => GRLFPC20_FPO_FRAC(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M9_50_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q3z: LUT6 
generic map(
  INIT => X"054515550FCF3FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPI_OP2(54),
  I4 => GRLFPC20_FPI_OP2(51),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  O => M9_50_0_2);
R_DPATH_RET_50_RNO_3: LUT4_L 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(50),
  I1 => GRLFPC20_FPO_FRAC(50),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_37_0_1);
R_DPATH_RET_54_RNO_3: LUT4_L 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(51),
  I1 => GRLFPC20_FPO_FRAC(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_36_0_1);
R_DPATH_RET_54_RNO_2: LUT6 
generic map(
  INIT => X"032313330FAF5FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => NN_4,
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPI_OP2(52),
  I4 => GRLFPC20_FPI_OP2(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  O => M9_36_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q7z: LUT4 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(49),
  I1 => GRLFPC20_FPO_FRAC(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_38_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q7z: LUT6 
generic map(
  INIT => X"051545550F3FCFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPI_OP2(47),
  I4 => GRLFPC20_FPI_OP2(50),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  O => M9_38_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q4z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(120),
  I1 => GRLFPC20_FPO_FRAC(53),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M9_35_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q4z: LUT6 
generic map(
  INIT => X"032313330FAF5FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => NN_3,
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPI_OP2(53),
  I4 => GRLFPC20_FPI_OP2(50),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  O => M9_35_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q9z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(125),
  I1 => GRLFPC20_FPO_FRAC(48),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M9_40_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q9z: LUT6 
generic map(
  INIT => X"031323330F5FAFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPI_OP2(45),
  I4 => GRLFPC20_FPI_OP2(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  O => M9_40_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q8z: LUT4_L 
generic map(
  INIT => X"2A3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(48),
  I1 => GRLFPC20_FPO_FRAC(48),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_39_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q8z: LUT6 
generic map(
  INIT => X"051545550F3FCFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPI_OP2(46),
  I4 => GRLFPC20_FPI_OP2(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  O => M9_39_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q54z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_FPO_FRAC(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => M9_4_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q54z: LUT4 
generic map(
  INIT => X"135F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(170),
  I1 => N_1212,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => M9_4_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq258z: LUT6_L 
generic map(
  INIT => X"3900C6FFC6FF3900"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => N_1383_I,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6322_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq234z: LUT6_L 
generic map(
  INIT => X"00000000BB88F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(234),
  I3 => GRLFPC20_FPO_EXP(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  LO => N_4_58);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq235z: LUT6_L 
generic map(
  INIT => X"00000000BB88F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(235),
  I3 => GRLFPC20_FPO_EXP(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  LO => N_4_59);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq236z: LUT6_L 
generic map(
  INIT => X"00000000BB88F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(236),
  I3 => GRLFPC20_FPO_EXP(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4,
  LO => N_4_60);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN588_TEMP_LUT6_2_RNI67FR7: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6126,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6127,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_117(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq13z: LUT6_L 
generic map(
  INIT => X"00AAFFAA002AFFEA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => N_3_39,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN1_AREGSIGN_SEL,
  LO => NN_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_0q5z: LUT5 
generic map(
  INIT => X"AAAA3CF0"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2205);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq246z: LUT6_L 
generic map(
  INIT => X"BFB08F8000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => N_1198,
  I4 => N_1199,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_0,
  LO => N_5_MUX_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA_Z6124: LUT4 
generic map(
  INIT => X"0800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA);
GRLFPC20_COMB_WREN2_11_IV_0_Z6125: LUT6 
generic map(
  INIT => X"EFE0000000000000"
)
port map (
  I0 => cpi_x_cnt(0),
  I1 => cpi_x_cnt(1),
  I2 => cpi_x_inst(20),
  I3 => cpi_x_inst(25),
  I4 => GRLFPC20_WREN1_0_SQMUXA_0,
  I5 => GRLFPC20_WREN2_1_SQMUXA_1,
  O => GRLFPC20_COMB_WREN2_11_IV_0);
GRLFPC20_COMB_WREN1_11_IV_0_Z6126: LUT6 
generic map(
  INIT => X"101F000000000000"
)
port map (
  I0 => cpi_x_cnt(0),
  I1 => cpi_x_cnt(1),
  I2 => cpi_x_inst(20),
  I3 => cpi_x_inst(25),
  I4 => GRLFPC20_WREN1_0_SQMUXA_0,
  I5 => GRLFPC20_WREN2_1_SQMUXA_1,
  O => GRLFPC20_COMB_WREN1_11_IV_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq142z: LUT6_L 
generic map(
  INIT => X"CAFFCA000AFF0A00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(144),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_1,
  I4 => GRLFPC20_FPO_FRAC(31),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SELECTQUOBITS_QUOBITS(0),
  LO => N_3_87_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq141z: LUT6_L 
generic map(
  INIT => X"CAFFCA000AFF0A00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(143),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_1,
  I4 => GRLFPC20_FPO_FRAC(32),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_T_3(0),
  LO => N_3_86_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq172z: LUT5_L 
generic map(
  INIT => X"22F000F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => N_1211,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SELECTQUOBITS_QUOBITS(0),
  LO => N_3_67_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq171z: LUT5_L 
generic map(
  INIT => X"22F000F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => N_1212,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_T_3(0),
  LO => N_3_66_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_27q75z: LUT5 
generic map(
  INIT => X"FDA87520"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2187,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2180,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2194,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196);
GRLFPC20_RF2REN_1q1z: LUT5 
generic map(
  INIT => X"FCB83030"
)
port map (
  I0 => GRLFPC20_RS1D_1,
  I1 => holdn,
  I2 => GRLFPC20_R_A_RF2REN(1),
  I3 => GRLFPC20_RS1_1(0),
  I4 => GRLFPC20_V_A_RF1REN_1_0(1),
  O => RFI2_REN1_90);
GRLFPC20_RF1REN_1q1z: LUT5 
generic map(
  INIT => X"B8FC3030"
)
port map (
  I0 => GRLFPC20_RS1D_1,
  I1 => holdn,
  I2 => GRLFPC20_R_A_RF1REN(1),
  I3 => GRLFPC20_RS1_1(0),
  I4 => GRLFPC20_V_A_RF1REN_1_0(1),
  O => RFI1_REN1_64);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEWq8z_Z6134: LUT6 
generic map(
  INIT => X"FFFFFFFFFF50CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(8),
  I2 => GRLFPC20_R_FSR_RD(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(1),
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_RNDMODESELECT_UN1_TEMP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_SCTRL_26_0q0z: LUT6_L 
generic map(
  INIT => X"FF00FF00CDC8CFC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(27),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN1_AREGSIGN_SEL,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2772);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_11_RNOq0z: LUT5_L 
generic map(
  INIT => X"FF969600"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_56(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_2(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI45ITQ1q66z: LUT6 
generic map(
  INIT => X"BEEBEBBE28828228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_AXB1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(65));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIK7BDS1q316z: LUT6 
generic map(
  INIT => X"BEEBEBBE28828228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(64));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_RNID23N32: LUT6 
generic map(
  INIT => X"CDDFFEEC044CC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_5(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(63));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_UN609_TEMP_LUT6_2_RNIKB82F1: LUT6 
generic map(
  INIT => X"FFFF530053000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6106,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6105,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_138(31),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(81));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMPVLS1q77z: LUT6 
generic map(
  INIT => X"A8FE80EAFEA8EA80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_78(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(78));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5SD062q77z: LUT6 
generic map(
  INIT => X"A8FE80EAFEA8EA80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_77(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(77));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq334z: LUT3_L 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_132(37),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(75));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN561_TEMP_RNI6FFN22: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6114,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6115,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_129(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(72));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_RNI4LKG22: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6115,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6116,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_128(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(71));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_RNI1IT3V1: LUT6 
generic map(
  INIT => X"FFFF530053000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6117,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6116,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_SI_127(42),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(70));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_RNI0KP1G1: LUT6 
generic map(
  INIT => X"BEEBEBBE28828228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(69));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNICMLEK1q24z: LUT6 
generic map(
  INIT => X"BEEBEBBE28828228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_CI_37_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(95));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFQK6S1q95z: LUT6 
generic map(
  INIT => X"EFFEAEEA8AA80880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_CI_37_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_151(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(94));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIN7TDV1q93z: LUT6 
generic map(
  INIT => X"CDDFFEEC044CC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_35(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(93));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBOU7O1q90z: LUT6 
generic map(
  INIT => X"A880FEEAFEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_CI_34_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_91(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(91));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIA10C22q90z: LUT6 
generic map(
  INIT => X"A880FEEAFEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_90(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(90));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFD06E2q86z: LUT6 
generic map(
  INIT => X"A8FEFEA880EAEA80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_87(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(87));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_RNI0KB4Q1: LUT6 
generic map(
  INIT => X"BEEBEBBE28828228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(85));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_RNILLH0P1: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6102,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6103,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_SI_141(28),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(84));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_RNI03ULS1: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6103,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6104,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_140(29),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(83));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_RNI492FM1: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6104,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6105,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_SI_139(30),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(82));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL138K1q110z: LUT6 
generic map(
  INIT => X"EBBEEBBEEBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_108(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(109));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFLCP91q108z: LUT6 
generic map(
  INIT => X"CDDFFEEC044CC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_SI_50(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(108));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq366z: LUT3_L 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_164(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(107));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISTMQJ1q106z: LUT6 
generic map(
  INIT => X"AF8E8E0AFAE8E8A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_105(8),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(105));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4EU1E1q103z: LUT6 
generic map(
  INIT => X"A8FE80EAFEA8EA80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_SI_103(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(103));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPA9GQ1q101z: LUT6 
generic map(
  INIT => X"A880FEEAFEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_102(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(102));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUFHNV1q101z: LUT6 
generic map(
  INIT => X"A8FE80EAFEA8EA80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_101(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(101));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_RNI2PIPL1q8z: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6087,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6088,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_156(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(99));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNICL62L1q24z: LUT6 
generic map(
  INIT => X"AF8E8E0AFAE8E8A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_AXB2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_97(16),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(97));
GRLFPC20_V_A_ST_1_Z6167: LUT2_L 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_COMB_FPDECODE_ST,
  I1 => GRLFPC20_COMB_UN4_LOCK,
  LO => GRLFPC20_V_A_ST_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq113z: LUT6_L 
generic map(
  INIT => X"FC74B83000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2533,
  I3 => N_1210,
  I4 => N_1212,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_5_MUX_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq115z: LUT5_L 
generic map(
  INIT => X"CE020000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2471,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => N_5_MUX_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA_Z6170: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA);
GRLFPC20_LOCK_1: LUT5 
generic map(
  INIT => X"00000010"
)
port map (
  I0 => cpi_d_annul,
  I1 => cpi_d_trap,
  I2 => GRLFPC20_COMB_LOCKGEN_LOCKI,
  I3 => GRLFPC20_R_STATE(0),
  I4 => GRLFPC20_R_STATE(1),
  O => cpo_ldlock);
GRLFPC20_V_A_AFSR_1_0_A2: LUT5_L 
generic map(
  INIT => X"00008000"
)
port map (
  I0 => cpi_d_inst(24),
  I1 => cpi_d_inst(30),
  I2 => cpi_d_inst(31),
  I3 => GRLFPC20_V_A_AFSR_1_0_A2_2,
  I4 => GRLFPC20_COMB_UN4_LOCK,
  LO => GRLFPC20_V_A_AFSR_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq17z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFA0E4B1F5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_844,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1172,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1176,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1160,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_717,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1179_I);
GRLFPC20_RF2REN_1q2z: LUT5 
generic map(
  INIT => X"3030FCB8"
)
port map (
  I0 => GRLFPC20_RS2D_1,
  I1 => holdn,
  I2 => GRLFPC20_R_A_RF2REN(2),
  I3 => GRLFPC20_RS2_1(0),
  I4 => GRLFPC20_COMB_LOCKGEN_LOCKI,
  O => RFI2_REN2_91);
GRLFPC20_RF1REN_1q2z: LUT6 
generic map(
  INIT => X"0F000F008F80AFA0"
)
port map (
  I0 => GRLFPC20_RS2_0_SQMUXA,
  I1 => GRLFPC20_RS2D_1,
  I2 => holdn,
  I3 => GRLFPC20_R_A_RF1REN(2),
  I4 => GRLFPC20_RS2_1(0),
  I5 => GRLFPC20_COMB_LOCKGEN_LOCKI,
  O => RFI1_REN2_65);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5SD062_0q77z: LUT6 
generic map(
  INIT => X"56A96A95A956956A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_77(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_RNI4LKG22_0: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6115,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6116,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_128(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_RNI1IT3V1_0: LUT6 
generic map(
  INIT => X"5300ACFFACFF5300"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6117,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6116,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_SI_127(42),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_RNI0KP1G1_0: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITEGNM1_0q321z: LUT5 
generic map(
  INIT => X"A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_67(46),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_124(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNICMLEK1_0q24z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_CI_37_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFQK6S1_0q95z: LUT6 
generic map(
  INIT => X"9AA959956556A66A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_CI_37_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_151(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIN7TDV1_0q93z: LUT6 
generic map(
  INIT => X"366CC993C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_35(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBOU7O1_0q90z: LUT6 
generic map(
  INIT => X"566AA995A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_CI_34_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_91(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIA10C22_0q90z: LUT6 
generic map(
  INIT => X"566AA995A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_90(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFD06E2_0q86z: LUT6 
generic map(
  INIT => X"56A9A9566A95956A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_87(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_RNI0KB4Q1_0: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_RNILLH0P1_0: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6102,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6103,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_SI_141(28),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_RNI03ULS1_0: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6103,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6104,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_140(29),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL138K1_0q110z: LUT6 
generic map(
  INIT => X"9669966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_108(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFLCP91_0q108z: LUT6 
generic map(
  INIT => X"366CC993C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_SI_50(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISTMQJ1_0q106z: LUT6 
generic map(
  INIT => X"5A6969A5A596965A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_105(8),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4EU1E1_0q103z: LUT6 
generic map(
  INIT => X"56A96A95A956956A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_SI_103(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPA9GQ1_0q101z: LUT6 
generic map(
  INIT => X"566AA995A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_102(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUFHNV1_0q101z: LUT6 
generic map(
  INIT => X"56A96A95A956956A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_101(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNICL62L1_0q24z: LUT6 
generic map(
  INIT => X"5A6969A5A596965A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_AXB2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_97(16),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_0q3z: LUT6 
generic map(
  INIT => X"AAAAAAAA3CCCCCCC"
)
port map (
  I0 => cpi_d_inst(11),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2203);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_EXPBREGLOADEN: LUT6 
generic map(
  INIT => X"FFFCFF54FF00FF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(47),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(12),
  I5 => I2_I_4,
  O => N_6_MUX_39_I);
GRLFPC20_V_FSR_FTT_1_SQMUXA_RNIGJMT: LUT6 
generic map(
  INIT => X"CCCCCCCCCCCC0C4C"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => holdn,
  I2 => rst,
  I3 => GRLFPC20_V_FSR_FTT_1_SQMUXA,
  I4 => GRLFPC20_COMB_V_STATE14,
  I5 => GRLFPC20_COMB_UN1_R_I_EXC,
  O => N_683);
GRLFPC20_ANNULRES_1_IV_1: LUT6 
generic map(
  INIT => X"FFFFFF10FFFF1010"
)
port map (
  I0 => GRLFPC20_R_I_EXEC,
  I1 => GRLFPC20_R_X_FPOP,
  I2 => GRLFPC20_ANNULRES_0_SQMUXA_2_1,
  I3 => GRLFPC20_R_X_SEQERR,
  I4 => GRLFPC20_ANNULRES_1_IV_1_0,
  I5 => GRLFPC20_WREN2_1_SQMUXA_1,
  O => GRLFPC20_N_824_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_M4: LUT6 
generic map(
  INIT => X"000000000F0E0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q6z_Z6202: LUT6 
generic map(
  INIT => X"F5F30000F5F3FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q4z_Z6203: LUT6 
generic map(
  INIT => X"FFFFFF55FF33FF0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q12z_Z6204: LUT6 
generic map(
  INIT => X"DDF00000DDF0FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q47z_Z6205: LUT5 
generic map(
  INIT => X"00D8FFD8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q49z_Z6206: LUT5 
generic map(
  INIT => X"D800D8FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q51z_Z6207: LUT5 
generic map(
  INIT => X"00E2FFE2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q53z_Z6208: LUT5 
generic map(
  INIT => X"E200E2FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q57z_Z6209: LUT5 
generic map(
  INIT => X"005CFF5C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_I(53),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(55),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q56z_Z6210: LUT3 
generic map(
  INIT => X"27"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q54z_Z6211: LUT5 
generic map(
  INIT => X"E200E2FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(52),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(48),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q52z_Z6212: LUT6 
generic map(
  INIT => X"FA0AFA0AFCFC0C0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(52),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(46),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q50z_Z6213: LUT6 
generic map(
  INIT => X"F3F3C0C0EE22EE22"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(46),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q48z_Z6214: LUT6 
generic map(
  INIT => X"DD88DD88F5F5A0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(46),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q46z_Z6215: LUT6 
generic map(
  INIT => X"DD88DD88F5F5A0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(46),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q40z_Z6216: LUT6 
generic map(
  INIT => X"DD88DD88F5F5A0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(34),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(38),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q38z_Z6217: LUT6 
generic map(
  INIT => X"BB88BB88F3F3C0C0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(32),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(38),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q36z_Z6218: LUT6 
generic map(
  INIT => X"5F505F50CFCFC0C0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_105,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(36),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q34z_Z6219: LUT5 
generic map(
  INIT => X"0074FF74"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_105,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q27z_Z6220: LUT5 
generic map(
  INIT => X"E200E2FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(25),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(21),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(27),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q25z_Z6221: LUT6 
generic map(
  INIT => X"CCF0CCF0FFAA00AA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(25),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(21),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q10z_Z6222: LUT6 
generic map(
  INIT => X"0000DDF0FFFFDDF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114_0_A2q56z: LUT6 
generic map(
  INIT => X"D2FF2D002D00D2FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I4 => N_1381_I,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKPP9Rq316z: LUT5 
generic map(
  INIT => X"FCE8E8C0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_SI_62(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_5(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3_RNIA5D1A: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  I3 => N_1379_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBPRKQq274z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_21(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_RNINKSSP: LUT6 
generic map(
  INIT => X"CF8E8E0CFCE8E8C0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_SI_18(39),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_AXB1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNIS4VBMq51z: LUT6 
generic map(
  INIT => X"F6F9F9F660909060"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_RNOq68z: LUT4 
generic map(
  INIT => X"BE28"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITVD9A1q93z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_35(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_SI_92(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_RNIQVOGQ: LUT6 
generic map(
  INIT => X"C8FE80ECFEC8EC80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_31(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNIFF7USq35z: LUT6 
generic map(
  INIT => X"F6F9F9F660909060"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIEVEOPq337z: LUT4 
generic map(
  INIT => X"BE28"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPFRQSq108z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_SI_50(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_SI_107(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNI087PMq14z: LUT6 
generic map(
  INIT => X"F6F9F9F660909060"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(14),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0O27Pq100z: LUT6 
generic map(
  INIT => X"C880FEECFEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_42(15),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_AXB1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_RNINH4QJq6z: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6132,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6133,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_112(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_10: LUT6 
generic map(
  INIT => X"8124184200000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6314,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_25);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq5z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFEBA5410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1036,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1039,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1052,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_717,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1054_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq29z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFEAC86240"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_722,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_729,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_733,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1462,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_736_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq61z: LUT6_L 
generic map(
  INIT => X"0000000000000007"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_731,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_18_0(56),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3(61),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5(61),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6(61),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_2(61),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4485_I);
GRLFPC20_V_STATE_2_SQMUXA_Z6242: LUT6 
generic map(
  INIT => X"000000000000AABF"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_X_AFQ,
  I2 => GRLFPC20_N_329_2,
  I3 => GRLFPC20_R_X_SEQERR,
  I4 => GRLFPC20_COMB_V_STATE14,
  I5 => GRLFPC20_COMB_UN1_R_I_EXC,
  O => GRLFPC20_V_STATE_2_SQMUXA);
GRLFPC20_V_A_RF1REN_1_0q1z_Z6243: LUT6 
generic map(
  INIT => X"00000000FFFFFEF0"
)
port map (
  I0 => cpi_d_cnt(0),
  I1 => cpi_d_cnt(1),
  I2 => GRLFPC20_MOV_1_SQMUXA,
  I3 => GRLFPC20_RS1V_0_SQMUXA,
  I4 => GRLFPC20_RS1V_0_SQMUXA_1,
  I5 => GRLFPC20_COMB_LOCKGEN_LOCKI,
  O => GRLFPC20_V_A_RF1REN_1_0(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_25q75z: LUT6 
generic map(
  INIT => X"D8FAFAFAD8D8D8D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2190,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_O0_A3_1_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2194);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIDMF03q369z: LUT6 
generic map(
  INIT => X"FFFF2DD22DD20000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(369),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_RNINKSSP_0: LUT6 
generic map(
  INIT => X"3C6969C3C396963C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_SI_18(39),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_AXB1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_133(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNIS4VBM_0q51z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_SI_127(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_RNIQVOGQ_0: LUT6 
generic map(
  INIT => X"36C96C93C936936C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_31(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_146(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNIFF7US_0q35z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_143(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNI087PM_0q14z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(14),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_164(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0O27P_0q100z: LUT6 
generic map(
  INIT => X"366CC993C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_42(15),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_AXB1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_157(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0q50z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_774,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_775,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0(50),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_1(50),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4(50),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0q39z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF40"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3132_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_0_1(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1360,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_901,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_875,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(39));
GRLFPC20_RDD_1_M14: LUT4_L 
generic map(
  INIT => X"4000"
)
port map (
  I0 => cpi_d_inst(22),
  I1 => cpi_d_inst(24),
  I2 => cpi_d_inst(31),
  I3 => GRLFPC20_RDD_1_I9_MUX,
  LO => GRLFPC20_RDD_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_1q57z_Z6255: LUT5 
generic map(
  INIT => X"FFF2F2F2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(315),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_0_0(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN10_NOTPROP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_1(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq11z: LUT6_L 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3013,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_0(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_8_1(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1(11),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_1(11),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2985_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq48z: LUT6_L 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_1(48),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_0(48),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2(48),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5(48),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1(48),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3752_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q6z_Z6258: LUT4 
generic map(
  INIT => X"0A0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_18q75z: LUT6 
generic map(
  INIT => X"EEDEEDDD22122111"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(48),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2186,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2187);
GRLFPC20_RS1D_1_U: LUT6 
generic map(
  INIT => X"FF002020FF000000"
)
port map (
  I0 => cpi_d_inst(21),
  I1 => cpi_d_inst(22),
  I2 => cpi_d_inst(24),
  I3 => GRLFPC20_COMB_FPDECODE_RS1D5,
  I4 => GRLFPC20_MOV_1_SQMUXA,
  I5 => GRLFPC20_RS1D_CNST_M10_1,
  O => GRLFPC20_RS1D_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q55z_Z6261: LUT6 
generic map(
  INIT => X"0000FFFFFCAAFCAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(51),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q56z_Z6262: LUT6 
generic map(
  INIT => X"0000FFFF0CAA0CAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(52),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q49z_Z6263: LUT6 
generic map(
  INIT => X"CCCCF0F0FF00AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q33z_Z6264: LUT6 
generic map(
  INIT => X"AAAACCCCF0F0FF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q31z_Z6265: LUT6 
generic map(
  INIT => X"CCCCFF00AAAAF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q28z_Z6266: LUT6 
generic map(
  INIT => X"CCCCFF00AAAAF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q26z_Z6267: LUT6 
generic map(
  INIT => X"F0F0AAAACCCCFF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q13z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3176,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3172,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3180,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_1(13),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7(13),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q60z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_11_2(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1725,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4444,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4153,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_0(60),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_9(60),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q56z: LUT4_L 
generic map(
  INIT => X"FFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1602,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_1(56),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_10(56),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_2(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0q7z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF6000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1725,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_873,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(7),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_98: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(18),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(20),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(18),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(19),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(20),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_53);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_34: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(24),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(24),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(25),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_109);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_42: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_102);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_26: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(7),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_116);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_106: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(37),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(38),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(37),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_46);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_138: LUT6 
generic map(
  INIT => X"8040080420100201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(47),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(46),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(46),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(47),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_18);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_114: LUT6 
generic map(
  INIT => X"8040080420100201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(42),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(43),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_39);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_146: LUT6 
generic map(
  INIT => X"8040080420100201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(53),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(51),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(52),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_154: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(33),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(34),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_58: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(13),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(13),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(14),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_88);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_74: LUT6 
generic map(
  INIT => X"8020080240100401"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(55),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(54),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(55),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_74);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_66: LUT6 
generic map(
  INIT => X"8008200240041001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(32),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(31),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_81);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_82: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(16),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(15),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(16),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_67);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_90: LUT6 
generic map(
  INIT => X"8020080240100401"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(41),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(39),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_60);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0q12z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_773,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_1(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_836,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0(12),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0(12),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_130: LUT6 
generic map(
  INIT => X"8020401008020401"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(48),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(50),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(48),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_25);
GRLFPC20_COMB_LOCKGEN_LOCKI_F0: LUT6 
generic map(
  INIT => X"1110111011100000"
)
port map (
  I0 => cpi_d_cnt(0),
  I1 => cpi_d_cnt(1),
  I2 => GRLFPC20_COMB_FPDECODE_ST,
  I3 => GRLFPC20_COMB_SEQERR_UN7_OP,
  I4 => GRLFPC20_UN1_DEPCHECK_1,
  I5 => GRLFPC20_COMB_LOCKGEN_DEPCHECK,
  O => GRLFPC20_COMB_LOCKGEN_LOCKI);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_122: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(22),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(21),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(22),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_32);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_18: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(4),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_123);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q40z: LUT6 
generic map(
  INIT => X"0002090B04060D0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(18),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(19),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP_1_Z6292: LUT4 
generic map(
  INIT => X"0008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(68),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_0_RNOq57z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(369),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN18_STKGEN_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_1_Z6294: LUT6 
generic map(
  INIT => X"2DD2FFFFD22DFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(369),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN10_NOTPROP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3_RNILB453_0: LUT6 
generic map(
  INIT => X"3200003200323200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_57(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKC4GCq317z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(317),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(56),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIU4JGCq336z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(336),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(37),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_24(33),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6AGGCq330z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(330),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_RNI1QF3C: LUT6 
generic map(
  INIT => X"FFFF530053000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6229,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6228,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_17(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6NADCq326z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(326),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_SI_14(43),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN198_TEMP_LUT6_2_RNI5B1QA: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6235,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6236,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_SI_10(47),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_UN282_TEMP_LUT6_2_RNIGOP4C: LUT6 
generic map(
  INIT => X"FFFF530053000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6207,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6206,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_39(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIF31HCq347z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(347),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7NSGCq346z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(346),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_34(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_CI_34_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7IKHBq343z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(343),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFSPGCq340z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(340),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNICOOGCq340z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(340),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_28(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_CI_28_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQ8JMBq337z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(337),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL0GI9q366z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(366),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_SI_54(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI69O5A_0q110z: LUT6 
generic map(
  INIT => X"35CAFFFFCA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_SI_109(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI69O5Aq110z: LUT6 
generic map(
  INIT => X"CA35000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_SI_109(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRCAE9q362z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(362),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6N9E9q361z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(361),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_49(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIJKS99q358z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(358),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIDHT9Aq356z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(356),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHNFHAq355z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(355),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(18),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI00S2Cq355z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(355),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(18),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_SI_43(14),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_UN213_TEMP_LUT6_2_RNI9VK2C: LUT6 
generic map(
  INIT => X"FFFF350035000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6205,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6206,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_40(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIB8N79q366z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(366),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_50: LUT6 
generic map(
  INIT => X"8040201008040201"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(27),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(27),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(28),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_95);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_5: LUT3_L 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6314);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq51z: LUT6_L 
generic map(
  INIT => X"FEDC7654BA983210"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1057,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1067,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1072,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1059,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq18z: LUT6_L 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_378,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_384,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_390,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_399,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq32z: LUT5_L 
generic map(
  INIT => X"BAFE1054"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_488,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_495,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_513,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq33z: LUT5_L 
generic map(
  INIT => X"FEBA5410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_520,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_526,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_546,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq53z: LUT5_L 
generic map(
  INIT => X"FD75A820"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_569,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_579,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_561,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq3z: LUT6_L 
generic map(
  INIT => X"BF9D3715AE8C2604"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_709,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_714,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_715,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_694,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq28z: LUT6_L 
generic map(
  INIT => X"FDDD7555A8882000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_841,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_846_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_840,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq0z: LUT6_L 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_870,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_875_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_878,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_883,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq19z: LUT5_L 
generic map(
  INIT => X"FEBA5410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_891,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_901_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_917,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq25z: LUT6_L 
generic map(
  INIT => X"BAFE98DC32761054"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_922,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_928,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_936,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6370,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq55z: LUT5_L 
generic map(
  INIT => X"FEBA5410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_952,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_957,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_975,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq4z: LUT5_L 
generic map(
  INIT => X"A820FD75"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1026,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1031,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1020,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq26z: LUT6_L 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1076,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1079,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1085,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1089,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq38z: LUT6_L 
generic map(
  INIT => X"D9FB5173C8EA4062"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1119,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1123,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1126,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq30z: LUT6_L 
generic map(
  INIT => X"AEAAEEEA04004440"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_719,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1139,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1148,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq52z: LUT6_L 
generic map(
  INIT => X"FBBBEAAA51114000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_4,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_I6_MUX_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1183,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1202,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q49z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_343,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_0(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_1(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7(49),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q34z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3654,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3661,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0(34),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q36z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF2000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3712,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3601_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3(36),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_8(36),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_17q75z: LUT5_L 
generic map(
  INIT => X"0F87F087"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(48),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2186);
GRLFPC20_RDD_1_M11: LUT6 
generic map(
  INIT => X"0008000000081000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(21),
  I3 => cpi_d_inst(23),
  I4 => cpi_d_inst(30),
  I5 => GRLFPC20_RDD_1_N_20,
  O => GRLFPC20_RDD_1_I9_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq14z: LUT6_L 
generic map(
  INIT => X"7555311164442000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1271_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_699,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1270_MUX,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_694,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq2z: LUT6_L 
generic map(
  INIT => X"AEEEAAEA04440040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1095,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_MUX,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1274_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq43z: LUT5_L 
generic map(
  INIT => X"EEEA4440"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_739_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_788,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_749,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq22z: LUT6_L 
generic map(
  INIT => X"FD75DD55A8208800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3231_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_805,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_799,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq1z: LUT4_L 
generic map(
  INIT => X"AE04"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_818,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq24z: LUT6_L 
generic map(
  INIT => X"FD75DD55A8208800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3231_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_856,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_853,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq40z: LUT6_L 
generic map(
  INIT => X"FBBBEAAA51114000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1105,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1277_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1116,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq15z: LUT6_L 
generic map(
  INIT => X"EEAEEAAA44044000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_691,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_784,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1217,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIU4JGC_0q336z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(336),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(37),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_24(33),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_82(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6AGGC_0q330z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(330),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_77(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_UN282_TEMP_LUT6_2_RNIGOP4C_0: LUT6 
generic map(
  INIT => X"5300ACFFACFF5300"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6207,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6206,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_39(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_97(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7NSGC_0q346z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(346),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_34(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_SI_92(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFSPGC_0q340z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(340),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_87(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL0GI9_0q366z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(366),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_SI_54(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_112(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRCAE9_0q362z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(362),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_SI_109(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6N9E9_0q361z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(361),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_49(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_SI_107(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIDHT9A_0q356z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(356),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_SI_103(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI00S2C_0q355z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(355),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(18),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_SI_43(14),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_101(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_UN213_TEMP_LUT6_2_RNI9VK2C_0: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6205,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6206,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_40(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_98(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIB8N79_0q366z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(366),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_113(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15q16z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFB3B3A280"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_72_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_74_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_I8_MUX_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1(16),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0q45z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3035_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_MUX,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1335,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(45),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_873,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_58_0_A2q56z: LUT6 
generic map(
  INIT => X"C6FF39003900C6FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  I5 => N_1379_I,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_10: LUT6 
generic map(
  INIT => X"8020080240100401"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_130);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_0_0q57z_Z6367: LUT6 
generic map(
  INIT => X"0EFBFBFDFDF7F70E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(371),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(373),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_0_0(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q4z: LUT6 
generic map(
  INIT => X"0A0208000F070D05"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(56),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(54),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2_RNILCGN3q53z: LUT6 
generic map(
  INIT => X"050401000F0E0B0A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(54),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q3z: LUT6 
generic map(
  INIT => X"050F010B040E000A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(55),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2_RNIJAGN3q51z: LUT6 
generic map(
  INIT => X"0A0802000F0D0705"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(54),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(51),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq8z: LUT6_L 
generic map(
  INIT => X"AEEEAAEA04440040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_824,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_784,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq23z: LUT6_L 
generic map(
  INIT => X"EEEFAAAB44450001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_860,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_862,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_866,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq35z: LUT6_L 
generic map(
  INIT => X"B333A22291118000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1134,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1130,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1133,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(35));
GRLFPC20_R_I_RES_RNOq63z: LUT5_L 
generic map(
  INIT => X"11F022F0"
)
port map (
  I0 => cpi_a_inst(7),
  I1 => cpi_a_inst(8),
  I2 => GRLFPC20_FPO_SIGN,
  I3 => GRLFPC20_COMB_UN2_HOLDN,
  I4 => GRLFPC20_FPI_OP2(63),
  LO => N_3_0_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q62z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4581,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4585,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3(62),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(62),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(62),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2(62),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q63z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4624,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4623,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4627,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4628,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(63),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(63));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_34: LUT6 
generic map(
  INIT => X"8214000014820000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6306,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14q77z_Z6379: LUT6 
generic map(
  INIT => X"0202020000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(46),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXC,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_8q36z_Z6380: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3713,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3384_I_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3031_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_1(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2(36),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0(36),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_8(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_1q11z_Z6381: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4269_I_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_7_0(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3(11),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4(11),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_2q61z_Z6382: LUT4_L 
generic map(
  INIT => X"FFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_0(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1(61),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2(61),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4(61),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_2(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_9q60z_Z6383: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3225_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3795_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(60),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5(60),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_6_0(60),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(60),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_9(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1q7z_Z6384: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFF4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_788,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6345,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(7),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0(7),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2(7),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSTICKYINFORSR_2_1_Z6385: LUT6 
generic map(
  INIT => X"00550011005F0013"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN40_SHDVAR,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN17_SHDVAR,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSTICKYINFORSR_2_1);
GRLFPC20_WRDATAq58z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(26),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(55),
  I3 => GRLFPC20_R_I_RES(58),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(26));
GRLFPC20_WRDATAq25z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(25),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(25),
  I3 => GRLFPC20_R_I_RES(54),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(25));
GRLFPC20_WRDATAq62z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(30),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(59),
  I3 => GRLFPC20_R_I_RES(62),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(30));
GRLFPC20_WRDATAq0z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(0),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(0),
  I3 => GRLFPC20_R_I_RES(29),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(0));
GRLFPC20_WRDATAq61z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(29),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(58),
  I3 => GRLFPC20_R_I_RES(61),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(29));
GRLFPC20_WRDATAq60z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(28),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(57),
  I3 => GRLFPC20_R_I_RES(60),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(28));
GRLFPC20_WRDATAq59z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(27),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(56),
  I3 => GRLFPC20_R_I_RES(59),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(27));
GRLFPC20_WRDATAq57z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(25),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(54),
  I3 => GRLFPC20_R_I_RES(57),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(25));
GRLFPC20_WRDATAq56z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(24),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(53),
  I3 => GRLFPC20_R_I_RES(56),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(24));
GRLFPC20_WRDATAq55z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(23),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(52),
  I3 => GRLFPC20_R_I_RES(55),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(23));
GRLFPC20_WRDATAq54z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(22),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(51),
  I3 => GRLFPC20_R_I_RES(54),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(22));
GRLFPC20_WRDATAq53z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(21),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(50),
  I3 => GRLFPC20_R_I_RES(53),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(21));
GRLFPC20_WRDATAq52z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(20),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(49),
  I3 => GRLFPC20_R_I_RES(52),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(20));
GRLFPC20_WRDATAq51z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(19),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(48),
  I3 => GRLFPC20_R_I_RES(51),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(19));
GRLFPC20_WRDATAq50z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(18),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(47),
  I3 => GRLFPC20_R_I_RES(50),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(18));
GRLFPC20_WRDATAq49z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(17),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(46),
  I3 => GRLFPC20_R_I_RES(49),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(17));
GRLFPC20_WRDATAq48z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(16),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(45),
  I3 => GRLFPC20_R_I_RES(48),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(16));
GRLFPC20_WRDATAq47z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(15),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(44),
  I3 => GRLFPC20_R_I_RES(47),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(15));
GRLFPC20_WRDATAq46z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(14),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(43),
  I3 => GRLFPC20_R_I_RES(46),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(14));
GRLFPC20_WRDATAq45z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(13),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(42),
  I3 => GRLFPC20_R_I_RES(45),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(13));
GRLFPC20_WRDATAq44z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(12),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(41),
  I3 => GRLFPC20_R_I_RES(44),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(12));
GRLFPC20_WRDATAq43z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(11),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(40),
  I3 => GRLFPC20_R_I_RES(43),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(11));
GRLFPC20_WRDATAq42z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(10),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(39),
  I3 => GRLFPC20_R_I_RES(42),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(10));
GRLFPC20_WRDATAq41z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(9),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(38),
  I3 => GRLFPC20_R_I_RES(41),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(9));
GRLFPC20_WRDATAq40z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(8),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(37),
  I3 => GRLFPC20_R_I_RES(40),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(8));
GRLFPC20_WRDATAq39z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(7),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(36),
  I3 => GRLFPC20_R_I_RES(39),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(7));
GRLFPC20_WRDATAq38z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(6),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(35),
  I3 => GRLFPC20_R_I_RES(38),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(6));
GRLFPC20_WRDATAq37z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(5),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(34),
  I3 => GRLFPC20_R_I_RES(37),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(5));
GRLFPC20_WRDATAq36z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(4),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(33),
  I3 => GRLFPC20_R_I_RES(36),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(4));
GRLFPC20_WRDATAq35z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(3),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(32),
  I3 => GRLFPC20_R_I_RES(35),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(3));
GRLFPC20_WRDATAq34z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(2),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(31),
  I3 => GRLFPC20_R_I_RES(34),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(2));
GRLFPC20_WRDATAq33z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(1),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(30),
  I3 => GRLFPC20_R_I_RES(33),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(1));
GRLFPC20_WRDATAq32z: LUT5 
generic map(
  INIT => X"AAAAFC30"
)
port map (
  I0 => cpi_lddata(0),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(29),
  I3 => GRLFPC20_R_I_RES(32),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi1_wrdata(0));
GRLFPC20_WRDATAq31z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(31),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(31),
  I3 => GRLFPC20_R_I_RES(63),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(31));
GRLFPC20_WRDATAq30z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(30),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(30),
  I3 => GRLFPC20_R_I_RES(59),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(30));
GRLFPC20_WRDATAq29z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(29),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(29),
  I3 => GRLFPC20_R_I_RES(58),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(29));
GRLFPC20_WRDATAq28z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(28),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(28),
  I3 => GRLFPC20_R_I_RES(57),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(28));
GRLFPC20_WRDATAq27z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(27),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(27),
  I3 => GRLFPC20_R_I_RES(56),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(27));
GRLFPC20_WRDATAq26z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(26),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(26),
  I3 => GRLFPC20_R_I_RES(55),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(26));
GRLFPC20_WRDATAq24z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(24),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(24),
  I3 => GRLFPC20_R_I_RES(53),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(24));
GRLFPC20_WRDATAq23z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(23),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(23),
  I3 => GRLFPC20_R_I_RES(52),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(23));
GRLFPC20_WRDATAq22z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(22),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(22),
  I3 => GRLFPC20_R_I_RES(51),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(22));
GRLFPC20_WRDATAq21z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(21),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(21),
  I3 => GRLFPC20_R_I_RES(50),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(21));
GRLFPC20_WRDATAq20z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(20),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(20),
  I3 => GRLFPC20_R_I_RES(49),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(20));
GRLFPC20_WRDATAq19z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(19),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(19),
  I3 => GRLFPC20_R_I_RES(48),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(19));
GRLFPC20_WRDATAq18z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(18),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(18),
  I3 => GRLFPC20_R_I_RES(47),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(18));
GRLFPC20_WRDATAq17z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(17),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(17),
  I3 => GRLFPC20_R_I_RES(46),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(17));
GRLFPC20_WRDATAq16z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(16),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(16),
  I3 => GRLFPC20_R_I_RES(45),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(16));
GRLFPC20_WRDATAq15z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(15),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(15),
  I3 => GRLFPC20_R_I_RES(44),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(15));
GRLFPC20_WRDATAq14z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(14),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(14),
  I3 => GRLFPC20_R_I_RES(43),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(14));
GRLFPC20_WRDATAq13z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(13),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(13),
  I3 => GRLFPC20_R_I_RES(42),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(13));
GRLFPC20_WRDATAq12z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(12),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(12),
  I3 => GRLFPC20_R_I_RES(41),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(12));
GRLFPC20_WRDATAq11z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(11),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(11),
  I3 => GRLFPC20_R_I_RES(40),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(11));
GRLFPC20_WRDATAq10z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(10),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(10),
  I3 => GRLFPC20_R_I_RES(39),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(10));
GRLFPC20_WRDATAq9z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(9),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(9),
  I3 => GRLFPC20_R_I_RES(38),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(9));
GRLFPC20_WRDATAq8z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(8),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(8),
  I3 => GRLFPC20_R_I_RES(37),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(8));
GRLFPC20_WRDATAq7z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(7),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(7),
  I3 => GRLFPC20_R_I_RES(36),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(7));
GRLFPC20_WRDATAq6z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(6),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(6),
  I3 => GRLFPC20_R_I_RES(35),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(6));
GRLFPC20_WRDATAq5z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(5),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(5),
  I3 => GRLFPC20_R_I_RES(34),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(5));
GRLFPC20_WRDATAq4z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(4),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(4),
  I3 => GRLFPC20_R_I_RES(33),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(4));
GRLFPC20_WRDATAq3z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(3),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(3),
  I3 => GRLFPC20_R_I_RES(32),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(3));
GRLFPC20_WRDATAq2z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(2),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(2),
  I3 => GRLFPC20_R_I_RES(31),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(2));
GRLFPC20_WRDATAq1z: LUT5 
generic map(
  INIT => X"AAAAF3C0"
)
port map (
  I0 => cpi_lddata(1),
  I1 => GRLFPC20_COMB_RDD_2,
  I2 => GRLFPC20_R_I_RES(1),
  I3 => GRLFPC20_R_I_RES(30),
  I4 => GRLFPC20_WRADDR_0_SQMUXA,
  O => rfi2_wrdata(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_RNOq39z: LUT6_L 
generic map(
  INIT => X"77F755D522A20080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_76_0_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_74_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_73_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_875);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q6z: LUT6 
generic map(
  INIT => X"CD89EFAB45016723"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_330,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_334,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_340,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_346,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_348);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q6z: LUT6 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_353,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_359,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_365,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_368,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_370);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q27z: LUT6 
generic map(
  INIT => X"FEDC7654BA983210"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_406,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_414,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_419,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_I3_MUX_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_421);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q27z: LUT6 
generic map(
  INIT => X"DC98FEBA54107632"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_424,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_429,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_436,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_441,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_443);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q31z: LUT6 
generic map(
  INIT => X"76325410FEBADC98"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_448,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_451,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_455,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_458,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_460);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q31z: LUT6 
generic map(
  INIT => X"FEBA7632DC985410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_466,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_470,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_480,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6367,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_482);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q32z: LUT6_L 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_500,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_504,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_507,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_511,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_513);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q33z: LUT6_L 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_531,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_536,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_540,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_544,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_546);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q53z: LUT6_L 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_550,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_552,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_556,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_559,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_561);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q54z: LUT6 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_583,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_584,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_588,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_591,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_593);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q54z: LUT6 
generic map(
  INIT => X"CD89EFAB45016723"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_597,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_600,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_604,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_609,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_611);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q58z: LUT6 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_616,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_618,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_623,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_626,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_628);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q58z: LUT6 
generic map(
  INIT => X"DC98FEBA54107632"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_632,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_635,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_641_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_646,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_648);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q59z: LUT6 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_652,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_655,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_659,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_661,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_663);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q59z: LUT6 
generic map(
  INIT => X"DC98FEBA54107632"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_666,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_669,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_675_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_678,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_680);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q28z: LUT5_L 
generic map(
  INIT => X"FDA87520"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_838,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_836_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_804_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_840);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q19z: LUT6_L 
generic map(
  INIT => X"DC98FEBA54107632"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_905,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_907,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_912,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_915,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_917);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q55z: LUT6_L 
generic map(
  INIT => X"CD89EFAB45016723"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_962,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_965,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_969,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_973,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_975);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q57z: LUT6 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_980,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_982,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_986,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_989,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_991);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q57z: LUT6 
generic map(
  INIT => X"CD89EFAB45016723"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_995,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_997,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1002,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1005,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1007);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q4z: LUT6_L 
generic map(
  INIT => X"BFAE9D8C37261504"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_776,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1012,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1016,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1018,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1020);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q5z: LUT6 
generic map(
  INIT => X"EFABCD8967234501"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1042,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1044,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1047,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1050,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1052);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq42z: LUT6_L 
generic map(
  INIT => X"F7D57755A2802200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3231_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1102,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1243_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q30z: LUT6_L 
generic map(
  INIT => X"FDECB9A875643120"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_8_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_725,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1143,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1146,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1148);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q17z: LUT5 
generic map(
  INIT => X"AF8D2705"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1153,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1155,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1158,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1160);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q17z: LUT6 
generic map(
  INIT => X"DC98FEBA54107632"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1163,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1165,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1168,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1170,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1172);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q17z: LUT6 
generic map(
  INIT => X"EAFAC8D862724050"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_24_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1155,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1158,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1176);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q52z: LUT6_L 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1192,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1195,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1197,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1200,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1202);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8q57z_Z6478: LUT4 
generic map(
  INIT => X"DD0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8q41z_Z6479: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8q25z_Z6480: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8q23z_Z6481: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q45z_Z6482: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(47),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q44z_Z6483: LUT5 
generic map(
  INIT => X"A8FD2075"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(47),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q42z_Z6484: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(43),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q41z_Z6485: LUT5 
generic map(
  INIT => X"A820FD75"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q34z_Z6486: LUT5 
generic map(
  INIT => X"5140FBEA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q33z_Z6487: LUT6 
generic map(
  INIT => X"FE76BA32DC549810"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(35),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q32z_Z6488: LUT5 
generic map(
  INIT => X"A820FD75"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(35),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q31z_Z6489: LUT5 
generic map(
  INIT => X"5140FBEA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(31),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q30z_Z6490: LUT5 
generic map(
  INIT => X"A280F7D5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(31),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(30),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q27z_Z6491: LUT6 
generic map(
  INIT => X"F7B3D591E6A2C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(28),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(27),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q26z_Z6492: LUT6 
generic map(
  INIT => X"F7B3E6A2D591C480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(28),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(26),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(27),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q25z_Z6493: LUT6 
generic map(
  INIT => X"F7D5B391E6C4A280"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(28),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(26),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(27),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(25),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q21z_Z6494: LUT6 
generic map(
  INIT => X"FBD97351EAC86240"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(24),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q14z_Z6495: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(16),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(15),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q13z_Z6496: LUT5 
generic map(
  INIT => X"A820FD75"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(16),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q12z_Z6497: LUT5 
generic map(
  INIT => X"5140FBEA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q11z_Z6498: LUT5 
generic map(
  INIT => X"A280F7D5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q4z_Z6499: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q3z_Z6500: LUT5 
generic map(
  INIT => X"A820FD75"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8q50z_Z6501: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNID5T11q369z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(369),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56_1_CO0: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(310),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(368),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIN33I4_0q262z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(262),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(320),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBDKM4_0q261z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(261),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(319),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI68KM4_0q260z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(260),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(318),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5ERM4_0q277z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(277),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(335),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2TSK4_0q275z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(275),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(333),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMUQM4_0q274z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(274),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(332),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHPQM4_0q273z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(273),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(331),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI48524q330z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(330),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIGNPM4_0q271z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(271),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(329),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_RNIH2MC7: LUT5 
generic map(
  INIT => X"ACFF5300"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6229,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6228,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_17(40),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBIPM4_0q270z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(270),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(328),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUR1K4_0q269z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(269),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(327),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBADM4_0q267z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(267),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(325),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNICIB63q49z: LUT6 
generic map(
  INIT => X"AF0ABB22AA00AA00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6291,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6292,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN198_TEMP_LUT6_2_RNIV2UN6: LUT5 
generic map(
  INIT => X"CAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6235,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6236,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_SI_10(47),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRD5N4_0q293z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(293),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(351),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4TFI4_0q292z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(292),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(350),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL64N4_0q290z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(290),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(348),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAO0N4_0q287z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(287),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(345),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMLS14q343z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(343),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIR80N4_0q284z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(284),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(342),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO_RNIDSO38_0: LUT6 
generic map(
  INIT => X"5A3CFFFFA5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_30(27),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO_RNIDSO38: LUT6 
generic map(
  INIT => X"A5C3000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_30(27),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AC0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIM30N4_0q283z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(283),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(341),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL1VM4_0q281z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(281),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(339),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIOOGV3q338z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(338),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIK9PO3_0q307z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(307),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(365),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMU9D3_0q305z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(305),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(363),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISMQ53q362z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(362),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7F9D3_0q302z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(302),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(360),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6VE53q359z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(359),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4TE53q358z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(358),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILQMQ3_0q299z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(299),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(357),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRB1K3q356z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(356),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAT5N4_0q296z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(296),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(354),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7KEK4_0q294z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(294),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(352),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIO2CD3_0q309z: LUT6 
generic map(
  INIT => X"00CC0FEE00000088"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(309),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(367),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_2_RNISASU3: LUT6 
generic map(
  INIT => X"2000000022222222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(67),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1205,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_26: LUT6 
generic map(
  INIT => X"8214148200000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(8),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6308,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_11);
GRLFPC20_RS1D_CNST_M10_1_Z6543: LUT6 
generic map(
  INIT => X"0810000008000000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(23),
  I3 => cpi_d_inst(30),
  I4 => cpi_d_inst(31),
  I5 => GRLFPC20_COMB_FPDECODE_RDD5,
  O => GRLFPC20_RS1D_CNST_M10_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOINq0z_Z6544: LUT6 
generic map(
  INIT => X"00F1F1F5F5F7F7FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(371),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(373),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXC_Z6545: LUT6 
generic map(
  INIT => X"0001FFFFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1(4),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXC);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULTq2z_Z6546: LUT6 
generic map(
  INIT => X"000000000001FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1(4),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq47z: LUT6_L 
generic map(
  INIT => X"B9A8998831201100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_777,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_784,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_74_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq21z: LUT5_L 
generic map(
  INIT => X"2A220800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_788_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q22z: LUT5_L 
generic map(
  INIT => X"A8B92031"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1255_MUX_I,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_792,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_797,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_799);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq41z: LUT6_L 
generic map(
  INIT => X"F5D57555A0802000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_808_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_810,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_73_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q24z: LUT6_L 
generic map(
  INIT => X"C8EAD9FB40625173"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_828,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1241_MUX,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_792,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_797,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_853);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q40z: LUT6_L 
generic map(
  INIT => X"80880008D5DD555D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1113,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_120_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1112,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1116);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_RNOq12z: LUT6 
generic map(
  INIT => X"F700A200D5008000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_59_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_56_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_57_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_773);
GRLFPC20_V_I_EXC_1q2z_Z6554: LUT6_L 
generic map(
  INIT => X"0000002000200020"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_128,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2_4(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3_4(2),
  LO => GRLFPC20_V_I_EXC_1(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4q34z_Z6555: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3343_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3026_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3q36z_Z6556: LUT6 
generic map(
  INIT => X"FFFFFFFFF0F0F040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3124_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6065_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_9_1(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3727_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7q49z_Z6557: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3858,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3853,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3860,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_1(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(49),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7q13z_Z6558: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3177_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3199,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3178,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(13),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(13),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1q48z_Z6559: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF5040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4_0(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_7_0(48),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_10q56z_Z6560: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFFF08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_9_0(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0(56),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_9(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_10(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4q50z_Z6561: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3035_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1259_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4_0(50),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(50),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_25_RNOq75z: LUT4_L 
generic map(
  INIT => X"FE00"
)
port map (
  I0 => N_1265,
  I1 => N_1266,
  I2 => GRLFPC20_FPO_FRAC(54),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_O0_A3_1_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_O0_A3_1_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_RNIG89V: LUT5 
generic map(
  INIT => X"2D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(370),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_RNOq0z: LUT6 
generic map(
  INIT => X"22EE22EE22EE22E2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK,
  I2 => N_1198,
  I3 => N_1199,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN21_LOCOV,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(0));
GRLFPC20_RS1_1q0z_Z6565: LUT6 
generic map(
  INIT => X"CA0ACF0FCA0AC000"
)
port map (
  I0 => cpi_d_inst(14),
  I1 => cpi_d_inst(25),
  I2 => GRLFPC20_RS1_1_SN_N_3,
  I3 => GRLFPC20_RS1V_0_SQMUXA,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS1(0),
  O => GRLFPC20_RS1_1(0));
GRLFPC20_RS1_1q1z: LUT6 
generic map(
  INIT => X"CA0ACF0FCA0AC000"
)
port map (
  I0 => cpi_d_inst(15),
  I1 => cpi_d_inst(26),
  I2 => GRLFPC20_RS1_1_SN_N_3,
  I3 => GRLFPC20_RS1V_0_SQMUXA,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS1(1),
  O => RFI2_RD1ADDR_70);
GRLFPC20_RS1_1q2z: LUT6 
generic map(
  INIT => X"CA0ACF0FCA0AC000"
)
port map (
  I0 => cpi_d_inst(16),
  I1 => cpi_d_inst(27),
  I2 => GRLFPC20_RS1_1_SN_N_3,
  I3 => GRLFPC20_RS1V_0_SQMUXA,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS1(2),
  O => RFI2_RD1ADDR_71);
GRLFPC20_RS1_1q3z: LUT6 
generic map(
  INIT => X"CA0ACF0FCA0AC000"
)
port map (
  I0 => cpi_d_inst(17),
  I1 => cpi_d_inst(28),
  I2 => GRLFPC20_RS1_1_SN_N_3,
  I3 => GRLFPC20_RS1V_0_SQMUXA,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS1(3),
  O => RFI2_RD1ADDR_72);
GRLFPC20_RS1_1q4z: LUT6 
generic map(
  INIT => X"CA0ACF0FCA0AC000"
)
port map (
  I0 => cpi_d_inst(18),
  I1 => cpi_d_inst(29),
  I2 => GRLFPC20_RS1_1_SN_N_3,
  I3 => GRLFPC20_RS1V_0_SQMUXA,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS1(4),
  O => RFI2_RD1ADDR_73);
GRLFPC20_V_E_STDATA_1_2q1z: LUT6_L 
generic map(
  INIT => X"44F044FF44F04400"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_INST(1),
  I2 => GRLFPC20_R_FSR_CEXC(1),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(33),
  LO => GRLFPC20_N_596);
GRLFPC20_V_E_STDATA_1_2q0z: LUT6_L 
generic map(
  INIT => X"44F044FF44F04400"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_INST(0),
  I2 => GRLFPC20_R_FSR_CEXC(0),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(32),
  LO => GRLFPC20_N_595);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATHq375z_Z6572: LUT5_L 
generic map(
  INIT => X"0D000070"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTDIVISORBIT,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(3),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH(375));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIN33I4q262z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(262),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(320),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_9(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBDKM4q261z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(261),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(319),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_SI_8(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI68KM4q260z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(260),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(318),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_SI_7(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIGK524q336z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(336),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(37),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_SI_25(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5ERM4q277z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(277),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(335),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_24(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2TSK4q275z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(275),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(333),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_22(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMUQM4q274z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(274),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(332),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_21(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHPQM4q273z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(273),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(331),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_20(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIGNPM4q271z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(271),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(329),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_SI_18(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBIPM4q270z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(270),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(328),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_17(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUR1K4q269z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(269),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(327),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_16(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBADM4q267z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(267),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(325),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_SI_14(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRD5N4q293z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(293),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(351),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_40(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4TFI4q292z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(292),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(350),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_39(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL64N4q290z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(290),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(348),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_SI_37(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIIO724q346z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(346),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_35(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAO0N4q287z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(287),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(345),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_34(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIR80N4q284z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(284),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(342),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_31(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIM30N4q283z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(283),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(341),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_30(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL1VM4q281z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(281),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(339),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_28(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIK9PO3q307z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(307),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(365),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_SI_54(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMU9D3q305z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(305),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(363),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQKQ53q361z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(361),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_SI_50(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7F9D3q302z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(302),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(360),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_49(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILQMQ3q299z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(299),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(357),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_46(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAT5N4q296z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(296),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(354),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_SI_43(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7KEK4q294z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(294),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(352),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_41(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIO2CD3q309z: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(309),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(367),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_56(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0q44z: LUT6_L 
generic map(
  INIT => X"FFFFFFFF2A220800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_201_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_MUX,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(44),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATHq374z_Z6602: LUT5_L 
generic map(
  INIT => X"02FFFF80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTDIVISORBIT,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(3),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH(374));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT_Z6603: LUT6 
generic map(
  INIT => X"0000551000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_WQSTSETS(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_18: LUT6 
generic map(
  INIT => X"2814000014280000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_13_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6312,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(9),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_N_18);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_1q50z_Z6605: LUT6 
generic map(
  INIT => X"FFFFFFFFF8F08800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4139_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1705,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_844,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3199,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_1(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1q16z_Z6606: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3853_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4527,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_0_0(16),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1_0(16),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1(16));
GRLFPC20_R_I_RDD_RNO: LUT6_L 
generic map(
  INIT => X"5050D8505050D0D0"
)
port map (
  I0 => holdn,
  I1 => rst,
  I2 => GRLFPC20_R_I_RDD,
  I3 => GRLFPC20_R_X_RDD,
  I4 => GRLFPC20_N_826,
  I5 => GRLFPC20_V_I_EXEC_0_SQMUXA,
  LO => GRLFPC20_R_I_RDD_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17q0z_Z6608: LUT6_L 
generic map(
  INIT => X"AFBBFFFFAFBBAAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS6,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS9,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2166,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M12(0),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17(0));
GRLFPC20_V_E_STDATA_1_2q17z: LUT6_L 
generic map(
  INIT => X"E4FFE4FFE4FFE400"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_INST(17),
  I2 => GRLFPC20_R_I_PC(17),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(49),
  LO => GRLFPC20_N_612);
GRLFPC20_V_E_STDATA_1_2q21z: LUT6_L 
generic map(
  INIT => X"E400E4FFE400E400"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_INST(21),
  I2 => GRLFPC20_R_I_PC(21),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(53),
  LO => GRLFPC20_N_616);
GRLFPC20_V_E_STDATA_1_2q29z: LUT6_L 
generic map(
  INIT => X"D800D8FFD800D800"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_PC(29),
  I2 => GRLFPC20_R_I_INST(29),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(61),
  LO => GRLFPC20_N_624);
GRLFPC20_V_E_STDATA_1_2q28z: LUT6_L 
generic map(
  INIT => X"D800D8FFD800D800"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_PC(28),
  I2 => GRLFPC20_R_I_INST(28),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(60),
  LO => GRLFPC20_N_623);
GRLFPC20_V_E_STDATA_1_2q20z: LUT6_L 
generic map(
  INIT => X"E400E4FFE400E400"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_INST(20),
  I2 => GRLFPC20_R_I_PC(20),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(52),
  LO => GRLFPC20_N_615);
GRLFPC20_V_E_STDATA_1_2q19z: LUT6_L 
generic map(
  INIT => X"D800D8FFD800D800"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_PC(19),
  I2 => GRLFPC20_R_I_INST(19),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(51),
  LO => GRLFPC20_N_614);
GRLFPC20_V_E_STDATA_1_2q18z: LUT6_L 
generic map(
  INIT => X"E4FFE4FFE4FFE400"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_INST(18),
  I2 => GRLFPC20_R_I_PC(18),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(50),
  LO => GRLFPC20_N_613);
GRLFPC20_V_E_STDATA_1_2q12z: LUT6_L 
generic map(
  INIT => X"E400E4FFE400E400"
)
port map (
  I0 => GRLFPC20_COMB_V_E_STDATA2,
  I1 => GRLFPC20_R_I_INST(12),
  I2 => GRLFPC20_R_I_PC(12),
  I3 => GRLFPC20_R_A_AFQ,
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_FPI_OP1(44),
  LO => GRLFPC20_N_607);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q3z: LUT6 
generic map(
  INIT => X"7F7FFFFBBFBA5F7F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_709);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIDHNM5q79z: LUT6 
generic map(
  INIT => X"5554111045440100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3858_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_690,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_746_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q23z: LUT6_L 
generic map(
  INIT => X"9A988A8812100200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_55_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_804_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_866);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q26z: LUT6 
generic map(
  INIT => X"0001000C802A0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1085);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL_Z6621: LUT6 
generic map(
  INIT => X"FFFFFFFE00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3(5),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_DIVMULTVq0z_Z6622: LUT4_L 
generic map(
  INIT => X"4002"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(3),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_DIVMULTV(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q46z_Z6623: LUT6 
generic map(
  INIT => X"FE5EF454AE0EA404"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(46),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q41z_Z6624: LUT6 
generic map(
  INIT => X"FFAAD8D85500D8D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(41),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(47),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q39z_Z6625: LUT5 
generic map(
  INIT => X"A088F5DD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(41),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(39),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q38z_Z6626: LUT5 
generic map(
  INIT => X"A088F5DD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q37z_Z6627: LUT5 
generic map(
  INIT => X"5044FAEE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(37),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(41),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(39),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q35z_Z6628: LUT5 
generic map(
  INIT => X"A088F5DD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(37),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(41),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q32z_Z6629: LUT5 
generic map(
  INIT => X"5044FAEE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q16z_Z6630: LUT5 
generic map(
  INIT => X"A088F5DD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(18),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(22),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q15z_Z6631: LUT6 
generic map(
  INIT => X"77772222FA50FA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_111,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(19),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q13z_Z6632: LUT6 
generic map(
  INIT => X"FFAA5500E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(13),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(19),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q8z_Z6633: LUT5 
generic map(
  INIT => X"5011FABB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_115,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q6z_Z6634: LUT5 
generic map(
  INIT => X"A022F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_115,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q3z_Z6635: LUT6 
generic map(
  INIT => X"5500FFAAE4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(7),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_114,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q2z_Z6636: LUT5 
generic map(
  INIT => X"5044FAEE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q0z_Z6637: LUT5 
generic map(
  INIT => X"A088F5DD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIJMEA1q11z: LUT6 
generic map(
  INIT => X"FCFA00000C0A0000"
)
port map (
  I0 => rfo1_data2(11),
  I1 => rfo2_data2(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q12z: LUT6 
generic map(
  INIT => X"FCFA00000C0A0000"
)
port map (
  I0 => rfo1_data2(10),
  I1 => rfo2_data2(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIDGEA1q11z: LUT6 
generic map(
  INIT => X"CFAF0000C0A00000"
)
port map (
  I0 => rfo1_data2(11),
  I1 => rfo2_data2(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(40),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(14));
GRLFPC20_R_I_RES_RNOq59z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(30),
  I1 => rfo2_data2(30),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(7),
  LO => N_3_1_I);
GRLFPC20_R_I_RES_RNOq58z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(29),
  I1 => rfo2_data2(29),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(6),
  LO => N_3_2_I);
GRLFPC20_R_I_RES_RNOq57z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(28),
  I1 => rfo2_data2(28),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(5),
  LO => N_3_3_I);
GRLFPC20_R_I_RES_RNOq56z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(27),
  I1 => rfo2_data2(27),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(4),
  LO => N_3_4_I);
GRLFPC20_R_I_RES_RNOq55z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(26),
  I1 => rfo2_data2(26),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(3),
  LO => N_3_5_I);
GRLFPC20_R_I_RES_RNOq54z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(25),
  I1 => rfo2_data2(25),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(2),
  LO => N_3_6_I);
GRLFPC20_R_I_RES_RNOq53z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(24),
  I1 => rfo2_data2(24),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(1),
  LO => N_3_7_I);
GRLFPC20_R_I_RES_RNOq52z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(23),
  I1 => rfo2_data2(23),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_EXP(0),
  LO => N_3_8_I);
GRLFPC20_R_I_RES_RNOq40z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(11),
  I1 => rfo2_data2(11),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(43),
  LO => N_3_20_I);
GRLFPC20_R_I_RES_RNOq39z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(10),
  I1 => rfo2_data2(10),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(42),
  LO => N_3_21_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0q34z_Z6651: LUT6_L 
generic map(
  INIT => X"FFFFFFFF80C00040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1277_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3343_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(34),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_0q49z_Z6652: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3854,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_0(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_1q49z_Z6653: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF2000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_4,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3827_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3852,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_1(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_1q13z_Z6654: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3071_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6065_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3185,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_1(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_7_0q48z_Z6655: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF40"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3031_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3803,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3782,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0(48),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_7_0(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6_1q61z_Z6656: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4637,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3425_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4520,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4522,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4518,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6_1(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_6_0q60z_Z6657: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF0400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4431_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3026_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4452,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(60),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_6_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_0q60z_Z6658: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_21_1(60),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_24_0(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(60),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0(60),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_0q56z_Z6659: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF0080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3601_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_9q56z_Z6660: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF0020"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4635_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4138_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_6_0(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_9(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0q7z_Z6661: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF1000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3340_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1631,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_25_RNO_0q75z: LUT6_L 
generic map(
  INIT => X"0000000000000002"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS,
  I2 => N_1198,
  I3 => N_1199,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN21_LOCOV,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_O0_A3_1_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_WQSTSETSq0z_Z6663: LUT6_L 
generic map(
  INIT => X"55D5555500800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2164_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN11_WQSTSETS,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_WQSTSETS(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_10q84z: LUT6_L 
generic map(
  INIT => X"0200000000158480"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1213);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1_0_A2: LUT6 
generic map(
  INIT => X"3CC396693C3C3C3C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56_1_SUM0_0_A2: LUT6 
generic map(
  INIT => X"FF33F09900CC0F66"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(310),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(368),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_57(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1q11z_Z6667: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFC400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_141_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3347_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3021,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q238z_Z6668: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(26),
  I1 => rfo1_data2(29),
  I2 => rfo2_data2(26),
  I3 => rfo2_data2(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(238));
GRLFPC20_MOV_5_SQMUXA_Z6669: LUT6_L 
generic map(
  INIT => X"5540000000000000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_1,
  I2 => GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_2,
  I3 => GRLFPC20_COMB_FPDECODE_UN1_FPCI_3,
  I4 => GRLFPC20_MOV_0_SQMUXA_4,
  I5 => GRLFPC20_V_A_AFSR_1_4,
  LO => GRLFPC20_MOV_5_SQMUXA);
GRLFPC20_UN1_DEPCHECK_1_Z6670: LUT6 
generic map(
  INIT => X"EEEEEEEEEEEEEEE0"
)
port map (
  I0 => GRLFPC20_COMB_FPDECODE_ST,
  I1 => GRLFPC20_RS2_0_SQMUXA,
  I2 => GRLFPC20_R_A_LD,
  I3 => GRLFPC20_R_E_LD,
  I4 => GRLFPC20_R_M_LD,
  I5 => GRLFPC20_R_X_LD,
  O => GRLFPC20_UN1_DEPCHECK_1);
GRLFPC20_V_E_STDATA_1_1q3z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(3),
  I1 => rfo2_data1(3),
  I2 => GRLFPC20_R_FSR_CEXC(3),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_565);
GRLFPC20_V_E_STDATA_1_1q31z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(31),
  I1 => rfo2_data1(31),
  I2 => GRLFPC20_R_FSR_RD(1),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_593);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q240z_Z6673: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(24),
  I1 => rfo1_data2(27),
  I2 => rfo2_data2(24),
  I3 => rfo2_data2(27),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(240));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14q1z_Z6674: LUT6_L 
generic map(
  INIT => X"FF00C3C3FF00AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2164_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M13(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14(1));
GRLFPC20_V_E_STDATA_1_1q9z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(9),
  I1 => rfo2_data1(9),
  I2 => GRLFPC20_R_FSR_AEXC(4),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_571);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q72z_Z6676: LUT5 
generic map(
  INIT => X"CFC0AFA0"
)
port map (
  I0 => rfo1_data1(11),
  I1 => rfo2_data1(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_OP1(40),
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(72));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q66z_Z6677: LUT5 
generic map(
  INIT => X"FC0CFA0A"
)
port map (
  I0 => rfo1_data1(14),
  I1 => rfo2_data1(14),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_OP1(49),
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(66));
GRLFPC20_V_E_STDATA_1_1q14z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(14),
  I1 => rfo2_data1(14),
  I2 => GRLFPC20_R_FSR_FTT(0),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_576);
GRLFPC20_V_E_STDATA_1_1q26z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(26),
  I1 => rfo2_data1(26),
  I2 => GRLFPC20_R_FSR_TEM(3),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_588);
GRLFPC20_V_E_STDATA_1_1q23z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(23),
  I1 => rfo2_data1(23),
  I2 => GRLFPC20_R_FSR_TEM(0),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_585);
GRLFPC20_V_E_STDATA_1_1q6z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(6),
  I1 => rfo2_data1(6),
  I2 => GRLFPC20_R_FSR_AEXC(1),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_568);
GRLFPC20_V_E_STDATA_1_1q11z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(11),
  I1 => rfo2_data1(11),
  I2 => CPO_CC_2,
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_573);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41q254z_Z6683: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data1(23),
  I1 => rfo1_data1(26),
  I2 => rfo2_data1(23),
  I3 => rfo2_data1(26),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41(254));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41q251z_Z6684: LUT5 
generic map(
  INIT => X"FC0CFA0A"
)
port map (
  I0 => rfo1_data1(26),
  I1 => rfo2_data1(26),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_OP1(61),
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41(251));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q237z_Z6685: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(27),
  I1 => rfo1_data2(30),
  I2 => rfo2_data2(27),
  I3 => rfo2_data2(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(237));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q239z_Z6686: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(25),
  I1 => rfo1_data2(28),
  I2 => rfo2_data2(25),
  I3 => rfo2_data2(28),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(239));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q241z_Z6687: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(23),
  I1 => rfo1_data2(26),
  I2 => rfo2_data2(23),
  I3 => rfo2_data2(26),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(241));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q80z_Z6688: LUT5 
generic map(
  INIT => X"CFC0AFA0"
)
port map (
  I0 => rfo1_data1(3),
  I1 => rfo2_data1(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_OP1(32),
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(80));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41q257z_Z6689: LUT5 
generic map(
  INIT => X"CFC0AFA0"
)
port map (
  I0 => rfo1_data1(23),
  I1 => rfo2_data1(23),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_OP1(52),
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41(257));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q74z_Z6690: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data1(6),
  I1 => rfo1_data1(9),
  I2 => rfo2_data1(6),
  I3 => rfo2_data1(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(74));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q69z_Z6691: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data1(11),
  I1 => rfo1_data1(14),
  I2 => rfo2_data1(11),
  I3 => rfo2_data1(14),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(69));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q71z_Z6692: LUT5 
generic map(
  INIT => X"FC0CFA0A"
)
port map (
  I0 => rfo1_data1(9),
  I1 => rfo2_data1(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_OP1(44),
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(71));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q77z_Z6693: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data1(3),
  I1 => rfo1_data1(6),
  I2 => rfo2_data1(3),
  I3 => rfo2_data1(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(77));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNO_0q13z: LUT5 
generic map(
  INIT => X"33550F0F"
)
port map (
  I0 => rfo1_data1(31),
  I1 => rfo2_data1(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I3 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  I4 => GRLFPC20_FPI_LDOP,
  O => N_3_39);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMPq1z_Z6695: LUT6 
generic map(
  INIT => X"FFFEFFFAFFFCFFF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN3_XZYBUSLSBS,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_XZYBUSLSBS,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZYBUS24_SN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN17_SHDVAR_Z6696: LUT6 
generic map(
  INIT => X"5000000030000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN17_SHDVAR);
GRLFPC20_RDD_1_M4_E: LUT6 
generic map(
  INIT => X"00007FFF00000000"
)
port map (
  I0 => cpi_d_inst(8),
  I1 => cpi_d_inst(11),
  I2 => GRLFPC20_COMB_FPDECODE_RDD2_1,
  I3 => GRLFPC20_COMB_FPDECODE_RDD2_2,
  I4 => GRLFPC20_COMB_FPDECODE_RDD4,
  I5 => GRLFPC20_RDD_1_N_20_2,
  O => GRLFPC20_RDD_1_N_20);
GRLFPC20_UN1_RDD3_Z6698: LUT6 
generic map(
  INIT => X"FFFFFFF1FFFFFFF0"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(7),
  I2 => GRLFPC20_COMB_FPDECODE_RDD4,
  I3 => GRLFPC20_COMB_FPDECODE_RDD5,
  I4 => GRLFPC20_COMB_FPDECODE_UN1_FPCI_1,
  I5 => GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_4,
  O => GRLFPC20_UN1_RDD3);
GRLFPC20_COMB_SEQERR_UN11_OP_Z6699: LUT6 
generic map(
  INIT => X"0000000B00000000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(21),
  I3 => cpi_d_inst(22),
  I4 => cpi_d_inst(23),
  I5 => cpi_d_inst(24),
  O => GRLFPC20_COMB_SEQERR_UN11_OP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMPq0z_Z6700: LUT6 
generic map(
  INIT => X"FFFEFFFAFFFEFFAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN26_XZYBUSLSBS,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZYBUS24_SN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_EXTEND_TEMP(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1q4z_Z6701: LUT6 
generic map(
  INIT => X"0000000000015555"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0q34z_Z6702: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFEA00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3644_I,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3179_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3667,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1q34z_Z6703: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3672,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_1(34),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0q36z_Z6704: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF1000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1367,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3734,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1q36z_Z6705: LUT6_L 
generic map(
  INIT => X"FFFFFFFF8C0C8800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3702_I_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3029_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4150_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1739,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3731,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2q36z_Z6706: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4150_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3347_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0q62z_Z6707: LUT6 
generic map(
  INIT => X"FFFFFFFF01000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3923_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4566_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4479_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(62),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0q11z_Z6708: LUT6 
generic map(
  INIT => X"FFFFFFFF00000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0_0(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3q11z_Z6709: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_748_I,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3078_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3015,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3036,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4q11z_Z6710: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFF080808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_22_1(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3012,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1q13z_Z6711: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3186_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3294_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3340_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3188,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0q48z_Z6712: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFFFF80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4431_I_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3031_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3794,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3799,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4529,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2q48z_Z6713: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF0400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3297_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3186_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3601_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3793,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_0(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5q48z_Z6714: LUT6 
generic map(
  INIT => X"FFFFFFFF5A405A00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3753_I,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_0(63),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_1(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6q48z_Z6715: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFF080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_I_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3795_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3790,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3789,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_1q48z_Z6716: LUT6 
generic map(
  INIT => X"FFFFFFFFA0002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1259_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3801,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_1(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2q61z_Z6717: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3340_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3132_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4534,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_1(61),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_0q61z_Z6718: LUT6 
generic map(
  INIT => X"FCF4F0F0CC440000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3425_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3132_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_3_1(61),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_0(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5q60z_Z6719: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFC080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1766,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4449,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4448,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1q44z_Z6720: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3246_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1343,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1341,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1q56z_Z6721: LUT6_L 
generic map(
  INIT => X"FFFFFFFF00040000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3096_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5q56z_Z6722: LUT6_L 
generic map(
  INIT => X"FFFFFFFF20000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3281_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_0(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0q12z_Z6723: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1244_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3548_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1462,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(12),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0q12z_Z6724: LUT6 
generic map(
  INIT => X"FFFFFFFFE4000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_38_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6365,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3231_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1602,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1q50z_Z6725: LUT5_L 
generic map(
  INIT => X"FFFFFF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_943,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1731,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0(50),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3866,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2q7z_Z6726: LUT6_L 
generic map(
  INIT => X"FFFFFFFFF222F000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3548_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_8_0(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3199,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1831,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1630,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIJ2U43q97z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN69_TEMP_LUT6_2_RNIO1723: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6263,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN69_TEMP_LUT6_2_RNIMV623: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6263,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIDQR43q85z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2_Z6731: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_UN87_TEMP_LUT6_2_RNIPVG43: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6272,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_1_Z6733: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6132,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2_Z6734: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_Z6735: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_RNIHDJF3: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6117,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_RNII7AO: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6141,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_RNIG5AO: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6141,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQLPJ1q85z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIOJPJ1q85z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN417_TEMP_LUT6_2_RNICPS91: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6162,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN417_TEMP_LUT6_2_RNIANS91: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6162,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q235z_Z6743: LUT4 
generic map(
  INIT => X"0C0A"
)
port map (
  I0 => rfo1_data2(29),
  I1 => rfo2_data2(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(235));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3_Z6744: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_2_Z6745: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQJNJ1q76z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIOHNJ1q76z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI14IS3q76z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIV1IS3q76z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q6z: LUT5 
generic map(
  INIT => X"08102188"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_353);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_UN132_TEMP_LUT6_2_RNII68M2: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6300,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_Z6752: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6300,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q234z_Z6753: LUT4 
generic map(
  INIT => X"0C0A"
)
port map (
  I0 => rfo1_data2(30),
  I1 => rfo2_data2(30),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(234));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q236z_Z6754: LUT4 
generic map(
  INIT => X"0C0A"
)
port map (
  I0 => rfo1_data2(28),
  I1 => rfo2_data2(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(236));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q52z_Z6755: LUT5 
generic map(
  INIT => X"C0A0CFAF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TOPBITSIN(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q39z_Z6756: LUT5 
generic map(
  INIT => X"0FCC0FAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q38z_Z6757: LUT5 
generic map(
  INIT => X"0FAA0FCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q35z_Z6758: LUT5 
generic map(
  INIT => X"CC0FAA0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q34z_Z6759: LUT5 
generic map(
  INIT => X"AA0FCC0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q31z_Z6760: LUT5 
generic map(
  INIT => X"0FCC0FAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q27z_Z6761: LUT5 
generic map(
  INIT => X"CC0FAA0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q25z_Z6762: LUT5 
generic map(
  INIT => X"0FCC0FAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_110,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q21z_Z6763: LUT5 
generic map(
  INIT => X"CCF0AAF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_111,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q16z_Z6764: LUT5 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_112,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q12z_Z6765: LUT5 
generic map(
  INIT => X"CC0FAA0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q10z_Z6766: LUT5 
generic map(
  INIT => X"0FAA0FCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q6z_Z6767: LUT5 
generic map(
  INIT => X"AA0FCC0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q4z_Z6768: LUT5 
generic map(
  INIT => X"F0AAF0CC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_115,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q0z_Z6769: LUT6 
generic map(
  INIT => X"AAAACCCCFF00F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_UN639_TEMP_LUT6_2_RNI3AOD3: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6083,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_UN639_TEMP_LUT6_2_RNI5COD3: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6083,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFA903q112z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_Z6773: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_1_Z6774: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6127,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN588_TEMP_LUT6_2_RNIPPNI3: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6126,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_RNIAO751: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6183,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPPFS3q64z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_RNICQ751: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6183,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIV7N43q60z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRRFS3q64z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNII9LJ1q64z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1AN43q62z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITTFS3q66z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKBLJ1q64z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3CN43q62z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVVFS3q66z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMDLJ1q66z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_UN105_TEMP_LUT6_2_RNIL7503: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6295,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI12GS3q67z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIOFLJ1q66z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_UN105_TEMP_LUT6_2_RNIN9503: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6295,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI34GS3q68z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQHLJ1q67z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI9IN43q66z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISTGS3q70z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISJLJ1q68z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN27_TEMP_LUT6_2_RNIJFQ23: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6292,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN417_TEMP_LUT6_2_RNIFQQ91: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6175,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN417_TEMP_LUT6_2_RNI8KR91: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6175,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_UN87_TEMP_LUT6_2_RNIQUE43: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6291,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIG9NJ1q71z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_UN150_TEMP_LUT6_2_RNIEG223: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6289,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_UN150_TEMP_LUT6_2_RNI7A323: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6289,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN561_TEMP_RNIODIG3: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6114,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_UN459_TEMP_LUT6_2_RNIL5S71: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6172,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3EP43q71z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMFNJ1q74z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5GP43q73z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7IP43q74z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI36IS3q77z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI9KP43q74z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI58IS3q79z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBMP43q76z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIU1JS3q79z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUNNJ1q79z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN27_TEMP_LUT6_2_RNIKHR23: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6282,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNINRJS3q80z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNINHOJ1q79z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN27_TEMP_LUT6_2_RNIMJR23: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6282,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_UN609_TEMP_LUT6_2_RNILE5S3: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6106,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_RNI4FG61: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6164,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHSP43q79z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_RNI6HG61: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6164,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAMQ43q79z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN69_TEMP_LUT6_2_RNIGO523: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6278,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN69_TEMP_LUT6_2_RNIIQ523: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6278,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7KR43q82z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_RNI35LD3: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6102,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI9MR43q83z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5AKS3q88z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBOR43q85z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7CKS3q88z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_UN609_TEMP_LUT6_2_RNITM5S3: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6098,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_RNIJ17F1: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6156,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_UN609_TEMP_LUT6_2_RNIMG6S3: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6098,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_RNICR7F1: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6156,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_UN87_TEMP_LUT6_2_RNIR1H43: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6272,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIR1MS3q91z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIJ0S43q88z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIT3MS3q93z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKHRJ1q91z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNICQS43q89z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIV5MS3q93z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5KT43q90z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI18MS3q95z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIOLRJ1q93z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7MT43q91z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3AMS3q95z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQNRJ1q95z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_UN105_TEMP_LUT6_2_RNINC803: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6266,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5CMS3q97z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISPRJ1q95z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_UN105_TEMP_LUT6_2_RNIPE803: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6266,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7EMS3q97z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_UN459_TEMP_LUT6_2_RNIPBU71: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6148,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIDST43q95z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_RNIQS7G3: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6089,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_RNIJDGH: LUT4 
generic map(
  INIT => X"3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6147,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6148,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_RNIK1K73: LUT4 
generic map(
  INIT => X"5300"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6089,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6088,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_RNIL6B51: LUT5 
generic map(
  INIT => X"3A350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6147,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI29K51q100z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_RNIA8173q8z: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6087,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2ICNq100z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIL4U43q98z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNID6703q103z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILDMM2q100z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIF8703q103z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILME82q100z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_UN132_TEMP_LUT6_2_RNIUU382: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6257,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_UN132_TEMP_LUT6_2_RNI01482: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6257,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILE703q106z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNICSCNq106z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRSE82q103z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNING703q108z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIEUCNq106z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITUE82q104z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPI703q108z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIV0F82q106z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIIC803q110z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNII2DNq108z: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI13F82q106z: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIB6903q111z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_UN150_TEMP_LUT6_2_RNIN5UJ2: LUT5 
generic map(
  INIT => X"A5330000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6251,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNID8903q112z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4MENq111z: LUT5 
generic map(
  INIT => X"CA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_UN150_TEMP_LUT6_2_RNIP7UJ2: LUT5 
generic map(
  INIT => X"33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6251,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_RNIMF111: LUT5 
generic map(
  INIT => X"A3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6133,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIU0G82q110z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNINQG82q111z: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_2_Z6890: LUT5 
generic map(
  INIT => X"AC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_1_Z6891: LUT5 
generic map(
  INIT => X"C3A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1_Z6892: LUT5 
generic map(
  INIT => X"A5C30000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_28: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6306);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3q62z_Z6894: LUT6 
generic map(
  INIT => X"C888400040004000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4564,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3384_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3343_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4479_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4q61z_Z6895: LUT6_L 
generic map(
  INIT => X"FFFFFFFFC0C04000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4274_I_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3340_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3132_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4_0(61),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0q50z_Z6896: LUT6_L 
generic map(
  INIT => X"FFFFFFFF90000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3277_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1289,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_10q75z: LUT6 
generic map(
  INIT => X"BEBB9C9936331411"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS,
  I4 => N_1266,
  I5 => N_1267,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2179);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_7q75z: LUT6 
generic map(
  INIT => X"A191AD9D61516D5D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(48),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6073,
  I5 => N_1199,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2176);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIFDCR1q12z: LUT6 
generic map(
  INIT => X"0000153F0000EAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZYBUS24_SN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3);
GRLFPC20_RDD_1_M4_E_2: LUT6 
generic map(
  INIT => X"0000FFF70000FFFF"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(8),
  I2 => cpi_d_inst(12),
  I3 => cpi_d_inst(13),
  I4 => GRLFPC20_COMB_FPDECODE_RDD5,
  I5 => GRLFPC20_COMB_FPDECODE_RDD6_3_0,
  O => GRLFPC20_RDD_1_N_20_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O8_3q63z: LUT5_L 
generic map(
  INIT => X"00110248"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4617);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRLq67z_Z6902: LUT5 
generic map(
  INIT => X"00020202"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(47),
  I1 => GRLFPC20_FPI_LDOP,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS,
  I4 => N_1267,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67));
GRLFPC20_COMB_UN9_CCV_2_RNILVBO: LUT5 
generic map(
  INIT => X"0103050F"
)
port map (
  I0 => cpi_e_inst(19),
  I1 => cpi_x_inst(19),
  I2 => GRLFPC20_COMB_UN9_CCV_2,
  I3 => GRLFPC20_R_E_FPOP,
  I4 => GRLFPC20_R_X_FPOP,
  O => cpo_ccv);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_5q62z: LUT6 
generic map(
  INIT => X"0000000000020000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3667_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4585);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_5q63z: LUT6 
generic map(
  INIT => X"0071000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3277_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4628);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN11_WQSTSETS_Z6906: LUT6_L 
generic map(
  INIT => X"00000000F7F7F707"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(14),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(16),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(5),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN11_WQSTSETS);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN_Z6907: LUT6 
generic map(
  INIT => X"8000000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN_Z6908: LUT6_L 
generic map(
  INIT => X"8080800000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN8_NOTBINFNAN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3_4q2z_Z6909: LUT6 
generic map(
  INIT => X"0100000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_1(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_0(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3_4(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_1q36z_Z6910: LUT6 
generic map(
  INIT => X"FFFFFFFF00005040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3207_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3340_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_1(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0q49z_Z6911: LUT6_L 
generic map(
  INIT => X"FFFFFFFF00002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3186_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3866,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2q62z_Z6912: LUT6_L 
generic map(
  INIT => X"FFFFFFFFF888F000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_2_0(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1739,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1771,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4590,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0q62z_Z6913: LUT6_L 
generic map(
  INIT => X"FFFFFFFF02000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4479_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4580,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0q62z_Z6914: LUT6 
generic map(
  INIT => X"FFFFFFFF08000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4566_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3384_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4274_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4579,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5q11z_Z6915: LUT6_L 
generic map(
  INIT => X"FFFFFFFFE0C0A000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3029_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3031_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3014,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_8_1q11z_Z6916: LUT6 
generic map(
  INIT => X"CCCC8800C0C08000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3177_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3129_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_8_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4q13z_Z6917: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFF800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3327_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3199,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3173,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0q13z_Z6918: LUT6_L 
generic map(
  INIT => X"10FF00FF10100000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3842_I,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4139_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3294_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_6_0(13),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0q13z_Z6919: LUT6 
generic map(
  INIT => X"FF40FF0040400000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_748_I,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3175_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_9_1(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_0q48z_Z6920: LUT6 
generic map(
  INIT => X"FF101010FF000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3753_I,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1771,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3_0(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_1q48z_Z6921: LUT6_L 
generic map(
  INIT => X"FFFFFFFFA2000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3222_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1699_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_1(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI39DK1q27z: LUT5 
generic map(
  INIT => X"FAFAFA32"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(27),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(47),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_EXPAREGLOADEN_274_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3q61z_Z6923: LUT6 
generic map(
  INIT => X"FFFF8F0FF8F08800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3667_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_0_0(61),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_3(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_1q61z_Z6924: LUT6_L 
generic map(
  INIT => X"FFFFFFFF28000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3793,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_1(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_0q61z_Z6925: LUT6_L 
generic map(
  INIT => X"75D5208020802080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3923_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6065_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_23_1(61),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_0(61));
GRLFPC20_ANNULRES_1_IV_1_0_Z6926: LUT6 
generic map(
  INIT => X"000000000000AAC0"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI_1,
  I1 => GRLFPC20_COMB_UN1_FPCI_2,
  I2 => GRLFPC20_R_E_FPOP,
  I3 => GRLFPC20_R_M_FPOP,
  I4 => GRLFPC20_R_I_EXEC,
  I5 => GRLFPC20_R_X_FPOP,
  O => GRLFPC20_ANNULRES_1_IV_1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0q60z_Z6927: LUT6 
generic map(
  INIT => X"FFFFFFFF00008000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3296_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(60),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0q60z_Z6928: LUT6_L 
generic map(
  INIT => X"BAAAAAAA30000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_13_0(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4139_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3026_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4q56z_Z6929: LUT6 
generic map(
  INIT => X"FFFFFFFFF8880000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4635_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3234_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3601_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4138_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4140,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0q56z_Z6930: LUT6_L 
generic map(
  INIT => X"FFFFFFFF10000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3294_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4274_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4142,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0q56z_Z6931: LUT6 
generic map(
  INIT => X"7520202055000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3222_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3175_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_4_0(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0q56z_Z6932: LUT6 
generic map(
  INIT => X"FFFFFFFF90000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3281_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4151,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0q12z_Z6933: LUT6_L 
generic map(
  INIT => X"AEAAAAAA0C000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1708,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1967,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_1q12z_Z6934: LUT6 
generic map(
  INIT => X"FFFF020000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3548_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_3_1(12),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_1(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0q45z_Z6935: LUT6 
generic map(
  INIT => X"F8F0F0F088000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1707,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3021_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3096_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3727_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0q7z_Z6936: LUT6_L 
generic map(
  INIT => X"7555555520000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_714_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1243_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_0_0q16z_Z6937: LUT4 
generic map(
  INIT => X"FF60"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1699_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1702,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_0_0(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO_Z6938: LUT6 
generic map(
  INIT => X"FEFEFE0E07F7F7F7"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUSq9z_Z6939: LUT6 
generic map(
  INIT => X"08080808C8080808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUSq7z_Z6940: LUT6 
generic map(
  INIT => X"08080808C8080808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUSq8z_Z6941: LUT6 
generic map(
  INIT => X"08080808C8080808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_8q60z: LUT6 
generic map(
  INIT => X"C000800040000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4635_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4452);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4_0q61z_Z6943: LUT6_L 
generic map(
  INIT => X"FFFFFFFFA3000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4310_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3791_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4527,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4_0(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0q60z_Z6944: LUT6_L 
generic map(
  INIT => X"FFFFFFFF20700000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3828_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3130_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4453,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q54z_Z6945: LUT5 
generic map(
  INIT => X"505F3333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIIACL1q12z: LUT5 
generic map(
  INIT => X"153FEAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZYBUS24_SN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2);
GRLFPC20_RS1V12_Z6947: LUT6 
generic map(
  INIT => X"0000009000000000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(21),
  I3 => cpi_d_inst(22),
  I4 => cpi_d_inst(23),
  I5 => cpi_d_inst(24),
  O => GRLFPC20_RS1V12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q47z_Z6948: LUT5 
generic map(
  INIT => X"353500FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q48z_Z6949: LUT5 
generic map(
  INIT => X"55330F0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q50z_Z6950: LUT5 
generic map(
  INIT => X"505F3333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1_Z6951: LUT6 
generic map(
  INIT => X"AAAAAAAAAAAAAAA8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(9),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN12_SRTOSTICKY_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q49z_Z6952: LUT5 
generic map(
  INIT => X"505F3333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q53z_Z6953: LUT5 
generic map(
  INIT => X"505F3333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q52z_Z6954: LUT5 
generic map(
  INIT => X"474700FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => NN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q51z_Z6955: LUT5 
generic map(
  INIT => X"474700FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => NN_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN40_SHDVAR_Z6956: LUT6 
generic map(
  INIT => X"FFFFFFFE00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN38_SHDVAR_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN40_SHDVAR);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SIGNRESULT: LUT5 
generic map(
  INIT => X"0A19A0A2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(23),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(24),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  O => GRLFPC20_FPO_SIGN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_12_Z6958: LUT6 
generic map(
  INIT => X"965AF05A3CF05AF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(232),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(245),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_36: LUT6 
generic map(
  INIT => X"965AF05A3CF05AF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(232),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(245),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6303);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20_0q49z: LUT6_L 
generic map(
  INIT => X"7300500000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3343_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3281_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3132_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3548_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3852);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_0q11z: LUT6_L 
generic map(
  INIT => X"0000080800000800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4431_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3012);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_1q11z: LUT6 
generic map(
  INIT => X"0005000000010000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3421_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3078_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3013);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_2q50z: LUT6_L 
generic map(
  INIT => X"2220000022000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1762,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3034_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3277_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1286);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15q44z: LUT6_L 
generic map(
  INIT => X"0208000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1341);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_3q36z: LUT6_L 
generic map(
  INIT => X"4444000040000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3297_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4150_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722);
GRLFPC20_COMB_UN1_MEXC_Z6966: LUT5 
generic map(
  INIT => X"135F0000"
)
port map (
  I0 => GRLFPC20_R_FSR_TEM(1),
  I1 => GRLFPC20_R_FSR_TEM(2),
  I2 => GRLFPC20_R_I_EXC(1),
  I3 => GRLFPC20_R_I_EXC(2),
  I4 => GRLFPC20_COMB_UN1_MEXC_2,
  O => GRLFPC20_COMB_UN1_MEXC);
GRLFPC20_ANNULFPU_1_SQMUXA_Z6967: LUT6 
generic map(
  INIT => X"0105030F115533FF"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI_1,
  I1 => GRLFPC20_COMB_UN1_FPCI_2,
  I2 => GRLFPC20_COMB_UN3_HOLDN,
  I3 => GRLFPC20_R_E_FPOP,
  I4 => GRLFPC20_R_M_FPOP,
  I5 => GRLFPC20_R_A_FPOP,
  O => GRLFPC20_ANNULFPU_1_SQMUXA);
GRLFPC20_COMB_FPDECODE_RDD4_Z6968: LUT6 
generic map(
  INIT => X"4000000000000000"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(6),
  I2 => cpi_d_inst(8),
  I3 => cpi_d_inst(10),
  I4 => GRLFPC20_COMB_FPDECODE_RDD2_1,
  I5 => GRLFPC20_COMB_FPDECODE_RDD4_4,
  O => GRLFPC20_COMB_FPDECODE_RDD4);
GRLFPC20_MOV_1_SQMUXA_Z6969: LUT6 
generic map(
  INIT => X"0080000000000000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(21),
  I2 => cpi_d_inst(23),
  I3 => cpi_d_inst(30),
  I4 => cpi_d_inst(31),
  I5 => GRLFPC20_MOV_1_SQMUXA_2,
  O => GRLFPC20_MOV_1_SQMUXA);
GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_Z6970: LUT6 
generic map(
  INIT => X"0001000000000000"
)
port map (
  I0 => cpi_d_inst(8),
  I1 => cpi_d_inst(9),
  I2 => cpi_d_inst(10),
  I3 => cpi_d_inst(11),
  I4 => GRLFPC20_COMB_FPDECODE_RS1D5_4,
  I5 => GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_0,
  O => GRLFPC20_COMB_FPDECODE_UN1_FPCI_3);
GRLFPC20_COMB_RSDECODE_UN1_FPCI_Z6971: LUT6 
generic map(
  INIT => X"0002000000000000"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(6),
  I2 => cpi_d_inst(9),
  I3 => cpi_d_inst(10),
  I4 => cpi_d_inst(11),
  I5 => GRLFPC20_COMB_FPDECODE_RS1D5_4,
  O => GRLFPC20_COMB_RSDECODE_UN1_FPCI);
GRLFPC20_COMB_FPDECODE_RDD5_Z6972: LUT6 
generic map(
  INIT => X"0004000000000000"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(6),
  I2 => cpi_d_inst(9),
  I3 => cpi_d_inst(10),
  I4 => cpi_d_inst(11),
  I5 => GRLFPC20_COMB_FPDECODE_RS1D5_4,
  O => GRLFPC20_COMB_FPDECODE_RDD5);
GRLFPC20_COMB_FPDECODE_RS1D5_Z6973: LUT6 
generic map(
  INIT => X"4000000000000000"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(6),
  I2 => cpi_d_inst(9),
  I3 => cpi_d_inst(11),
  I4 => GRLFPC20_COMB_FPDECODE_RS1D5_3,
  I5 => GRLFPC20_COMB_FPDECODE_RS1D5_4,
  O => GRLFPC20_COMB_FPDECODE_RS1D5);
GRLFPC20_COMB_FPDECODE_UN1_FPCI_1_Z6974: LUT6 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(6),
  I2 => cpi_d_inst(7),
  I3 => cpi_d_inst(9),
  I4 => cpi_d_inst(10),
  I5 => GRLFPC20_COMB_FPDECODE_UN1_FPCI_1_2_0,
  O => GRLFPC20_COMB_FPDECODE_UN1_FPCI_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_Z6975: LUT6 
generic map(
  INIT => X"EAAA000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I1 => GRLFPC20_FPO_EXP(8),
  I2 => GRLFPC20_FPO_EXP(9),
  I3 => GRLFPC20_FPO_EXP(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN_2_Z6976: LUT6_L 
generic map(
  INIT => X"C0008000C0000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN8_NOTAINFNAN_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2_4q2z_Z6977: LUT5 
generic map(
  INIT => X"01000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_4_0(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2_4(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_3_1q61z_Z6978: LUT6_L 
generic map(
  INIT => X"8AA8000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_3_1(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0q36z_Z6979: LUT6_L 
generic map(
  INIT => X"FFFFFFFF28000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3732,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0q60z_Z6980: LUT6_L 
generic map(
  INIT => X"F8F0F0F088000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3016_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_18_0(60),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4462_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT_IV_0q1z_Z6981: LUT6 
generic map(
  INIT => X"222E22E2AAAAAAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_AREGXORBREG_M_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT_IV_0(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1q0z_Z6982: LUT6 
generic map(
  INIT => X"0000000007F7F7F7"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0q114z: LUT5 
generic map(
  INIT => X"20FF2000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(117),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I4 => N_1211,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2472);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUSq5z_Z6984: LUT5 
generic map(
  INIT => X"C8080808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUSq6z_Z6985: LUT5 
generic map(
  INIT => X"C8080808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_RNOq2z: LUT5 
generic map(
  INIT => X"2222222E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(58),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK,
  I2 => N_1265,
  I3 => N_1266,
  I4 => GRLFPC20_FPO_FRAC(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBITq3z_Z6987: LUT5 
generic map(
  INIT => X"0010FFDF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => N_1265,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBITq2z_Z6988: LUT5 
generic map(
  INIT => X"0010FFDF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_FPO_FRAC(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBITq1z_Z6989: LUT5 
generic map(
  INIT => X"0010FFDF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_FPO_FRAC(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBITq0z_Z6990: LUT5 
generic map(
  INIT => X"0010FFDF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_FPO_FRAC(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTDIVISORBIT_Z6991: LUT5 
generic map(
  INIT => X"33333533"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTDIVISORBIT);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0q115z: LUT5 
generic map(
  INIT => X"20FF2000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(118),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I4 => N_1210,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2471);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_4q63z: LUT6 
generic map(
  INIT => X"2E00000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3078_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4627);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_2q255z: LUT5 
generic map(
  INIT => X"BFB08F80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPO_EXP(2),
  I4 => GRLFPC20_FPO_EXP(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2325);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_2q253z: LUT5 
generic map(
  INIT => X"BFB08F80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPO_EXP(4),
  I4 => GRLFPC20_FPO_EXP(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2327);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_2q248z: LUT5 
generic map(
  INIT => X"BFB08F80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPO_EXP(9),
  I4 => GRLFPC20_FPO_EXP(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2332);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN21_LOCOV_Z6997: LUT4 
generic map(
  INIT => X"AAA8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I1 => GRLFPC20_FPO_EXP(8),
  I2 => GRLFPC20_FPO_EXP(9),
  I3 => GRLFPC20_FPO_EXP(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN21_LOCOV);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN26_XZYBUSLSBS_Z6998: LUT5 
generic map(
  INIT => X"A888A000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(231),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN26_XZYBUSLSBS);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_2q250z: LUT5 
generic map(
  INIT => X"BFB08F80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPO_EXP(7),
  I4 => GRLFPC20_FPO_EXP(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2330);
GRLFPC20_COMB_UN1_FPCI_4_Z7000: LUT5 
generic map(
  INIT => X"BA303030"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => GRLFPC20_R_A_RS2D,
  I2 => GRLFPC20_R_A_RS2(0),
  I3 => GRLFPC20_R_A_RS1D,
  I4 => GRLFPC20_R_A_ST,
  O => GRLFPC20_COMB_UN1_FPCI_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_2q252z: LUT5 
generic map(
  INIT => X"BFB08F80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPO_EXP(5),
  I4 => GRLFPC20_FPO_EXP(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2328);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN8_TEMP_2q0z: LUT6_L 
generic map(
  INIT => X"FEF45E54AEA40E04"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2809);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_2q256z: LUT5 
generic map(
  INIT => X"BFB08F80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPO_EXP(1),
  I4 => GRLFPC20_FPO_EXP(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2324);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_XZYBUSLSBS_Z7004: LUT5 
generic map(
  INIT => X"A888A000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(230),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_XZYBUSLSBS);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD_Z7005: LUT6 
generic map(
  INIT => X"EAC0FFFFEAC0EAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(13),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(375),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN3_NOTXZYFROMD: LUT6 
generic map(
  INIT => X"FFFFEAC0EAC0EAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(14),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(376),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZYBUS24_SN);
GRLFPC20_COMB_LOCKGEN_DEPCHECK_Z7007: LUT5 
generic map(
  INIT => X"FFFFFFFE"
)
port map (
  I0 => GRLFPC20_R_E_FPOP,
  I1 => GRLFPC20_R_M_FPOP,
  I2 => GRLFPC20_R_A_FPOP,
  I3 => GRLFPC20_R_I_EXEC,
  I4 => GRLFPC20_R_X_FPOP,
  O => GRLFPC20_COMB_LOCKGEN_DEPCHECK);
GRLFPC20_MOV_0_SQMUXA_4_Z7008: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => cpi_d_inst(21),
  I1 => cpi_d_inst(23),
  I2 => cpi_d_inst(24),
  I3 => cpi_d_inst(30),
  I4 => cpi_d_inst(31),
  O => GRLFPC20_MOV_0_SQMUXA_4);
GRLFPC20_COMB_FPDECODE_ST_0: LUT6 
generic map(
  INIT => X"0200000000000000"
)
port map (
  I0 => cpi_d_inst(21),
  I1 => cpi_d_inst(22),
  I2 => cpi_d_inst(23),
  I3 => cpi_d_inst(24),
  I4 => cpi_d_inst(30),
  I5 => cpi_d_inst(31),
  O => GRLFPC20_COMB_FPDECODE_ST);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_0q2z_Z7010: LUT6 
generic map(
  INIT => X"0000000000000013"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_128);
GRLFPC20_COMB_UN9_CCV_2_Z7011: LUT6 
generic map(
  INIT => X"FFFFEAC0EAC0EAC0"
)
port map (
  I0 => cpi_m_inst(19),
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_INST(19),
  I3 => GRLFPC20_R_M_FPOP,
  I4 => GRLFPC20_R_X_AFSR,
  I5 => GRLFPC20_R_X_LD,
  O => GRLFPC20_COMB_UN9_CCV_2);
GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_4_Z7012: LUT6 
generic map(
  INIT => X"0000800000000000"
)
port map (
  I0 => cpi_d_inst(6),
  I1 => cpi_d_inst(9),
  I2 => cpi_d_inst(11),
  I3 => cpi_d_inst(12),
  I4 => cpi_d_inst(13),
  I5 => GRLFPC20_COMB_FPDECODE_RS1D5_3,
  O => GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_4);
GRLFPC20_COMB_FPDECODE_RDD6_3_0_Z7013: LUT5 
generic map(
  INIT => X"01000000"
)
port map (
  I0 => cpi_d_inst(6),
  I1 => cpi_d_inst(7),
  I2 => cpi_d_inst(9),
  I3 => cpi_d_inst(10),
  I4 => cpi_d_inst(11),
  O => GRLFPC20_COMB_FPDECODE_RDD6_3_0);
GRLFPC20_COMB_UN1_MEXC_2_Z7014: LUT6_L 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_R_FSR_TEM(0),
  I1 => GRLFPC20_R_FSR_TEM(3),
  I2 => GRLFPC20_R_FSR_TEM(4),
  I3 => GRLFPC20_R_I_EXC(0),
  I4 => GRLFPC20_R_I_EXC(3),
  I5 => GRLFPC20_R_I_EXC(4),
  LO => GRLFPC20_COMB_UN1_MEXC_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3q6z_Z7015: LUT5 
generic map(
  INIT => X"FFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_2(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3q5z_Z7016: LUT5 
generic map(
  INIT => X"FFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN3_NOTAZERODENORM,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_3(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_0_Z7017: LUT6 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => NN_4,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I4 => NN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN_0_Z7018: LUT5_L 
generic map(
  INIT => X"80000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTBINFNAN_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_0_1q2z: LUT6 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_0(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_1q2z_Z7020: LUT6_L 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_1(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2q2z_Z7021: LUT6 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3q2z_Z7022: LUT6_L 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_23_1q61z_Z7023: LUT5 
generic map(
  INIT => X"02000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_23_1(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_3_Z7024: LUT5 
generic map(
  INIT => X"80000000"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(47),
  I1 => GRLFPC20_FPO_FRAC(48),
  I2 => GRLFPC20_FPO_FRAC(49),
  I3 => GRLFPC20_FPO_FRAC(52),
  I4 => GRLFPC20_FPO_FRAC(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITTPT1q56z: LUT5 
generic map(
  INIT => X"06F6F606"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUSq4z_Z7026: LUT4 
generic map(
  INIT => X"C808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_4q75z: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(48),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6073);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_RNOq0z: LUT3 
generic map(
  INIT => X"DC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => NN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14_RNOq1z: LUT3 
generic map(
  INIT => X"DC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIC8O51q7z: LUT3 
generic map(
  INIT => X"BA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS6);
GRLFPC20_COMB_UN1_R_I_V_Z7031: LUT3 
generic map(
  INIT => X"40"
)
port map (
  I0 => GRLFPC20_R_I_EXEC,
  I1 => GRLFPC20_R_I_V,
  I2 => GRLFPC20_R_X_FPOP,
  O => GRLFPC20_COMB_UN1_R_I_V);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN8_NOTBINFNAN_Z7032: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN8_NOTBINFNAN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M11S4: LUT4 
generic map(
  INIT => X"FFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => NN_4,
  I3 => NN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2166);
GRLFPC20_V_I_EXC_1q3z_Z7034: LUT3_L 
generic map(
  INIT => X"02"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  LO => GRLFPC20_V_I_EXC_1(3));
GRLFPC20_V_I_EXC_1q4z_Z7035: LUT4_L 
generic map(
  INIT => X"A080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(41),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  LO => GRLFPC20_V_I_EXC_1(4));
GRLFPC20_COMB_FPDECODE_RDD2_1_Z7036: LUT3 
generic map(
  INIT => X"01"
)
port map (
  I0 => cpi_d_inst(7),
  I1 => cpi_d_inst(9),
  I2 => cpi_d_inst(13),
  O => GRLFPC20_COMB_FPDECODE_RDD2_1);
GRLFPC20_AFQ_3_SQMUXA_0_0_Z7037: LUT4 
generic map(
  INIT => X"1000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(23),
  I2 => cpi_d_inst(30),
  I3 => cpi_d_inst(31),
  O => GRLFPC20_AFQ_3_SQMUXA_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN38_SHDVAR_1_Z7038: LUT4 
generic map(
  INIT => X"FFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_UN38_SHDVAR_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_2q6z_Z7039: LUT4_L 
generic map(
  INIT => X"FFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1_2(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1_Z7040: LUT4 
generic map(
  INIT => X"0001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_0_Z7041: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_FPO_EXP(1),
  I1 => GRLFPC20_FPO_EXP(2),
  I2 => GRLFPC20_FPO_EXP(3),
  I3 => GRLFPC20_FPO_EXP(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_1_Z7042: LUT3_L 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_FPO_EXP(5),
  I1 => GRLFPC20_FPO_EXP(6),
  I2 => GRLFPC20_FPO_EXP(7),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN13_LOCOV_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_2_Z7043: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(50),
  I1 => GRLFPC20_FPO_FRAC(51),
  I2 => GRLFPC20_FPO_FRAC(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK_1: LUT2_L 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_AREGXORBREG_M_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14S2_3_2: LUT2 
generic map(
  INIT => X"E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12_3_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14S2_3_1: LUT2 
generic map(
  INIT => X"E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M5S2: LUT2 
generic map(
  INIT => X"E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2164_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq15z: LUT1_L 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_I(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIFJBBq69z: LUT1_L 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(69),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_I(69));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_12_Z7050: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(232),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(245),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq11z: LUT1_L 
generic map(
  INIT => X"1"
)
port map (
  I0 => cpi_d_inst(6),
  LO => CPI_D_INST_I(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN12_SRTOSTICKY_2_Z7052: LUT2_L 
generic map(
  INIT => X"E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(10),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(11),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN12_SRTOSTICKY_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_11q75z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2176,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2179,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2180);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq54z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_593,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_611,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq57z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_991,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1007,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1008);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq6z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_348,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_370,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq27z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_421,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_443,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq31z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_460,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_482,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq58z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_628,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_648,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(58));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq59z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_663,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_680,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(59));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq66z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(66),
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2698,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
    O => N_3_161_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_0q7z: LUT6 
generic map(
  INIT => X"0000000008000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3129_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4566_I_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1631);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNICIB63_0q49z: LUT6 
generic map(
  INIT => X"5AA5669955AA55AA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6291,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6292,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_1_0_I(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN5_ZERO,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_13(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3_RNILB453: LUT6 
generic map(
  INIT => X"CD3232CD32CDCD32"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_57(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN16_NOTPROP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHNFHA_0q355z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(355),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(18),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_102(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIJKS99_0q358z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(358),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_105(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNICOOGC_0q340z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(340),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_28(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_86(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7IKHB_0q343z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(343),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_90(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6NADC_0q326z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(326),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_SI_14(43),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_72(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO_RNIL1IUK: LUT3 
generic map(
  INIT => X"EC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AC0_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q51z: LUT6 
generic map(
  INIT => X"0009020B040D060F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(7),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(6),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_RNINH4QJ_0q6z: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6132,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6133,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_112(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SCLSBS_1(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZAREGLOADEN: LUT6 
generic map(
  INIT => X"00000000FFFE0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => M20_E_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_RNI2PIPL1_0q8z: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6087,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6088,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_156(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_RNI492FM1_0: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6104,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6105,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_SI_139(30),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN561_TEMP_RNI6FFN22_0: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6114,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6115,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_129(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMPVLS1_0q77z: LUT6 
generic map(
  INIT => X"56A96A95A956956A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_78(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_UN609_TEMP_LUT6_2_RNIKB82F1_0: LUT6 
generic map(
  INIT => X"5300ACFFACFF5300"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6106,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6105,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_138(31),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_RNID23N32_0: LUT6 
generic map(
  INIT => X"366CC993C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_5(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIK7BDS1_0q316z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI45ITQ1_0q66z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_AXB1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIJ1K5Q1q67z: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_123(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN588_TEMP_LUT6_2_RNI67FR7_0: LUT6 
generic map(
  INIT => X"3500CAFFCAFF3500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6126,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6127,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_117(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_52_RNIF1PC: LUT5_L 
generic map(
  INIT => X"00FF80BF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(47),
  I1 => M9_18_3_RETO,
  I2 => M20_E_18_0_1_RETO,
  I3 => R_DPATH_RET_38,
  I4 => M20_E_0_RETO_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq21z: LUT5_L 
generic map(
  INIT => X"2FFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => M20_E_0,
  I2 => M9_22_3,
  I3 => M9_22_1_0,
  I4 => M9_22_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_25);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_56_RNIA4PC: LUT5_L 
generic map(
  INIT => X"00FF80BF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(23),
  I1 => M9_24_3_RETO,
  I2 => M20_E_24_0_1_RETO,
  I3 => R_DPATH_RET_44,
  I4 => M20_E_0_RETO_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_48_RNI20PC: LUT5_L 
generic map(
  INIT => X"00FF80BF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(24),
  I1 => M9_25_3_RETO,
  I2 => M20_E_25_0_1_RETO,
  I3 => R_DPATH_RET_32,
  I4 => M20_E_0_RETO_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_54_RNI83PC: LUT5_L 
generic map(
  INIT => X"00FF80BF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(25),
  I1 => M9_26_3_RETO,
  I2 => M20_E_26_0_1_RETO,
  I3 => R_DPATH_RET_41,
  I4 => M20_E_0_RETO_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_2_RNIBNKQ: LUT4_L 
generic map(
  INIT => X"0F8B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(31),
  I1 => M9_32_3_RETO,
  I2 => R_DPATH_RET_5,
  I3 => M20_E_0_RETO_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_64_RNI5IDA: LUT3_L 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(6),
  I1 => R_DPATH_RET_50,
  I2 => M20_E_0_RETO_0,
  LO => NN_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_46_RNIR0PC: LUT5_L 
generic map(
  INIT => X"0800FBFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(11),
  I1 => M9_42_3_RETO,
  I2 => M20_E_0_RETO_22,
  I3 => M20_E_42_0_1_RETO,
  I4 => R_DPATH_RET_29,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq12z: LUT5_L 
generic map(
  INIT => X"2FFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I1 => M20_E_0,
  I2 => M9_43_3,
  I3 => M9_43_1_0,
  I4 => M9_43_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_46);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_58_RNI19PC: LUT5_L 
generic map(
  INIT => X"0800FBFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(13),
  I1 => M9_44_3_RETO,
  I2 => M20_E_0_RETO_28,
  I3 => M20_E_44_0_1_RETO,
  I4 => R_DPATH_RET_47,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_50_RNI85PC: LUT5_L 
generic map(
  INIT => X"0800FBFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(14),
  I1 => M9_45_3_RETO,
  I2 => M20_E_0_RETO_24,
  I3 => M20_E_45_0_1_RETO,
  I4 => R_DPATH_RET_35,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_66_RNI9DJB: LUT4_L 
generic map(
  INIT => X"0F8B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(17),
  I1 => M20_E_48_2_RETO,
  I2 => R_DPATH_RET_52,
  I3 => M20_E_0_RETO_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51);
R_DPATH_RET_5_RNO: LUT4_L 
generic map(
  INIT => X"0008"
)
port map (
  I0 => M9_32_2,
  I1 => M9_32_2_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(26),
  LO => N_38_MUX_32);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq79z: LUT5_L 
generic map(
  INIT => X"FF88FCFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2206,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2215,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq78z: LUT5_L 
generic map(
  INIT => X"FF88FCFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2207,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2216,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q12z: LUT5 
generic map(
  INIT => X"2030A0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(45),
  I2 => M9_43_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => M9_43_1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q21z: LUT5 
generic map(
  INIT => X"2030A0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(36),
  I2 => M9_22_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => M9_22_1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSRRESq55z_Z7101: LUT5 
generic map(
  INIT => X"FDF0FFF2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(55),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSRRES(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0_CY_Z7102: MUXCY_L port map (
    DI => NN_5,
    CI => NN_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2812,
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0_CY);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0_CY_Z7103: MUXCY_L port map (
    DI => NN_5,
    CI => NN_2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_MIXOIN(0),
    LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0_CY);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_14q4z_Z7104: LUT4_L 
generic map(
  INIT => X"8040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_10(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2778,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_14(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEWq7z_Z7105: LUT4_L 
generic map(
  INIT => X"9050"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_10(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2778,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(7));
R_DPATH_RET_13_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(159),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_14_2);
R_DPATH_RET_25_RNO_3: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(157),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_12_2);
GRLFPC20_R_FSR_AEXC_RNO_0q2z: LUT6 
generic map(
  INIT => X"CCCCCCCC4C0C0C0C"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => holdn,
  I2 => rst,
  I3 => GRLFPC20_R_X_AFSR,
  I4 => GRLFPC20_R_X_LD,
  I5 => GRLFPC20_WRRES_1,
  O => GRLFPC20_R_FSR_AEXCCE_0_0(2));
R_DPATH_RET_7_RNO_3: LUT6_L 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(160),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  LO => M9_15_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q12z: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q0z: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(1));
R_DPATH_RET_52_RNO_1: LUT6_L 
generic map(
  INIT => X"040C44CC050F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(39),
  I2 => GRLFPC20_FPO_FRAC(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_48_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q56z: LUT5 
generic map(
  INIT => X"08000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I3 => N_1210,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_M_0(0));
R_DPATH_RET_15_RNO_2: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(162),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_17_2);
R_DPATH_RET_9_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(134),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_49_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q12z: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(128),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_43_2);
R_DPATH_RET_3_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(126),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_41_2);
R_DPATH_RET_19_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(164),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_19_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q20z: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(136),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_21_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq245z: LUT6_L 
generic map(
  INIT => X"00BF008000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(232),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => N_1199,
  I5 => N_6_MUX_39_I,
  LO => N_5_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_RNIL0GT1q2z: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_RNIO2FT1q2z: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q21z: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(22));
R_DPATH_RET_22_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(144),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_29_2);
R_DPATH_RET_16_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(143),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_28_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q57z: LUT6 
generic map(
  INIT => X"0008000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(0),
  I5 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(1));
R_DPATH_RET_11_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(138),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_23_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q55z: LUT6_L 
generic map(
  INIT => X"105030F0115533FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(55),
  I2 => N_1267,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  LO => M8_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_RNIAGHU1q2z: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(30));
R_DPATH_RET_6_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(142),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_27_2);
R_DPATH_RET_23_RNO_4: LUT6_L 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(169),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  LO => M9_3_2);
R_DPATH_RET_26_RNO_2: LUT5_L 
generic map(
  INIT => X"0000E0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(7),
  I2 => M9_0_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(8),
  LO => M9_0_1_0);
R_DPATH_RET_24_RNO_2: LUT5_L 
generic map(
  INIT => X"0000E0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(5),
  I2 => M9_2_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(6),
  LO => M9_2_1_0);
R_DPATH_RET_26_RNO_3: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(166),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q20z: LUT6_L 
generic map(
  INIT => X"C800FA00CC00FF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(37),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(37),
  I3 => M9_21_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => M9_21_1_0);
R_DPATH_RET_18_RNO_3: LUT6_L 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(145),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  LO => M9_30_2);
R_DPATH_RET_24_RNO_3: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(168),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_2_2);
GRLFPC20_R_FSR_CEXC_RNO_1q1z: LUT5 
generic map(
  INIT => X"00000080"
)
port map (
  I0 => cpi_lddata(1),
  I1 => rst,
  I2 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I3 => GRLFPC20_COMB_V_STATE14,
  I4 => GRLFPC20_COMB_V_FSR_FCC10,
  O => GRLFPC20_FPCI_M(353));
GRLFPC20_R_FSR_CEXC_RNO_1q2z: LUT5 
generic map(
  INIT => X"00000080"
)
port map (
  I0 => cpi_lddata(2),
  I1 => rst,
  I2 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I3 => GRLFPC20_COMB_V_STATE14,
  I4 => GRLFPC20_COMB_V_FSR_FCC10,
  O => GRLFPC20_FPCI_M(354));
GRLFPC20_R_FSR_CEXC_RNO_1q3z: LUT5 
generic map(
  INIT => X"00000080"
)
port map (
  I0 => cpi_lddata(3),
  I1 => rst,
  I2 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I3 => GRLFPC20_COMB_V_STATE14,
  I4 => GRLFPC20_COMB_V_FSR_FCC10,
  O => GRLFPC20_FPCI_M(355));
R_DPATH_RET_20_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(132),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_47_2);
R_DPATH_RET_12_RNO_5: LUT6_L 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(131),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  LO => M9_46_2);
R_DPATH_RET_25_RNO_2: LUT5_L 
generic map(
  INIT => X"0000E0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(16),
  I2 => M9_12_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(17),
  LO => M9_12_1_0);
R_DPATH_RET_21_RNO_4: LUT6_L 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(146),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  LO => M9_31_2);
R_DPATH_RET_17_RNO_4: LUT6_L 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(148),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  LO => M9_33_2);
R_DPATH_RET_10_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(153),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_8_2);
GRLFPC20_R_FSR_CEXC_RNO_1q4z: LUT5 
generic map(
  INIT => X"00000080"
)
port map (
  I0 => cpi_lddata(4),
  I1 => rst,
  I2 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I3 => GRLFPC20_COMB_V_STATE14,
  I4 => GRLFPC20_COMB_V_FSR_FCC10,
  O => GRLFPC20_FPCI_M(356));
GRLFPC20_R_FSR_CEXC_RNO_1q0z: LUT5 
generic map(
  INIT => X"00000080"
)
port map (
  I0 => cpi_lddata(0),
  I1 => rst,
  I2 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I3 => GRLFPC20_COMB_V_STATE14,
  I4 => GRLFPC20_COMB_V_FSR_FCC10,
  O => GRLFPC20_FPCI_M(352));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q21z: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(137),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_22_2);
R_DPATH_RET_14_RNO_3: LUT6_L 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(154),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  LO => M9_9_2);
R_DPATH_RET_5_RNO_0: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(147),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_32_2);
R_DPATH_RET_8_RNO_1: LUT6 
generic map(
  INIT => X"FFF5F3FFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(149),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I5 => M20_E_0,
  O => M9_34_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q57z: LUT5 
generic map(
  INIT => X"40440000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2780,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(0));
R_DPATH_RET_47_RNO_0: LUT6_L 
generic map(
  INIT => X"FFF7FFFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(44),
  I4 => M20_E_0,
  I5 => M9_44_0_1,
  LO => M9_44_1_0);
R_DPATH_RET_32_RNO_0: LUT6_L 
generic map(
  INIT => X"FFF7FFFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(33),
  I4 => M20_E_0,
  I5 => M9_25_0_1,
  LO => M9_25_1_0);
R_DPATH_RET_44_RNO_0: LUT6_L 
generic map(
  INIT => X"FFF7FFFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(34),
  I4 => M20_E_0,
  I5 => M9_24_0_1,
  LO => M9_24_1_0);
R_DPATH_RET_38_RNO_0: LUT6_L 
generic map(
  INIT => X"FFF7FFFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(10),
  I4 => M20_E_0,
  I5 => M9_18_0_1,
  LO => M9_18_1_0);
R_DPATH_RET_29_RNO_0: LUT6_L 
generic map(
  INIT => X"FFF7FFFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(46),
  I4 => M20_E_0,
  I5 => M9_42_0_1,
  LO => M9_42_1_0);
R_DPATH_RET_35_RNO_0: LUT6_L 
generic map(
  INIT => X"FFF7FFFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(43),
  I4 => M20_E_0,
  I5 => M9_45_0_1,
  LO => M9_45_1_0);
R_DPATH_RET_41_RNO_0: LUT6_L 
generic map(
  INIT => X"FFF7FFFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(32),
  I4 => M20_E_0,
  I5 => M9_26_0_1,
  LO => M9_26_1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_RNIG2571q39z: LUT5 
generic map(
  INIT => X"00800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(39),
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M_0(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_1q7z: LUT4 
generic map(
  INIT => X"CCCA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(53),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2216);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_1q6z: LUT5 
generic map(
  INIT => X"F3F3F3AA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2215);
R_DPATH_RET_20_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(16),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_47_3);
R_DPATH_RET_11_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(22),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_23_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNII39032: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(31),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_32_3);
R_DPATH_RET_19_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(48),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_19_3);
R_DPATH_RET_8_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_34_3);
R_DPATH_RET_9_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(18),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_49_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNIE7DM32: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_45_3);
R_DPATH_RET_24_RNO_0: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_2_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q36z: LUT5_L 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => M9_7_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q34z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_5_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNI46RPN1: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_41_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNIVTS5L1: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_24_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q54z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(54),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_4_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNI70UQD1: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_18_3);
R_DPATH_RET_10_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(37),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_8_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI79SUH2q12z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_42_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q20z: LUT5_L 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(20),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => M9_21_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q51z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_1_3);
R_DPATH_RET_26_RNO_0: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(50),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_0_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q49z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(49),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNILD8602: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(13),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_44_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNIEV6VN1: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(25),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_26_3);
R_DPATH_RET_15_RNO_3: LUT5_L 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(46),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => M9_17_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q7z: LUT5 
generic map(
  INIT => X"4CCC5FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(50),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M20_E_38_2);
R_DPATH_RET_25_RNO_0: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(41),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_12_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_RNI85J4G1: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_25_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q8z: LUT5 
generic map(
  INIT => X"4CCC5FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M20_E_39_2);
R_DPATH_RET_22_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(28),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_29_3);
R_DPATH_RET_16_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_28_3);
R_DPATH_RET_6_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_27_3);
R_DPATH_RET_13_RNO_2: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_14_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q42z: LUT5_L 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => M9_13_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q39z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_10_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q45z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_16_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q40z: LUT5 
generic map(
  INIT => X"153F55FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => M9_11_3);
R_DPATH_RET_53_RNO: LUT6_L 
generic map(
  INIT => X"4CCC5FFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(52),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I5 => M20_E_36_1,
  LO => M20_E_36_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq252z: LUT6_L 
generic map(
  INIT => X"E4FFE400E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(57),
  I2 => GRLFPC20_FPI_OP1(60),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2328,
  I5 => N_6_MUX_39_I,
  LO => N_3_48_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq257z: LUT6_L 
generic map(
  INIT => X"F3E2D1C0F0F0F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I1 => GRLFPC20_FPI_LDOP,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41(257),
  I3 => GRLFPC20_FPO_EXP(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2309,
  I5 => N_6_MUX_39_I,
  LO => N_3_53_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq250z: LUT6_L 
generic map(
  INIT => X"E4FFE400E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(59),
  I2 => GRLFPC20_FPI_OP1(62),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2330,
  I5 => N_6_MUX_39_I,
  LO => N_3_46_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq256z: LUT6_L 
generic map(
  INIT => X"D8FFD800D8D8D8D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(56),
  I2 => GRLFPC20_FPI_OP1(53),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2324,
  I5 => N_6_MUX_39_I,
  LO => N_3_52_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq253z: LUT6_L 
generic map(
  INIT => X"E4FFE400E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(56),
  I2 => GRLFPC20_FPI_OP1(59),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2327,
  I5 => N_6_MUX_39_I,
  LO => N_3_49_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq254z: LUT6_L 
generic map(
  INIT => X"F3E2D1C0F0F0F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I1 => GRLFPC20_FPI_LDOP,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41(254),
  I3 => GRLFPC20_FPO_EXP(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2312,
  I5 => N_6_MUX_39_I,
  LO => N_3_50_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq251z: LUT6_L 
generic map(
  INIT => X"F3E2D1C0F0F0F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I1 => GRLFPC20_FPI_LDOP,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_41(251),
  I3 => GRLFPC20_FPO_EXP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2315,
  I5 => N_6_MUX_39_I,
  LO => N_3_47_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq255z: LUT6_L 
generic map(
  INIT => X"E4FFE400E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(54),
  I2 => GRLFPC20_FPI_OP1(57),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2325,
  I5 => N_6_MUX_39_I,
  LO => N_3_51_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq248z: LUT5_L 
generic map(
  INIT => X"4F404444"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I1 => GRLFPC20_FPI_OP1(61),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2332,
  I4 => N_6_MUX_39_I,
  LO => N_3_44_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21_Z7209: LUT6 
generic map(
  INIT => X"0000000000040000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20_Z7210: LUT6 
generic map(
  INIT => X"0000000000100000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_1q5z: LUT4 
generic map(
  INIT => X"CCCA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2214);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22_Z7212: LUT6 
generic map(
  INIT => X"0000000000400000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23_Z7213: LUT6 
generic map(
  INIT => X"0000000000020000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA_Z7214: LUT6 
generic map(
  INIT => X"0000000000200000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA);
GRLFPC20_V_FSR_FTT_CNSTq1z_Z7215: LUT6_L 
generic map(
  INIT => X"0000008000800080"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_I_EXC(5),
  I2 => GRLFPC20_COMB_UN1_R_I_V_1,
  I3 => GRLFPC20_COMB_V_STATE14,
  I4 => GRLFPC20_V_FSR_FTT_2_SQMUXA_1_0,
  I5 => GRLFPC20_WREN2_1_SQMUXA_1,
  LO => GRLFPC20_V_FSR_FTT_CNST(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI94UT1q47z: LUT6 
generic map(
  INIT => X"00FC005400000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(47),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(12),
  I5 => I2_I_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_0);
GRLFPC20_V_I_V_3_SQMUXA_3_Z7217: LUT6_L 
generic map(
  INIT => X"0000000000000010"
)
port map (
  I0 => GRLFPC20_COMB_UN2_HOLDN,
  I1 => GRLFPC20_COMB_UN19_IUEXEC,
  I2 => GRLFPC20_V_I_V_1_SQMUXA,
  I3 => GRLFPC20_N_824_1,
  I4 => GRLFPC20_N_824_3,
  I5 => GRLFPC20_COMB_WREN129,
  LO => GRLFPC20_V_I_V_3_SQMUXA_3);
GRLFPC20_V_FSR_FTT_CNSTq2z_Z7218: LUT6_L 
generic map(
  INIT => X"0000002A002A002A"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_I_EXC(5),
  I2 => GRLFPC20_COMB_UN1_R_I_V_1,
  I3 => GRLFPC20_COMB_V_STATE14,
  I4 => GRLFPC20_V_FSR_FTT_2_SQMUXA_1_0,
  I5 => GRLFPC20_WREN2_1_SQMUXA_1,
  LO => GRLFPC20_V_FSR_FTT_CNST(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1q3z_Z7219: LUT6_L 
generic map(
  INIT => X"F0F0E4E4FFF0FFA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2203,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_1q1z: LUT6 
generic map(
  INIT => X"F3F3F3F3F3FFF3AA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT_IV_0(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN3_LOCUV_M,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2210);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1q1z_Z7221: LUT6_L 
generic map(
  INIT => X"FFFFCC88FCF8FCF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2201,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2196,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2210,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_8_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIVIR42_0q3z: LUT6 
generic map(
  INIT => X"F0F0F0F0FFFEF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => N_6_MUX_106_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIVIR42q3z: LUT6 
generic map(
  INIT => X"F0F0F0F0FFFEF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I4 => I2_I_4,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIPDTG2q27z: LUT5 
generic map(
  INIT => X"00000100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(27),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_EXPAREGLOADEN_274_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28q75z: LUT6 
generic map(
  INIT => X"FFFDFFA8FF75FF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2187,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2180,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2194,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12(75));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q110z: LUT5 
generic map(
  INIT => X"EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_167(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2536);
GRLFPC20_V_FSR_FTT_CNSTq0z_Z7227: LUT5_L 
generic map(
  INIT => X"00282028"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_COMB_V_STATE14,
  I2 => GRLFPC20_COMB_UN1_R_I_EXC,
  I3 => GRLFPC20_V_FSR_FTT_2_SQMUXA_1_0,
  I4 => GRLFPC20_WREN2_1_SQMUXA_1,
  LO => GRLFPC20_V_FSR_FTT_CNST(0));
GRLFPC20_COMB_V_MK_BUSY2_2_Z7228: LUT6_L 
generic map(
  INIT => X"00000000084C0000"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_MK_BUSY,
  I2 => GRLFPC20_R_X_FPOP,
  I3 => GRLFPC20_R_X_SEQERR,
  I4 => GRLFPC20_ANNULFPU_1_SQMUXA,
  I5 => GRLFPC20_COMB_UN1_R_I_EXC,
  LO => GRLFPC20_COMB_V_MK_BUSY2_2);
GRLFPC20_R_STATE_RNOq0z: LUT6_L 
generic map(
  INIT => X"CC4CCC4CC040CC4C"
)
port map (
  I0 => cpi_exack,
  I1 => rst,
  I2 => GRLFPC20_R_STATE(0),
  I3 => GRLFPC20_R_STATE(1),
  I4 => GRLFPC20_V_I_V_1_SQMUXA,
  I5 => GRLFPC20_COMB_UN1_R_I_EXC,
  LO => GRLFPC20_V_STATE_1(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0q75z_Z7230: LUT6 
generic map(
  INIT => X"FEFEFEFFFCFCFCFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(46),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXC,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_AC0_9: LUT6 
generic map(
  INIT => X"8000000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq123z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(125),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(50),
  LO => N_3_128_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq122z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(124),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(51),
  LO => N_3_127_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq138z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(140),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(35),
  LO => N_3_113_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq129z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(131),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(44),
  LO => N_3_104_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq130z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(132),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(43),
  LO => N_3_105_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq137z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(139),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(36),
  LO => N_3_112_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq120z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(122),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(53),
  LO => N_3_125_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq121z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(123),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(52),
  LO => N_3_126_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq116z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(118),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => N_1267,
  LO => N_3_121_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq127z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(129),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(46),
  LO => N_3_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq173z: LUT5_L 
generic map(
  INIT => X"5F005D00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I2 => GRLFPC20_FPI_LDOP,
  I3 => N_1210,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  LO => N_5_MUX_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq124z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(126),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(49),
  LO => N_3_99_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq125z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(127),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(48),
  LO => N_3_100_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq128z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(130),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(45),
  LO => N_3_103_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq136z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(138),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(37),
  LO => N_3_111_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq135z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(137),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(38),
  LO => N_3_110_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq118z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(120),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => N_1265,
  LO => N_3_123_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq163z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(165),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(10),
  LO => N_3_78_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq166z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(168),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(7),
  LO => N_3_81_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq145z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(147),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(28),
  LO => N_3_90_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq147z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(149),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(26),
  LO => N_3_92_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq148z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(150),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(25),
  LO => N_3_93_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq149z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(151),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(24),
  LO => N_3_94_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq153z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(155),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(20),
  LO => N_3_98_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq154z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(156),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(19),
  LO => N_3_69_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq168z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(170),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(5),
  LO => N_3_83_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq156z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(158),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(17),
  LO => N_3_71_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq119z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(121),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(54),
  LO => N_3_124_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq161z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(163),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(12),
  LO => N_3_76_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq162z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(164),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(11),
  LO => N_3_77_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq165z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(167),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(8),
  LO => N_3_80_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq151z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(153),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(22),
  LO => N_3_96_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq146z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(148),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(27),
  LO => N_3_91_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq150z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(152),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(23),
  LO => N_3_95_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq134z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(136),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(39),
  LO => N_3_109_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq152z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(154),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(21),
  LO => N_3_97_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq155z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(157),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(18),
  LO => N_3_70_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq126z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(128),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(47),
  LO => N_3_101_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq159z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(161),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(14),
  LO => N_3_74_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq144z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(146),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(29),
  LO => N_3_89_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq167z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(169),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(6),
  LO => N_3_82_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq164z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(166),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(9),
  LO => N_3_79_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq131z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(133),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(42),
  LO => N_3_106_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq117z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(119),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => N_1266,
  LO => N_3_122_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq139z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(141),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(34),
  LO => N_3_84_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq160z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(162),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(13),
  LO => N_3_75_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq143z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(145),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(30),
  LO => N_3_88_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq158z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(160),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(15),
  LO => N_3_73_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq133z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(135),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(40),
  LO => N_3_108_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq132z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(134),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(41),
  LO => N_3_107_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq157z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(159),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(16),
  LO => N_3_72_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq170z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(172),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(3),
  LO => N_3_65_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq140z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(142),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(33),
  LO => N_3_85_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq169z: LUT6_L 
generic map(
  INIT => X"BBFFBBFB88008808"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(171),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_FPO_FRAC(4),
  LO => N_3_64_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_Z7286: LUT5 
generic map(
  INIT => X"00000010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I1 => GRLFPC20_FPI_LDOP,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q112z: LUT6 
generic map(
  INIT => X"E2EEEEE222E2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_AXB2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2534);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q80z: LUT6 
generic map(
  INIT => X"E2EEEEE222E2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2566);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q73z: LUT6 
generic map(
  INIT => X"E2EEEEE222E2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2573);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q68z: LUT5 
generic map(
  INIT => X"EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_125(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2578);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q58z: LUT5 
generic map(
  INIT => X"EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1,
  I3 => N_1383_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2588);
GRLFPC20_COMB_V_STATE_9_IVq0z: LUT6 
generic map(
  INIT => X"FFFFFFFFFDFCF5F0"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_I_EXC(5),
  I2 => GRLFPC20_R_STATE(0),
  I3 => GRLFPC20_R_X_SEQERR,
  I4 => GRLFPC20_COMB_UN1_R_I_V_1,
  I5 => GRLFPC20_COMB_V_STATE14,
  O => GRLFPC20_COMB_V_STATE_9(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q92z: LUT5 
generic map(
  INIT => X"EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_SI_149(20),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2554);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q61z: LUT6 
generic map(
  INIT => X"E2EEEEE222E2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_AXB1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2585);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIKQLC41q49z: LUT6 
generic map(
  INIT => X"366CC993C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq369z: LUT6_L 
generic map(
  INIT => X"CDDFFEEC044CC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(110));
GRLFPC20_ANNULRES_1_IV: LUT5 
generic map(
  INIT => X"FFFFFF20"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_X_FPOP,
  I3 => GRLFPC20_COMB_UN1_R_I_EXC,
  I4 => GRLFPC20_N_824_3,
  O => GRLFPC20_ANNULRES_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q88z: LUT6 
generic map(
  INIT => X"E2EE22E2EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2558);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q62z: LUT6 
generic map(
  INIT => X"E2EEEEE222E2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2584);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_0q0z: LUT6 
generic map(
  INIT => X"F0F0F0F00F8BAAAA"
)
port map (
  I0 => cpi_d_inst(10),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2200);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_RNIF0AP1q31z: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(33),
  I3 => GRLFPC20_FPO_FRAC(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_24_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNI8AEC1q32z: LUT6 
generic map(
  INIT => X"001B1B1B00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_116,
  I3 => GRLFPC20_FPO_FRAC(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_25_1);
R_DPATH_RET_14_RNO_2: LUT6 
generic map(
  INIT => X"001B1B1B00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(18),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(16),
  I3 => GRLFPC20_FPO_FRAC(19),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_9_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq327z: LUT6_L 
generic map(
  INIT => X"EFFEAEEA8AA80880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_125(44),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(68));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNICE8QG2q70z: LUT6 
generic map(
  INIT => X"9AA959956556A66A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_125(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(11));
R_DPATH_RET_23_RNO_3: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(3),
  I3 => GRLFPC20_FPO_FRAC(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_3_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2_RNIIBU72q38z: LUT6 
generic map(
  INIT => X"0004090D02060B0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(40),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(39),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4_0q56z_Z7308: LUT5_L 
generic map(
  INIT => X"BA30AA00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_IV_4_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q21z: LUT6_L 
generic map(
  INIT => X"001B1B1B00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(33),
  I3 => GRLFPC20_FPO_FRAC(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_22_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNIE3N32q34z: LUT6 
generic map(
  INIT => X"0A0B0E0F00010405"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(35),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(36),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q21z: LUT6 
generic map(
  INIT => X"0009020B040D060F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(37),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(36),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q49z: LUT6 
generic map(
  INIT => X"0009020B040D060F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(8),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNI4SP32q41z: LUT6 
generic map(
  INIT => X"05070D0F0002080A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(40),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(41),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q39z: LUT6 
generic map(
  INIT => X"00040206090D0B0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(20),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(18),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(19),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q34z: LUT6 
generic map(
  INIT => X"050D070F0008020A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(24),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(23),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(24),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNI2IQC3q11z: LUT6 
generic map(
  INIT => X"050D070F0008020A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAKGA82q73z: LUT6 
generic map(
  INIT => X"EBEBEBBE82828228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_73(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(74));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAKGA82_0q73z: LUT6 
generic map(
  INIT => X"9696966969696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_73(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1q0z_Z7319: LUT6 
generic map(
  INIT => X"FFD8D8D8FF000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(56),
  I3 => N_1266,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_1(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNID5Q32q44z: LUT6 
generic map(
  INIT => X"05070D0F0002080A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(43),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(44),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q39z: LUT6_L 
generic map(
  INIT => X"001B1B1B00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(15),
  I3 => GRLFPC20_FPO_FRAC(18),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  LO => M9_10_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2_RNIOJ082q47z: LUT6 
generic map(
  INIT => X"0009020B040D060F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(47),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(46),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq347z: LUT6_L 
generic map(
  INIT => X"ABAFFEFA020AA8A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AC0_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(88));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO_RNIPE4G12: LUT6 
generic map(
  INIT => X"565AA9A5A9A5565A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AC0_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_RNIO9CP1q43z: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(45),
  I3 => GRLFPC20_FPO_FRAC(46),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_42_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_RNII5CP1q43z: LUT6 
generic map(
  INIT => X"001B1B1B00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(41),
  I3 => GRLFPC20_FPO_FRAC(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_44_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_0q2z: LUT6 
generic map(
  INIT => X"AAAAAAAAF0F03CF0"
)
port map (
  I0 => cpi_d_inst(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2202);
R_DPATH_RET_19_RNO_5: LUT6 
generic map(
  INIT => X"0027272700FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(8),
  I3 => GRLFPC20_FPO_FRAC(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M9_19_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN20_STKOUT: LUT6 
generic map(
  INIT => X"0000CF5FFFFFFCF5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN16_NOTPROP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN19_NOTPROP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_2(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_11q0z_Z7330: LUT6 
generic map(
  INIT => X"3A0000003AFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN16_NOTPROP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN19_NOTPROP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_11(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_0q57z_Z7331: LUT6 
generic map(
  INIT => X"FDFFAAAAFDFD0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN10_NOTPROP,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN18_STKGEN_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_GEN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_NOTPROP_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN16_NOTPROP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_1_0(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2_RNIKSFL2: LUT5 
generic map(
  INIT => X"E080FEF8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2,
  I3 => N_1379_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  O => N_1383_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_RNI2AN92: LUT5 
generic map(
  INIT => X"366CC993"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  I3 => N_1379_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_117(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q55z: LUT6 
generic map(
  INIT => X"00FEFEFE00FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I3 => N_1211,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  O => M8_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q2z_Z7335: LUT5 
generic map(
  INIT => X"FFF3FFF5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_2_RNI9GEG2: LUT5 
generic map(
  INIT => X"FAD4D4A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  I4 => N_1379_I,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3_RNIDJO2L: LUT6 
generic map(
  INIT => X"366CC993C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  I3 => N_1379_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_AXB1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq320z: LUT6_L 
generic map(
  INIT => X"CDDFFEEC044CC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  I3 => N_1379_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_AXB1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q42z: LUT6 
generic map(
  INIT => X"53FF530000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(13),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(15),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q8z: LUT6 
generic map(
  INIT => X"050104000F0B0E0A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(51),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4EG8Rq260z: LUT6 
generic map(
  INIT => X"C880FEECFEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_SI_7(50),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_AXB1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_RNIBK0MD: LUT4 
generic map(
  INIT => X"6996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_31(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_27_CI_31_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_RNOq92z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(29),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_AXB0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_CI_34_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_SI_149(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIOSCPDq76z: LUT4 
generic map(
  INIT => X"6996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_SI_18(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISTP5Dq100z: LUT4 
generic map(
  INIT => X"6996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_42(15),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIR1ALP_0q49z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_13(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_129(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q44z_Z7347: LUT6 
generic map(
  INIT => X"DD88DD88F5F5A0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(38),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(44),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q42z_Z7348: LUT6 
generic map(
  INIT => X"DD88DD88F5F5A0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(36),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(38),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(40),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(42),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_RNIB4Q61q13z: LUT6 
generic map(
  INIT => X"35FF350000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(14),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(16),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q23z_Z7350: LUT6 
generic map(
  INIT => X"FF0FF000ACACACAC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(19),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(23),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(21),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q36z: LUT6 
generic map(
  INIT => X"FF27002700000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(21),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(19),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_3_I_Z7352: LUT6 
generic map(
  INIT => X"C333A5550FFFC333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(174),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_SS0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_3_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_CI_113_1_CO0: LUT3 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_56(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_CI_113(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q47z_Z7354: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q12z: LUT6 
generic map(
  INIT => X"0F0E0B0A05040100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(47),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3_RNI2HRE7: LUT6 
generic map(
  INIT => X"36C9C9366C93936C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_57(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_56(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN19_NOTPROP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIAGICJq108z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_SI_50(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_CI_51_C3);
GRLFPC20_R_FSR_CEXC_RNO_0q0z: LUT6 
generic map(
  INIT => X"0000000080000000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_FSR_TEM(0),
  I2 => GRLFPC20_R_I_EXC(0),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_COMB_V_I_EXEC_5,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_MEXC_1_M(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKG2361q326z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_SI_15(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_72(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q7z: LUT6 
generic map(
  INIT => X"0A0208000F070D05"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(53),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(51),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q20z_Z7361: LUT6 
generic map(
  INIT => X"FE76BA32DC549810"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(20),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(22),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q19z_Z7362: LUT6 
generic map(
  INIT => X"FEDC7654BA983210"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(19),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(20),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(22),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q24z_Z7363: LUT6 
generic map(
  INIT => X"FBEA7362D9C85140"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(24),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(27),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(25),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q35z_Z7364: LUT5 
generic map(
  INIT => X"A820FD75"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(38),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q36z_Z7365: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(38),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQNOV01q317z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_5(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_RNO_0q16z: LUT5 
generic map(
  INIT => X"C0804000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_54_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_55_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_I8_MUX_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q45z_Z7368: LUT5 
generic map(
  INIT => X"B800B8FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q43z_Z7369: LUT6 
generic map(
  INIT => X"AACCAACCF0FFF000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(37),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(41),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(43),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q10z_Z7370: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q35z: LUT6 
generic map(
  INIT => X"53FF530000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(16),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(20),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(22),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(23));
GRLFPC20_R_FSR_CEXC_RNO_0q4z: LUT6 
generic map(
  INIT => X"0000000080000000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_FSR_TEM(4),
  I2 => GRLFPC20_R_I_EXC(4),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_COMB_V_I_EXEC_5,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_MEXC_1_M(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q39z_Z7373: LUT5 
generic map(
  INIT => X"00ACFFAC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_RNI2BOUq5z: LUT6 
generic map(
  INIT => X"35FF350000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(7),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_RNINJ3Sq3z: LUT6 
generic map(
  INIT => X"00550F3300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(6));
GRLFPC20_R_FSR_CEXC_RNO_0q3z: LUT6 
generic map(
  INIT => X"0000000080000000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_FSR_TEM(3),
  I2 => GRLFPC20_R_I_EXC(3),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_COMB_V_I_EXEC_5,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_MEXC_1_M(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q35z: LUT6_L 
generic map(
  INIT => X"9D1D850598188000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_54_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_57_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1133);
GRLFPC20_R_FSR_CEXC_RNO_0q1z: LUT6 
generic map(
  INIT => X"0000000080000000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_FSR_TEM(1),
  I2 => GRLFPC20_R_I_EXC(1),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_COMB_V_I_EXEC_5,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_MEXC_1_M(1));
GRLFPC20_R_FSR_CEXC_RNO_0q2z: LUT6 
generic map(
  INIT => X"0000000080000000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_FSR_TEM(2),
  I2 => GRLFPC20_R_I_EXC(2),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_COMB_V_I_EXEC_5,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_MEXC_1_M(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q9z_Z7380: LUT6 
generic map(
  INIT => X"FEBADC9876325410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNISDBR2q79z: LUT4 
generic map(
  INIT => X"0800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_73_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_RNOq50z: LUT6 
generic map(
  INIT => X"1400040010000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_7_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_12_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_775);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q29z_Z7383: LUT5 
generic map(
  INIT => X"5410FEBA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(31),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(30),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q28z_Z7384: LUT6 
generic map(
  INIT => X"FBD9EAC873516240"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(28),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(31),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIGVTD9q359z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(359),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQBDECq353z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(353),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(20),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_16_CI_42_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_100(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q29z_Z7387: LUT6 
generic map(
  INIT => X"CCCCFF00AAAAF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q11z_Z7388: LUT6 
generic map(
  INIT => X"FFAA5500E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(13),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(15),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNII2GO9q322z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(322),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q19z_Z7390: LUT5 
generic map(
  INIT => X"5044FAEE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q17z_Z7391: LUT6 
generic map(
  INIT => X"BBBB1111FA50FA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_111,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(19),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIT0R69q362z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(362),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_SI_50(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_108(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIQ1FLJq9z: LUT6 
generic map(
  INIT => X"FEF8E08000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52(5),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AXB2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AC0_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_RNOq110z: LUT6_L 
generic map(
  INIT => X"01071F7FFEF8E080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52(5),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_AXB2,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_167(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq46z: LUT6_L 
generic map(
  INIT => X"1050101000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6065_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_776,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q40z_Z7396: LUT6 
generic map(
  INIT => X"FFAA5500D8D8D8D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(46),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q43z_Z7397: LUT6 
generic map(
  INIT => X"FFE4AAE455E400E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(45),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(47),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q12z_Z7398: LUT6 
generic map(
  INIT => X"F0F0CCCCFF00AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q8z_Z7399: LUT5 
generic map(
  INIT => X"00F0CCAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q1z_Z7400: LUT6 
generic map(
  INIT => X"FFAA5500E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(7),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIT4GGC_0q344z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(344),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_91(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIT4GGCq344z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(344),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVOO6Cq343z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(343),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_31(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_SI_89(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q15z_Z7404: LUT6 
generic map(
  INIT => X"CCCCFF00F0F0AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q14z_Z7405: LUT6 
generic map(
  INIT => X"AAAAFF00CCCCF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q35z_Z7406: LUT6 
generic map(
  INIT => X"AAAAF0F0FF00CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q5z_Z7407: LUT6 
generic map(
  INIT => X"AAFF0055E4E4E4E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_114,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(11),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q9z_Z7408: LUT6 
generic map(
  INIT => X"FFAA5500B1B1B1B1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_114,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(15),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q7z_Z7409: LUT6 
generic map(
  INIT => X"FFAA55004E4E4E4E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_114,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(13),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIMQ5KCq24z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(24),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(24),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0E4V9q358z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(358),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_46(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q23z_Z7412: LUT5 
generic map(
  INIT => X"4450EEFA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(27),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(25),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q36z_Z7413: LUT5 
generic map(
  INIT => X"5044FAEE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(36),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q47z_Z7414: LUT6 
generic map(
  INIT => X"FEDCBA9876543210"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(51),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q53z_Z7415: LUT5 
generic map(
  INIT => X"FD31EC20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(55),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(57),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q44z_Z7416: LUT6 
generic map(
  INIT => X"FFE4AAE455E400E4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(46),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIU8L5Cq330z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(330),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_SI_18(39),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_76(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_11_RNO_0q0z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(369),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_57(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_2(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q54z_Z7419: LUT6 
generic map(
  INIT => X"F0F0AAAAFF00CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(54));
GRLFPC20_COMB_UN1_R_I_EXC_Z7420: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_R_I_EXC(5),
  I1 => GRLFPC20_R_I_V,
  I2 => GRLFPC20_COMB_V_I_EXEC_5,
  I3 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_COMB_UN1_R_I_EXC);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXCSHFT_UN13_EXMIPTRLSBS_Z7421: LUT6 
generic map(
  INIT => X"0015000000150015"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN3_NOTAZERODENORM,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1(4),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN14_CONDITIONAL,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXCSHFT_UN13_EXMIPTRLSBS);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q16z_Z7422: LUT6 
generic map(
  INIT => X"F0F0AAAACCCCFF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q22z_Z7423: LUT6 
generic map(
  INIT => X"FF00CCCCF0F0AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q18z_Z7424: LUT6 
generic map(
  INIT => X"CCCCF0F0FF00AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q24z_Z7425: LUT6 
generic map(
  INIT => X"AAAACCCCF0F0FF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q20z_Z7426: LUT6 
generic map(
  INIT => X"CCCCFF00AAAAF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q37z_Z7427: LUT6 
generic map(
  INIT => X"F0F0FF00CCCCAAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q39z_Z7428: LUT6 
generic map(
  INIT => X"F0F0AAAACCCCFF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q45z_Z7429: LUT6 
generic map(
  INIT => X"FF00F0F0AAAACCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q41z_Z7430: LUT6 
generic map(
  INIT => X"CCCCAAAAFF00F0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q18z_Z7431: LUT6 
generic map(
  INIT => X"FFAA55004E4E4E4E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(18),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_112,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(24),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q20z_Z7432: LUT6 
generic map(
  INIT => X"FFAA5500B1B1B1B1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_112,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(22),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(24),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(26),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q24z_Z7433: LUT6 
generic map(
  INIT => X"E4E4E4E4FFAA5500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(28),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(24),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(26),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q30z_Z7434: LUT6 
generic map(
  INIT => X"FAFA5050DD88DD88"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(36),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15q49z: LUT6 
generic map(
  INIT => X"FFFF400040004000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4630,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3828_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1731,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_0_1(39),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_717);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1_0_RNOq16z: LUT6_L 
generic map(
  INIT => X"4000200000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_57_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1357);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIS22ECq338z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(338),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_CI_27_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_2_RNIU41R5: LUT6 
generic map(
  INIT => X"1EE17887E11E8778"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3_RNIQSQ96: LUT6 
generic map(
  INIT => X"1EE17887E11E8778"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_RNI4DRUB: LUT6 
generic map(
  INIT => X"78871EE18778E11E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q17z_Z7441: LUT6 
generic map(
  INIT => X"CCCCF0F0FF00AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q13z_Z7442: LUT6 
generic map(
  INIT => X"AAAAFF00CCCCF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q27z_Z7443: LUT6 
generic map(
  INIT => X"CCCCAAAAF0F0FF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2q3z_Z7444: LUT5 
generic map(
  INIT => X"FFF5FFF3"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q51z_Z7445: LUT6_L 
generic map(
  INIT => X"FB73EA62D951C840"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(55),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(57),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(51),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(53),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q50z_Z7446: LUT5 
generic map(
  INIT => X"5140FBEA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(54),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(50),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q48z_Z7447: LUT6 
generic map(
  INIT => X"FB73EA62D951C840"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(54),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4q43z_Z7448: LUT6 
generic map(
  INIT => X"CCCCF0F0AAAAFF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFC6TB_0q326z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(326),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_73(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFC6TBq326z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(326),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_RNOq112z: LUT6 
generic map(
  INIT => X"6996966996696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20_6q49z: LUT6 
generic map(
  INIT => X"0008000400000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3828_I_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3858);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKE8M1q73z: LUT5 
generic map(
  INIT => X"0C53CA30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_3);
GRLFPC20_V_E_STDATA_1_1q8z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(8),
  I1 => rfo2_data1(8),
  I2 => GRLFPC20_R_FSR_AEXC(3),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_570);
GRLFPC20_V_E_STDATA_1_1q22z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(22),
  I1 => rfo2_data1(22),
  I2 => GRLFPC20_R_FSR_NONSTD,
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_584);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES_LUT6_2_RNITLSH1: LUT6 
generic map(
  INIT => X"965AF05A3CF05AF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_11);
GRLFPC20_V_E_STDATA_1_1q27z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(27),
  I1 => rfo2_data1(27),
  I2 => GRLFPC20_R_FSR_TEM(4),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_589);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN10_AREGSIGN_SEL_Z7458: LUT4 
generic map(
  INIT => X"3C5A"
)
port map (
  I0 => rfo1_data2(31),
  I1 => rfo2_data2(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(0),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN10_AREGSIGN_SEL);
GRLFPC20_V_E_STDATA_1_1q13z: LUT6_L 
generic map(
  INIT => X"0F00CCCC0F00AAAA"
)
port map (
  I0 => rfo1_data1(13),
  I1 => rfo2_data1(13),
  I2 => GRLFPC20_R_STATE(0),
  I3 => GRLFPC20_R_STATE(1),
  I4 => GRLFPC20_R_A_AFSR,
  I5 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_575);
GRLFPC20_V_E_STDATA_1_1q5z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(5),
  I1 => rfo2_data1(5),
  I2 => GRLFPC20_R_FSR_AEXC(0),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_567);
GRLFPC20_V_E_STDATA_1_1q15z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(15),
  I1 => rfo2_data1(15),
  I2 => GRLFPC20_R_FSR_FTT(1),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_577);
GRLFPC20_V_E_STDATA_1_1q16z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(16),
  I1 => rfo2_data1(16),
  I2 => GRLFPC20_R_FSR_FTT(2),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_578);
GRLFPC20_V_E_STDATA_1_1q25z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(25),
  I1 => rfo2_data1(25),
  I2 => GRLFPC20_R_FSR_TEM(2),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_587);
GRLFPC20_V_E_STDATA_1_1q24z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(24),
  I1 => rfo2_data1(24),
  I2 => GRLFPC20_R_FSR_TEM(1),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_586);
GRLFPC20_V_E_STDATA_1_1q7z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(7),
  I1 => rfo2_data1(7),
  I2 => GRLFPC20_R_FSR_AEXC(2),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_569);
GRLFPC20_V_E_STDATA_1_1q4z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(4),
  I1 => rfo2_data1(4),
  I2 => GRLFPC20_R_FSR_CEXC(4),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_566);
GRLFPC20_V_E_STDATA_1_1q30z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(30),
  I1 => rfo2_data1(30),
  I2 => GRLFPC20_R_FSR_RD(0),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_592);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q11z_Z7468: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(220),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q14z_Z7469: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(217),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q15z_Z7470: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(216),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q51z_Z7471: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(180),
  I1 => NN_4,
  I2 => NN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q8z_Z7472: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(223),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q23z_Z7473: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(208),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q13z_Z7474: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(218),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q44z_Z7475: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(187),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q28z_Z7476: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(203),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q29z_Z7477: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(202),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q50z_Z7478: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(181),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I2 => NN_4,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q52z_Z7479: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(179),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I2 => NN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q12z_Z7480: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(219),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q38z_Z7481: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(193),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q27z_Z7482: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(204),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q2z_Z7483: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(229),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q32z_Z7484: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(199),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q34z_Z7485: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(197),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q22z_Z7486: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(209),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q56z_Z7487: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(175),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q36z_Z7488: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(195),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q37z_Z7489: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(194),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q5z_Z7490: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(226),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q7z_Z7491: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(224),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q10z_Z7492: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(221),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q16z_Z7493: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(215),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q17z_Z7494: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(214),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q31z_Z7495: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(200),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q42z_Z7496: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(189),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q25z_Z7497: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(206),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q24z_Z7498: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(207),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q20z_Z7499: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(211),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q33z_Z7500: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(198),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q45z_Z7501: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(186),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q47z_Z7502: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(184),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q48z_Z7503: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(183),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q54z_Z7504: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(177),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q39z_Z7505: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(192),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q19z_Z7506: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(212),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q49z_Z7507: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(182),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q35z_Z7508: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(196),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q43z_Z7509: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(188),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q46z_Z7510: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(185),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q55z_Z7511: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(176),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q30z_Z7512: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(201),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q40z_Z7513: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(191),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q21z_Z7514: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(210),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q26z_Z7515: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(205),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q9z_Z7516: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(222),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q57z_Z7517: LUT5_L 
generic map(
  INIT => X"CACC0C00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(174),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q53z_Z7518: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(178),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q18z_Z7519: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(213),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q41z_Z7520: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(190),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q3z_Z7521: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(228),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q4z_Z7522: LUT6 
generic map(
  INIT => X"F0AAF0F000CC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(227),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1q6z_Z7523: LUT6 
generic map(
  INIT => X"CCAACCCC00F00000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(225),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISK6M1q67z: LUT5 
generic map(
  INIT => X"0C53CA30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN);
GRLFPC20_V_E_STDATA_1_1q10z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(10),
  I1 => rfo2_data1(10),
  I2 => NN_1,
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_572);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_RNI86CVq5z: LUT5 
generic map(
  INIT => X"A0C0AFC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_COMPUTECONST_UN25_RESVEC,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2_LUT6_2_RNI2N231q3z: LUT5 
generic map(
  INIT => X"AFC0A0C0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES_LUT6_2_RNIVNSH1: LUT6 
generic map(
  INIT => X"965AF05A3CF05AF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_12: LUT6 
generic map(
  INIT => X"965AF05A3CF05AF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6312);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19q63z_Z7530: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data1(17),
  I1 => rfo1_data1(20),
  I2 => rfo2_data1(17),
  I3 => rfo2_data1(20),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_19(63));
GRLFPC20_V_E_STDATA_1_1q2z: LUT5_L 
generic map(
  INIT => X"F0CCF0AA"
)
port map (
  I0 => rfo1_data1(2),
  I1 => rfo2_data1(2),
  I2 => GRLFPC20_R_FSR_CEXC(2),
  I3 => GRLFPC20_R_A_AFSR,
  I4 => GRLFPC20_COMB_UN1_R_A_RS1_1,
  LO => GRLFPC20_N_564);
R_DPATH_RET_50_RNO_2: LUT6 
generic map(
  INIT => X"051545550F3FCFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPI_OP2(48),
  I4 => GRLFPC20_FPI_OP2(51),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  O => M9_37_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q51z_Z7533: LUT5 
generic map(
  INIT => X"C0A0CFAF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TOPBITSIN(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(51),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2q55z_Z7534: LUT6 
generic map(
  INIT => X"0F0F0F0F33333355"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TOPBITSIN(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_3q7z: LUT6_L 
generic map(
  INIT => X"0000022000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3425_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1634);
GRLFPC20_COMB_V_STATE14_Z7536: LUT6 
generic map(
  INIT => X"00000000F0F080C0"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_V,
  I3 => GRLFPC20_R_X_SEQERR,
  I4 => GRLFPC20_V_I_EXEC_0_SQMUXA,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_COMB_V_STATE14);
GRLFPC20_COMB_UN1_R_I_V_1_Z7537: LUT6 
generic map(
  INIT => X"F0F080C000000000"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_V,
  I3 => GRLFPC20_R_X_SEQERR,
  I4 => GRLFPC20_V_I_EXEC_0_SQMUXA,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_COMB_UN1_R_I_V_1);
GRLFPC20_V_I_V_1_SQMUXA_Z7538: LUT6 
generic map(
  INIT => X"AAFFAAFF0A0F2A3F"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_V,
  I3 => GRLFPC20_R_X_SEQERR,
  I4 => GRLFPC20_V_I_EXEC_0_SQMUXA,
  I5 => GRLFPC20_COMB_UN1_MEXC,
  O => GRLFPC20_V_I_V_1_SQMUXA);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_UN213_TEMP_LUT6_2_RNIFBEJ7: LUT6 
generic map(
  INIT => X"CC5AFFFF33A50000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6205,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_41(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_RNIHFJA1q5z: LUT6 
generic map(
  INIT => X"AAFFCC00AAF0CC00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_COMPUTECONST_UN25_RESVEC,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_3_I_RNO: LUT6 
generic map(
  INIT => X"FFFFFFFFEAC0153F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZYBUS24_SN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN15_NOTXZYFROMD,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_SS0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q29z_Z7542: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(286),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIDIBF1q11z: LUT6 
generic map(
  INIT => X"00000000AAAAAAA2"
)
port map (
  I0 => rfo2_data2(13),
  I1 => rst,
  I2 => GRLFPC20_R_MK_LDOP,
  I3 => GRLFPC20_R_MK_RST,
  I4 => GRLFPC20_R_MK_RST2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN561_TEMP: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6114);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q19z: LUT6 
generic map(
  INIT => X"555F91805181C5D7"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_901_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_1q79z: LUT5 
generic map(
  INIT => X"00404000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1243_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_UN306_TEMP_LUT6_2_RNIV13D3: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6236,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIE4FN3q70z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_UN306_TEMP_LUT6_2_RNI9OUU2: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6199,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILCGN3q77z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_UN213_TEMP_LUT6_2_RNIT1N93: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6230,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_UN234_TEMP_LUT6_2_RNI9GN83: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6223,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_UN234_TEMP_LUT6_2_RNID0JQ2: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6192,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNID2EN3q64z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIB0EN3q64z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVE7R2q112z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITA5R2q101z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIH8GN3q76z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_38_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1_Z7559: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHCKN3q93z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_UN234_TEMP_LUT6_2_RNIK6IQ2: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6192,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIBP5R2q108z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_UN306_TEMP_LUT6_2_RNI7MUU2: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6199,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIR85R2q100z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI9N5R2q108z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI5J5R2q106z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3H5R2q104z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIICJN3q89z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN198_TEMP_LUT6_2_RNIL3FN3: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6234,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHAIN3q85z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIF8IN3q83z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_RNIU2CJ3: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6242,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN219_TEMP_RNIA9MC3: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6228,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIB6KN3q90z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_UN282_TEMP_LUT6_2_RNIGSRD3: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6214,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_UN285_TEMP_LUT6_2_RNICPHN3: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6220,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7UFN3q70z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_UN285_TEMP_LUT6_2_RNIANHN3: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6220,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3_Z7579: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI9UDN3q62z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7L5R2q106z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_7_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_UN282_TEMP_LUT6_2_RNIEQRD3: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6214,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRVC93q100z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRMKN3q98z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_UN213_TEMP_LUT6_2_RNI6DP93: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6205,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIJAGN3q76z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNID8KN3q91z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIFAKN3q93z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3_Z7589: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6242,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_UN282_TEMP_LUT6_2_RNICPSD3: LUT6 
generic map(
  INIT => X"0A55AA5003333330"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6207,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI92IN3q80z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3_Z7592: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIJCIN3q85z: LUT6 
generic map(
  INIT => X"0A55AA500C33CC30"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_28_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_UN234_TEMP_LUT6_2_RNI2AO83: LUT6 
generic map(
  INIT => X"033333300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6223,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7SDN3q62z: LUT6 
generic map(
  INIT => X"0C33CC300A55AA50"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN);
GRLFPC20_FPI_OP1q51z_Z7596: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(19),
  I2 => rfo2_data1(19),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_16q56z: LUT6_L 
generic map(
  INIT => X"0000040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4151);
GRLFPC20_FPI_OP1q53z_Z7598: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(21),
  I2 => rfo2_data1(21),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNI04ID1q11z: LUT6 
generic map(
  INIT => X"FCFA00000C0A0000"
)
port map (
  I0 => rfo1_data2(9),
  I1 => rfo2_data2(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(13));
GRLFPC20_R_I_RES_RNOq38z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(9),
  I1 => rfo2_data2(9),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(41),
  LO => N_3_22_I);
GRLFPC20_FPI_OP1q42z_Z7601: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(10),
  I2 => rfo2_data1(10),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(42));
GRLFPC20_FPI_OP1q48z_Z7602: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(16),
  I2 => rfo2_data1(16),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_13q36z: LUT6 
generic map(
  INIT => X"0000000100000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3732);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q7z_Z7604: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(308),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_2q11z: LUT6_L 
generic map(
  INIT => X"0000004000400000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3014);
GRLFPC20_R_I_RES_RNOq43z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(14),
  I1 => rfo2_data2(14),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(46),
  LO => N_3_17_I);
GRLFPC20_COMB_UN2_HOLDN_Z7607: LUT5 
generic map(
  INIT => X"10000000"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => holdn,
  I3 => GRLFPC20_R_A_MOV,
  I4 => GRLFPC20_R_A_FPOP,
  O => GRLFPC20_COMB_UN2_HOLDN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1q0z: LUT4 
generic map(
  INIT => X"D0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2813);
GRLFPC20_FPI_OP1q40z_Z7609: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(8),
  I2 => rfo2_data1(8),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O19_5q36z: LUT4 
generic map(
  INIT => X"F305"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3712);
GRLFPC20_V_X_FPOP_1_Z7611: LUT3_L 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_m_annul,
  I1 => cpi_m_trap,
  I2 => GRLFPC20_R_M_FPOP,
  LO => GRLFPC20_V_X_FPOP_1);
GRLFPC20_FPI_OP1q44z_Z7612: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(12),
  I2 => rfo2_data1(12),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q9z_Z7613: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(306),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q11z_Z7614: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(304),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q12z_Z7615: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(303),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q24z_Z7616: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(291),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1_2_Z7617: LUT4 
generic map(
  INIT => X"0001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_COUNTSUCCESSIVEZERO_0_SQMUXA_5_1_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q35z_Z7618: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(280),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q36z_Z7619: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(279),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q39z_Z7620: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(276),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q43z_Z7621: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(272),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQN9A1q115z: LUT5 
generic map(
  INIT => X"AAAAFC00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(115),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q50z_Z7623: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(265),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_19q48z: LUT6 
generic map(
  INIT => X"0000000000040000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3799);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVGQLq257z: LUT4 
generic map(
  INIT => X"6F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0));
GRLFPC20_FPI_OP1q36z_Z7626: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(4),
  I2 => rfo2_data1(4),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(36));
GRLFPC20_V_I_EXC_1q1z_Z7627: LUT4_L 
generic map(
  INIT => X"0040"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(41),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  LO => GRLFPC20_V_I_EXC_1(1));
GRLFPC20_FPI_OP1q39z_Z7628: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(7),
  I2 => rfo2_data1(7),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(39));
GRLFPC20_FPI_OP1q47z_Z7629: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(15),
  I2 => rfo2_data1(15),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI24T01q111z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNI0KN61q11z: LUT6 
generic map(
  INIT => X"00000000AAAAAAA2"
)
port map (
  I0 => rfo2_data2(7),
  I1 => rst,
  I2 => GRLFPC20_R_MK_LDOP,
  I3 => GRLFPC20_R_MK_RST,
  I4 => GRLFPC20_R_MK_RST2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIPM9A1q3z: LUT5 
generic map(
  INIT => X"F0F0EE00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIDI5A1q11z: LUT6 
generic map(
  INIT => X"CCF0AAF000000000"
)
port map (
  I0 => rfo1_data2(0),
  I1 => rfo2_data2(0),
  I2 => rfo2_data2(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I4 => GRLFPC20_COMB_UN1_FPCI_4,
  I5 => GRLFPC20_FPI_LDOP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(25));
GRLFPC20_R_I_RES_RNOq29z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(0),
  I1 => rfo2_data2(0),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(32),
  LO => N_3_31_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNI7D6A1q11z: LUT6 
generic map(
  INIT => X"CCF0AAF000000000"
)
port map (
  I0 => rfo1_data2(1),
  I1 => rfo2_data2(1),
  I2 => rfo2_data2(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I4 => GRLFPC20_COMB_UN1_FPCI_4,
  I5 => GRLFPC20_FPI_LDOP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q21z: LUT6 
generic map(
  INIT => X"FCFA00000C0A0000"
)
port map (
  I0 => rfo1_data2(1),
  I1 => rfo2_data2(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(21));
GRLFPC20_R_I_RES_RNOq30z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(1),
  I1 => rfo2_data2(1),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(33),
  LO => N_3_30_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14_9q34z: LUT6_L 
generic map(
  INIT => X"0040000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3671);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2_1_0q16z: LUT6 
generic map(
  INIT => X"0000800000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1699_1);
GRLFPC20_R_I_RES_RNOq36z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(7),
  I1 => rfo2_data2(7),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(39),
  LO => N_3_24_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNI01FD1q11z: LUT6 
generic map(
  INIT => X"CFAF0000C0A00000"
)
port map (
  I0 => rfo1_data2(8),
  I1 => rfo2_data2(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(17));
GRLFPC20_R_I_RES_RNOq37z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(8),
  I1 => rfo2_data2(8),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(40),
  LO => N_3_23_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNINQEA1q11z: LUT6 
generic map(
  INIT => X"FCFA00000C0A0000"
)
port map (
  I0 => rfo1_data2(12),
  I1 => rfo2_data2(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(47),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(10));
GRLFPC20_R_I_RES_RNOq41z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(12),
  I1 => rfo2_data2(12),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(44),
  LO => N_3_19_I);
GRLFPC20_R_I_RES_RNOq44z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(15),
  I1 => rfo2_data2(15),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(47),
  LO => N_3_16_I);
GRLFPC20_R_I_RES_RNOq46z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(17),
  I1 => rfo2_data2(17),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(49),
  LO => N_3_14_I);
GRLFPC20_R_I_RES_RNOq47z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(18),
  I1 => rfo2_data2(18),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(50),
  LO => N_3_13_I);
GRLFPC20_R_I_RES_RNOq48z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(19),
  I1 => rfo2_data2(19),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(51),
  LO => N_3_12_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q243z_Z7649: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(21),
  I1 => rfo1_data2(24),
  I2 => rfo2_data2(21),
  I3 => rfo2_data2(24),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(243));
GRLFPC20_R_I_RES_RNOq50z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(21),
  I1 => rfo2_data2(21),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(53),
  LO => N_3_10_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIMMED1q11z: LUT6 
generic map(
  INIT => X"FCFA00000C0A0000"
)
port map (
  I0 => rfo1_data2(3),
  I1 => rfo2_data2(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(19));
GRLFPC20_R_I_RES_RNOq32z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(3),
  I1 => rfo2_data2(3),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(35),
  LO => N_3_28_I);
GRLFPC20_FPI_OP1q62z_Z7653: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(30),
  I2 => rfo2_data1(30),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(62));
GRLFPC20_FPI_OP1q45z_Z7654: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(13),
  I2 => rfo2_data1(13),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIPM9A1q6z: LUT5 
generic map(
  INIT => X"F0F0EE00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIREN61q11z: LUT6 
generic map(
  INIT => X"00000000AAAAAAA2"
)
port map (
  I0 => rfo2_data2(2),
  I1 => rst,
  I2 => GRLFPC20_R_MK_LDOP,
  I3 => GRLFPC20_R_MK_RST,
  I4 => GRLFPC20_R_MK_RST2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNITGN61q11z: LUT6 
generic map(
  INIT => X"00000000AAAAAAA2"
)
port map (
  I0 => rfo2_data2(4),
  I1 => rst,
  I2 => GRLFPC20_R_MK_LDOP,
  I3 => GRLFPC20_R_MK_RST,
  I4 => GRLFPC20_R_MK_RST2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITJ2F1q86z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(29));
GRLFPC20_R_MK_BUSY2_RNINJ6A1: LUT6 
generic map(
  INIT => X"FFFF0002FFFF0000"
)
port map (
  I0 => GRLFPC20_R_MK_BUSY2,
  I1 => GRLFPC20_R_MK_BUSY,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  I4 => GRLFPC20_COMB_UN2_HOLDN,
  I5 => GRLFPC20_COMB_LOCKGEN_DEPCHECK,
  O => N_6_MUX_I);
GRLFPC20_R_I_RES_RNOq45z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(16),
  I1 => rfo2_data2(16),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(48),
  LO => N_3_15_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_9_1q13z_Z7661: LUT5 
generic map(
  INIT => X"00000048"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_9_1(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_0_Z7662: LUT6_L 
generic map(
  INIT => X"DFFFCFEFDFFFDFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3127_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6065_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_0);
GRLFPC20_V_E_AFQ_1_Z7663: LUT3_L 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => GRLFPC20_R_A_AFQ,
  LO => GRLFPC20_V_E_AFQ_1);
GRLFPC20_V_M_AFQ_1_Z7664: LUT3_L 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_e_annul,
  I1 => cpi_e_trap,
  I2 => GRLFPC20_R_E_AFQ,
  LO => GRLFPC20_V_M_AFQ_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_15_1q56z_Z7665: LUT6 
generic map(
  INIT => X"000C000800000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_15_1(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNINJ712q54z: LUT5 
generic map(
  INIT => X"06F6F606"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_2_0_I(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_0_1q61z: LUT5 
generic map(
  INIT => X"02020A00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_0_0(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_4q61z: LUT6 
generic map(
  INIT => X"0000000010504000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4520);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK_Z7669: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK);
GRLFPC20_FPI_OP1q59z_Z7670: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(27),
  I2 => rfo2_data1(27),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(59));
GRLFPC20_FPI_OP1q61z_Z7671: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(29),
  I2 => rfo2_data1(29),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN219_TEMP: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6228);
GRLFPC20_R_I_RES_RNOq35z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(6),
  I1 => rfo2_data2(6),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(38),
  LO => N_3_25_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVM3F1q97z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q20z_Z7675: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(295),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SCTRL_NEWq0z_Z7676: LUT4_L 
generic map(
  INIT => X"D515"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(16),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(4),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SCTRL_NEW(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1q3z_Z7677: LUT4 
generic map(
  INIT => X"FA3A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_14q48z: LUT6 
generic map(
  INIT => X"0200000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3794);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_21q48z: LUT6 
generic map(
  INIT => X"0000000100000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3801);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_9_1q36z_Z7680: LUT5 
generic map(
  INIT => X"00040000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_9_1(36));
GRLFPC20_V_M_FPOP_1_Z7681: LUT3_L 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_e_annul,
  I1 => cpi_e_trap,
  I2 => GRLFPC20_R_E_FPOP,
  LO => GRLFPC20_V_M_FPOP_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q2z_Z7682: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(313),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_6_0q13z_Z7683: LUT6_L 
generic map(
  INIT => X"0000000000020000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_6_0(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_11_1q11z_Z7684: LUT5_L 
generic map(
  INIT => X"00001200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_11_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIA8LH1q252z: LUT6 
generic map(
  INIT => X"AAAAF000CCCC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q18z_Z7686: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(297),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q27z_Z7687: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(288),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_12q36z: LUT6_L 
generic map(
  INIT => X"0000000800000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3731);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14_10q34z: LUT6 
generic map(
  INIT => X"0020000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3672);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUL3F1q96z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(19));
GRLFPC20_FPI_OP1q32z_Z7691: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(0),
  I2 => rfo2_data1(0),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(32));
GRLFPC20_FPI_OP1q33z_Z7692: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(1),
  I2 => rfo2_data1(1),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(33));
GRLFPC20_FPI_OP1q34z_Z7693: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(2),
  I2 => rfo2_data1(2),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(34));
GRLFPC20_FPI_OP1q37z_Z7694: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(5),
  I2 => rfo2_data1(5),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQH3F1q92z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI13T01q110z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(5));
GRLFPC20_FPI_OP1q54z_Z7697: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(22),
  I2 => rfo2_data1(22),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(54));
GRLFPC20_FPI_OP1q57z_Z7698: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(25),
  I2 => rfo2_data1(25),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI89S01q108z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI78S01q107z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI67S01q106z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q20z: LUT6 
generic map(
  INIT => X"FCFA00000C0A0000"
)
port map (
  I0 => rfo1_data2(2),
  I1 => rfo2_data2(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_FPI_OP2(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIAG6A1q11z: LUT6 
generic map(
  INIT => X"CCF0AAF000000000"
)
port map (
  I0 => rfo1_data2(2),
  I1 => rfo2_data2(2),
  I2 => rfo2_data2(31),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I4 => GRLFPC20_COMB_UN1_FPCI_4,
  I5 => GRLFPC20_FPI_LDOP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(23));
GRLFPC20_R_I_RES_RNOq31z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(2),
  I1 => rfo2_data2(2),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(34),
  LO => N_3_29_I);
GRLFPC20_R_I_RES_RNOq33z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(4),
  I1 => rfo2_data2(4),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(36),
  LO => N_3_27_I);
GRLFPC20_R_I_RES_RNOq42z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(13),
  I1 => rfo2_data2(13),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(45),
  LO => N_3_18_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI12S01q101z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q51z_Z7708: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(264),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q244z_Z7709: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(20),
  I1 => rfo1_data2(23),
  I2 => rfo2_data2(20),
  I3 => rfo2_data2(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(244));
GRLFPC20_R_I_RES_RNOq49z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(20),
  I1 => rfo2_data2(20),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(52),
  LO => N_3_11_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q56z_Z7711: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(259),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33q242z_Z7712: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(22),
  I1 => rfo1_data2(25),
  I2 => rfo2_data2(22),
  I3 => rfo2_data2(25),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_33(242));
GRLFPC20_R_I_RES_RNOq51z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(22),
  I1 => rfo2_data2(22),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(54),
  LO => N_3_9_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q4z_Z7714: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(311),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(4));
GRLFPC20_FPI_OP1q56z_Z7715: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(24),
  I2 => rfo2_data1(24),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(56));
GRLFPC20_FPI_OP1q50z_Z7716: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(18),
  I2 => rfo2_data1(18),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(50));
GRLFPC20_FPI_OP1q49z_Z7717: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(17),
  I2 => rfo2_data1(17),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISJ3F1q94z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q1z_Z7719: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(314),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(1));
GRLFPC20_V_X_AFSR_1_Z7720: LUT3_L 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_m_annul,
  I1 => cpi_m_trap,
  I2 => GRLFPC20_R_M_AFSR,
  LO => GRLFPC20_V_X_AFSR_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q57z_Z7721: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(258),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI35T01q112z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPG3F1q91z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q3z_Z7724: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(312),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISCLJ2q51z: LUT5 
generic map(
  INIT => X"12DEDE12"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_4_0_I(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIUK2F1q87z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0UD61q253z: LUT5 
generic map(
  INIT => X"AAF0CC00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI23S01q102z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q15z_Z7729: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(300),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_21: LUT5_L 
generic map(
  INIT => X"A695596A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2833,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(7),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6308);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q26z_Z7731: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(289),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q14z_Z7732: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(301),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q47z_Z7733: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(268),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIRI3F1q93z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q33z_Z7735: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(282),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(33));
GRLFPC20_V_X_LD_1_Z7736: LUT3_L 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_m_annul,
  I1 => cpi_m_trap,
  I2 => GRLFPC20_R_M_LD,
  LO => GRLFPC20_V_X_LD_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q37z_Z7737: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(278),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(37));
GRLFPC20_FPI_OP1q52z_Z7738: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(20),
  I2 => rfo2_data1(20),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI9AS01q109z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(6));
GRLFPC20_V_M_LD_1_Z7740: LUT3_L 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_e_annul,
  I1 => cpi_e_trap,
  I2 => GRLFPC20_R_E_LD,
  LO => GRLFPC20_V_M_LD_1);
GRLFPC20_FPI_OP1q60z_Z7741: LUT6 
generic map(
  INIT => X"E4E4F0CCCCCCF0CC"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => rfo1_data1(28),
  I2 => rfo2_data1(28),
  I3 => GRLFPC20_R_A_RS1(0),
  I4 => GRLFPC20_R_A_RS1D,
  I5 => GRLFPC20_R_A_ST,
  O => GRLFPC20_FPI_OP1(60));
GRLFPC20_R_I_RES_RNOq34z: LUT5_L 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => rfo1_data2(5),
  I1 => rfo2_data2(5),
  I2 => GRLFPC20_COMB_UN2_HOLDN,
  I3 => GRLFPC20_COMB_UN1_FPCI_4,
  I4 => GRLFPC20_FPO_FRAC(37),
  LO => N_3_26_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_2_0q62z_Z7743: LUT4 
generic map(
  INIT => X"0102"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_2_0(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q17z_Z7744: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(298),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITK3F1q95z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI01S01q100z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI45S01q104z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q52z_Z7748: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(263),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIOF3F1q90z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(25));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq14z: LUT4_L 
generic map(
  INIT => X"15D5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(16),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(5),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_SCTRL_I(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q30z_Z7751: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(285),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIVL2F1q88z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI86LH1q251z: LUT6 
generic map(
  INIT => X"AAAAF000CCCC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4q49z_Z7754: LUT6 
generic map(
  INIT => X"3330AAAA0030AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(266),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0O3F1q98z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISI2F1q85z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1P3F1q99z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0N2F1q89z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI34S01q103z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI56S01q105z: LUT4 
generic map(
  INIT => X"AAC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIOE2F1q4z: LUT4 
generic map(
  INIT => X"CCA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL_1_0q1z: LUT5 
generic map(
  INIT => X"EEE2EE22"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2790);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_2q48z: LUT6 
generic map(
  INIT => X"5501000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3827_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3782);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_5q60z: LUT6 
generic map(
  INIT => X"0010100000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3281_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4449);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0q7z_Z7765: LUT6 
generic map(
  INIT => X"FFFFFFFF00400000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1244_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3207_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1634,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_6q48z: LUT6_L 
generic map(
  INIT => X"28A8000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3124_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3786);
GRLFPC20_V_E_STDATA_1_2q6z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(6),
  I3 => GRLFPC20_R_I_PC(6),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_568,
  LO => GRLFPC20_N_601);
GRLFPC20_V_E_STDATA_1_2q23z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(23),
  I3 => GRLFPC20_R_I_PC(23),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_585,
  LO => GRLFPC20_N_618);
GRLFPC20_V_E_STDATA_1_2q11z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(11),
  I3 => GRLFPC20_R_I_PC(11),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_573,
  LO => GRLFPC20_N_606);
GRLFPC20_V_E_STDATA_1_2q14z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(14),
  I3 => GRLFPC20_R_I_PC(14),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_576,
  LO => GRLFPC20_N_609);
GRLFPC20_V_E_STDATA_1_2q31z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(31),
  I3 => GRLFPC20_R_I_PC(31),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_593,
  LO => GRLFPC20_N_626);
GRLFPC20_V_E_STDATA_1_2q9z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(9),
  I3 => GRLFPC20_R_I_PC(9),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_571,
  LO => GRLFPC20_N_604);
GRLFPC20_V_E_STDATA_1_2q3z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(3),
  I3 => GRLFPC20_R_I_PC(3),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_565,
  LO => GRLFPC20_N_598);
GRLFPC20_V_E_STDATA_1_2q26z: LUT6_L 
generic map(
  INIT => X"FD20FFFFFD200000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_PC(26),
  I3 => GRLFPC20_R_I_INST(26),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_588,
  LO => GRLFPC20_N_621);
GRLFPC20_V_E_STDATA_1_2q8z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(8),
  I3 => GRLFPC20_R_I_PC(8),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_570,
  LO => GRLFPC20_N_603);
GRLFPC20_V_E_STDATA_1_2q25z: LUT6_L 
generic map(
  INIT => X"FD20FFFFFD200000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_PC(25),
  I3 => GRLFPC20_R_I_INST(25),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_587,
  LO => GRLFPC20_N_620);
GRLFPC20_V_E_STDATA_1_2q27z: LUT6_L 
generic map(
  INIT => X"FD20FFFFFD200000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_PC(27),
  I3 => GRLFPC20_R_I_INST(27),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_589,
  LO => GRLFPC20_N_622);
GRLFPC20_V_E_STDATA_1_2q10z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(10),
  I3 => GRLFPC20_R_I_PC(10),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_572,
  LO => GRLFPC20_N_605);
GRLFPC20_V_E_STDATA_1_2q2z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(2),
  I3 => GRLFPC20_R_I_PC(2),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_564,
  LO => GRLFPC20_N_597);
GRLFPC20_V_E_STDATA_1_2q15z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(15),
  I3 => GRLFPC20_R_I_PC(15),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_577,
  LO => GRLFPC20_N_610);
GRLFPC20_V_E_STDATA_1_2q16z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(16),
  I3 => GRLFPC20_R_I_PC(16),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_578,
  LO => GRLFPC20_N_611);
GRLFPC20_V_E_STDATA_1_2q22z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(22),
  I3 => GRLFPC20_R_I_PC(22),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_584,
  LO => GRLFPC20_N_617);
GRLFPC20_V_E_STDATA_1_2q24z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(24),
  I3 => GRLFPC20_R_I_PC(24),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_586,
  LO => GRLFPC20_N_619);
GRLFPC20_V_E_STDATA_1_2q7z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(7),
  I3 => GRLFPC20_R_I_PC(7),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_569,
  LO => GRLFPC20_N_602);
GRLFPC20_V_E_STDATA_1_2q30z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(30),
  I3 => GRLFPC20_R_I_PC(30),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_592,
  LO => GRLFPC20_N_625);
GRLFPC20_V_E_STDATA_1_2q13z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(13),
  I3 => GRLFPC20_R_I_PC(13),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_575,
  LO => GRLFPC20_N_608);
GRLFPC20_V_E_STDATA_1_2q4z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(4),
  I3 => GRLFPC20_R_I_PC(4),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_566,
  LO => GRLFPC20_N_599);
GRLFPC20_V_E_STDATA_1_2q5z: LUT6_L 
generic map(
  INIT => X"F2D0FFFFF2D00000"
)
port map (
  I0 => cpi_a_cnt(0),
  I1 => cpi_a_cnt(1),
  I2 => GRLFPC20_R_I_INST(5),
  I3 => GRLFPC20_R_I_PC(5),
  I4 => GRLFPC20_R_A_AFQ,
  I5 => GRLFPC20_N_567,
  LO => GRLFPC20_N_600);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20_3q49z: LUT6_L 
generic map(
  INIT => X"0101000001000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3327_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3127_2,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3855);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_1q49z_Z7790: LUT6 
generic map(
  INIT => X"0400040032000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4630,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_1(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_0q11z_Z7791: LUT6 
generic map(
  INIT => X"F8000007F8000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4431_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_12_1(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_0(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_RNIA6AVq7z: LUT5 
generic map(
  INIT => X"CFAFC0A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI76MH1q255z: LUT6 
generic map(
  INIT => X"AAAAFFF0CCCC0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_9q60z: LUT6_L 
generic map(
  INIT => X"0300020001000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4453);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2q11z_Z7795: LUT6 
generic map(
  INIT => X"FFFFFFFF01000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_714_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_0(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2(11));
GRLFPC20_COMB_RDD_2_Z7796: LUT6 
generic map(
  INIT => X"DCCC8CCCCCCCCCCC"
)
port map (
  I0 => GRLFPC20_R_I_EXEC,
  I1 => GRLFPC20_R_I_RDD,
  I2 => GRLFPC20_R_I_V,
  I3 => GRLFPC20_R_X_FPOP,
  I4 => GRLFPC20_R_X_RDD,
  I5 => GRLFPC20_V_I_EXEC_0_SQMUXA,
  O => GRLFPC20_COMB_RDD_2);
GRLFPC20_WRADDR_1q1z: LUT6 
generic map(
  INIT => X"AAAAAAAAE2F0F0F0"
)
port map (
  I0 => cpi_x_inst(26),
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_INST(26),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_R_X_FPOP,
  I5 => GRLFPC20_WRADDR_0_SQMUXA,
  O => RFI2_WRADDR_78);
GRLFPC20_WRADDR_1q3z: LUT6 
generic map(
  INIT => X"AAAAAAAAE2F0F0F0"
)
port map (
  I0 => cpi_x_inst(28),
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_INST(28),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_R_X_FPOP,
  I5 => GRLFPC20_WRADDR_0_SQMUXA,
  O => RFI2_WRADDR_80);
GRLFPC20_WRADDR_1q4z: LUT6 
generic map(
  INIT => X"AAAAAAAAE2F0F0F0"
)
port map (
  I0 => cpi_x_inst(29),
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_INST(29),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_R_X_FPOP,
  I5 => GRLFPC20_WRADDR_0_SQMUXA,
  O => RFI2_WRADDR_81);
GRLFPC20_WRADDR_1q2z: LUT6 
generic map(
  INIT => X"AAAAAAAAE2F0F0F0"
)
port map (
  I0 => cpi_x_inst(27),
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_INST(27),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_R_X_FPOP,
  I5 => GRLFPC20_WRADDR_0_SQMUXA,
  O => RFI2_WRADDR_79);
GRLFPC20_WRADDR_1q0z_Z7801: LUT6 
generic map(
  INIT => X"AAAAAAAAE2F0F0F0"
)
port map (
  I0 => cpi_x_inst(25),
  I1 => GRLFPC20_R_I_EXEC,
  I2 => GRLFPC20_R_I_INST(25),
  I3 => GRLFPC20_R_I_V,
  I4 => GRLFPC20_R_X_FPOP,
  I5 => GRLFPC20_WRADDR_0_SQMUXA,
  O => GRLFPC20_WRADDR_1(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_0q60z: LUT6 
generic map(
  INIT => X"2202220000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3384_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4479_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4444);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0q13z_Z7803: LUT6_L 
generic map(
  INIT => X"FFFFFFFF20000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4139_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3234_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3732,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_0(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1q63z_Z7804: LUT6_L 
generic map(
  INIT => X"FFFF200020002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4614,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3231_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_0(63),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4617,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(63));
GRLFPC20_RS2D_1_IV: LUT6 
generic map(
  INIT => X"0101000002000000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(22),
  I3 => GRLFPC20_COMB_FPDECODE_RS1D5,
  I4 => GRLFPC20_MOV_0_SQMUXA_4,
  I5 => GRLFPC20_UN1_RDD3,
  O => GRLFPC20_RS2D_1);
GRLFPC20_RS1V_0_SQMUXA_1_Z7806: LUT6 
generic map(
  INIT => X"0100000001010000"
)
port map (
  I0 => cpi_d_inst(19),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(22),
  I3 => GRLFPC20_COMB_RSDECODE_UN1_FPCI,
  I4 => GRLFPC20_MOV_0_SQMUXA_4,
  I5 => GRLFPC20_RDD_1_N_20_2,
  O => GRLFPC20_RS1V_0_SQMUXA_1);
GRLFPC20_FPOP_1_Z7807: LUT6 
generic map(
  INIT => X"0000000010100010"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  I2 => GRLFPC20_MOV_0_SQMUXA_4,
  I3 => GRLFPC20_R_STATE(0),
  I4 => GRLFPC20_R_STATE(1),
  I5 => GRLFPC20_COMB_LOCK,
  O => GRLFPC20_FPOP_1);
GRLFPC20_COMB_SEQERR_UN7_OP_Z7808: LUT6 
generic map(
  INIT => X"F1111111F0000000"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  I2 => cpi_d_inst(30),
  I3 => cpi_d_inst(31),
  I4 => GRLFPC20_COMB_SEQERR_UN11_OP,
  I5 => GRLFPC20_MOV_0_SQMUXA_4,
  O => GRLFPC20_COMB_SEQERR_UN7_OP);
GRLFPC20_RS2_1q2z: LUT6 
generic map(
  INIT => X"0200FFFF02000000"
)
port map (
  I0 => cpi_d_inst(2),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(22),
  I3 => GRLFPC20_MOV_0_SQMUXA_4,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS2(2),
  O => RFI2_RD2ADDR_75);
GRLFPC20_RS2_1q3z: LUT6 
generic map(
  INIT => X"0200FFFF02000000"
)
port map (
  I0 => cpi_d_inst(3),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(22),
  I3 => GRLFPC20_MOV_0_SQMUXA_4,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS2(3),
  O => RFI2_RD2ADDR_76);
GRLFPC20_RS2_1q1z: LUT6 
generic map(
  INIT => X"0200FFFF02000000"
)
port map (
  I0 => cpi_d_inst(1),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(22),
  I3 => GRLFPC20_MOV_0_SQMUXA_4,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS2(1),
  O => RFI2_RD2ADDR_74);
GRLFPC20_RS2_1q0z_Z7812: LUT6 
generic map(
  INIT => X"0200FFFF02000000"
)
port map (
  I0 => cpi_d_inst(0),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(22),
  I3 => GRLFPC20_MOV_0_SQMUXA_4,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS2(0),
  O => GRLFPC20_RS2_1(0));
GRLFPC20_RS2_1q4z: LUT6 
generic map(
  INIT => X"0200FFFF02000000"
)
port map (
  I0 => cpi_d_inst(4),
  I1 => cpi_d_inst(20),
  I2 => cpi_d_inst(22),
  I3 => GRLFPC20_MOV_0_SQMUXA_4,
  I4 => holdn,
  I5 => GRLFPC20_R_A_RS2(4),
  O => RFI2_RD2ADDR_77);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4_0q48z_Z7814: LUT6 
generic map(
  INIT => X"FFFFFFFF80000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3601_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3786,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_4_0(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_1q56z_Z7815: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFF2D20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_14_1(56),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_15_1(56),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4134,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4153,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_1(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_5q36z: LUT6 
generic map(
  INIT => X"0000008000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3702_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO_Z7817: LUT6 
generic map(
  INIT => X"FEFEFE0E07F7F7F7"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN20_ZERO);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_0q56z_Z7818: LUT6_L 
generic map(
  INIT => X"5555020002000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1259_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_6_0(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_5_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1q12z_Z7819: LUT6 
generic map(
  INIT => X"FFFFFFFF10000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3077_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3753_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3246_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_CRY_0_CY_RNO: LUT6 
generic map(
  INIT => X"AEFE0CFC04540CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2809,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2812);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_57_Z7821: LUT5 
generic map(
  INIT => X"21D1DE2E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(57),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_57);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_RNOq3z: LUT6 
generic map(
  INIT => X"0CFCAAAA0000AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q56z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_56);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_15q36z: LUT6_L 
generic map(
  INIT => X"0000001000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3734);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN3_S_SQRT_Z7825: LUT6 
generic map(
  INIT => X"0220000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3130_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4274_I_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN3_S_SQRT);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_1q34z_Z7826: LUT6_L 
generic map(
  INIT => X"0770055000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3127_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3124_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1_1(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15q45z: LUT6 
generic map(
  INIT => X"0020001000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1739,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1335);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5q61z_Z7828: LUT6 
generic map(
  INIT => X"FFFFFFFF00230000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3201,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5_0(61),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_5(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_2q56z_Z7829: LUT6_L 
generic map(
  INIT => X"FFFFFFFF5D000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4269_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4462_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_0(56),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_7_2(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI81MD1_0q84z: LUT4 
generic map(
  INIT => X"0008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_690);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_12q13z: LUT6 
generic map(
  INIT => X"8000000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3071_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3185);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_7_RNO: LUT5 
generic map(
  INIT => X"AFCFA0C0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_0q11z_Z7833: LUT6_L 
generic map(
  INIT => X"AA202020AA000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_23_0(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4431_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_0(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q54z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_54);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q53z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_53);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q52z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_52);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q51z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(51),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_51);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q50z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_50);
GRLFPC20_V_FSR_FTT_1_SQMUXA_Z7839: LUT6 
generic map(
  INIT => X"00000000F5FF3133"
)
port map (
  I0 => GRLFPC20_R_X_AFQ,
  I1 => GRLFPC20_R_X_AFSR,
  I2 => GRLFPC20_R_STATE(0),
  I3 => GRLFPC20_R_STATE(1),
  I4 => GRLFPC20_R_X_LD,
  I5 => GRLFPC20_R_X_SEQERR,
  O => GRLFPC20_V_FSR_FTT_1_SQMUXA);
GRLFPC20_V_FSR_FTT_2_SQMUXA_1_0_Z7840: LUT6 
generic map(
  INIT => X"0A00CECC00000000"
)
port map (
  I0 => GRLFPC20_R_X_AFQ,
  I1 => GRLFPC20_R_X_AFSR,
  I2 => GRLFPC20_R_STATE(0),
  I3 => GRLFPC20_R_STATE(1),
  I4 => GRLFPC20_R_X_LD,
  I5 => GRLFPC20_V_I_V_1_SQMUXA,
  O => GRLFPC20_V_FSR_FTT_2_SQMUXA_1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q43z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(43),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_43);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q42z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(42),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_42);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q41z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_41);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_1_RNOq1z: LUT6 
generic map(
  INIT => X"8000800080000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS,
  I5 => N_1199,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_REEXCOVUV_UN3_LOCUV_M);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q38z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_38);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_18q61z: LUT6 
generic map(
  INIT => X"0010000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1259_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4534);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14_4q34z: LUT6 
generic map(
  INIT => X"00A8002000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14_4_0(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q33z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(33),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_33);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23q113z_Z7849: LUT6 
generic map(
  INIT => X"0000000013DFDFDF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(113));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO_Z7850: LUT6 
generic map(
  INIT => X"FEFEFE3213DFDFDF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN50_ZERO);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIHR0UAq323z: LUT6 
generic map(
  INIT => X"FF2D2D00FFD2D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(323),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(50),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_4q60z: LUT6_L 
generic map(
  INIT => X"4501000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3026_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4448);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_0q13z: LUT6_L 
generic map(
  INIT => X"1110000001000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1705,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3173);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_9q48z: LUT6_L 
generic map(
  INIT => X"0000000000800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3789);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0q49z_Z7855: LUT6_L 
generic map(
  INIT => X"FFFFFFFF04000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3851,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4q49z_Z7856: LUT6 
generic map(
  INIT => X"FFFFFFFF0C000400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3664_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq20z: LUT6_L 
generic map(
  INIT => X"88A8888800200000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_761,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1254_MUX,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20_14q49z: LUT6 
generic map(
  INIT => X"0000000400000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4630,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3866);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0q49z_Z7859: LUT6 
generic map(
  INIT => X"FFFFFFFF04000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3855,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0_0(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q57z_Z7860: LUT4 
generic map(
  INIT => X"470F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q55z_Z7861: LUT5 
generic map(
  INIT => X"505F3333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q56z_Z7862: LUT6 
generic map(
  INIT => X"AFA0AFA0FF00CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q53z_Z7863: LUT6 
generic map(
  INIT => X"B800F000B8FFF0FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q54z_Z7864: LUT6 
generic map(
  INIT => X"B800F000B8FFF0FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0q50z_Z7865: LUT6 
generic map(
  INIT => X"FFFFFFFFF8F08800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1254_MUX,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3801,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_0(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_3_0(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_13q61z: LUT6 
generic map(
  INIT => X"0080000800000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3234_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4529);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_15q13z: LUT6 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3234_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3188);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_2q12z: LUT6_L 
generic map(
  INIT => X"2000000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1603);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3UBCCq349z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(349),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_SI_37(20),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_CI_37_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI3UBCC_0q349z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(349),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_SI_37(20),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_95(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNID10UBq349z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(349),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_96(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4q60z_Z7872: LUT6_L 
generic map(
  INIT => X"FFFFFFFF63000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3488_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0(60),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13q62z: LUT6_L 
generic map(
  INIT => X"0043000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4579);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_UN2_NOTABORTWB: LUT5 
generic map(
  INIT => X"FF00FF54"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1V553_1q76z: LUT6 
generic map(
  INIT => X"0000000000540000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_EXPAREGLOADEN_274_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1V553q76z: LUT6 
generic map(
  INIT => X"FF00FF00FF54FF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_EXPAREGLOADEN_274_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1V553_0q76z: LUT6 
generic map(
  INIT => X"FF00FF00FF54FF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_EXPAREGLOADEN_274_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => N_10_MUX_6_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_1_RNIBG832: LUT6 
generic map(
  INIT => X"000000002220FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(63),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_RNDMODESELECT_UN1_TEMP_Z7879: LUT6 
generic map(
  INIT => X"AAAA0000AAAA2220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_RNDMODESELECT_UN1_TEMP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIFG5V1q76z: LUT6 
generic map(
  INIT => X"FF000000FF005400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN_Z7881: LUT6 
generic map(
  INIT => X"FF000000FF005400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN1_AREGSIGN_SEL_Z7882: LUT6 
generic map(
  INIT => X"FFFFFFFF00FF00AB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SFTLFT_UN1_AREGSIGN_SEL);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_9q11z: LUT6 
generic map(
  INIT => X"0600000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3021);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25q56z: LUT6 
generic map(
  INIT => X"0101000500000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3031_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4134);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_7q13z: LUT6 
generic map(
  INIT => X"0000000000010000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3180);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15q45z: LUT6 
generic map(
  INIT => X"FFFFFFFFF4F04400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4269_I_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2_1(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_74_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1735,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_873);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_0q50z_Z7887: LUT6_L 
generic map(
  INIT => X"FFFFFFFF02000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1286,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_2_0(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_6q61z: LUT6 
generic map(
  INIT => X"80A0200000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3130_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4522);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14_5q34z: LUT6_L 
generic map(
  INIT => X"8008000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3124_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3667);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_5q13z: LUT6 
generic map(
  INIT => X"020A000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3178);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_23q48z: LUT6 
generic map(
  INIT => X"0000010000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3803);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_11q61z: LUT6 
generic map(
  INIT => X"0031000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4527);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1q61z_Z7893: LUT6 
generic map(
  INIT => X"FFFFFFFF04000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4529,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_1_1(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2_2q16z: LUT6_L 
generic map(
  INIT => X"0001000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3548_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1702);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_3q11z: LUT6 
generic map(
  INIT => X"0010001300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3347_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3015);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_1q29z: LUT6 
generic map(
  INIT => X"0800000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3130_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1462);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_1q36z: LUT6 
generic map(
  INIT => X"0000401000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3246_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1367);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0q60z_Z7898: LUT6_L 
generic map(
  INIT => X"5511540011110000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3923_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_19_1(60),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_3_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2_1q45z_Z7899: LUT6 
generic map(
  INIT => X"0000000000020000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2_1(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN10_S_MOV_Z7900: LUT6_L 
generic map(
  INIT => X"0000000001000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3127_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN10_S_MOV);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_0q62z: LUT6_L 
generic map(
  INIT => X"0200022200000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_2,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4580);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0q36z_Z7902: LUT6_L 
generic map(
  INIT => X"FFFFFFFF58000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1259_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_1(36),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2q6z: LUT6_L 
generic map(
  INIT => X"0080000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1277_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1735);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A2q12z: LUT6_L 
generic map(
  INIT => X"0000000000080000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1967);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_0q48z_Z7905: LUT6_L 
generic map(
  INIT => X"ACA400000C040000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3124_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_2_0(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_7q56z: LUT6_L 
generic map(
  INIT => X"0000000000004000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3842_I,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4142);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_10q62z: LUT6_L 
generic map(
  INIT => X"0010000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3246_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4590);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_5q56z: LUT6_L 
generic map(
  INIT => X"0000000000000800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4140);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILBTT9q364z: LUT6 
generic map(
  INIT => X"FF2DFFD22D00D200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(364),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILBTT9_0q364z: LUT6 
generic map(
  INIT => X"2DD2D22DD22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(364),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_4_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_111(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_5q7z: LUT6 
generic map(
  INIT => X"0200000200000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1277_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6345);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_RNO_0q12z: LUT6 
generic map(
  INIT => X"8D88888805000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_24_I,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_MUX,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_836);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SEq1z_Z7913: LUT6 
generic map(
  INIT => X"FFF4BFB44B400B00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q5z_Z7914: LUT6 
generic map(
  INIT => X"0005FAFF00C53AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q17z_Z7915: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q28z_Z7916: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q32z_Z7917: LUT6 
generic map(
  INIT => X"00FA05FF003AC5FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q1z_Z7918: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q3z_Z7919: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q6z_Z7920: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q11z_Z7921: LUT6 
generic map(
  INIT => X"00FA05FF003AC5FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q12z_Z7922: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q18z_Z7923: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q22z_Z7924: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q24z_Z7925: LUT6 
generic map(
  INIT => X"0005FAFF00C53AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q27z_Z7926: LUT6 
generic map(
  INIT => X"00FA05FF003AC5FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(27));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q35z_Z7927: LUT6 
generic map(
  INIT => X"0005FAFF00C53AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q37z_Z7928: LUT6 
generic map(
  INIT => X"3333353555333535"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q40z_Z7929: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q41z_Z7930: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q42z_Z7931: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q33z_Z7932: LUT6 
generic map(
  INIT => X"00FA05FF003AC5FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q19z_Z7933: LUT6 
generic map(
  INIT => X"0005FAFF00C53AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q23z_Z7934: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q34z_Z7935: LUT6 
generic map(
  INIT => X"00FA05FF003AC5FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q36z_Z7936: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q46z_Z7937: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_0_M2q8z: LUT6 
generic map(
  INIT => X"FFEE0022AFEEA022"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_115);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q2z_Z7939: LUT6 
generic map(
  INIT => X"0011FFDD50115FDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_I_M2q30z: LUT6 
generic map(
  INIT => X"0005FAFF00C53AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q7z_Z7941: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q13z_Z7942: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q14z_Z7943: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q15z_Z7944: LUT6 
generic map(
  INIT => X"5555535333555353"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q26z_Z7945: LUT6 
generic map(
  INIT => X"0005FAFF00C53AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q43z_Z7946: LUT6 
generic map(
  INIT => X"00FA05FF003AC5FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => NN_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q44z_Z7947: LUT6 
generic map(
  INIT => X"0005FAFF00C53AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I4 => NN_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8q45z_Z7948: LUT6 
generic map(
  INIT => X"5555535333555353"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_0_M2q9z: LUT6 
generic map(
  INIT => X"AABBAA88FABB0A88"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_114);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_0_M2q20z: LUT6 
generic map(
  INIT => X"FFFA0500FF3AC500"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_112);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_0_M2q21z: LUT6 
generic map(
  INIT => X"FFEE0022AFEEA022"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_111);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_I_M2q29z: LUT6 
generic map(
  INIT => X"554455770544F577"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_110);
GRLFPC20_V_I_EXC_1q0z_Z7953: LUT6_L 
generic map(
  INIT => X"000000A200A200A2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_128,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_2_4(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_3_4(2),
  LO => GRLFPC20_V_I_EXC_1(0));
GRLFPC20_COMB_V_I_EXEC_5_IV: LUT5 
generic map(
  INIT => X"FFFFBF00"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_X_SEQERR_0_DOUT(0),
  I2 => RqXzXRDDY_1,
  I3 => GRLFPC20_R_I_EXEC,
  I4 => GRLFPC20_V_I_EXEC_0_SQMUXA,
  O => GRLFPC20_COMB_V_I_EXEC_5);
GRLFPC20_ANNULFPU_1_IV_Z7955: LUT6 
generic map(
  INIT => X"0000000015BF0000"
)
port map (
  I0 => GRLFPC20_COMB_UN1_FPCI,
  I1 => GRLFPC20_R_X_SEQERR_0_DOUT(0),
  I2 => RqXzXRDDY_1,
  I3 => GRLFPC20_R_X_FPOP,
  I4 => GRLFPC20_ANNULFPU_1_SQMUXA,
  I5 => GRLFPC20_COMB_UN1_R_I_EXC,
  O => GRLFPC20_ANNULFPU_1_IV);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_0q63z_Z7956: LUT6 
generic map(
  INIT => X"04A0000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3175_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4623);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6q61z_Z7957: LUT6 
generic map(
  INIT => X"FFFFFFFF0A200000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4490,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6_1(61),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_6(61));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_RNIB3I52q4z: LUT6 
generic map(
  INIT => X"C9C33933363CC6CC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2830,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXPYBUS(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_AXB_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNILQSN1q31z: LUT6 
generic map(
  INIT => X"335FCCA0CCA0335F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(31),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_31);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14S2_3_2_RNI0ANF2: LUT6 
generic map(
  INIT => X"000000000000FFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM6,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12_3_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q49z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_49);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q48z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_48);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q47z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(47),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_47);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q46z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_46);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q45z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_45);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q44z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_44);
GRLFPC20_COMB_V_MK_BUSY_2_Z7967: LUT6_L 
generic map(
  INIT => X"0000000000080000"
)
port map (
  I0 => GRLFPC20_R_MK_HOLDN2,
  I1 => GRLFPC20_R_MK_HOLDN1,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  I4 => GRLFPC20_ANNULFPU_1_IV,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_BUSYMULXFF_UN2_TEMP,
  LO => GRLFPC20_COMB_V_MK_BUSY_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q40z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(40),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_40);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q39z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(39),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_39);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q37z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_37);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI7AM42q36z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_36);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q35z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_35);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q34z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_34);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIU1N42q32z: LUT6 
generic map(
  INIT => X"59A9F303A6560CFC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_32);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7VQTB_0q334z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(334),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_22(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_80(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI7VQTBq334z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(334),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_22(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIVCK91q15z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(15),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_15);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOHNB1q7z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOTSN1q30z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(30),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_30);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOHNB1q6z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIF9OB1q5z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIVCK91q14z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(14),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_14);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOTSN1q23z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_23);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOTSN1q24z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(24),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_24);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q17z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_17);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q26z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_26);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOTSN1q25z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(25),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_25);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q29z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_29);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIVCK91q11z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q16z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_16);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q18z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_18);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOTSN1q20z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(20),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_20);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOTSN1q22z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(22),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_22);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIF9OB1q3z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIF9OB1q4z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOHNB1q8z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIVCK91q10z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIVCK91q12z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIVCK91q13z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_13);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOTSN1q21z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_21);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q19z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(19),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_19);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q28z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(28),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_28);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNI16SN1q27z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(27),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_27);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1_RNIOHNB1q9z: LUT6 
generic map(
  INIT => X"553FAAC0AAC0553F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_TEMP_1(9),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUF_AXB_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4KUUq316z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  O => N_1379_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_RNOq61z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_60_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3_RNID45S1: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_TRFWWBASICCELL_SA_I_1,
  O => N_1381_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKTI87_0q316z: LUT6 
generic map(
  INIT => X"20DFF20DDF200DF2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_SI_62(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKTI87q316z: LUT6 
generic map(
  INIT => X"FF202D20F2D2F200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_10q48z: LUT6 
generic map(
  INIT => X"A020000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3790);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4_0q50z_Z8011: LUT6 
generic map(
  INIT => X"FFFFFFFF00400000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1725,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1288,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_4_0(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_6_0q56z_Z8012: LUT6 
generic map(
  INIT => X"FB0A0000F1000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4182_I_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4176,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3096_I,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_6_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_24q11z: LUT6 
generic map(
  INIT => X"0000001000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3347_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3036);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_2_Z8014: LUT6_L 
generic map(
  INIT => X"0000FEFF00000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1820,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN3_S_SQRT,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_ENTRYPOINT_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20_1q49z: LUT6 
generic map(
  INIT => X"0000045000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3853_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3853);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_7_0q11z_Z8016: LUT6 
generic map(
  INIT => X"04AA00AA04000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1280_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_7_0(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_4q50z: LUT6_L 
generic map(
  INIT => X"080A000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1288);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0_0q11z_Z8018: LUT6_L 
generic map(
  INIT => X"2033003320200000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3026_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_11_1(11),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_0_0(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_RNIFGD02q9z: LUT6 
generic map(
  INIT => X"F0F0F8F000000800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2834,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1q45z_Z8020: LUT6 
generic map(
  INIT => X"8F8080800F000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1877,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1831,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_18q56z: LUT6 
generic map(
  INIT => X"0800000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3175_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4153);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q81z: LUT6 
generic map(
  INIT => X"E222222222222222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_FEEDBACKMULXFF_UN6_FEEDBACK,
  I2 => GRLFPC20_FPO_FRAC(50),
  I3 => GRLFPC20_FPO_FRAC(51),
  I4 => GRLFPC20_FPO_FRAC(54),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_CHECKOVANDDENORM_UN13_NOTPOSSIBLEOV_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_RESULT(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15q39z: LUT6 
generic map(
  INIT => X"8000400000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1766,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1360);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20_8q49z: LUT6 
generic map(
  INIT => X"80A2000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3860);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_RNO_0q50z: LUT4 
generic map(
  INIT => X"1000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_7_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q99z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(99),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2547);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q98z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(98),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2548);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q97z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(97),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2549);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q96z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(96),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2550);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q95z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(95),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2551);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q94z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(94),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2552);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q93z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(93),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2553);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q91z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(91),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2555);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q90z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(90),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2556);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q89z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(89),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2557);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q87z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(87),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2559);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q86z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(86),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2560);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q85z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2561);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q84z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2562);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q83z: LUT5_L 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(83),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2563);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q82z: LUT5_L 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(82),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2564);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q81z: LUT5_L 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(81),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2565);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q79z: LUT5_L 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(79),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2567);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q78z: LUT5_L 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(78),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2568);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q77z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(77),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2569);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q76z: LUT5_L 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(76),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2570);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q74z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(74),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2572);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q72z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(72),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2574);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q71z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(71),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2575);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q70z: LUT5_L 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(70),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2576);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q69z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(69),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2577);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q67z: LUT5_L 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(67),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2579);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q65z: LUT5_L 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(65),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2581);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q64z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => NN_4,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(64),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2582);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q63z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => NN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(63),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2583);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q60z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(60),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2586);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q59z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(59),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2587);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q113z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(113),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2533);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q111z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(111),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2535);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q109z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(109),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2537);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q108z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(108),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2538);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q106z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(106),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2540);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q105z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(105),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2541);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q104z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(104),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2542);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q103z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(103),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2543);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q102z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(102),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2544);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q101z: LUT5 
generic map(
  INIT => X"FF807F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(101),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2545);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1q100z: LUT5 
generic map(
  INIT => X"EAAA2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(100),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2546);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q57z: LUT5 
generic map(
  INIT => X"80000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(57),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_M(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q12z: LUT6 
generic map(
  INIT => X"000000007FFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(13),
  O => M9_43_3);
R_DPATH_RET_18_RNO_4: LUT6_L 
generic map(
  INIT => X"000000007FFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(30),
  LO => M9_30_3);
R_DPATH_RET_14_RNO_4: LUT6_L 
generic map(
  INIT => X"000000007FFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(38),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(39),
  LO => M9_9_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q21z: LUT6 
generic map(
  INIT => X"000000007FFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(21),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(22),
  O => M9_22_3);
R_DPATH_RET_7_RNO_4: LUT6_L 
generic map(
  INIT => X"000000007FFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_M_0(45),
  LO => M9_15_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q56z: LUT5 
generic map(
  INIT => X"80000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_15(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_MIXOOUT0_1_M);
GRLFPC20_ANNULRES_1_IV_2: LUT6 
generic map(
  INIT => X"FFFFFFFF00FE0000"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  I3 => GRLFPC20_R_I_EXEC,
  I4 => GRLFPC20_R_X_FPOP,
  I5 => GRLFPC20_COMB_UN1_R_I_EXC,
  O => GRLFPC20_N_824_1);
GRLFPC20_R_X_AFSR_RNIFMQK: LUT6 
generic map(
  INIT => X"0100000000000000"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  I3 => holdn,
  I4 => GRLFPC20_R_X_AFSR,
  I5 => GRLFPC20_R_X_LD,
  O => N_342);
GRLFPC20_WRDATAq63z: LUT6 
generic map(
  INIT => X"FFFEFFFF00040000"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_lddata(31),
  I2 => cpi_x_annul,
  I3 => cpi_x_trap,
  I4 => GRLFPC20_COMB_WRADDR_0_SQMUXA,
  I5 => GRLFPC20_R_I_RES(63),
  O => rfi1_wrdata(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14S2: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => NN_4,
  I3 => NN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM6,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12_3_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M13q1z_Z8080: LUT6 
generic map(
  INIT => X"CCDDCCDCCCDCCCDD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => NN_4,
  I3 => NN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM6,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS6,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M13(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M13q2z_Z8081: LUT6 
generic map(
  INIT => X"FFEEFFEEFFEEFFEF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I2 => NN_4,
  I3 => NN_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM6,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SS6,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M13(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_1_Z8082: LUT6 
generic map(
  INIT => X"00000000AAA02222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(74),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(71),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_ENTRYSHFT_UN10_S_MOV,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1q3z_Z8083: LUT6_L 
generic map(
  INIT => X"0000000000015555"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN26_NOTAINFNAN,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSTSETS_1(3));
GRLFPC20_R_A_MOV_RNIQDH91: LUT6 
generic map(
  INIT => X"10FF00FF00FF00FF"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => holdn,
  I3 => rst,
  I4 => GRLFPC20_R_A_MOV,
  I5 => GRLFPC20_R_A_FPOP,
  O => N_333);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17q3z_Z8085: LUT5_L 
generic map(
  INIT => X"FFFFFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2166,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q14z_Z8086: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(14),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q9z_Z8087: LUT5 
generic map(
  INIT => X"3B00FFC4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_114,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q42z_Z8088: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q24z_Z8089: LUT5 
generic map(
  INIT => X"00C43BFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(28),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(24),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q19z_Z8090: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(19),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q29z_Z8091: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_110,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(33),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q11z_Z8092: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(15),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q36z_Z8093: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(40),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q33z_Z8094: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q30z_Z8095: LUT5 
generic map(
  INIT => X"00C43BFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q28z_Z8096: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(28),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q49z_Z8097: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(53),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q26z_Z8098: LUT5 
generic map(
  INIT => X"00C43BFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q20z_Z8099: LUT5 
generic map(
  INIT => X"3B00FFC4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_112,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(24),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q47z_Z8100: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(47),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(51),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q45z_Z8101: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(49),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4q1z_Z8102: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKVGT3q321z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(321),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_SI_10(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIA5NSB_0q321z: LUT6 
generic map(
  INIT => X"F20D20DF0DF2DF20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(321),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_9(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_67(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIA5NSBq321z: LUT6 
generic map(
  INIT => X"FFF2FF20F2002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(321),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(52),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_9(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M12q0z_Z8106: LUT6_L 
generic map(
  INIT => X"00AA00FF30303030"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M12(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17q2z_Z8107: LUT6_L 
generic map(
  INIT => X"FFFFAAAAFFFEFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M13(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_SM12,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROLq3z_Z8108: LUT6 
generic map(
  INIT => X"F8C83808F8F83838"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROLq1z_Z8109: LUT6 
generic map(
  INIT => X"AAAA0000AAAE0004"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2790,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17_M14(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROLq2z_Z8110: LUT6 
generic map(
  INIT => X"C8C80808C8F80838"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROLq0z_Z8111: LUT6 
generic map(
  INIT => X"2020A8A82064A8EC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_COMPUTECONST_UN25_RESVEC,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_NORMDETECT_NOTSLFROMNORM_17(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_1q44z: LUT6 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_148_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1343);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_3q17z: LUT6 
generic map(
  INIT => X"008010C000800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1153);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q35z: LUT6 
generic map(
  INIT => X"0000000000141B04"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1130);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIIAAA6q73z: LUT6 
generic map(
  INIT => X"0C53CA3000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_16(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q3z: LUT6 
generic map(
  INIT => X"0000000000000400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_715);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_11q84z: LUT6 
generic map(
  INIT => X"080000000000E000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_694);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA_Z8118: LUT6 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I4 => GRLFPC20_FPI_LDOP,
  I5 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q40z: LUT6_L 
generic map(
  INIT => X"7BFF7FFDEF7FF7EF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1112);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q5z: LUT6 
generic map(
  INIT => X"0008040004C1A008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1039);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q25z: LUT6 
generic map(
  INIT => X"7FEFFFFBF77BFFFE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_928);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q32z: LUT6 
generic map(
  INIT => X"0008100044000018"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_488);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_9q84z: LUT6_L 
generic map(
  INIT => X"7BFF7FFDEFFFF7FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_119_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q25z: LUT6 
generic map(
  INIT => X"080410AA00AE200E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_922);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_3q0z: LUT6 
generic map(
  INIT => X"0010200855500000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_883);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q3z: LUT6 
generic map(
  INIT => X"0000000001058181"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_714);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q5z: LUT6 
generic map(
  INIT => X"000010400000000A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1036);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_3q18z: LUT6 
generic map(
  INIT => X"1011201875502081"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_399);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q38z: LUT6 
generic map(
  INIT => X"0000800080000020"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1119);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q55z: LUT6 
generic map(
  INIT => X"4082018C05D88144"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_952);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O2_0q43z: LUT6 
generic map(
  INIT => X"0000008800080000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_788);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q18z: LUT6 
generic map(
  INIT => X"5557818001004557"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_384);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_14q84z: LUT6 
generic map(
  INIT => X"0000000000000010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_74_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q19z: LUT6 
generic map(
  INIT => X"57D711EA40EA0018"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_891);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q18z: LUT6 
generic map(
  INIT => X"5757010040400010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_378);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_62q84z: LUT5 
generic map(
  INIT => X"00002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_804_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q14z: LUT6 
generic map(
  INIT => X"0020002000200000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1270_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_RNOq16z: LUT6 
generic map(
  INIT => X"0000000000000020"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_72_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q33z: LUT6 
generic map(
  INIT => X"0400AABBAEAA001A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_520);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q52z: LUT6 
generic map(
  INIT => X"420000440440001A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1183);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q26z: LUT6 
generic map(
  INIT => X"0400050B00040010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1089);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q1z: LUT6 
generic map(
  INIT => X"5F7FDFFF9FBE5F7F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_818);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q33z: LUT6 
generic map(
  INIT => X"08201327136620A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_526);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q51z: LUT6 
generic map(
  INIT => X"000000AA04BA001A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1057);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI27G42q79z: LUT6 
generic map(
  INIT => X"0000000000000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1274_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_12q84z: LUT6 
generic map(
  INIT => X"0000008000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_1q63z: LUT6 
generic map(
  INIT => X"C031000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3294_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4635_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4624);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_13q84z: LUT6 
generic map(
  INIT => X"0000000010001A00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_2q61z: LUT6_L 
generic map(
  INIT => X"0000448000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4518);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1_0q16z_Z8150: LUT6_L 
generic map(
  INIT => X"FFFFFFFF80000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1357,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_O15_1_0(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q40z_Z8151: LUT6 
generic map(
  INIT => X"000090FF6F00FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q39z_Z8152: LUT6 
generic map(
  INIT => X"00006F0090FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(39),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q5z_Z8153: LUT6 
generic map(
  INIT => X"000090FF6F00FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(5),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q2z_Z8154: LUT6 
generic map(
  INIT => X"00006F0090FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q0z_Z8155: LUT6 
generic map(
  INIT => X"00006F0090FFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q15z_Z8156: LUT6 
generic map(
  INIT => X"000090FF6F00FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(15),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q1z_Z8157: LUT6_L 
generic map(
  INIT => X"000090FF6F00FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(2),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1q43z_Z8158: LUT6 
generic map(
  INIT => X"000090FF6F00FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(43),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14q34z: LUT6 
generic map(
  INIT => X"10A1000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3034_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3661);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0q49z_Z8160: LUT6_L 
generic map(
  INIT => X"0101020200800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1145,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_4_0(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q43z: LUT6 
generic map(
  INIT => X"0000484000000800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_739_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0q60z_Z8162: LUT6 
generic map(
  INIT => X"00F800F000080000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3488_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_17_1(60),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19q13z: LUT6 
generic map(
  INIT => X"0818000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3172);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20q49z: LUT6_L 
generic map(
  INIT => X"5A40000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3795_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3327_I_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3851);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SEq7z_Z8165: LUT6 
generic map(
  INIT => X"FFBFF4B44B0B4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(7),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSTICKYINFORSR_0: LUT6 
generic map(
  INIT => X"0000B3330000F333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_NOTSTICKYINFORSR_2_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(0),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2780);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q45z: LUT5 
generic map(
  INIT => X"0F0B0400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNI8J5A1q32z: LUT5 
generic map(
  INIT => X"0F0B0400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNIAL5A1q33z: LUT5 
generic map(
  INIT => X"0F040B00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(33),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNIER7A1q44z: LUT5 
generic map(
  INIT => X"0F040B00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q54z: LUT6_L 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(4),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNIUPFP1q26z: LUT6 
generic map(
  INIT => X"0F0B040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(27),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(26),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(26));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q55z: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNIMLO75q47z: LUT6 
generic map(
  INIT => X"0F0B040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(48),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(47),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SEq37z_Z8175: LUT6 
generic map(
  INIT => X"FFF4BBB04F440B00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(37),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(39),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SEq16z_Z8176: LUT6 
generic map(
  INIT => X"FF4FBB0BF444B000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(18),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_SEq5z_Z8177: LUT6 
generic map(
  INIT => X"FFF4BBB04F440B00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(7),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SE(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15q7z: LUT6_L 
generic map(
  INIT => X"0000200800000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3225_2,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1630);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A20_2q49z: LUT6 
generic map(
  INIT => X"5000004000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3854);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_3q63z: LUT6 
generic map(
  INIT => X"C100000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4479_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0q34z_Z8181: LUT6 
generic map(
  INIT => X"FFFFFFFF34000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3664_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3671,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_2_0(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q4z: LUT6 
generic map(
  INIT => X"00200008802B91A1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1026);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q18z: LUT6 
generic map(
  INIT => X"4001100840280000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_390);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q26z: LUT6 
generic map(
  INIT => X"0010010009000001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1079);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q22z: LUT6 
generic map(
  INIT => X"0044000008000104"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_805);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q0z: LUT6 
generic map(
  INIT => X"0000000800294000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_878);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_3q25z: LUT6 
generic map(
  INIT => X"0400050B00840410"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6370);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q25z: LUT6 
generic map(
  INIT => X"10010028802A0001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_936);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q24z: LUT6 
generic map(
  INIT => X"0044000008000100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_856);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q55z: LUT6 
generic map(
  INIT => X"532500AC00224212"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_957);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q0z: LUT6 
generic map(
  INIT => X"1755000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_870);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q4z: LUT6 
generic map(
  INIT => X"0000050908A20012"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1031);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q53z: LUT6 
generic map(
  INIT => X"0C7620B25D508507"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_579);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q0z: LUT6 
generic map(
  INIT => X"3575212221220555"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_875_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q28z: LUT6 
generic map(
  INIT => X"0400000804405010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_846_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_2q51z: LUT6 
generic map(
  INIT => X"0A00100200000911"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1072);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q32z: LUT6 
generic map(
  INIT => X"77F7FCEBFC6BF7F7"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_495);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0q50z_Z8198: LUT6 
generic map(
  INIT => X"2200202200000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1922,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_1_0(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_0q53z: LUT6 
generic map(
  INIT => X"41AE7A584D68A025"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_569);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNO_1q51z: LUT6 
generic map(
  INIT => X"019A0848213A0408"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1067);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq1z: LUT6_L 
generic map(
  INIT => X"8FFFFFFFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_9_3,
  I4 => M8_0_4,
  I5 => M8_0_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_54);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q1z: LUT6 
generic map(
  INIT => X"FEF0FFF1FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(57),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(56),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_9_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q1z: LUT6 
generic map(
  INIT => X"05550FFF01110333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq7z: LUT6_L 
generic map(
  INIT => X"2EEE0FFFEEEEFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  I1 => M20_E_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_8_3,
  I3 => M9_38_0_4,
  I4 => M20_E_38_2,
  I5 => M9_38_0_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_41);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q7z: LUT6 
generic map(
  INIT => X"00150000003F0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(50),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_5,
  I4 => M9_38_0_2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_8_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q7z: LUT4 
generic map(
  INIT => X"ECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(123),
  I1 => GRLFPC20_FPO_FRAC(50),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq8z: LUT6_L 
generic map(
  INIT => X"2EFFFFFFEEFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => M20_E_0,
  I2 => M9_39_0_2,
  I3 => M20_E_39_2,
  I4 => M20_E_39_1,
  I5 => M9_39_0_3,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_42);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq55z: LUT6_L 
generic map(
  INIT => X"FFFFFFFF77F0FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(2),
  I1 => M20_E_0,
  I2 => N_2523,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => M8_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(2),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q55z: LUT4 
generic map(
  INIT => X"2CE0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => M20_E_0,
  I2 => M8_1,
  I3 => M8_3,
  O => N_2523);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq54z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFFFF7350"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_7_7,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(3),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q54z: LUT6 
generic map(
  INIT => X"CEFFFFFFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_16,
  I2 => M20_E_0,
  I3 => M9_4_0_1,
  I4 => M9_4_0_0,
  I5 => M9_4_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_7_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q54z: LUT6 
generic map(
  INIT => X"00000000AAAAAAA2"
)
port map (
  I0 => rfo2_data2(0),
  I1 => rst,
  I2 => GRLFPC20_R_MK_LDOP,
  I3 => GRLFPC20_R_MK_RST,
  I4 => GRLFPC20_R_MK_RST2,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_16);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q20z: LUT6 
generic map(
  INIT => X"7CCC5E6E5F7F5F5F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(20),
  I2 => GRLFPC20_FPO_FRAC(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I4 => M20_E_0,
  I5 => M9_21_3,
  O => N_2526);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q34z: LUT5 
generic map(
  INIT => X"0A00CECC"
)
port map (
  I0 => rfo2_data2(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_19);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q40z: LUT5 
generic map(
  INIT => X"0A00CECC"
)
port map (
  I0 => rfo2_data2(14),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_24);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_8q45z: LUT5 
generic map(
  INIT => X"0A00CECC"
)
port map (
  I0 => rfo2_data2(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_29);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q39z: LUT5 
generic map(
  INIT => X"0A00CECC"
)
port map (
  I0 => rfo2_data2(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_34);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q51z: LUT5 
generic map(
  INIT => X"0A00CECC"
)
port map (
  I0 => rfo2_data2(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_39);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q49z: LUT5 
generic map(
  INIT => X"0A00CECC"
)
port map (
  I0 => rfo2_data2(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => M20_E_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_44);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq4z: LUT6_L 
generic map(
  INIT => X"FBB2FFFFFFFEFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I1 => M20_E_0,
  I2 => N_2528,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I4 => M9_35_0_4,
  I5 => M9_35_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_38);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q4z: LUT5 
generic map(
  INIT => X"F0CC00AA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(53),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(4),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => M20_E_0,
  O => N_2528);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q9z: LUT6 
generic map(
  INIT => X"0111033305550FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(48),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_46);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q3z: LUT6 
generic map(
  INIT => X"0111033305550FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_51);
R_DPATH_RET_3_RNO: LUT6_L 
generic map(
  INIT => X"0000001500000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_1_M(10),
  I1 => GRLFPC20_FPO_FRAC(46),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => M9_41_N_3_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M(47),
  I5 => M9_41_1,
  LO => N_38_MUX_41);
R_DPATH_RET_3_RNO_0: LUT4 
generic map(
  INIT => X"7F3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(47),
  I1 => M9_41_2,
  I2 => M9_41_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => M9_41_N_3_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_8q35z: LUT3_L 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_7_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q35z: LUT5_L 
generic map(
  INIT => X"3133F5FF"
)
port map (
  I0 => rfo2_data2(19),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q35z: LUT6 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(151),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => M9_6_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_9q35z: LUT5 
generic map(
  INIT => X"0F040B00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_0(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_0(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_10q35z: LUT6 
generic map(
  INIT => X"FDECB9A875643120"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_0(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(24),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(25),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_0(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_11q35z: LUT6 
generic map(
  INIT => X"FE76DC54BA329810"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_0(23),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(26),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(24),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(25),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_0(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_RNIQAAO1q27z: LUT5 
generic map(
  INIT => X"00C43BFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(27),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_0(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q42z: LUT6 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(158),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => M9_13_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q42z: LUT6 
generic map(
  INIT => X"00FF00FF0000003B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G6_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(15),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_I_M2_0_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q42z: LUT5_L 
generic map(
  INIT => X"004480C4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G6_0,
  I3 => N_6,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(16),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_I_M2_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q42z: LUT6 
generic map(
  INIT => X"53535353FFF00F00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(19),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2),
  O => N_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q36z: LUT6 
generic map(
  INIT => X"0103050F113355FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(152),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => M9_7_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE_LUT6_2_RNO: LUT6 
generic map(
  INIT => X"FDB97531ECA86420"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_0(22),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_1(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(24),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_0(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE_LUT6_2_RNO_0: LUT6_L 
generic map(
  INIT => X"FEDCBA9876543210"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_0(22),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_1(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(24),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(25),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq35z: LUT6_L 
generic map(
  INIT => X"FFFFFDFCFFFFFFFF"
)
port map (
  I0 => G3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(23),
  I5 => M9_6_0_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q35z: LUT6 
generic map(
  INIT => X"3333555500FF0F0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_0(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q35z: LUT6 
generic map(
  INIT => X"00FF33330F0F5555"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_0(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q35z: LUT5 
generic map(
  INIT => X"FFFFECA0"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(21),
  I1 => GRLFPC20_FPO_FRAC(22),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_7_8,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q35z: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => M20_E_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_5_12,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq42z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFEFCFFFF"
)
port map (
  I0 => N_30,
  I1 => M41_I_1,
  I2 => M41_I_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  I4 => M9_13_0_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(16),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_16);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q42z: LUT6 
generic map(
  INIT => X"FF202020FFFFFFFF"
)
port map (
  I0 => rfo2_data2(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPO_FRAC(14),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => M9_13_3,
  O => M41_I_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI67O92q45z: LUT6 
generic map(
  INIT => X"F0F0CCCCFF00AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => N_29);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q42z: LUT4 
generic map(
  INIT => X"C0EA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I1 => GRLFPC20_FPO_FRAC(15),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => M20_E_0,
  O => M41_I_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq36z: LUT6_L 
generic map(
  INIT => X"FFFFFFFFFEFCFFFF"
)
port map (
  I0 => N_30_0,
  I1 => M41_I_1_0,
  I2 => M41_I_2_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  I4 => M9_7_0_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1_1_M(22),
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q36z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => N_29_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(20),
  O => N_30_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q36z: LUT6 
generic map(
  INIT => X"FF202020FFFFFFFF"
)
port map (
  I0 => rfo2_data2(18),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => GRLFPC20_FPO_FRAC(20),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I5 => M9_7_3,
  O => M41_I_2_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q36z: LUT6 
generic map(
  INIT => X"CCCCF0F0FF00AAAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => N_29_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q36z: LUT4 
generic map(
  INIT => X"C0EA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_FPO_FRAC(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => M20_E_0,
  O => M41_I_1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq9z: LUT6_L 
generic map(
  INIT => X"B3A0BFAFBFAFBFAF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(48),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_46,
  I5 => M9_40_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_43);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_4q9z: LUT6 
generic map(
  INIT => X"33330F0F00FF5555"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q9z: LUT6 
generic map(
  INIT => X"0F0F555500FF3333"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2);
R_DPATH_RET_5_RNO_1: LUT6 
generic map(
  INIT => X"2A003F0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(25),
  I1 => GRLFPC20_FPO_FRAC(25),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I3 => N_6_169,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  I5 => G0_0,
  O => M9_32_2_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNII6FV2q36z: LUT6 
generic map(
  INIT => X"0F0F5555333300FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIS7NA2q34z: LUT6 
generic map(
  INIT => X"00FF0F0F33335555"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2_0);
R_DPATH_RET_5_RNO_3: LUT4_L 
generic map(
  INIT => X"DF00"
)
port map (
  I0 => rfo2_data2(23),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => M9_32_3,
  LO => G0_0);
R_DPATH_RET_5_RNO_2: LUT2 
generic map(
  INIT => X"7"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(26),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  O => N_6_169);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq3z: LUT6_L 
generic map(
  INIT => X"B3A0BFAFBFAFBFAF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(54),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_6_51,
  I5 => M9_50_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_55);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_LUT6_2_RNOq37z: LUT6 
generic map(
  INIT => X"00FF555533330F0F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I2 => NN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q3z: LUT4 
generic map(
  INIT => X"070F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(3),
  I2 => M20_E_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0_1);
R_DPATH_RET_9_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0,
  I1 => M9_49_2,
  I2 => M9_49_3,
  I3 => N_7,
  I4 => N_6_170,
  I5 => M9_49_1,
  LO => N_38_MUX_49);
R_DPATH_RET_9_RNO_0: LUT4 
generic map(
  INIT => X"F222"
)
port map (
  I0 => GRLFPC20_FPI_LDOP,
  I1 => N_30_1,
  I2 => GRLFPC20_FPO_FRAC(38),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0);
R_DPATH_RET_9_RNO_4: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(39),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(40),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_170);
R_DPATH_RET_9_RNO_6: LUT6 
generic map(
  INIT => X"00FF0F0F33335555"
)
port map (
  I0 => rfo1_data2(4),
  I1 => rfo1_data2(7),
  I2 => rfo2_data2(4),
  I3 => rfo2_data2(7),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => N_30_1);
R_DPATH_RET_9_RNO_3: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(37),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7);
R_DPATH_RET_20_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_0,
  I1 => M9_47_2,
  I2 => M9_47_3,
  I3 => N_7_0,
  I4 => N_6_171,
  I5 => M9_47_1,
  LO => N_38_MUX_47);
R_DPATH_RET_20_RNO_0: LUT4 
generic map(
  INIT => X"F222"
)
port map (
  I0 => GRLFPC20_FPI_LDOP,
  I1 => N_30_2,
  I2 => GRLFPC20_FPO_FRAC(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_0);
R_DPATH_RET_20_RNO_4: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(41),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(42),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_171);
R_DPATH_RET_20_RNO_6: LUT6 
generic map(
  INIT => X"00FF0F0F33335555"
)
port map (
  I0 => rfo1_data2(6),
  I1 => rfo1_data2(9),
  I2 => rfo2_data2(6),
  I3 => rfo2_data2(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => N_30_2);
R_DPATH_RET_20_RNO_3: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(41),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_0);
R_DPATH_RET_12_RNO: LUT6_L 
generic map(
  INIT => X"0000020300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(42),
  I1 => N_5_I_I_0,
  I2 => N_5_I_I_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => N_7_1,
  I5 => M9_46_1,
  LO => N_38_MUX_46);
R_DPATH_RET_12_RNO_0: LUT4 
generic map(
  INIT => X"F222"
)
port map (
  I0 => GRLFPC20_FPI_LDOP,
  I1 => N_15,
  I2 => GRLFPC20_FPO_FRAC(41),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_5_I_I_0);
R_DPATH_RET_12_RNO_2: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(42),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(43),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_7_1);
R_DPATH_RET_12_RNO_4: LUT6 
generic map(
  INIT => X"00FF0F0F33335555"
)
port map (
  I0 => rfo1_data2(7),
  I1 => rfo1_data2(10),
  I2 => rfo2_data2(7),
  I3 => rfo2_data2(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => N_15);
R_DPATH_RET_8_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_1,
  I1 => M9_34_2,
  I2 => M9_34_3,
  I3 => N_7_2,
  I4 => N_6_172,
  I5 => M9_34_1,
  LO => N_38_MUX_34);
R_DPATH_RET_8_RNO_4: LUT6 
generic map(
  INIT => X"0F0B040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(25),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(24),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_172);
R_DPATH_RET_8_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_139,
  I3 => GRLFPC20_FPO_FRAC(23),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_1);
R_DPATH_RET_8_RNO_3: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(22),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_2);
R_DPATH_RET_17_RNO: LUT6_L 
generic map(
  INIT => X"0000020300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(25),
  I1 => N_5_I_I_0_0,
  I2 => N_5_I_I_1_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => N_7_3,
  I5 => M9_33_1,
  LO => N_38_MUX_33);
R_DPATH_RET_17_RNO_2: LUT6 
generic map(
  INIT => X"0F0B040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(26),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(25),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_7_3);
R_DPATH_RET_17_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(22),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_131,
  I3 => GRLFPC20_FPO_FRAC(24),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_5_I_I_0_0);
R_DPATH_RET_21_RNO: LUT6_L 
generic map(
  INIT => X"0000020300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(27),
  I1 => N_5_I_I_0_1,
  I2 => N_5_I_I_1_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => N_7_4,
  I5 => M9_31_1,
  LO => N_38_MUX_31);
R_DPATH_RET_21_RNO_2: LUT6 
generic map(
  INIT => X"0F0B040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(28),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(27),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_7_4);
R_DPATH_RET_21_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(24),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_131_0,
  I3 => GRLFPC20_FPO_FRAC(26),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_5_I_I_0_1);
R_DPATH_RET_18_RNO: LUT6_L 
generic map(
  INIT => X"000000008C000000"
)
port map (
  I0 => G5_0,
  I1 => G0_0_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I3 => G0_1,
  I4 => M9_30_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(28),
  LO => N_38_MUX_30);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNI2UFP1q28z: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(28),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(29),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(28));
R_DPATH_RET_18_RNO_0: LUT6 
generic map(
  INIT => X"FF55FF5700000000"
)
port map (
  I0 => rfo2_data2(25),
  I1 => GRLFPC20_R_MK_RST,
  I2 => GRLFPC20_R_MK_RST2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0,
  I5 => M9_30_2,
  O => G0_0_0);
R_DPATH_RET_18_RNO_1: LUT3 
generic map(
  INIT => X"70"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(27),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I2 => M9_30_3,
  O => G0_1);
R_DPATH_RET_22_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_2,
  I1 => M9_29_2,
  I2 => M9_29_3,
  I3 => N_7_5,
  I4 => N_6_173,
  I5 => M9_29_1,
  LO => N_38_MUX_29);
R_DPATH_RET_22_RNO_4: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(30),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_173);
R_DPATH_RET_22_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(26),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_139_0,
  I3 => GRLFPC20_FPO_FRAC(28),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_2);
R_DPATH_RET_22_RNO_3: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(27),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_5);
R_DPATH_RET_16_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_3,
  I1 => M9_28_2,
  I2 => M9_28_3,
  I3 => N_7_6,
  I4 => N_6_174,
  I5 => M9_28_1,
  LO => N_38_MUX_28);
R_DPATH_RET_16_RNO_4: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(31),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_174);
R_DPATH_RET_16_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(27),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_139_1,
  I3 => GRLFPC20_FPO_FRAC(29),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_3);
R_DPATH_RET_16_RNO_3: LUT4 
generic map(
  INIT => X"E400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_116,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(28),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_6);
R_DPATH_RET_6_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_4,
  I1 => M9_27_2,
  I2 => M9_27_3,
  I3 => N_7_7,
  I4 => N_6_175,
  I5 => M9_27_1,
  LO => N_38_MUX_27);
R_DPATH_RET_6_RNO_4: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(31),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(32),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_175);
R_DPATH_RET_6_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(28),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_139_2,
  I3 => GRLFPC20_FPO_FRAC(30),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_4);
R_DPATH_RET_6_RNO_3: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(31),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_7);
R_DPATH_RET_11_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_5,
  I1 => M9_23_2,
  I2 => M9_23_3,
  I3 => N_7_8,
  I4 => N_6_176,
  I5 => M9_23_1,
  LO => N_38_MUX_23);
R_DPATH_RET_11_RNO_0: LUT4 
generic map(
  INIT => X"F888"
)
port map (
  I0 => GRLFPC20_FPI_LDOP,
  I1 => N_30_3,
  I2 => GRLFPC20_FPO_FRAC(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_5);
R_DPATH_RET_11_RNO_4: LUT6 
generic map(
  INIT => X"0F0B040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(36),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(35),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_176);
R_DPATH_RET_11_RNO_6: LUT6 
generic map(
  INIT => X"FF00F0F0CCCCAAAA"
)
port map (
  I0 => rfo1_data2(0),
  I1 => rfo1_data2(3),
  I2 => rfo2_data2(0),
  I3 => rfo2_data2(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I5 => GRLFPC20_COMB_UN1_FPCI_4,
  O => N_30_3);
R_DPATH_RET_11_RNO_3: LUT4 
generic map(
  INIT => X"E400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(33),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_8);
R_DPATH_RET_19_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_6,
  I1 => M9_19_2,
  I2 => M9_19_3,
  I3 => N_7_9,
  I4 => N_6_177,
  I5 => M9_19_1,
  LO => N_38_MUX_19);
R_DPATH_RET_19_RNO_4: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(9),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(10),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_177);
R_DPATH_RET_19_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_139_3,
  I3 => GRLFPC20_FPO_FRAC(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_6);
R_DPATH_RET_19_RNO_3: LUT4 
generic map(
  INIT => X"E400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(9),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_9);
R_DPATH_RET_15_RNO: LUT6_L 
generic map(
  INIT => X"2030A0F000000000"
)
port map (
  I0 => G5,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_2,
  I2 => G0_1_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_17_0_0,
  LO => N_38_MUX_17);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_RNI47N71q44z: LUT6 
generic map(
  INIT => X"DD0F0000DD0FFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1_0_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_0(11),
  O => G5);
R_DPATH_RET_15_RNO_0: LUT5 
generic map(
  INIT => X"DF000000"
)
port map (
  I0 => rfo2_data2(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => GRLFPC20_FPI_LDOP,
  I3 => M9_17_2,
  I4 => M9_17_3,
  O => G0_1_0);
R_DPATH_RET_7_RNO: LUT6_L 
generic map(
  INIT => X"000000008C000000"
)
port map (
  I0 => G5_0_0,
  I1 => G0_0_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I3 => G0_1_1,
  I4 => M9_15_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(13),
  LO => N_38_MUX_15);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNIMFDP1q13z: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(14),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(13));
R_DPATH_RET_7_RNO_0: LUT6 
generic map(
  INIT => X"FF55FF5700000000"
)
port map (
  I0 => rfo2_data2(10),
  I1 => GRLFPC20_R_MK_RST,
  I2 => GRLFPC20_R_MK_RST2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0_0,
  I5 => M9_15_2,
  O => G0_0_1);
R_DPATH_RET_7_RNO_1: LUT3 
generic map(
  INIT => X"70"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I2 => M9_15_3,
  O => G0_1_1);
R_DPATH_RET_13_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_7,
  I1 => M9_14_2,
  I2 => M9_14_3,
  I3 => N_7_10,
  I4 => N_6_178,
  I5 => M9_14_1,
  LO => N_38_MUX_14);
R_DPATH_RET_13_RNO_4: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(14),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(15),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_178);
R_DPATH_RET_13_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(11),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_139_4,
  I3 => GRLFPC20_FPO_FRAC(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_7);
R_DPATH_RET_13_RNO_3: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(12),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(14),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_10);
R_DPATH_RET_14_RNO: LUT6_L 
generic map(
  INIT => X"000000008C000000"
)
port map (
  I0 => G5_0_1,
  I1 => G0_0_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I3 => G0_1_2,
  I4 => M9_9_1,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(19),
  LO => N_38_MUX_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_RNIPJEP1q19z: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(19),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(20),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(19));
R_DPATH_RET_14_RNO_0: LUT6 
generic map(
  INIT => X"FF55FF5700000000"
)
port map (
  I0 => rfo2_data2(16),
  I1 => GRLFPC20_R_MK_RST,
  I2 => GRLFPC20_R_MK_RST2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0_1,
  I5 => M9_9_2,
  O => G0_0_2);
R_DPATH_RET_14_RNO_1: LUT3 
generic map(
  INIT => X"70"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(18),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I2 => M9_9_3,
  O => G0_1_2);
R_DPATH_RET_10_RNO: LUT6_L 
generic map(
  INIT => X"0000004000000000"
)
port map (
  I0 => N_12_I_I_0_8,
  I1 => M9_8_2,
  I2 => M9_8_3,
  I3 => N_7_11,
  I4 => N_6_179,
  I5 => M9_8_1,
  LO => N_38_MUX_8);
R_DPATH_RET_10_RNO_4: LUT6 
generic map(
  INIT => X"0F0B040000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(21),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(20),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_6_179);
R_DPATH_RET_10_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(17),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_139_5,
  I3 => GRLFPC20_FPO_FRAC(19),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_12_I_I_0_8);
R_DPATH_RET_10_RNO_3: LUT4 
generic map(
  INIT => X"D800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(18),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(20),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  O => N_7_11);
R_DPATH_RET_23_RNO: LUT6_L 
generic map(
  INIT => X"0000020300000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(4),
  I1 => N_5_I_I_0_2,
  I2 => N_5_I_I_1_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_8_SQMUXA,
  I4 => N_7_12,
  I5 => M9_3_1,
  LO => N_38_MUX_3);
R_DPATH_RET_23_RNO_2: LUT6 
generic map(
  INIT => X"0F040B0000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(4),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(5),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  O => N_7_12);
R_DPATH_RET_23_RNO_0: LUT5 
generic map(
  INIT => X"FF020202"
)
port map (
  I0 => rfo2_data2(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  I2 => N_131_1,
  I3 => GRLFPC20_FPO_FRAC(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_5_I_I_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq51z: LUT6_L 
generic map(
  INIT => X"FFEFFFCFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(6),
  I1 => N_28,
  I2 => M9_1_3,
  I3 => M80_I_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_1_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q51z: LUT6 
generic map(
  INIT => X"0008000000000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I4 => N_14,
  I5 => M20_E_0,
  O => N_28);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q51z: LUT6 
generic map(
  INIT => X"F0F0FF00AAAACCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => N_14);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q51z: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(167),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => N_134,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_39,
  O => M80_I_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q51z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_134);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq49z: LUT6_L 
generic map(
  INIT => X"FFEFFFCFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_2_0,
  I2 => G1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_1_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_1,
  LO => NN_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_2q49z: LUT5 
generic map(
  INIT => X"FFF7FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(8),
  I4 => M20_E_0,
  O => G1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q49z: LUT6 
generic map(
  INIT => X"F5F30000F5F3FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q49z: LUT4 
generic map(
  INIT => X"F8FF"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_44,
  I3 => M9_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_1_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q49z: LUT4 
generic map(
  INIT => X"ECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(165),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_2_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq45z: LUT6_L 
generic map(
  INIT => X"FFEFFFCFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(12),
  I1 => N_30_4,
  I2 => M9_16_3,
  I3 => M96_I_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_16_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_19);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q45z: LUT6 
generic map(
  INIT => X"0A02080000000000"
)
port map (
  I0 => M96_I_A3_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => N_13,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(12),
  I5 => M20_E_0,
  O => N_30_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q45z: LUT5 
generic map(
  INIT => X"00CCAAF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => N_13);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q45z: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(161),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => N_148,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_29,
  O => M96_I_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_7q45z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(11),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_148);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q45z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  O => M96_I_A3_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq40z: LUT6_L 
generic map(
  INIT => X"FFEFFFCFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(17),
  I1 => N_32,
  I2 => M9_11_3,
  I3 => M74_I_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_11_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_14);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q40z: LUT6 
generic map(
  INIT => X"0A08020000000000"
)
port map (
  I0 => M74_I_A3_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => N_10,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(15),
  I5 => M20_E_0,
  O => N_32);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q40z: LUT5 
generic map(
  INIT => X"AC00ACFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(17),
  O => N_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q40z: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(156),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => N_122,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_24,
  O => M74_I_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q40z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(16),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_122);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq39z: LUT6_L 
generic map(
  INIT => X"FFEFFFCFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(18),
  I1 => N_32_0,
  I2 => M9_10_3,
  I3 => M74_I_3_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_10_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_13);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q39z: LUT6 
generic map(
  INIT => X"080A000200000000"
)
port map (
  I0 => M74_I_A3_0_0,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => N_13_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(16),
  I5 => M20_E_0,
  O => N_32_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q39z: LUT5 
generic map(
  INIT => X"FF003535"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(14),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => N_13_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q39z: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(155),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => N_122_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_34,
  O => M74_I_3_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q39z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(17),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_122_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq34z: LUT6_L 
generic map(
  INIT => X"FFEFFFCFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(23),
  I1 => N_37,
  I2 => M9_5_3,
  I3 => M64_I_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_6_SQMUXA,
  I5 => M9_5_1,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q34z: LUT5 
generic map(
  INIT => X"00080000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(0),
  I3 => N_12,
  I4 => M20_E_0,
  O => N_37);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_5q34z: LUT6 
generic map(
  INIT => X"FF0FF000ACACACAC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(19),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(23),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(17),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(21),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  O => N_12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_3q34z: LUT6 
generic map(
  INIT => X"FFFFFFFFFFFFECA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(150),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_23,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_2_SQMUXA_21,
  I4 => N_112,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_E_N_4_19,
  O => M64_I_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_6q34z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_FPO_FRAC(22),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_5_SQMUXA,
  O => N_112);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q35z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_0(21),
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_0(19),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
    O => G3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_0q9z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1_0,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL_RNIP76G5q1z: MUXF7 port map (
    I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1,
    I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2_0,
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(25));
R_DPATH_RET_23_RNO_1: LUT6 
generic map(
  INIT => X"EAC0AA00FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(53),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => M9_3_2,
  O => N_5_I_I_1_2);
R_DPATH_RET_21_RNO_1: LUT6 
generic map(
  INIT => X"EAC0AA00FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(30),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => M9_31_2,
  O => N_5_I_I_1_1);
R_DPATH_RET_17_RNO_1: LUT6 
generic map(
  INIT => X"EAC0AA00FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => M9_33_2,
  O => N_5_I_I_1_0);
R_DPATH_RET_12_RNO_1: LUT6 
generic map(
  INIT => X"EAC0AA00FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(15),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_3_SQMUXA_22,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  I5 => M9_46_2,
  O => N_5_I_I_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNOq20z: LUT6_L 
generic map(
  INIT => X"FFD5FFC0FFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(36),
  I1 => GRLFPC20_FPO_FRAC(37),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_1_SQMUXA_20,
  I3 => N_2526,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_7_SQMUXA,
  I5 => M9_21_1_0,
  LO => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_24);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNO_1q9z: LUT6 
generic map(
  INIT => X"00007DD70000FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_123(46),
  I4 => M20_E_0,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_5_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_35: MUXCY port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_DATA_TMP(3),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6303,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_I_155: MUXCY port map (
    DI => NN_5,
    CI => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_DATA_TMP(18),
    S => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS_0_N_3_I,
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN18_XZXBUS);
GRLFPC20_R_X_SEQERR_0_R_X_RDD_1: SRL16E port map (
  Q => GRLFPC20_R_X_SEQERR_0_TMP_D_ARRAY_0(0),
  A0 => NN_2,
  A1 => NN_5,
  A2 => NN_5,
  A3 => NN_5,
  D => GRLFPC20_R_A_SEQERR,
  CLK => clk,
  CE => holdn);
GRLFPC20_R_X_RDD_0_R_X_RDD_1: SRL16E port map (
  Q => GRLFPC20_R_X_RDD_0_TMP_D_ARRAY_0(0),
  A0 => NN_2,
  A1 => NN_5,
  A2 => NN_5,
  A3 => NN_5,
  D => GRLFPC20_R_A_RDD,
  CLK => clk,
  CE => holdn);
RqXzXRDDY_1_Z8414: FDRE port map (
  Q => RqXzXRDDY_1,
  D => RqXzXRDDY_0,
  C => clk,
  R => N_331,
  CE => holdn);
RqXzXRDDY_0_Z8415: FDRE port map (
  Q => RqXzXRDDY_0,
  D => RqXzXRDDY,
  C => clk,
  R => N_331,
  CE => holdn);
RqXzXRDDY_Z8416: FDRE port map (
  Q => RqXzXRDDY,
  D => NN_2,
  C => clk,
  R => N_331,
  CE => holdn);
R_DPATH_RET_54_Z8417: FD port map (
  Q => R_DPATH_RET_54,
  D => N_38_MUX_36,
  C => clk);
R_DPATH_RET_53: FD port map (
  Q => M20_E_36_3_RETO,
  D => M20_E_36_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_68: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(5),
  D => NN_3,
  C => clk);
R_DPATH_RET_52_Z8420: FD port map (
  Q => R_DPATH_RET_52,
  D => N_38_MUX_48,
  C => clk);
R_DPATH_RET_51: FD port map (
  Q => M20_E_48_2_RETO,
  D => M20_E_48_2,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_66: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(17),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  C => clk);
R_DPATH_RET_50_Z8423: FD port map (
  Q => R_DPATH_RET_50,
  D => N_38_MUX_37,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_64: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(6),
  D => NN_6,
  C => clk);
R_DPATH_RET_49_Z8425: FD port map (
  Q => R_DPATH_RET_49,
  D => N_38_MUX_20,
  C => clk);
R_DPATH_RET_48: FD port map (
  Q => M20_E_20_0_2_RETO,
  D => M20_E_20_0_2,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_61: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8_RETO(19),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(19),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_60: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(19),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  C => clk);
R_DPATH_RET_47_Z8429: FD port map (
  Q => R_DPATH_RET_47,
  D => N_38_MUX_44,
  C => clk);
R_DPATH_RET_46: FD port map (
  Q => M20_E_44_0_1_RETO,
  D => M20_E_44_0_1,
  C => clk);
R_DPATH_RET_45: FD port map (
  Q => M9_44_3_RETO,
  D => M9_44_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_58: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(13),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  C => clk);
R_DPATH_RET_44_Z8433: FD port map (
  Q => R_DPATH_RET_44,
  D => N_38_MUX_24,
  C => clk);
R_DPATH_RET_43: FD port map (
  Q => M20_E_24_0_1_RETO,
  D => M20_E_24_0_1,
  C => clk);
R_DPATH_RET_42: FD port map (
  Q => M9_24_3_RETO,
  D => M9_24_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_56: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(23),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  C => clk);
R_DPATH_RET_41_Z8437: FD port map (
  Q => R_DPATH_RET_41,
  D => N_38_MUX_26,
  C => clk);
R_DPATH_RET_40: FD port map (
  Q => M20_E_26_0_1_RETO,
  D => M20_E_26_0_1,
  C => clk);
R_DPATH_RET_39: FD port map (
  Q => M9_26_3_RETO,
  D => M9_26_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_54: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(25),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  C => clk);
R_DPATH_RET_38_Z8441: FD port map (
  Q => R_DPATH_RET_38,
  D => N_38_MUX_18,
  C => clk);
R_DPATH_RET_37: FD port map (
  Q => M20_E_18_0_1_RETO,
  D => M20_E_18_0_1,
  C => clk);
R_DPATH_RET_36: FD port map (
  Q => M9_18_3_RETO,
  D => M9_18_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_52: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(47),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  C => clk);
R_DPATH_RET_35_Z8445: FD port map (
  Q => R_DPATH_RET_35,
  D => N_38_MUX_45,
  C => clk);
R_DPATH_RET_34: FD port map (
  Q => M20_E_45_0_1_RETO,
  D => M20_E_45_0_1,
  C => clk);
R_DPATH_RET_33: FD port map (
  Q => M9_45_3_RETO,
  D => M9_45_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_50: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(14),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  C => clk);
R_DPATH_RET_32_Z8449: FD port map (
  Q => R_DPATH_RET_32,
  D => N_38_MUX_25,
  C => clk);
R_DPATH_RET_31: FD port map (
  Q => M20_E_25_0_1_RETO,
  D => M20_E_25_0_1,
  C => clk);
R_DPATH_RET_30: FD port map (
  Q => M9_25_3_RETO,
  D => M9_25_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_48: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(24),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_28,
  C => clk);
R_DPATH_RET_29_Z8453: FD port map (
  Q => R_DPATH_RET_29,
  D => N_38_MUX_42,
  C => clk);
R_DPATH_RET_28: FD port map (
  Q => M20_E_42_0_1_RETO,
  D => M20_E_42_0_1,
  C => clk);
R_DPATH_RET_27: FD port map (
  Q => M9_42_3_RETO,
  D => M9_42_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_46: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(11),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  C => clk);
R_DPATH_RET_26_Z8457: FD port map (
  Q => R_DPATH_RET_26,
  D => N_38_MUX_0,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_44: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(50),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0_0,
  C => clk);
R_DPATH_RET_25_Z8459: FD port map (
  Q => R_DPATH_RET_25,
  D => N_38_MUX_12,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_42: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(41),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15_0,
  C => clk);
R_DPATH_RET_24_Z8461: FD port map (
  Q => R_DPATH_RET_24,
  D => N_38_MUX_2,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_40: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(52),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2_0,
  C => clk);
R_DPATH_RET_23_Z8463: FD port map (
  Q => R_DPATH_RET_23,
  D => N_38_MUX_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_38: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(53),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3_0,
  C => clk);
R_DPATH_RET_22_Z8465: FD port map (
  Q => R_DPATH_RET_22,
  D => N_38_MUX_29,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_36: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(28),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32_0,
  C => clk);
R_DPATH_RET_21_Z8467: FD port map (
  Q => R_DPATH_RET_21,
  D => N_38_MUX_31,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_34: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(30),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34_0,
  C => clk);
R_DPATH_RET_20_Z8469: FD port map (
  Q => R_DPATH_RET_20,
  D => N_38_MUX_47,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_32: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(16),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50_0,
  C => clk);
R_DPATH_RET_19_Z8471: FD port map (
  Q => R_DPATH_RET_19,
  D => N_38_MUX_19,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_30: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(48),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22_0,
  C => clk);
R_DPATH_RET_18_Z8473: FD port map (
  Q => R_DPATH_RET_18,
  D => N_38_MUX_30,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_28: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(29),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33_0,
  C => clk);
R_DPATH_RET_17_Z8475: FD port map (
  Q => R_DPATH_RET_17,
  D => N_38_MUX_33,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_26: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(32),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36_0,
  C => clk);
R_DPATH_RET_16_Z8477: FD port map (
  Q => R_DPATH_RET_16,
  D => N_38_MUX_28,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_24: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(27),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31_0,
  C => clk);
R_DPATH_RET_15_Z8479: FD port map (
  Q => R_DPATH_RET_15,
  D => N_38_MUX_17,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_22: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(46),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20_0,
  C => clk);
R_DPATH_RET_14_Z8481: FD port map (
  Q => R_DPATH_RET_14,
  D => N_38_MUX_9,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_20: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(38),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12_0,
  C => clk);
R_DPATH_RET_13_Z8483: FD port map (
  Q => R_DPATH_RET_13,
  D => N_38_MUX_14,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_18: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(43),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17_0,
  C => clk);
R_DPATH_RET_12_Z8485: FD port map (
  Q => R_DPATH_RET_12,
  D => N_38_MUX_46,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_16: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(15),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49_0,
  C => clk);
R_DPATH_RET_11_Z8487: FD port map (
  Q => R_DPATH_RET_11,
  D => N_38_MUX_23,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_14: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(22),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26_0,
  C => clk);
R_DPATH_RET_10_Z8489: FD port map (
  Q => R_DPATH_RET_10,
  D => N_38_MUX_8,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_12: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(37),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11_0,
  C => clk);
R_DPATH_RET_9_Z8491: FD port map (
  Q => R_DPATH_RET_9,
  D => N_38_MUX_49,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_10: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(18),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52_0,
  C => clk);
R_DPATH_RET_8_Z8493: FD port map (
  Q => R_DPATH_RET_8,
  D => N_38_MUX_34,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_8: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(33),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37_0,
  C => clk);
R_DPATH_RET_7_Z8495: FD port map (
  Q => R_DPATH_RET_7,
  D => N_38_MUX_15,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_6: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(44),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18_0,
  C => clk);
R_DPATH_RET_6_Z8497: FD port map (
  Q => R_DPATH_RET_6,
  D => N_38_MUX_27,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_4: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(26),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30_0,
  C => clk);
R_DPATH_RET_5_Z8499: FD port map (
  Q => R_DPATH_RET_5,
  D => N_38_MUX_32,
  C => clk);
R_DPATH_RET_4: FD port map (
  Q => M9_32_3_RETO,
  D => M9_32_3,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_2: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(31),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  C => clk);
R_DPATH_RET_3_Z8502: FD port map (
  Q => R_DPATH_RET_3,
  D => N_38_MUX_41,
  C => clk);
R_DPATH_RET_2: FD port map (
  Q => M20_E_41_3_RETO,
  D => M20_E_41_3,
  C => clk);
R_DPATH_RET_1: FD port map (
  Q => M9_41_1_RETO,
  D => M9_41_1,
  C => clk);
R_DPATH_RET: FD port map (
  Q => M9_41_2_RETO,
  D => M9_41_2_0,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(10),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  C => clk);
GRLFPC20_R_X_SEQERR_0_DOUTq0z_Z8507: FDE port map (
  Q => GRLFPC20_R_X_SEQERR_0_DOUT(0),
  D => GRLFPC20_R_X_SEQERR_0_TMP_D_ARRAY_0(0),
  C => clk,
  CE => holdn);
GRLFPC20_R_X_RDD_0_DOUTq0z_Z8508: FDE port map (
  Q => GRLFPC20_R_X_RDD_0_DOUT(0),
  D => GRLFPC20_R_X_RDD_0_TMP_D_ARRAY_0(0),
  C => clk,
  CE => holdn);
GRLFPC20_R_MK_RST2_Z8509: FD port map (
  Q => GRLFPC20_R_MK_RST2,
  D => GRLFPC20_R_MK_RST,
  C => clk);
GRLFPC20_R_MK_RST_Z8510: FD port map (
  Q => GRLFPC20_R_MK_RST,
  D => GRLFPC20_V_MK_RST_1,
  C => clk);
GRLFPC20_R_MK_LDOP_Z8511: FD port map (
  Q => GRLFPC20_R_MK_LDOP,
  D => GRLFPC20_RIN_MK_LDOP_0,
  C => clk);
GRLFPC20_R_A_RS1q4z_Z8512: FD port map (
  Q => GRLFPC20_R_A_RS1(4),
  D => RFI2_RD1ADDR_73,
  C => clk);
GRLFPC20_R_A_RS1q3z_Z8513: FD port map (
  Q => GRLFPC20_R_A_RS1(3),
  D => RFI2_RD1ADDR_72,
  C => clk);
GRLFPC20_R_A_RS1q2z_Z8514: FD port map (
  Q => GRLFPC20_R_A_RS1(2),
  D => RFI2_RD1ADDR_71,
  C => clk);
GRLFPC20_R_A_RS1q1z_Z8515: FD port map (
  Q => GRLFPC20_R_A_RS1(1),
  D => RFI2_RD1ADDR_70,
  C => clk);
GRLFPC20_R_A_RS1q0z_Z8516: FD port map (
  Q => GRLFPC20_R_A_RS1(0),
  D => GRLFPC20_RS1_1(0),
  C => clk);
GRLFPC20_R_A_RF2RENq1z_Z8517: FD port map (
  Q => GRLFPC20_R_A_RF2REN(1),
  D => RFI2_REN1_90,
  C => clk);
GRLFPC20_R_A_RF2RENq2z_Z8518: FD port map (
  Q => GRLFPC20_R_A_RF2REN(2),
  D => RFI2_REN2_91,
  C => clk);
GRLFPC20_R_A_RF1RENq1z_Z8519: FD port map (
  Q => GRLFPC20_R_A_RF1REN(1),
  D => RFI1_REN1_64,
  C => clk);
GRLFPC20_R_A_RF1RENq2z_Z8520: FD port map (
  Q => GRLFPC20_R_A_RF1REN(2),
  D => RFI1_REN2_65,
  C => clk);
GRLFPC20_R_A_RS2q4z_Z8521: FD port map (
  Q => GRLFPC20_R_A_RS2(4),
  D => RFI2_RD2ADDR_77,
  C => clk);
GRLFPC20_R_A_RS2q3z_Z8522: FD port map (
  Q => GRLFPC20_R_A_RS2(3),
  D => RFI2_RD2ADDR_76,
  C => clk);
GRLFPC20_R_A_RS2q2z_Z8523: FD port map (
  Q => GRLFPC20_R_A_RS2(2),
  D => RFI2_RD2ADDR_75,
  C => clk);
GRLFPC20_R_A_RS2q1z_Z8524: FD port map (
  Q => GRLFPC20_R_A_RS2(1),
  D => RFI2_RD2ADDR_74,
  C => clk);
GRLFPC20_R_A_RS2q0z_Z8525: FD port map (
  Q => GRLFPC20_R_A_RS2(0),
  D => GRLFPC20_RS2_1(0),
  C => clk);
GRLFPC20_R_E_AFQ_Z8526: FDE port map (
  Q => GRLFPC20_R_E_AFQ,
  D => GRLFPC20_V_E_AFQ_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_E_AFSR_Z8527: FDE port map (
  Q => GRLFPC20_R_E_AFSR,
  D => GRLFPC20_V_E_AFSR_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_E_FPOP_Z8528: FDE port map (
  Q => GRLFPC20_R_E_FPOP,
  D => GRLFPC20_V_E_FPOP_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_E_LD_Z8529: FDE port map (
  Q => GRLFPC20_R_E_LD,
  D => GRLFPC20_V_E_LD_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_M_AFQ_Z8530: FDE port map (
  Q => GRLFPC20_R_M_AFQ,
  D => GRLFPC20_V_M_AFQ_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_M_AFSR_Z8531: FDE port map (
  Q => GRLFPC20_R_M_AFSR,
  D => GRLFPC20_V_M_AFSR_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_M_FPOP_Z8532: FDE port map (
  Q => GRLFPC20_R_M_FPOP,
  D => GRLFPC20_V_M_FPOP_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_M_LD_Z8533: FDE port map (
  Q => GRLFPC20_R_M_LD,
  D => GRLFPC20_V_M_LD_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_X_AFQ_Z8534: FDE port map (
  Q => GRLFPC20_R_X_AFQ,
  D => GRLFPC20_V_X_AFQ_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_X_AFSR_Z8535: FDE port map (
  Q => GRLFPC20_R_X_AFSR,
  D => GRLFPC20_V_X_AFSR_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_X_FPOP_Z8536: FDE port map (
  Q => GRLFPC20_R_X_FPOP,
  D => GRLFPC20_V_X_FPOP_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_X_LD_Z8537: FDE port map (
  Q => GRLFPC20_R_X_LD,
  D => GRLFPC20_V_X_LD_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_A_MOV_Z8538: FDE port map (
  Q => GRLFPC20_R_A_MOV,
  D => GRLFPC20_MOV_5_SQMUXA,
  C => clk,
  CE => holdn);
GRLFPC20_R_I_RDD_Z8539: FD port map (
  Q => GRLFPC20_R_I_RDD,
  D => GRLFPC20_R_I_RDD_0,
  C => clk);
GRLFPC20_R_A_RS2D_Z8540: FDE port map (
  Q => GRLFPC20_R_A_RS2D,
  D => GRLFPC20_RS2D_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_A_RDD_Z8541: FDE port map (
  Q => GRLFPC20_R_A_RDD,
  D => GRLFPC20_RDD_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_A_RS1D_Z8542: FDE port map (
  Q => GRLFPC20_R_A_RS1D,
  D => GRLFPC20_RS1D_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_STATEq1z_Z8543: FDE port map (
  Q => GRLFPC20_R_STATE(1),
  D => GRLFPC20_V_STATE_1_IV_I(1),
  C => clk,
  CE => holdn);
GRLFPC20_R_STATEq0z_Z8544: FDE port map (
  Q => GRLFPC20_R_STATE(0),
  D => GRLFPC20_V_STATE_1(0),
  C => clk,
  CE => holdn);
GRLFPC20_R_FSR_FTTq2z_Z8545: FDE port map (
  Q => GRLFPC20_R_FSR_FTT(2),
  D => GRLFPC20_V_FSR_FTT_CNST(2),
  C => clk,
  CE => N_683);
GRLFPC20_R_FSR_FTTq1z_Z8546: FDE port map (
  Q => GRLFPC20_R_FSR_FTT(1),
  D => GRLFPC20_V_FSR_FTT_CNST(1),
  C => clk,
  CE => N_683);
GRLFPC20_R_FSR_FTTq0z_Z8547: FDE port map (
  Q => GRLFPC20_R_FSR_FTT(0),
  D => GRLFPC20_V_FSR_FTT_CNST(0),
  C => clk,
  CE => N_683);
GRLFPC20_R_A_FPOP_Z8548: FDE port map (
  Q => GRLFPC20_R_A_FPOP,
  D => GRLFPC20_FPOP_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_A_LD_Z8549: FDE port map (
  Q => GRLFPC20_R_A_LD,
  D => GRLFPC20_V_A_LD_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_A_ST_Z8550: FDE port map (
  Q => GRLFPC20_R_A_ST,
  D => GRLFPC20_V_A_ST_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_I_EXEC_Z8551: FDE port map (
  Q => GRLFPC20_R_I_EXEC,
  D => GRLFPC20_N_824_I,
  C => clk,
  CE => holdn);
GRLFPC20_R_A_AFQ_Z8552: FDE port map (
  Q => GRLFPC20_R_A_AFQ,
  D => GRLFPC20_AFQ_3_SQMUXA,
  C => clk,
  CE => holdn);
GRLFPC20_R_FSR_AEXCq4z_Z8553: FD port map (
  Q => GRLFPC20_R_FSR_AEXC(4),
  D => NN_7,
  C => clk);
GRLFPC20_R_FSR_AEXCq3z_Z8554: FD port map (
  Q => GRLFPC20_R_FSR_AEXC(3),
  D => GRLFPC20_R_FSR_AEXC_0,
  C => clk);
GRLFPC20_R_FSR_AEXCq2z_Z8555: FD port map (
  Q => GRLFPC20_R_FSR_AEXC(2),
  D => GRLFPC20_R_FSR_AEXC_1,
  C => clk);
GRLFPC20_R_FSR_AEXCq1z_Z8556: FD port map (
  Q => GRLFPC20_R_FSR_AEXC(1),
  D => GRLFPC20_R_FSR_AEXC_2,
  C => clk);
GRLFPC20_R_FSR_AEXCq0z_Z8557: FD port map (
  Q => GRLFPC20_R_FSR_AEXC(0),
  D => GRLFPC20_R_FSR_AEXC_3,
  C => clk);
GRLFPC20_R_FSR_CEXCq4z_Z8558: FD port map (
  Q => GRLFPC20_R_FSR_CEXC(4),
  D => NN_8,
  C => clk);
GRLFPC20_R_FSR_CEXCq3z_Z8559: FD port map (
  Q => GRLFPC20_R_FSR_CEXC(3),
  D => GRLFPC20_R_FSR_CEXC_0,
  C => clk);
GRLFPC20_R_FSR_CEXCq2z_Z8560: FD port map (
  Q => GRLFPC20_R_FSR_CEXC(2),
  D => GRLFPC20_R_FSR_CEXC_1,
  C => clk);
GRLFPC20_R_FSR_CEXCq1z_Z8561: FD port map (
  Q => GRLFPC20_R_FSR_CEXC(1),
  D => GRLFPC20_R_FSR_CEXC_2,
  C => clk);
GRLFPC20_R_FSR_CEXCq0z_Z8562: FD port map (
  Q => GRLFPC20_R_FSR_CEXC(0),
  D => GRLFPC20_R_FSR_CEXC_3,
  C => clk);
GRLFPC20_R_I_V_Z8563: FDR port map (
  Q => GRLFPC20_R_I_V,
  D => GRLFPC20_R_I_V_0,
  C => clk,
  R => RST_I);
GRLFPC20_R_A_SEQERR_Z8564: FDE port map (
  Q => GRLFPC20_R_A_SEQERR,
  D => GRLFPC20_V_A_SEQERR_1,
  C => clk,
  CE => holdn);
GRLFPC20_R_A_AFSR_Z8565: FDE port map (
  Q => GRLFPC20_R_A_AFSR,
  D => GRLFPC20_V_A_AFSR_1,
  C => clk,
  CE => holdn);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq76z_Z8566: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_UN31_PCTRL_NEW_I_0,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq77z_Z8567: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14_0(77),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq78z_Z8568: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(7),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq79z_Z8569: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(6),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq80z_Z8570: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(5),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq81z_Z8571: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(4),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq82z_Z8572: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(3),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq83z_Z8573: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(2),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq84z_Z8574: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(1),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq85z_Z8575: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1(0),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq60z_Z8576: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(60),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(60),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq61z_Z8577: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(61),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4485_I,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq62z_Z8578: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(62),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(62),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq63z_Z8579: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(63),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(63),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq64z_Z8580: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(64),
  D => GRLFPC20_FPI_RST_0,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq66z_Z8581: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(66),
  D => GRLFPC20_FPI_START_0,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq67z_Z8582: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(67),
  D => NN_9,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq70z_Z8583: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(70),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(68),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq71z_Z8584: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(71),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_UN36_PCTRL_NEW_I_0,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq72z_Z8585: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_0(75),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq74z_Z8586: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(74),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_18_0(74),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq45z_Z8587: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(45),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq46z_Z8588: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(46),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(46),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq47z_Z8589: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(47),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(47),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq48z_Z8590: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(48),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3752_I,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq49z_Z8591: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(49),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq50z_Z8592: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(50),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(50),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq51z_Z8593: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(51),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(51),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq52z_Z8594: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(52),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq53z_Z8595: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(53),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(53),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq54z_Z8596: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(54),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(54),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq55z_Z8597: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(55),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(55),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq56z_Z8598: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(56),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(56),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq57z_Z8599: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(57),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1008,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq58z_Z8600: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(58),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(58),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq59z_Z8601: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(59),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(59),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq29z_Z8602: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_736_I,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq30z_Z8603: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(30),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq31z_Z8604: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(31),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq32z_Z8605: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(32),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq33z_Z8606: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(33),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(33),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq34z_Z8607: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(34),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq35z_Z8608: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(35),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(35),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq36z_Z8609: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(36),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq38z_Z8610: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(38),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq39z_Z8611: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(39),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq40z_Z8612: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(40),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq41z_Z8613: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(41),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(41),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq42z_Z8614: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(42),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq43z_Z8615: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(43),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(43),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq44z_Z8616: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(44),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq14z_Z8617: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(14),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(14),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq15z_Z8618: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(15),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(15),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq17z_Z8619: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(17),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1179_I,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq18z_Z8620: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(18),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(18),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq19z_Z8621: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(19),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq20z_Z8622: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(20),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(20),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq21z_Z8623: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(21),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(21),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq22z_Z8624: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(22),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(22),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq23z_Z8625: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(23),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(23),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq24z_Z8626: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(24),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(24),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq25z_Z8627: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(25),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq26z_Z8628: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(26),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(26),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq27z_Z8629: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(27),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(27),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq28z_Z8630: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(28),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq16z_Z8631: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(16),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SCTRL_NEW(0),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq0z_Z8632: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(0),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq1z_Z8633: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(1),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq2z_Z8634: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(2),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq3z_Z8635: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(3),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(3),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq4z_Z8636: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(4),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq5z_Z8637: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1054_I,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq6z_Z8638: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(6),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq7z_Z8639: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(7),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq8z_Z8640: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(8),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq9z_Z8641: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(9),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(9),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq10z_Z8642: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(10),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq11z_Z8643: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2985_I,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq12z_Z8644: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(12),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(12),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq13z_Z8645: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(13),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(13),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq3z_Z8646: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(3),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_13(3),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq4z_Z8647: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(4),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_14(4),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq7z_Z8648: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(7),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(7),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq10z_Z8649: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_10(10),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq11z_Z8650: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(11),
  D => CPI_D_INST_I(6),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq12z_Z8651: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2778,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq13z_Z8652: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  D => NN_10,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq14z_Z8653: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(14),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_SCTRL_I(0),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq15z_Z8654: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_I(42),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq364z_Z8655: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(364),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(105),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq365z_Z8656: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(365),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(106),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq366z_Z8657: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(366),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(107),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq367z_Z8658: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(367),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(108),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq368z_Z8659: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(368),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(109),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq369z_Z8660: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(369),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(110),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq370z_Z8661: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(370),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(111),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq371z_Z8662: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(371),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(112),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq372z_Z8663: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(372),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(113),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq373z_Z8664: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(373),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_MIXOIN_15(0),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq374z_Z8665: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH(374),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq375z_Z8666: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(375),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH(375),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq376z_Z8667: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(376),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN2_DIVMULTV(0),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq377z_Z8668: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(377),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTREMBIT(3),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq349z_Z8669: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(349),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(90),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq350z_Z8670: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(350),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(91),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq351z_Z8671: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(351),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(92),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq352z_Z8672: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(352),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(93),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq353z_Z8673: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(353),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(94),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq354z_Z8674: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(354),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(95),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq355z_Z8675: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(355),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(96),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq356z_Z8676: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(356),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(97),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq357z_Z8677: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(357),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(98),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq358z_Z8678: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(358),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(99),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq359z_Z8679: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(359),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(100),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq360z_Z8680: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(360),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(101),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq361z_Z8681: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(361),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(102),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq362z_Z8682: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(362),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(103),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq363z_Z8683: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(363),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(104),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq334z_Z8684: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(334),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(75),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq335z_Z8685: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(335),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(76),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq336z_Z8686: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(336),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(77),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq337z_Z8687: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(337),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(78),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq338z_Z8688: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(338),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(79),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq339z_Z8689: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(339),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(80),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq340z_Z8690: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(340),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(81),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq341z_Z8691: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(341),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(82),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq342z_Z8692: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(342),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(83),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq343z_Z8693: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(343),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(84),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq344z_Z8694: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(344),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(85),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq345z_Z8695: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(345),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(86),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq346z_Z8696: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(346),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(87),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq347z_Z8697: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(347),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(88),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq348z_Z8698: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(348),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(89),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq319z_Z8699: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(319),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(60),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq320z_Z8700: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(320),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(61),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq321z_Z8701: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(321),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(62),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq322z_Z8702: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(322),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(63),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq323z_Z8703: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(323),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(64),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq324z_Z8704: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(324),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(65),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq325z_Z8705: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(325),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(66),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq326z_Z8706: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(326),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(67),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq327z_Z8707: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(327),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(68),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq328z_Z8708: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(328),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(69),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq329z_Z8709: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(329),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(70),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq330z_Z8710: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(330),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(71),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq331z_Z8711: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(331),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(72),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq332z_Z8712: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(332),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(73),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq333z_Z8713: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(333),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(74),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq304z_Z8714: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(304),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(45),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq305z_Z8715: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(305),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(46),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq306z_Z8716: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(306),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(47),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq307z_Z8717: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(307),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(48),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq308z_Z8718: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(308),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(49),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq309z_Z8719: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(309),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(50),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq310z_Z8720: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(310),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(51),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq311z_Z8721: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(311),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(52),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq312z_Z8722: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(312),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(53),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq313z_Z8723: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(313),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(54),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq314z_Z8724: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(314),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(55),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq315z_Z8725: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(315),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(57),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq316z_Z8726: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_50(316),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq317z_Z8727: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(317),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(58),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq318z_Z8728: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(318),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(59),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq289z_Z8729: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(289),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(30),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq290z_Z8730: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(290),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(31),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq291z_Z8731: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(291),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(32),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq292z_Z8732: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(292),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(33),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq293z_Z8733: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(293),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(34),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq294z_Z8734: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(294),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(35),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq295z_Z8735: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(295),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(36),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq296z_Z8736: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(296),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(37),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq297z_Z8737: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(297),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(38),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq298z_Z8738: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(298),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(39),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq299z_Z8739: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(299),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(40),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq300z_Z8740: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(300),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(41),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq301z_Z8741: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(301),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(42),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq302z_Z8742: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(302),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(43),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq303z_Z8743: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(303),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(44),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq274z_Z8744: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(274),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(15),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq275z_Z8745: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(275),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(16),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq276z_Z8746: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(276),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(17),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq277z_Z8747: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(277),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(18),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq278z_Z8748: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(278),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(19),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq279z_Z8749: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(279),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(20),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq280z_Z8750: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(280),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(21),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq281z_Z8751: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(281),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(22),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq282z_Z8752: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(282),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(23),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq283z_Z8753: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(283),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(24),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq284z_Z8754: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(284),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(25),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq285z_Z8755: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(285),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(26),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq286z_Z8756: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(286),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(27),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq287z_Z8757: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(287),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(28),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq288z_Z8758: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(288),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(29),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq259z_Z8759: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(259),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6321_I,
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq260z_Z8760: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(260),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(1),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq261z_Z8761: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(261),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(2),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq262z_Z8762: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(262),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(3),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq263z_Z8763: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(263),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(4),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq264z_Z8764: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(264),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(5),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq265z_Z8765: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(265),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(6),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq266z_Z8766: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(266),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(7),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq267z_Z8767: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(267),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(8),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq268z_Z8768: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(268),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(9),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq269z_Z8769: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(269),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(10),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq270z_Z8770: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(270),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(11),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq271z_Z8771: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(271),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(12),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq272z_Z8772: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(272),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(13),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq273z_Z8773: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(273),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(14),
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq244z_Z8774: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  D => N_5_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq245z_Z8775: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(245),
  D => N_5_MUX,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq246z_Z8776: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
  D => N_5_MUX_0,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq247z_Z8777: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  D => N_3_43_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq248z_Z8778: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  D => N_3_44_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq249z_Z8779: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  D => N_3_45_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq250z_Z8780: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
  D => N_3_46_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq251z_Z8781: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
  D => N_3_47_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq252z_Z8782: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
  D => N_3_48_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq253z_Z8783: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
  D => N_3_49_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq254z_Z8784: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
  D => N_3_50_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq255z_Z8785: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
  D => N_3_51_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq256z_Z8786: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
  D => N_3_52_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq257z_Z8787: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  D => N_3_53_I,
  C => clk,
  CE => N_6_MUX_39_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq258z_Z8788: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(258),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6322_I,
  C => clk,
  CE => I2_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq229z_Z8789: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(229),
  D => N_1212,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq230z_Z8790: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(230),
  D => N_1211,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq231z_Z8791: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(231),
  D => N_1210,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq232z_Z8792: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(232),
  D => N_9_MUX_6,
  C => clk,
  CE => N_10_MUX_6_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq233z_Z8793: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  D => N_9_MUX_7,
  C => clk,
  CE => N_10_MUX_6_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq234z_Z8794: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  D => N_4_58,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq235z_Z8795: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  D => N_4_59,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq236z_Z8796: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  D => N_4_60,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq237z_Z8797: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  D => N_5_3_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq238z_Z8798: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  D => N_5_4_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq239z_Z8799: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  D => N_5_5_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq240z_Z8800: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  D => N_5_6_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq241z_Z8801: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  D => N_5_7_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq242z_Z8802: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  D => N_5_8_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq243z_Z8803: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  D => N_5_9_I,
  C => clk,
  CE => N_9_MUX_8_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq214z_Z8804: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(214),
  D => GRLFPC20_FPO_FRAC(17),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq215z_Z8805: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(215),
  D => GRLFPC20_FPO_FRAC(16),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq216z_Z8806: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(216),
  D => GRLFPC20_FPO_FRAC(15),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq217z_Z8807: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(217),
  D => GRLFPC20_FPO_FRAC(14),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq218z_Z8808: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(218),
  D => GRLFPC20_FPO_FRAC(13),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq219z_Z8809: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(219),
  D => GRLFPC20_FPO_FRAC(12),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq220z_Z8810: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(220),
  D => GRLFPC20_FPO_FRAC(11),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq221z_Z8811: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(221),
  D => GRLFPC20_FPO_FRAC(10),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq222z_Z8812: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(222),
  D => GRLFPC20_FPO_FRAC(9),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq223z_Z8813: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(223),
  D => GRLFPC20_FPO_FRAC(8),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq224z_Z8814: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(224),
  D => GRLFPC20_FPO_FRAC(7),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq225z_Z8815: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(225),
  D => GRLFPC20_FPO_FRAC(6),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq226z_Z8816: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(226),
  D => GRLFPC20_FPO_FRAC(5),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq227z_Z8817: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(227),
  D => GRLFPC20_FPO_FRAC(4),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq228z_Z8818: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(228),
  D => GRLFPC20_FPO_FRAC(3),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq199z_Z8819: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(199),
  D => GRLFPC20_FPO_FRAC(32),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq200z_Z8820: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(200),
  D => GRLFPC20_FPO_FRAC(31),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq201z_Z8821: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(201),
  D => GRLFPC20_FPO_FRAC(30),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq202z_Z8822: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(202),
  D => GRLFPC20_FPO_FRAC(29),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq203z_Z8823: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(203),
  D => GRLFPC20_FPO_FRAC(28),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq204z_Z8824: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(204),
  D => GRLFPC20_FPO_FRAC(27),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq205z_Z8825: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(205),
  D => GRLFPC20_FPO_FRAC(26),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq206z_Z8826: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(206),
  D => GRLFPC20_FPO_FRAC(25),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq207z_Z8827: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(207),
  D => GRLFPC20_FPO_FRAC(24),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq208z_Z8828: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(208),
  D => GRLFPC20_FPO_FRAC(23),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq209z_Z8829: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(209),
  D => GRLFPC20_FPO_FRAC(22),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq210z_Z8830: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(210),
  D => GRLFPC20_FPO_FRAC(21),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq211z_Z8831: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(211),
  D => GRLFPC20_FPO_FRAC(20),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq212z_Z8832: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(212),
  D => GRLFPC20_FPO_FRAC(19),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq213z_Z8833: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(213),
  D => GRLFPC20_FPO_FRAC(18),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq184z_Z8834: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(184),
  D => GRLFPC20_FPO_FRAC(47),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq185z_Z8835: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(185),
  D => GRLFPC20_FPO_FRAC(46),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq186z_Z8836: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(186),
  D => GRLFPC20_FPO_FRAC(45),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq187z_Z8837: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(187),
  D => GRLFPC20_FPO_FRAC(44),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq188z_Z8838: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(188),
  D => GRLFPC20_FPO_FRAC(43),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq189z_Z8839: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(189),
  D => GRLFPC20_FPO_FRAC(42),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq190z_Z8840: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(190),
  D => GRLFPC20_FPO_FRAC(41),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq191z_Z8841: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(191),
  D => GRLFPC20_FPO_FRAC(40),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq192z_Z8842: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(192),
  D => GRLFPC20_FPO_FRAC(39),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq193z_Z8843: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(193),
  D => GRLFPC20_FPO_FRAC(38),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq194z_Z8844: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(194),
  D => GRLFPC20_FPO_FRAC(37),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq195z_Z8845: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(195),
  D => GRLFPC20_FPO_FRAC(36),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq196z_Z8846: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(196),
  D => GRLFPC20_FPO_FRAC(35),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq197z_Z8847: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(197),
  D => GRLFPC20_FPO_FRAC(34),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq198z_Z8848: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(198),
  D => GRLFPC20_FPO_FRAC(33),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq169z_Z8849: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(169),
  D => N_3_64_I,
  C => clk,
  CE => N_6_MUX_52_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq170z_Z8850: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(170),
  D => N_3_65_I,
  C => clk,
  CE => N_6_MUX_52_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq171z_Z8851: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(171),
  D => N_3_66_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq172z_Z8852: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(172),
  D => N_3_67_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq173z_Z8853: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(173),
  D => N_5_MUX_1,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq174z_Z8854: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(174),
  D => N_1267,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq175z_Z8855: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(175),
  D => N_1266,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq176z_Z8856: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(176),
  D => N_1265,
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq177z_Z8857: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(177),
  D => GRLFPC20_FPO_FRAC(54),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq178z_Z8858: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(178),
  D => GRLFPC20_FPO_FRAC(53),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq179z_Z8859: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(179),
  D => GRLFPC20_FPO_FRAC(52),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq180z_Z8860: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(180),
  D => GRLFPC20_FPO_FRAC(51),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq181z_Z8861: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(181),
  D => GRLFPC20_FPO_FRAC(50),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq182z_Z8862: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(182),
  D => GRLFPC20_FPO_FRAC(49),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq183z_Z8863: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(183),
  D => GRLFPC20_FPO_FRAC(48),
  C => clk,
  CE => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_XZTREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq154z_Z8864: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(154),
  D => N_3_69_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq155z_Z8865: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(155),
  D => N_3_70_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq156z_Z8866: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(156),
  D => N_3_71_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq157z_Z8867: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(157),
  D => N_3_72_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq158z_Z8868: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(158),
  D => N_3_73_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq159z_Z8869: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(159),
  D => N_3_74_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq160z_Z8870: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(160),
  D => N_3_75_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq161z_Z8871: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(161),
  D => N_3_76_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq162z_Z8872: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(162),
  D => N_3_77_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq163z_Z8873: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(163),
  D => N_3_78_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq164z_Z8874: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(164),
  D => N_3_79_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq165z_Z8875: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(165),
  D => N_3_80_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq166z_Z8876: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(166),
  D => N_3_81_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq167z_Z8877: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(167),
  D => N_3_82_I,
  C => clk,
  CE => N_6_MUX_52_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq168z_Z8878: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(168),
  D => N_3_83_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq139z_Z8879: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(139),
  D => N_3_84_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq140z_Z8880: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(140),
  D => N_3_85_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq141z_Z8881: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(141),
  D => N_3_86_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq142z_Z8882: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(142),
  D => N_3_87_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq143z_Z8883: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(143),
  D => N_3_88_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq144z_Z8884: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(144),
  D => N_3_89_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq145z_Z8885: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(145),
  D => N_3_90_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq146z_Z8886: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(146),
  D => N_3_91_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq147z_Z8887: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(147),
  D => N_3_92_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq148z_Z8888: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(148),
  D => N_3_93_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq149z_Z8889: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(149),
  D => N_3_94_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq150z_Z8890: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(150),
  D => N_3_95_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq151z_Z8891: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(151),
  D => N_3_96_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq152z_Z8892: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(152),
  D => N_3_97_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq153z_Z8893: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(153),
  D => N_3_98_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq124z_Z8894: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(124),
  D => N_3_99_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq125z_Z8895: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(125),
  D => N_3_100_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq126z_Z8896: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(126),
  D => N_3_101_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq127z_Z8897: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(127),
  D => N_3_102_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq128z_Z8898: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(128),
  D => N_3_103_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq129z_Z8899: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(129),
  D => N_3_104_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq130z_Z8900: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(130),
  D => N_3_105_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq131z_Z8901: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(131),
  D => N_3_106_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq132z_Z8902: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(132),
  D => N_3_107_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq133z_Z8903: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(133),
  D => N_3_108_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq134z_Z8904: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(134),
  D => N_3_109_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq135z_Z8905: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(135),
  D => N_3_110_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq136z_Z8906: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(136),
  D => N_3_111_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq137z_Z8907: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(137),
  D => N_3_112_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq138z_Z8908: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(138),
  D => N_3_113_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq109z_Z8909: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(109),
  D => N_3_114_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq110z_Z8910: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  D => N_3_115_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq111z_Z8911: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(111),
  D => N_3_116_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq112z_Z8912: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  D => N_3_117_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq113z_Z8913: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  D => N_5_MUX_2,
  C => clk,
  CE => N_6_MUX_106_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq114z_Z8914: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(114),
  D => N_5_MUX_3,
  C => clk,
  CE => N_6_MUX_106_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq115z_Z8915: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(115),
  D => N_5_MUX_4,
  C => clk,
  CE => N_6_MUX_106_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq116z_Z8916: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(116),
  D => N_3_121_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq117z_Z8917: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(117),
  D => N_3_122_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq118z_Z8918: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(118),
  D => N_3_123_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq119z_Z8919: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(119),
  D => N_3_124_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq120z_Z8920: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(120),
  D => N_3_125_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq121z_Z8921: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(121),
  D => N_3_126_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq122z_Z8922: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(122),
  D => N_3_127_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq123z_Z8923: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(123),
  D => N_3_128_I,
  C => clk,
  CE => N_6_MUX_54_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq94z_Z8924: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(94),
  D => N_3_129_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq95z_Z8925: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  D => N_3_130_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq96z_Z8926: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  D => N_3_131_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq97z_Z8927: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  D => N_3_132_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq98z_Z8928: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  D => N_3_133_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq99z_Z8929: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  D => N_3_134_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq100z_Z8930: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  D => N_3_135_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq101z_Z8931: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  D => N_3_136_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq102z_Z8932: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  D => N_3_137_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq103z_Z8933: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  D => N_3_138_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq104z_Z8934: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  D => N_3_139_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq105z_Z8935: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  D => N_3_140_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq106z_Z8936: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(106),
  D => N_3_141_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq107z_Z8937: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  D => N_3_142_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq108z_Z8938: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  D => N_3_143_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq79z_Z8939: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  D => N_3_144_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq80z_Z8940: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(80),
  D => N_3_145_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq81z_Z8941: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  D => N_3_146_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq82z_Z8942: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  D => N_3_147_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq83z_Z8943: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  D => N_3_148_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq84z_Z8944: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  D => N_3_149_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq85z_Z8945: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  D => N_3_150_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq86z_Z8946: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  D => N_3_151_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq87z_Z8947: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  D => N_3_152_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq88z_Z8948: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  D => N_3_153_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq89z_Z8949: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  D => N_3_154_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq90z_Z8950: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  D => N_3_155_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq91z_Z8951: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  D => N_3_156_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq92z_Z8952: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  D => N_3_157_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq93z_Z8953: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  D => N_3_158_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq64z_Z8954: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  D => N_3_159_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq65z_Z8955: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(65),
  D => N_3_160_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq66z_Z8956: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  D => N_3_161_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq67z_Z8957: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  D => N_3_162_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq68z_Z8958: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  D => N_3_163_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq69z_Z8959: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(69),
  D => N_3_164_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq70z_Z8960: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  D => N_3_165_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq71z_Z8961: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  D => N_3_166_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq72z_Z8962: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  D => N_3_167_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq73z_Z8963: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  D => N_3_168_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq74z_Z8964: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(74),
  D => N_3_169_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq75z_Z8965: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(75),
  D => N_3_170_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq76z_Z8966: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(76),
  D => N_3_171_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq77z_Z8967: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  D => N_3_172_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq78z_Z8968: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  D => N_3_173_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq49z_Z8969: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  D => NN_11,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq51z_Z8970: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_1,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq54z_Z8971: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_4,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq55z_Z8972: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_5,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq56z_Z8973: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_6,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq57z_Z8974: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_7,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq58z_Z8975: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  D => N_5_MUX_5,
  C => clk,
  CE => N_6_MUX_106_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq59z_Z8976: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  D => N_5_MUX_6,
  C => clk,
  CE => N_6_MUX_106_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq60z_Z8977: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  D => N_5_MUX_7_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq61z_Z8978: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  D => N_3_177_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq62z_Z8979: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  D => N_3_178_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq63z_Z8980: FDE port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(63),
  D => N_3_179_I,
  C => clk,
  CE => N_6_MUX_102_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq34z_Z8981: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(34),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_8,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq35z_Z8982: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_9,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq36z_Z8983: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_10,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq39z_Z8984: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_13,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq40z_Z8985: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_14,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq42z_Z8986: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_16,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq45z_Z8987: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_19,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq20z_Z8988: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_24,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq21z_Z8989: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_25,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq4z_Z8990: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_38,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq7z_Z8991: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(7),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_41,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq8z_Z8992: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_42,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq9z_Z8993: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_43,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq12z_Z8994: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_46,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq0z_Z8995: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_53,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq1z_Z8996: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_54,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq2z_Z8997: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(2),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_IV_I(2),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATHq3z_Z8998: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_55,
  C => clk);
GRLFPC20_RST_I: INV port map (
    I => rst,
    O => RST_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN6_GRFPUE_CRY_0_CY_RNO: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_MIXOIN(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_11_Z9001: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(233),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(246),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_10_Z9002: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(247),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_10);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_9_Z9003: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_9);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_8_Z9004: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_8);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_7_Z9005: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_7);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_6_Z9006: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_5_Z9007: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_4_Z9008: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_3_Z9009: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_2_Z9010: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_1_Z9011: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_0_Z9012: LUT2 
generic map(
  INIT => X"9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_AXB_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq77z: LUT6 
generic map(
  INIT => X"0000000008080800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_OPREXC,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(46),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14_0(77));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_59: FDR port map (
  Q => M20_E_0_RETO_28,
  D => M20_E_0_0,
  C => clk,
  R => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_51: FDR port map (
  Q => M20_E_0_RETO_24,
  D => M20_E_0_0,
  C => clk,
  R => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_47: FDR port map (
  Q => M20_E_0_RETO_22,
  D => M20_E_0_0,
  C => clk,
  R => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_11: FDR port map (
  Q => M20_E_0_RETO_0,
  D => M20_E_0_0,
  C => clk,
  R => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_1: FDR port map (
  Q => M20_E_0_RETO,
  D => M20_E_0_0,
  C => clk,
  R => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_44_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(50),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_26,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_40_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(52),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_24,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_38_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(53),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_12_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(37),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_10,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_20_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(38),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_14,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_42_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(41),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_25,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_18_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(43),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_13,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_6_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(44),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_7,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_22_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(46),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_15,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_30_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(48),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_19,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_14_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(22),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_11,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_4_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(26),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_6,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_24_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(27),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_16,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_36_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(28),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_22,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_28_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(29),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_18,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_34_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(30),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_21,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_26_RNO: LUT3 
generic map(
  INIT => X"2F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(32),
  I1 => M20_E_0_RETO_0,
  I2 => R_DPATH_RET_17,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36_0);
R_DPATH_RET_RNO: LUT6 
generic map(
  INIT => X"FFFF9DBFFFFFFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(126),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I5 => M20_E_0,
  O => M9_41_2_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq72z: LUT6 
generic map(
  INIT => X"FFF0FFCCFFAAFFAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2180,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2187,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2194,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_28_0(75),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(49),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_0(75));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq71z: LUT5 
generic map(
  INIT => X"FEFFAAAA"
)
port map (
  I0 => GRLFPC20_FPI_START,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(63),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_UN36_PCTRL_NEW_I_0);
GRLFPC20_R_FSR_FCC_RNOq1z: LUT6 
generic map(
  INIT => X"C088C088FFFF0000"
)
port map (
  I0 => cpi_lddata(11),
  I1 => rst,
  I2 => GRLFPC20_R_I_CC(1),
  I3 => GRLFPC20_COMB_V_FSR_FCC10,
  I4 => CPO_CC_2,
  I5 => N_689,
  O => N_3_32_I_0);
GRLFPC20_R_FSR_FCC_RNOq0z: LUT6 
generic map(
  INIT => X"C088C088FFFF0000"
)
port map (
  I0 => cpi_lddata(10),
  I1 => rst,
  I2 => GRLFPC20_R_I_CC(0),
  I3 => GRLFPC20_COMB_V_FSR_FCC10,
  I4 => NN_1,
  I5 => N_689,
  O => N_3_33_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIM0AM1q13z: LUT6 
generic map(
  INIT => X"44404440FFFF0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  I4 => GRLFPC20_R_I_CC(0),
  I5 => GRLFPC20_COMB_UN19_IUEXEC,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_99_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIN1AM1q13z: LUT6 
generic map(
  INIT => X"40444044FFFF0000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(38),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(40),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(13),
  I4 => GRLFPC20_R_I_CC(1),
  I5 => GRLFPC20_COMB_UN19_IUEXEC,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_101_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq65z: LUT4 
generic map(
  INIT => X"FF4F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(66),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(68),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(64),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_2_0_E(65));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq69z: LUT4 
generic map(
  INIT => X"FFB8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(66),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(69),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(64),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_E_0_E(69));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNOq73z: LUT3 
generic map(
  INIT => X"F1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(66),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTRESETORUNIMP_I_0_E);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq2z: LUT4 
generic map(
  INIT => X"0040"
)
port map (
  I0 => cpi_d_inst(7),
  I1 => cpi_d_inst(9),
  I2 => cpi_d_inst(11),
  I3 => cpi_d_inst(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_4_0_E(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq0z: LUT5 
generic map(
  INIT => X"0000F200"
)
port map (
  I0 => cpi_d_inst(7),
  I1 => cpi_d_inst(8),
  I2 => cpi_d_inst(9),
  I3 => cpi_d_inst(11),
  I4 => cpi_d_inst(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_6_0_E(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_62_RNO: LUT5 
generic map(
  INIT => X"00000004"
)
port map (
  I0 => GRLFPC20_FPI_LDOP,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_WQSCTRL(67),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_0_E);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq6z: LUT3 
generic map(
  INIT => X"04"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_10(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_16_0_E(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq8z: LUT6 
generic map(
  INIT => X"FFFFFFFFBABAFF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(2),
  I2 => GRLFPC20_R_FSR_RD(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(8),
  I4 => GRLFPC20_FPI_LDOP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_RNDMODESELECT_UN1_TEMP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_0_E(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNOq9z: LUT5 
generic map(
  INIT => X"FFFFEEF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(1),
  I1 => GRLFPC20_R_FSR_RD(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(9),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_RNDMODESELECT_UN1_TEMP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_0_E(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq8z_Z9052: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(8),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_0_E(8),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq9z_Z9053: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(9),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_0_E(9),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq65z_Z9054: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_2_0_E(65),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq73z_Z9055: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(73),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTRESETORUNIMP_I_0_E,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq69z_Z9056: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(69),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_E_0_E(69),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRLq68z_Z9057: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(68),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN2_NOTDECODEDUNIMP_I_0_E,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq2z_Z9058: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(2),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_4_0_E(2),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq1z_Z9059: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(1),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_5_0_E(1),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq0z_Z9060: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(0),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_6_0_E(0),
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_62: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_RETO,
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_DPATH_NEW_4_SQMUXA_0_E,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq5z_Z9062: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(5),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_UN53_SCTRL_NEW_I_0_E,
  C => clk);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRLq6z_Z9063: FD port map (
  Q => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(6),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_16_0_E(6),
  C => clk);
GRLFPC20_R_FSR_FCCq0z: FD port map (
  Q => NN_1,
  D => N_3_33_I_0,
  C => clk);
GRLFPC20_R_FSR_FCCq1z: FD port map (
  Q => CPO_CC_2,
  D => N_3_32_I_0,
  C => clk);
GRLFPC20_R_MK_HOLDN1_Z9066: FD port map (
  Q => GRLFPC20_R_MK_HOLDN1,
  D => GRLFPC20_R_MK_RST2_I_E,
  C => clk);
GRLFPC20_R_I_CCq1z_Z9067: FDR port map (
  Q => GRLFPC20_R_I_CC(1),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_101_I_0,
  C => clk,
  R => RST_I);
GRLFPC20_R_I_CCq0z_Z9068: FDR port map (
  Q => GRLFPC20_R_I_CC(0),
  D => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_99_I_0,
  C => clk,
  R => RST_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_1q84z: LUT6_2 
generic map(
  INIT => X"0422464500020000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_729,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_725);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_6q84z: LUT6_2 
generic map(
  INIT => X"0010500200121200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_722,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_719);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_5q84z: LUT6_2 
generic map(
  INIT => X"0015001110000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_733,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_8_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_0q84z: LUT6_2 
generic map(
  INIT => X"0A90400400800000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1126,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_110_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_4q84z: LUT6_2 
generic map(
  INIT => X"0040100008000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1102,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_810);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_7q84z: LUT6_2 
generic map(
  INIT => X"0008000500000080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_743,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_691);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42q84z: LUT6_2 
generic map(
  INIT => X"5F7FF7DFFFFFBFFB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1123,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_76_0_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_8q84z: LUT6_2 
generic map(
  INIT => X"00050500FB000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_862,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1255_MUX_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_3q84z: LUT6_2 
generic map(
  INIT => X"010A0A00000A0A00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1076,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_777);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIV4H42_2q84z: LUT6_2 
generic map(
  INIT => X"014A0A0000AAAA00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_836_0,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1820);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO_LUT6_2: LUT6_2 
generic map(
  INIT => X"EFEFEFE0707F7F7F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN33_ZERO_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_RNISHEN3q51z: LUT6_2 
generic map(
  INIT => X"00000000A280F7D5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(0),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(48),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(48),
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_AXBXC4_LUT6_2: LUT6_2 
generic map(
  INIT => X"FFFF7FFF00008000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O6 => N_1628,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C4);
GRLFPC20_UN1_HOLDN_1_LUT6_2: LUT6_2 
generic map(
  INIT => X"FFFFFFFF00020000"
)
port map (
  I0 => GRLFPC20_R_MK_BUSY2,
  I1 => GRLFPC20_R_MK_BUSY,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  I4 => GRLFPC20_COMB_LOCKGEN_DEPCHECK,
  I5 => GRLFPC20_COMB_UN2_HOLDN,
  O6 => GRLFPC20_UN1_HOLDN_1,
  O5 => GRLFPC20_COMB_UN19_IUEXEC);
GRLFPC20_AFQ_3_SQMUXA_LUT6_2: LUT6_2 
generic map(
  INIT => X"0000000008000000"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(21),
  I2 => cpi_d_inst(22),
  I3 => cpi_d_inst(24),
  I4 => GRLFPC20_AFQ_3_SQMUXA_0_0,
  I5 => GRLFPC20_COMB_UN4_LOCK,
  O6 => GRLFPC20_AFQ_3_SQMUXA,
  O5 => GRLFPC20_AFQ_3_SQMUXA_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIMNM5Aq108z: LUT6_2 
generic map(
  INIT => X"35CAFFFFCA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(107),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_SI_107(6),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4K8QCq101z: LUT6_2 
generic map(
  INIT => X"53ACFFFFAC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_101(12),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_CI_44_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITAO4Eq93z: LUT6_2 
generic map(
  INIT => X"35CAFFFFCA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(92),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_SI_92(21),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIP1G5Dq90z: LUT6_2 
generic map(
  INIT => X"53ACFFFFAC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(91),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_90(23),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_CI_33_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIDMJ4Eq88z: LUT6_2 
generic map(
  INIT => X"35CAFFFFCA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_87(26),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_CI_30_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI8GI4Eq86z: LUT6_2 
generic map(
  INIT => X"53ACFFFFAC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_86(27),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2084Eq77z: LUT6_2 
generic map(
  INIT => X"53ACFFFFAC530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(78),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_77(36),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_UN459_TEMP_LUT6_2_RNIPQ6LD: LUT6_2 
generic map(
  INIT => X"5CACFFFFA3530000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6172,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_72(41),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNINDS8Bq103z: LUT6_2 
generic map(
  INIT => X"35CAFFFFCA350000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_UN35_ZERO,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_102(11),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_CI_45_AXB2,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2q19z: LUT6_2 
generic map(
  INIT => X"FF00AAAAF0F0CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(42),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(19),
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_I(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2q32z: LUT6_2 
generic map(
  INIT => X"CCCCF0F0AAAAFF00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(32),
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_I(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2q53z: LUT6_2 
generic map(
  INIT => X"FF00AAAAF0F0CCCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(4),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(12),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(53),
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_I(53));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_I_M2_LUT6_2q30z: LUT6_2 
generic map(
  INIT => X"CCCCFF00AAAAF0F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(35),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(39),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_116,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_105);
GRLFPC20_COMB_UN4_LOCK_LUT6_2: LUT6_2 
generic map(
  INIT => X"FFFFFEFFFFFFFEFE"
)
port map (
  I0 => cpi_d_annul,
  I1 => cpi_d_trap,
  I2 => cpi_flush,
  I3 => GRLFPC20_R_STATE(1),
  I4 => GRLFPC20_COMB_LOCKGEN_LOCKI,
  I5 => GRLFPC20_R_STATE(0),
  O6 => GRLFPC20_COMB_UN4_LOCK,
  O5 => GRLFPC20_COMB_LOCK);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIRPFUq9z: LUT6_2 
generic map(
  INIT => X"0000000000000533"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(9),
  I2 => GRLFPC20_R_FSR_RD(0),
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_RNDMODESELECT_UN1_TEMP,
  I5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(8),
  O6 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_UN53_SCTRL_NEW_I_0_E,
  O5 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_I(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL_RNIRPFU_0q9z: INV port map (
    I => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_I(9),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNI0IK6q32z: INV port map (
    I => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_I(32),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNI5LI6q19z: INV port map (
    I => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_I(19),
    O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(19));
II_GND: GND port map (
    G => NN_5);
II_VCC: VCC port map (
    P => NN_2);
GRLFPC20_WRADDR_0_SQMUXA_LUT6_2_RNIFDSL_O6: LUT3 
generic map(
  INIT => X"5D"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I2 => GRLFPC20_COMB_V_FSR_FCC10,
  O => I2_I);
GRLFPC20_WRADDR_0_SQMUXA_LUT6_2_RNIFDSL_O5: LUT4 
generic map(
  INIT => X"CCC4"
)
port map (
  I0 => rst,
  I1 => holdn,
  I2 => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN,
  I3 => GRLFPC20_COMB_V_FSR_FCC10,
  O => N_689);
GRLFPC20_R_I_EXC_RNI9VSP1_O6q0z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_I_EXC(0),
  I2 => GRLFPC20_WRRES_1,
  O => GRLFPC20_R_I_EXC_M(0));
GRLFPC20_R_I_EXC_RNI9VSP1_O5q0z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_I_EXC(1),
  I2 => GRLFPC20_WRRES_1,
  O => GRLFPC20_R_I_EXC_M(1));
GRLFPC20_R_I_EXC_RNIBMKC2_O6q4z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_I_EXC(4),
  I2 => GRLFPC20_WRRES_1,
  O => GRLFPC20_R_I_EXC_M(4));
GRLFPC20_R_I_EXC_RNIBMKC2_O5q4z: LUT3 
generic map(
  INIT => X"FD"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_RST,
  I2 => GRLFPC20_R_MK_RST2,
  O => GRLFPC20_FPI_RST_0);
GRLFPC20_R_I_EXC_RNID3TP1_O6q2z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_I_EXC(3),
  I2 => GRLFPC20_WRRES_1,
  O => GRLFPC20_R_I_EXC_M(3));
GRLFPC20_R_I_EXC_RNID3TP1_O5q2z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_I_EXC(2),
  I2 => GRLFPC20_WRRES_1,
  O => GRLFPC20_R_I_EXC_M(2));
GRLFPC20_COMB_UN1_R_I_V_RNI3TLO1_O6: LUT2 
generic map(
  INIT => X"D"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_WRRES_1,
  O => GRLFPC20_V_FSR_AEXC_1_SM0);
GRLFPC20_COMB_UN1_R_I_V_RNI3TLO1_O5: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => rst,
  I1 => holdn,
  O => N_331);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_1_RNITAJ63_O6: LUT5 
generic map(
  INIT => X"8EA0FA8E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2,
  I3 => N_1381_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(59));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_1_RNITAJ63_O5: LUT5 
generic map(
  INIT => X"695AA569"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2,
  I3 => N_1381_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(2));
GRLFPC20_COMB_UN1_V_STATE_LUT6_2_O6: LUT3 
generic map(
  INIT => X"13"
)
port map (
  I0 => GRLFPC20_R_STATE(1),
  I1 => GRLFPC20_COMB_V_STATE_9(0),
  I2 => GRLFPC20_V_STATE_2_SQMUXA,
  O => GRLFPC20_COMB_UN1_V_STATE);
GRLFPC20_COMB_UN1_V_STATE_LUT6_2_O5: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_R_STATE(1),
  I1 => GRLFPC20_R_STATE(0),
  O => GRLFPC20_N_329_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O6q66z: LUT5 
generic map(
  INIT => X"EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(8),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_123(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2580);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O5q66z: LUT3 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_123(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(66));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3_RNIRDNOC1_O6: LUT4 
generic map(
  INIT => X"6996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_AXB2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_3_RNIRDNOC1_O5: LUT4 
generic map(
  INIT => X"BE28"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_C2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_CI_4_AXB2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(62));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIH7I3K1_O6q9z: LUT4 
generic map(
  INIT => X"6996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_AXB2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIH7I3K1_O5q9z: LUT4 
generic map(
  INIT => X"BE28"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_AXB2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(80));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIU9E1S1_O6q80z: LUT5 
generic map(
  INIT => X"EBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_78(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(79));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIU9E1S1_O5q80z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_78(35),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIO1C3O1_O6q330z: LUT5 
generic map(
  INIT => X"FEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_76(37),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_133(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(76));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIO1C3O1_O5q330z: LUT5 
generic map(
  INIT => X"A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_CI_19_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_76(37),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_133(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITEGNM1_O6q321z: LUT5 
generic map(
  INIT => X"FEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_67(46),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_124(45),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(67));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNITEGNM1_O5q321z: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_46_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_67(46),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_125(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIO458J1_O6q24z: LUT5 
generic map(
  INIT => X"FEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_96(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_153(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(96));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIO458J1_O5q24z: LUT5 
generic map(
  INIT => X"A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_SI_96(17),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_19_CI_39_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_153(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2NKKN1_O6q343z: LUT5 
generic map(
  INIT => X"FEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_SI_89(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_146(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(89));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2NKKN1_O5q343z: LUT5 
generic map(
  INIT => X"A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_SI_89(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_25_SI_146(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNINU0182_O6q35z: LUT5 
generic map(
  INIT => X"FEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_86(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_143(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(86));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_RNINU0182_O5q35z: LUT5 
generic map(
  INIT => X"A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_SI_86(27),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_29_CI_29_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_28_SI_143(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNISBOF81_O6q49z: LUT5 
generic map(
  INIT => X"FEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_111(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_168(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(111));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNISBOF81_O5q49z: LUT5 
generic map(
  INIT => X"A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_111(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_168(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI69M8D1_O6q108z: LUT5 
generic map(
  INIT => X"EBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_105(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(106));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI69M8D1_O5q108z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_CI_48_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_10_SI_105(8),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_9_CI_49_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_UN639_TEMP_LUT6_2_RNI7RFGC1_O6: LUT5 
generic map(
  INIT => X"EBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_SI_103(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(104));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_UN639_TEMP_LUT6_2_RNI7RFGC1_O5: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_8_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_10_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_SI_103(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6UPML1_O6q353z: LUT5 
generic map(
  INIT => X"FEEAA880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_100(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_157(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(100));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI6UPML1_O5q353z: LUT5 
generic map(
  INIT => X"A995566A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_13_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_CI_43_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_100(13),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_14_SI_157(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_RNI06E6L1_O6: LUT5 
generic map(
  INIT => X"EBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_97(16),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(98));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_RNI06E6L1_O5: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_CI_40_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_97(16),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(41));
GRLFPC20_RS1V_0_SQMUXA_LUT6_2_O6: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => cpi_d_inst(30),
  I1 => cpi_d_inst(31),
  I2 => GRLFPC20_RS1V12,
  O => GRLFPC20_RS1V_0_SQMUXA);
GRLFPC20_RS1V_0_SQMUXA_LUT6_2_O5: LUT4 
generic map(
  INIT => X"0080"
)
port map (
  I0 => cpi_d_inst(30),
  I1 => cpi_d_inst(31),
  I2 => GRLFPC20_COMB_SEQERR_UN11_OP,
  I3 => GRLFPC20_COMB_UN4_LOCK,
  O => GRLFPC20_V_A_LD_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISDGDN1_O6q49z: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_164(5),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(50));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISDGDN1_O5q49z: LUT5 
generic map(
  INIT => X"EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN_2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_164(5),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_8_CI_50_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2539);
GRLFPC20_AFQ_3_SQMUXA_LUT6_2_RNICAL81_O6: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_R_STATE(0),
  I1 => GRLFPC20_R_STATE(1),
  O => cpo_exc);
GRLFPC20_AFQ_3_SQMUXA_LUT6_2_RNICAL81_O5: LUT5 
generic map(
  INIT => X"0000AC0A"
)
port map (
  I0 => GRLFPC20_AFQ_3_SQMUXA_0,
  I1 => GRLFPC20_COMB_SEQERR_UN7_OP,
  I2 => GRLFPC20_R_STATE(0),
  I3 => GRLFPC20_R_STATE(1),
  I4 => GRLFPC20_COMB_LOCK,
  O => GRLFPC20_V_A_SEQERR_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_LUT6_2_O6q37z: LUT3 
generic map(
  INIT => X"27"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(35),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_LUT6_2_O5q37z: LUT3 
generic map(
  INIT => X"8D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G2_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(54),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_0(54));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_LUT6_2_O6q33z: LUT3 
generic map(
  INIT => X"27"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(33),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(33));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2_LUT6_2_O5q33z: LUT3 
generic map(
  INIT => X"1B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(32),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_116,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_2(32));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIH8IGQ_O6q321z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_SI_8(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIH8IGQ_O5q321z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_SI_8(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_49_CI_9_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_124(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1NHOR_O6q66z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_SI_8(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_65(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1NHOR_O5q66z: LUT5 
generic map(
  INIT => X"C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_49_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_CI_8_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_SI_8(49),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_65(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_SI_123(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIHVGIL_O6q9z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_SI_23(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_80(33),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIHVGIL_O5q9z: LUT5 
generic map(
  INIT => X"C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_SI_23(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_SI_80(33),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_138(31));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_RNIK6BOO_O6: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_16(41),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_RNIK6BOO_O5: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_16(41),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_41_CI_17_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_132(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIRGM0M_O6q24z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_SI_38(19),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_95(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIRGM0M_O5q24z: LUT5 
generic map(
  INIT => X"C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_CI_38_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_SI_38(19),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_95(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_153(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0NLOT_O6q347z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_35(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI0NLOT_O5q347z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_35(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_20_SI_151(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNID50UG_O6q49z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNID50UG_O5q49z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_5_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_3_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_7_SI_52(5),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_5_CI_53_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_168(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_RNI5AB1K_O6: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_46(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_RNI5AB1K_O5: LUT4 
generic map(
  INIT => X"6996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_9_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_13_SI_46(11),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_12_CI_46_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_RNI0VQ5P_O6: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_41(16),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_98(15),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_RNI0VQ5P_O5: LUT5 
generic map(
  INIT => X"C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_15_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_18_SI_41(16),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_98(15),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_15_SI_156(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_O6q0z: LUT3 
generic map(
  INIT => X"02"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_O5q0z: LUT3 
generic map(
  INIT => X"02"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISLM4D_O6q260z: LUT3 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_SI_7(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNISLM4D_O5q260z: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_50_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_51_CI_7_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_SI_7(50),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_50_SI_65(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4Q0NE_O6q274z: LUT4 
generic map(
  INIT => X"6996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_21(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_CI_22_AXB2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4Q0NE_O5q274z: LUT3 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_SI_21(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_CI_21_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQ265D_O6q273z: LUT3 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_20(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQ265D_O5q273z: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_38_CI_20_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_20(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_37_SI_78(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIR1ALP_O6q49z: LUT3 
generic map(
  INIT => X"E8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_13(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIR1ALP_O5q49z: LUT5 
generic map(
  INIT => X"F9F69060"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_SI_13(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_CIN_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_CI_14_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIIDSG5_O6q64z: LUT4 
generic map(
  INIT => X"000E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(66),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_M6_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIIDSG5_O5q64z: LUT3 
generic map(
  INIT => X"FB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(66),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN3_NOTDECODEDUNIMP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_STARTSHFT_UN2_NOTDECODEDUNIMP_I_0_E);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1F66O_O6q270z: LUT3 
generic map(
  INIT => X"48"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_16(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_AC0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI1F66O_O5q270z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_16(41),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_SI_73(40),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q43z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(43));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q43z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q47z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_44,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(47));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q47z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(48));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q51z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => NN_4,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_48,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(51));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q51z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I1 => NN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q9z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q9z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_21,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q13z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(13));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q13z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(14));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q44z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_47,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q44z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G1_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q40z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(40));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q40z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q37z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q37z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(38));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q36z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(36));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q36z: LUT2 
generic map(
  INIT => X"D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q35z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q35z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_35,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q21z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(36),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(21));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q21z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(20));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q17z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(40),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(17));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q17z: LUT3 
generic map(
  INIT => X"53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q46z: LUT3 
generic map(
  INIT => X"35"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_45,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(46));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q46z: LUT3 
generic map(
  INIT => X"02"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1_1_CO0_LUT6_2_O6: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(370),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1_1_CO0_LUT6_2_O5: LUT5 
generic map(
  INIT => X"D22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(370),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_STCKYPAIR_UN10_NOTPROP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIE4GP7_O6q317z: LUT5 
generic map(
  INIT => X"D22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(317),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(56),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_51_TRFWWBASICCELL_CIN_1,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_52_CI_6_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIE4GP7_O5q317z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(317),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(56),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_53_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI68324_O6q322z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(322),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(51),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI68324_O5q322z: LUT3 
generic map(
  INIT => X"D2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(322),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_48_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_48_CI_10_AXB0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQSSP7_O6q347z: LUT5 
generic map(
  INIT => X"D22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(347),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_22_CI_36_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQSSP7_O5q347z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(347),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(26),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_23_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI10S14_O6q344z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(344),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(29),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI10S14_O5q344z: LUT3 
generic map(
  INIT => X"D2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(344),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_26_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_26_CI_32_AXB0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2G2N7_O6q337z: LUT5 
generic map(
  INIT => X"D22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(337),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN_2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2G2N7_O5q337z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(337),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(36),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILNIV3_O6q353z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(353),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(20),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_CI_41_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNILNIV3_O5q353z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(353),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(20),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_17_SI_42(15));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_AC0_LUT6_2_O6: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_R_PCTRL_AC0_LUT6_2_O5: LUT4 
generic map(
  INIT => X"1700"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_11_2(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q5z: LUT2 
generic map(
  INIT => X"D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q5z: LUT4 
generic map(
  INIT => X"0103"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_EXCEP_1_I_A2_4_0(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O6q3z: LUT2 
generic map(
  INIT => X"D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_8_LUT6_2_O5q3z: LUT5 
generic map(
  INIT => X"00CCAAF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_0(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQ0O24_O6q326z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(326),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(47),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_44_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_44_SI_15(42));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIQ0O24_O5q326z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPAIV5_O6q338z: LUT3 
generic map(
  INIT => X"D2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(338),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_AXB0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIPAIV5_O5q338z: LUT3 
generic map(
  INIT => X"D2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(359),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_11_CI_47_AXB0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_T_3_LUT6_2_O6q0z: LUT5 
generic map(
  INIT => X"AA91AA9D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(377),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(375),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(376),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  I4 => N_1267,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_T_3(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_T_3_LUT6_2_O5q0z: LUT3 
generic map(
  INIT => X"1E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(376),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(374),
  I2 => N_1267,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SELECTQUOBITS_QUOBITS(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_26_O6q84z: LUT5 
generic map(
  INIT => X"1E4DFF7B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_330);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_26_O5q84z: LUT5 
generic map(
  INIT => X"4858119D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_359);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_10_O6q84z: LUT5 
generic map(
  INIT => X"647755E0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_346);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_10_O5q84z: LUT5 
generic map(
  INIT => X"018EFCC8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1002);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_24_O6q84z: LUT5 
generic map(
  INIT => X"222328C4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_365);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_24_O5q84z: LUT5 
generic map(
  INIT => X"04444C29"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_414);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_23_O6q84z: LUT5 
generic map(
  INIT => X"22C00414"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_406);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_23_O5q84z: LUT5 
generic map(
  INIT => X"001110CA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_424);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_11_O6q84z: LUT5 
generic map(
  INIT => X"562247C7"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_429);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_11_O5q84z: LUT5 
generic map(
  INIT => X"4C0340C7"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_466);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_9_O6q84z: LUT5 
generic map(
  INIT => X"656F881B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_441);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_9_O5q84z: LUT5 
generic map(
  INIT => X"16625FE5"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_470);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_8_O6q84z: LUT5 
generic map(
  INIT => X"66354815"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_480);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_8_O5q84z: LUT5 
generic map(
  INIT => X"562A0285"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_504);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_16_O6q84z: LUT5 
generic map(
  INIT => X"4413204B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_500);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_16_O5q84z: LUT5 
generic map(
  INIT => X"4221C803"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_511);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_34_O6q84z: LUT5 
generic map(
  INIT => X"0C1234AB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_531);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_34_O5q84z: LUT5 
generic map(
  INIT => X"352D2F79"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1005);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_5_O6q84z: LUT5 
generic map(
  INIT => X"6AEA9383"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_536);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_5_O5q84z: LUT5 
generic map(
  INIT => X"41202C80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1050);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_21_O6q84z: LUT5 
generic map(
  INIT => X"2C2300C4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_540);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_21_O5q84z: LUT5 
generic map(
  INIT => X"06821CA0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1192);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_36_O6q84z: LUT5 
generic map(
  INIT => X"08E38022"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_544);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_36_O5q84z: LUT5 
generic map(
  INIT => X"0962460E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1195);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_14_O6q84z: LUT5 
generic map(
  INIT => X"4F00341A"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_550);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_14_O5q84z: LUT5 
generic map(
  INIT => X"00093121"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1200);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_39_O6q84z: LUT5 
generic map(
  INIT => X"07062D10"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_591);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_39_O5q84z: LUT5 
generic map(
  INIT => X"00052B53"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1163);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_0_O6q84z: LUT5 
generic map(
  INIT => X"7FD87F3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_597);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_0_O5q84z: LUT5 
generic map(
  INIT => X"00150010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1146);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_35_O6q84z: LUT5 
generic map(
  INIT => X"0A62A44C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_600);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_35_O5q84z: LUT5 
generic map(
  INIT => X"73FBFBFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1095);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_18_O6q84z: LUT5 
generic map(
  INIT => X"37C8258E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_616);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_18_O5q84z: LUT5 
generic map(
  INIT => X"00404000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_2_O6q84z: LUT5 
generic map(
  INIT => X"78161E7C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_623);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_2_O5q84z: LUT5 
generic map(
  INIT => X"321200A0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_507);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_32_O6q84z: LUT5 
generic map(
  INIT => X"0F426582"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_635);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_32_O5q84z: LUT5 
generic map(
  INIT => X"205F5F4E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_I3_MUX_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_30_O6q84z: LUT5 
generic map(
  INIT => X"112A38F9"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_646);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_30_O5q84z: LUT5 
generic map(
  INIT => X"00000188"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1165);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_20_O6q84z: LUT5 
generic map(
  INIT => X"30E81400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_652);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_20_O5q84z: LUT5 
generic map(
  INIT => X"100040D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1044);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_1_O6q84z: LUT5 
generic map(
  INIT => X"7D14187B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_659);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_1_O5q84z: LUT5 
generic map(
  INIT => X"57060603"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_588);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_41_O6q84z: LUT5 
generic map(
  INIT => X"0523B042"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_666);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_41_O5q84z: LUT5 
generic map(
  INIT => X"06181803"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_556);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_38_O6q84z: LUT5 
generic map(
  INIT => X"0762A3C8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_669);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_38_O5q84z: LUT5 
generic map(
  INIT => X"22FFFF72"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_451);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_3_O6q84z: LUT5 
generic map(
  INIT => X"6CAEF8CC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_675_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_3_O5q84z: LUT5 
generic map(
  INIT => X"00565E00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_455);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_29_O6q84z: LUT5 
generic map(
  INIT => X"112F3ED8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_678);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_29_O5q84z: LUT5 
generic map(
  INIT => X"188F78C4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_641_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_46_O6q84z: LUT5 
generic map(
  INIT => X"0145A942"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_905);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_46_O5q84z: LUT5 
generic map(
  INIT => X"00024641"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1143);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_28_O6q84z: LUT5 
generic map(
  INIT => X"140207C8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_907);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_28_O5q84z: LUT5 
generic map(
  INIT => X"116D2E58"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_609);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_37_O6q84z: LUT5 
generic map(
  INIT => X"086A7D58"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_915);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_37_O5q84z: LUT5 
generic map(
  INIT => X"22000080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_745_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_4_O6q84z: LUT5 
generic map(
  INIT => X"6C127F3F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_962);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_4_O5q84z: LUT5 
generic map(
  INIT => X"20000008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_788_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_33_O6q84z: LUT5 
generic map(
  INIT => X"0F322700"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_965);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_33_O5q84z: LUT5 
generic map(
  INIT => X"0040E652"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_448);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_13_O6q84z: LUT5 
generic map(
  INIT => X"518A04CC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_969);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_13_O5q84z: LUT5 
generic map(
  INIT => X"00283D00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1170);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_22_O6q84z: LUT5 
generic map(
  INIT => X"256109D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_973);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_22_O5q84z: LUT5 
generic map(
  INIT => X"35BFB777"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1158);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_15_O6q84z: LUT5 
generic map(
  INIT => X"4CF21C94"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_980);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_15_O5q84z: LUT5 
generic map(
  INIT => X"30040000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1197);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_31_O6q84z: LUT5 
generic map(
  INIT => X"110F0FC3"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_982);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_31_O5q84z: LUT5 
generic map(
  INIT => X"50100009"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1047);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_27_O6q84z: LUT5 
generic map(
  INIT => X"170D2591"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_989);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_27_O5q84z: LUT5 
generic map(
  INIT => X"01058460"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_632);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIIH3P1_O6q84z: LUT5 
generic map(
  INIT => X"60830142"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_I6_MUX_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIIH3P1_O5q84z: LUT5 
generic map(
  INIT => X"00000008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_8_0(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O14_1_LUT6_2_O6q34z: LUT4 
generic map(
  INIT => X"6021"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3654);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O14_1_LUT6_2_O5q34z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_1);
GRLFPC20_FPI_OP2_LUT6_2_O6q53z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(21),
  I1 => rfo2_data2(21),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(53));
GRLFPC20_FPI_OP2_LUT6_2_O5q53z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(22),
  I1 => rfo2_data2(22),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(54));
GRLFPC20_FPI_OP2_LUT6_2_O6q63z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(31),
  I1 => rfo2_data2(31),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(63));
GRLFPC20_FPI_OP2_LUT6_2_O5q63z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(12),
  I1 => rfo2_data2(12),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(44));
GRLFPC20_FPI_OP2_LUT6_2_O6q52z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(20),
  I1 => rfo2_data2(20),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(52));
GRLFPC20_FPI_OP2_LUT6_2_O5q52z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(19),
  I1 => rfo2_data2(19),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(51));
GRLFPC20_FPI_OP2_LUT6_2_O6q50z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(18),
  I1 => rfo2_data2(18),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(50));
GRLFPC20_FPI_OP2_LUT6_2_O5q50z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(17),
  I1 => rfo2_data2(17),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(49));
GRLFPC20_FPI_OP2_LUT6_2_O6q48z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(16),
  I1 => rfo2_data2(16),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(48));
GRLFPC20_FPI_OP2_LUT6_2_O5q48z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(15),
  I1 => rfo2_data2(15),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(47));
GRLFPC20_FPI_OP2_LUT6_2_O6q46z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(14),
  I1 => rfo2_data2(14),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(46));
GRLFPC20_FPI_OP2_LUT6_2_O5q46z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(13),
  I1 => rfo2_data2(13),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(45));
GRLFPC20_FPI_OP2_LUT6_2_O6q40z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(8),
  I1 => rfo2_data2(8),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(40));
GRLFPC20_FPI_OP2_LUT6_2_O5q40z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(4),
  I1 => rfo2_data2(4),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(36));
GRLFPC20_FPI_OP2_LUT6_2_O6q38z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(6),
  I1 => rfo2_data2(6),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(38));
GRLFPC20_FPI_OP2_LUT6_2_O5q38z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => rfo1_data2(5),
  I1 => rfo2_data2(5),
  I2 => GRLFPC20_COMB_UN1_FPCI_4,
  O => GRLFPC20_FPI_OP2(37));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNINL2P1_O6q79z: LUT4 
generic map(
  INIT => X"3F95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_833);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNINL2P1_O5q79z: LUT4 
generic map(
  INIT => X"0010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3179_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O19_6_LUT6_2_O6q36z: LUT4 
generic map(
  INIT => X"42E0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3713);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O19_6_LUT6_2_O5q36z: LUT5 
generic map(
  INIT => X"03020000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_14_1(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O6q1z: LUT5 
generic map(
  INIT => X"FCAA0CAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(372),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O5q1z: LUT4 
generic map(
  INIT => X"10D0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(57),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_29,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4_SN_N_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_O6q7z: LUT4 
generic map(
  INIT => X"0080"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2820);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_O5q7z: LUT4 
generic map(
  INIT => X"C0E0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2816);
GRLFPC20_COMB_UN1_R_A_RS1_1_LUT6_2_O6: LUT4 
generic map(
  INIT => X"AC0C"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => GRLFPC20_R_A_RS1(0),
  I2 => GRLFPC20_R_A_RS1D,
  I3 => GRLFPC20_R_A_ST,
  O => GRLFPC20_COMB_UN1_R_A_RS1_1);
GRLFPC20_COMB_UN1_R_A_RS1_1_LUT6_2_O5: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => cpi_a_cnt(1),
  I1 => cpi_a_cnt(0),
  O => GRLFPC20_COMB_V_E_STDATA2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O8_0_LUT6_2_O6q63z: LUT4 
generic map(
  INIT => X"6004"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4614);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_O8_0_LUT6_2_O5q63z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_822_I_0);
GRLFPC20_COMB_FPDECODE_UN1_FPCI_1_2_0_LUT6_2_O6: LUT4 
generic map(
  INIT => X"0040"
)
port map (
  I0 => cpi_d_inst(8),
  I1 => cpi_d_inst(11),
  I2 => cpi_d_inst(12),
  I3 => cpi_d_inst(13),
  O => GRLFPC20_COMB_FPDECODE_UN1_FPCI_1_2_0);
GRLFPC20_COMB_FPDECODE_UN1_FPCI_1_2_0_LUT6_2_O5: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => cpi_d_inst(8),
  I1 => cpi_d_inst(10),
  O => GRLFPC20_COMB_FPDECODE_RS1D5_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_6_0_LUT6_2_O6q56z: LUT5 
generic map(
  INIT => X"21000300"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_6_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_6_0_LUT6_2_O5q56z: LUT3 
generic map(
  INIT => X"40"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4462_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_21_LUT6_2_O6q75z: LUT4 
generic map(
  INIT => X"A695"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(48),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2190);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_12_21_LUT6_2_O5q75z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(48),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_O6q5z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2818);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_O5q5z: LUT3 
generic map(
  INIT => X"20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_COMPUTECONST_UN25_RESVEC);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2_LUT6_2_O6q3z: LUT3 
generic map(
  INIT => X"CE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2_LUT6_2_O5q3z: LUT2 
generic map(
  INIT => X"E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPYBUS_2(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC_LUT6_2_O6: LUT3 
generic map(
  INIT => X"AB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC_LUT6_2_O5: LUT4 
generic map(
  INIT => X"BBBF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(61),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(76),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_UN31_PCTRL_NEW_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2_LUT6_2_O6q1z: LUT3 
generic map(
  INIT => X"E0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(5),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2_LUT6_2_O5q1z: LUT3 
generic map(
  INIT => X"E0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(6),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(3),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_XZXBUS_2(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_20_1_LUT6_2_O6q56z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4138_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_20_1_LUT6_2_O5q56z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3225_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_1_RNI7UMM1_O6: LUT3 
generic map(
  INIT => X"C4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE_S_1_RNI7UMM1_O5: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(10),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_2(10));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_RNI0LEO1_O6q44z: LUT3 
generic map(
  INIT => X"C4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8_RNI0LEO1_O5q44z: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(44),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(48),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(44));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN3_NOTAZERODENORM_LUT6_2_O6: LUT3 
generic map(
  INIT => X"FE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN3_NOTAZERODENORM);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN3_NOTAZERODENORM_LUT6_2_O5: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => N_1198,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2319);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN3_XZYBUSLSBS_LUT6_2_O6: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(11),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN3_XZYBUSLSBS);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_FAX_UN3_XZYBUSLSBS_LUT6_2_O5: LUT3 
generic map(
  INIT => X"D1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(19),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(8),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(58),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UN1_SUB(0));
GRLFPC20_COMB_UN1_FPCI_LUT6_2_O6: LUT3 
generic map(
  INIT => X"FE"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  O => GRLFPC20_COMB_UN1_FPCI);
GRLFPC20_COMB_UN1_FPCI_LUT6_2_O5: LUT5 
generic map(
  INIT => X"00010101"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  I3 => GRLFPC20_R_I_EXC(5),
  I4 => GRLFPC20_COMB_UN1_R_I_V_1,
  O => GRLFPC20_WREN2_1_SQMUXA_1);
GRLFPC20_FPI_LDOP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"FFFD"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => GRLFPC20_FPI_LDOP);
GRLFPC20_FPI_LDOP_LUT6_2_O5: LUT2 
generic map(
  INIT => X"B"
)
port map (
  I0 => RST_I,
  I1 => GRLFPC20_R_MK_RST2,
  O => GRLFPC20_R_MK_RST2_I_E);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MAPMULXFF_UN4_UNIMPMAP_LUT6_2_O6: LUT3 
generic map(
  INIT => X"F7"
)
port map (
  I0 => cpi_d_inst(9),
  I1 => cpi_d_inst(11),
  I2 => cpi_d_inst(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MAPMULXFF_UN4_UNIMPMAP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MAPMULXFF_UN4_UNIMPMAP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"0800"
)
port map (
  I0 => cpi_d_inst(9),
  I1 => cpi_d_inst(11),
  I2 => cpi_d_inst(12),
  I3 => cpi_d_inst(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SXC_SCTRL_NEW_5_0_E(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1_LUT6_2_O6q2z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1_LUT6_2_O5q2z: LUT5 
generic map(
  INIT => X"CCCCCCC8"
)
port map (
  I0 => GRLFPC20_FPI_LDOP,
  I1 => I2_I_4,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  O => M20_E_0_0);
GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_1_LUT6_2_O6: LUT4 
generic map(
  INIT => X"0008"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(8),
  I2 => cpi_d_inst(9),
  I3 => cpi_d_inst(10),
  O => GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_1);
GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_1_LUT6_2_O5: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => cpi_d_inst(5),
  I1 => cpi_d_inst(6),
  O => GRLFPC20_COMB_FPDECODE_UN1_FPCI_3_0);
GRLFPC20_MOV_1_SQMUXA_2_LUT6_2_O6: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  I2 => cpi_d_inst(24),
  O => GRLFPC20_MOV_1_SQMUXA_2);
GRLFPC20_MOV_1_SQMUXA_2_LUT6_2_O5: LUT4 
generic map(
  INIT => X"0010"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  I2 => cpi_d_inst(19),
  I3 => cpi_d_inst(23),
  O => GRLFPC20_V_A_AFSR_1_0_A2_2);
GRLFPC20_COMB_FPDECODE_RDD2_2_LUT6_2_O6: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_d_inst(6),
  I1 => cpi_d_inst(10),
  I2 => cpi_d_inst(12),
  O => GRLFPC20_COMB_FPDECODE_RDD2_2);
GRLFPC20_COMB_FPDECODE_RDD2_2_LUT6_2_O5: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => cpi_d_inst(12),
  I1 => cpi_d_inst(11),
  O => GRLFPC20_COMB_FPDECODE_RDD4_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_18_0_LUT6_2_O6q60z: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_18_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_18_0_LUT6_2_O5q60z: LUT5 
generic map(
  INIT => X"00000004"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_21_1(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q95z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(18),
  I2 => GRLFPC20_FPO_FRAC(20),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2491);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q95z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(19),
  I2 => GRLFPC20_FPO_FRAC(21),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2492);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q87z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(26),
  I2 => GRLFPC20_FPO_FRAC(28),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2499);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q87z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(25),
  I2 => GRLFPC20_FPO_FRAC(27),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2498);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O6q8z: LUT3 
generic map(
  INIT => X"1D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O5q8z: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(101),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6087);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O6q3z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2829);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O5q3z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(241),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_FPO_EXP(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2312);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O6q242z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_FPO_EXP(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2253);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O5q242z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_FPO_EXP(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2252);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O6q2z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(255),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(242),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2828);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O5q2z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(256),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(243),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2827);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q93z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(20),
  I2 => GRLFPC20_FPO_FRAC(22),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2493);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q93z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(36),
  I2 => GRLFPC20_FPO_FRAC(38),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2509);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O6q249z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_FPO_EXP(9),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2317);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O5q249z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_AEBEEXC_UN8_NOTAINFNAN_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O6q9z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(235),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(248),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2835);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O5q9z: LUT3 
generic map(
  INIT => X"CA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(236),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(249),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2834);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q90z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(23),
  I2 => GRLFPC20_FPO_FRAC(25),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2496);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q90z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(24),
  I2 => GRLFPC20_FPO_FRAC(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2497);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q99z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(14),
  I2 => GRLFPC20_FPO_FRAC(16),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2487);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q99z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(13),
  I2 => GRLFPC20_FPO_FRAC(15),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2486);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O6q240z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_FPO_EXP(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2255);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O5q240z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(254),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_FPO_EXP(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2254);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O6q0z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2826);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O5q0z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G6_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q72z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(41),
  I2 => GRLFPC20_FPO_FRAC(43),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2514);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q72z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(42),
  I2 => GRLFPC20_FPO_FRAC(44),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2515);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q108z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(5),
  I2 => GRLFPC20_FPO_FRAC(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2478);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q108z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(4),
  I2 => GRLFPC20_FPO_FRAC(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2477);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q86z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(27),
  I2 => GRLFPC20_FPO_FRAC(29),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2500);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q86z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(28),
  I2 => GRLFPC20_FPO_FRAC(30),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2501);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O6q7z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(237),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2833);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O5q7z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2832);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O6q4z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(253),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(240),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2830);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_2_LUT6_2_O5q4z: LUT3 
generic map(
  INIT => X"AC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(239),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2831);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q112z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => N_1211,
  I2 => GRLFPC20_FPO_FRAC(3),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2474);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q112z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => N_1212,
  I2 => GRLFPC20_FPO_FRAC(4),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2475);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O6q3z: LUT3 
generic map(
  INIT => X"1D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(3));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O5q3z: LUT3 
generic map(
  INIT => X"1D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_M2_LUT6_2_O6q50z: LUT3 
generic map(
  INIT => X"D1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_943);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_M2_LUT6_2_O5q50z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3290_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O6q251z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(238),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I2 => GRLFPC20_FPO_EXP(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2315);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O5q251z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(25),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(244),
  I2 => GRLFPC20_FPO_EXP(1),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2309);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O6q237z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(250),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_FPO_EXP(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2258);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O5q237z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(257),
  I2 => GRLFPC20_FPO_EXP(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2251);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O6q238z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(251),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_FPO_EXP(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2257);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_1_LUT6_2_O5q238z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(252),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(28),
  I2 => GRLFPC20_FPO_EXP(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2256);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_TOPBITSIN_LUT6_2_O6q8z: LUT3 
generic map(
  INIT => X"B8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TOPBITSIN(8));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_TOPBITSIN_LUT6_2_O5q8z: LUT5 
generic map(
  INIT => X"0000B8F0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(12),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(44),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(0),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRCONTROL_1(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_SRESULT_1_M_0(57));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q80z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(33),
  I2 => GRLFPC20_FPO_FRAC(35),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2506);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q80z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(6),
  I2 => GRLFPC20_FPO_FRAC(8),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2479);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q74z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(39),
  I2 => GRLFPC20_FPO_FRAC(41),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2512);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q74z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(3),
  I2 => GRLFPC20_FPO_FRAC(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2476);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O6q4z: LUT3 
generic map(
  INIT => X"47"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(4));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O5q4z: LUT5 
generic map(
  INIT => X"606F6F60"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(20),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULTIPLELOGIC_SHIFT_3_0_I(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q84z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(29),
  I2 => GRLFPC20_FPO_FRAC(31),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2502);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q84z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(15),
  I2 => GRLFPC20_FPO_FRAC(17),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2488);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q102z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(11),
  I2 => GRLFPC20_FPO_FRAC(13),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2484);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q102z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(12),
  I2 => GRLFPC20_FPO_FRAC(14),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2485);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q63z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(50),
  I2 => GRLFPC20_FPO_FRAC(52),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2523);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q63z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(44),
  I2 => GRLFPC20_FPO_FRAC(46),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2517);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q91z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(22),
  I2 => GRLFPC20_FPO_FRAC(24),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2495);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q91z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(21),
  I2 => GRLFPC20_FPO_FRAC(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2494);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q96z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(17),
  I2 => GRLFPC20_FPO_FRAC(19),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2490);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q96z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(16),
  I2 => GRLFPC20_FPO_FRAC(18),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2489);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q103z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(10),
  I2 => GRLFPC20_FPO_FRAC(12),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2483);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q103z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(9),
  I2 => GRLFPC20_FPO_FRAC(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2482);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O6q105z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(8),
  I2 => GRLFPC20_FPO_FRAC(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2481);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_0_LUT6_2_O5q105z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(4),
  I1 => GRLFPC20_FPO_FRAC(7),
  I2 => GRLFPC20_FPO_FRAC(9),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2480);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O6q6z: LUT3 
generic map(
  INIT => X"1D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP(6));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_NOTMULTIP_LUT6_2_O5q6z: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(113),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6132);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O6q24z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(349),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(24));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O5q24z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(349),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(24),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_21_SI_38(19));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES_LUT6_2_O6: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_UN20_NOTSLRES_LUT6_2_O5: LUT4 
generic map(
  INIT => X"F708"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(234),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(31),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(32),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(36),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_UN25_EXPXBUS_0_I_13_0);
GRLFPC20_COMB_FPDECODE_ST2_2_LUT6_2_O6: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  O => GRLFPC20_V_A_AFSR_1_4);
GRLFPC20_COMB_FPDECODE_ST2_2_LUT6_2_O5: LUT4 
generic map(
  INIT => X"EF00"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  I2 => GRLFPC20_MOV_0_SQMUXA_4,
  I3 => holdn,
  O => GRLFPC20_RS1_1_SN_N_3);
GRLFPC20_FPCO_HOLDN_LUT6_2_O6: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_R_MK_HOLDN1,
  I1 => GRLFPC20_R_MK_HOLDN2,
  O => cpo_holdn);
GRLFPC20_FPCO_HOLDN_LUT6_2_O5: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_MK_HOLDN2,
  O => GRLFPC20_V_MK_RST_1_0);
GRLFPC20_COMB_UN3_HOLDN_LUT6_2_O6: LUT2 
generic map(
  INIT => X"E"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  O => GRLFPC20_COMB_UN3_HOLDN);
GRLFPC20_COMB_UN3_HOLDN_LUT6_2_O5: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => GRLFPC20_R_A_AFSR,
  O => GRLFPC20_V_E_AFSR_1);
GRLFPC20_COMB_UN1_FPCI_2_LUT6_2_O6: LUT2 
generic map(
  INIT => X"E"
)
port map (
  I0 => cpi_e_annul,
  I1 => cpi_e_trap,
  O => GRLFPC20_COMB_UN1_FPCI_2);
GRLFPC20_COMB_UN1_FPCI_2_LUT6_2_O5: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_e_annul,
  I1 => cpi_e_trap,
  I2 => GRLFPC20_R_E_AFSR,
  O => GRLFPC20_V_M_AFSR_1);
GRLFPC20_COMB_UN1_FPCI_1_LUT6_2_O6: LUT2 
generic map(
  INIT => X"E"
)
port map (
  I0 => cpi_m_annul,
  I1 => cpi_m_trap,
  O => GRLFPC20_COMB_UN1_FPCI_1);
GRLFPC20_COMB_UN1_FPCI_1_LUT6_2_O5: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_m_annul,
  I1 => cpi_m_trap,
  I2 => GRLFPC20_R_M_AFQ,
  O => GRLFPC20_V_X_AFQ_1);
GRLFPC20_COMB_WRADDR_0_SQMUXA_LUT6_2_O6: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_R_X_AFSR,
  I1 => GRLFPC20_R_X_LD,
  O => GRLFPC20_COMB_WRADDR_0_SQMUXA);
GRLFPC20_COMB_WRADDR_0_SQMUXA_LUT6_2_O5: LUT4 
generic map(
  INIT => X"0444"
)
port map (
  I0 => GRLFPC20_R_X_AFSR,
  I1 => GRLFPC20_R_X_LD,
  I2 => GRLFPC20_R_X_SEQERR_0_DOUT(0),
  I3 => RqXzXRDDY_1,
  O => GRLFPC20_WREN1_0_SQMUXA_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI3M821_O6q84z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1271_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI3M821_O5q84z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1257_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI3L721_O6q79z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3177_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI3L721_O5q79z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4479_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6O721_0_O6q79z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3029_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6O721_0_O5q79z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3384_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI5N721_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3296_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI5N721_O5q78z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3071_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1K821_O6q83z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3425_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1K821_O5q83z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3031_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI9R721_O6q79z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3722_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI9R721_O5q79z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3077_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_LUT6_2_O6: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_TEMP_LUT6_2_O5: LUT5 
generic map(
  INIT => X"0F0B0400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(12),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1(11),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI3L721_O6q78z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3127_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI3L721_O5q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3346_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIRISV4_0_O6q79z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3231_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIRISV4_0_O5q79z: LUT5 
generic map(
  INIT => X"D55D0008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1214,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1213,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1217);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O6q9z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(364),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O5q9z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(334),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(39),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_36_TRFWWBASICCELL_CIN,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_SI_23(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_0_1_LUT6_2_O6q63z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4635_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_0_1_LUT6_2_O5q63z: LUT4 
generic map(
  INIT => X"0010"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1725);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_X2_1_1_LUT6_2_O6q61z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6065_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_X2_1_1_LUT6_2_O5q61z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3340_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIRISV4_O6q79z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1_I_4);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIRISV4_O5q79z: LUT5 
generic map(
  INIT => X"8000D555"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_120_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_119_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_123_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIG8LD1_0_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3175_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIG8LD1_0_O5q78z: LUT3 
generic map(
  INIT => X"20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1766);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIJBLD1_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3130_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIJBLD1_O5q78z: LUT3 
generic map(
  INIT => X"20"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_148_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIUG821_O6q81z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4566_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIUG821_O5q81z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3092_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNITR2P1_O6q78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3182_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNITR2P1_O5q78z: LUT5 
generic map(
  INIT => X"00400000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1831);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIA3MD1_O6q84z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3601_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIA3MD1_O5q84z: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_23_0(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI92MD1_O6q84z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3096_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI92MD1_O5q84z: LUT3 
generic map(
  INIT => X"01"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3858_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIA1O63_O6q84z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3375_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIA1O63_O5q84z: LUT5 
generic map(
  INIT => X"00010000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1877,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1289);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_O6q79z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3186_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_O5q79z: LUT5 
generic map(
  INIT => X"00061412"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1205);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIIH3P1_0_O6q84z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3327_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIIH3P1_0_O5q84z: LUT5 
generic map(
  INIT => X"20A02000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_4_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNID5LD1_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3026_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNID5LD1_O5q78z: LUT3 
generic map(
  INIT => X"14"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3664_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIG8LD1_1_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3343_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIG8LD1_1_O5q78z: LUT3 
generic map(
  INIT => X"08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A14_4_0(34));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIB2O63_O6q78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3019_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIB2O63_O5q78z: LUT5 
generic map(
  INIT => X"00400000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_201_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1602);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNID5LD1_O6q79z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4487_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNID5LD1_O5q79z: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1145);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI81MD1_O6q84z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3234_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI81MD1_O5q84z: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_38_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6O721_O6q79z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3667_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6O721_O5q79z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3724_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6VLD1_O6q83z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3294_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6VLD1_O5q83z: LUT3 
generic map(
  INIT => X"40"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1J721_O6q79z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3116_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1J721_O5q79z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3292_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIH9LD1_O6q78z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3827_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIH9LD1_O5q78z: LUT3 
generic map(
  INIT => X"18"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4564);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6VLD1_0_O6q83z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4182_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6VLD1_0_O5q83z: LUT3 
generic map(
  INIT => X"01"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_54_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6VLD1_1_O6q83z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3828_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI6VLD1_1_O5q83z: LUT3 
generic map(
  INIT => X"08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1708);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNID5LD1_0_O6q78z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4310_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNID5LD1_0_O5q78z: LUT3 
generic map(
  INIT => X"08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3201);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0J821_O6q82z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3488_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0J821_O5q82z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4431_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIE6LD1_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3129_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIE6LD1_O5q78z: LUT3 
generic map(
  INIT => X"37"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_141_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNICT621_O6q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3120_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNICT621_O5q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1244_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNINEKD1_O6q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3078_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNINEKD1_O5q78z: LUT3 
generic map(
  INIT => X"01"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3199);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIE4N63_O6q78z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3207_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIE4N63_O5q78z: LUT5 
generic map(
  INIT => X"00002000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_833,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3176);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNINM3P1_O6q84z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3421_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNINM3P1_O5q84z: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3028_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI2K721_O6q78z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3347_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI2K721_O5q78z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_748_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI7O621_O6q78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3034_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI7O621_O5q78z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4269_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIG8LD1_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3923_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIG8LD1_O5q78z: LUT3 
generic map(
  INIT => X"40"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1706);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILJ2P1_O6q78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3795_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILJ2P1_O5q78z: LUT4 
generic map(
  INIT => X"0AA2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_844);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4M721_0_O6q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4M721_0_O5q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0U1P1_O6q78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4139_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0U1P1_O5q78z: LUT4 
generic map(
  INIT => X"3055"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4490);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIH8KD1_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3222_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIH8KD1_O5q78z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1280_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIAR621_O6q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4150_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIAR621_O5q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3035_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4M721_O6q78z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3644_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4M721_O5q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3277_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIA3MD1_0_O6q84z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_714_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIA3MD1_0_O5q84z: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4176);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0U1P1_0_O6q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4626_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0U1P1_0_O5q78z: LUT4 
generic map(
  INIT => X"0008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1771);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0J821_O6q84z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4630);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0J821_O5q84z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3281_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4M721_O6q79z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3753_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4M721_O5q79z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3666_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0MQV4_O6q78z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1267_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI0MQV4_O5q78z: LUT5 
generic map(
  INIT => X"EAAA4000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_766_I,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1274_MUX,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI7P721_O6q79z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1263_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI7P721_O5q79z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3132_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIVH821_O6q82z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3016_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIVH821_O5q82z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1277_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT_RNI64RE3_O6: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3025_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT_RNI64RE3_O5: LUT5 
generic map(
  INIT => X"AAAACC3C"
)
port map (
  I0 => cpi_d_inst(9),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_MULTIPLEXORMULXFF_RESULT_1_SN_N_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2201);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_2_RNIJHNQ1_O6q12z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3020_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_2_RNIJHNQ1_O5q12z: LUT5 
generic map(
  INIT => X"FFFF0200"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_24_0(58),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1603,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_0(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNITR2P1_0_O6q78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3246_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNITR2P1_0_O5q78z: LUT4 
generic map(
  INIT => X"0008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3795_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIB2O63_0_O6q78z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3124_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIB2O63_0_O5q78z: LUT5 
generic map(
  INIT => X"00000800"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1011,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4581);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIU9294_O6q84z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1259_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIU9294_O5q84z: LUT5 
generic map(
  INIT => X"70502000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_54_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_12_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1059);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_8_1_LUT6_2_O6q56z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3017_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_8_1_LUT6_2_O5q56z: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3727_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_1_0_LUT6_2_O6q62z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4443_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A13_1_0_LUT6_2_O5q62z: LUT5 
generic map(
  INIT => X"7D752020"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_745_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_746_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_743,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_749);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_X2_LUT6_2_O6q49z: LUT2 
generic map(
  INIT => X"6"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3842_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_X2_LUT6_2_O5q49z: LUT3 
generic map(
  INIT => X"01"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3791_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O6q49z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(324),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3(49));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_O5q49z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(364),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(9),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_CIN_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_6_CI_52_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_7_0_LUT6_2_O6q34z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4274_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_7_0_LUT6_2_O5q34z: LUT5 
generic map(
  INIT => X"3FAFAFFD"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1139);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_1_0_LUT6_2_O6q36z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3297_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_1_0_LUT6_2_O5q36z: LUT3 
generic map(
  INIT => X"14"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_776);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A3_12_0_LUT6_2_O6q49z: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3548_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A3_12_0_LUT6_2_O5q49z: LUT5 
generic map(
  INIT => X"00010000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_3_1(12));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_3_0_LUT6_2_O6q36z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3476_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_3_0_LUT6_2_O5q36z: LUT3 
generic map(
  INIT => X"08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1922);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_9_0_LUT6_2_O6q63z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3702_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A2_9_0_LUT6_2_O5q63z: LUT5 
generic map(
  INIT => X"00200000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_17_1(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_16_0_LUT6_2_O6q61z: LUT2 
generic map(
  INIT => X"4"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3551_1_I_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A26_16_0_LUT6_2_O5q61z: LUT5 
generic map(
  INIT => X"00000400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_19_1(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_5_0_LUT6_2_O6q50z: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4424_I_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_5_0_LUT6_2_O5q50z: LUT5 
generic map(
  INIT => X"00000002"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1254_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIO6OV9_O6q78z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_M44_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIO6OV9_O5q78z: LUT5 
generic map(
  INIT => X"BBEA1100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_110_0,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_109_0,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_123_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_901);
GRLFPC20_COMB_FPDECODE_RDD5_1_0_0_LUT6_2_O6: LUT2 
generic map(
  INIT => X"1"
)
port map (
  I0 => cpi_d_inst(12),
  I1 => cpi_d_inst(13),
  O => GRLFPC20_COMB_FPDECODE_RS1D5_4);
GRLFPC20_COMB_FPDECODE_RDD5_1_0_0_LUT6_2_O5: LUT5 
generic map(
  INIT => X"00000001"
)
port map (
  I0 => cpi_d_inst(12),
  I1 => cpi_d_inst(13),
  I2 => cpi_d_inst(6),
  I3 => cpi_d_inst(7),
  I4 => cpi_d_inst(11),
  O => GRLFPC20_COMB_FPDECODE_UN1_FPCI_2_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1_LUT6_2_RNI6UD7N1_O6q2z: LUT3 
generic map(
  INIT => X"96"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_132(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(18));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1_LUT6_2_RNI6UD7N1_O5q2z: LUT5 
generic map(
  INIT => X"EEE2E222"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLBREGXZ_XZBREGLC_1(2),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_37_TRFWWBASICCELL_CIN_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_40_CI_18_C3,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_39_SI_132(37),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2571);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_10_RNINGSK_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(50),
  I1 => R_DPATH_RET_26,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_10_RNINGSK_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(18),
  I1 => R_DPATH_RET_9,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_38_RNI707G_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(52),
  I1 => R_DPATH_RET_24,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_38_RNI707G_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(53),
  I1 => R_DPATH_RET_23,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_12_RNIOP6G_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(37),
  I1 => R_DPATH_RET_10,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_11);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_12_RNIOP6G_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(38),
  I1 => R_DPATH_RET_14,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_12);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_42_RNIA1JQ_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(41),
  I1 => R_DPATH_RET_25,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_15);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_42_RNIA1JQ_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(33),
  I1 => R_DPATH_RET_8,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_18_RNI7TIQ_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(43),
  I1 => R_DPATH_RET_13,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_17);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_18_RNI7TIQ_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(44),
  I1 => R_DPATH_RET_7,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_18);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_22_RNI637G_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(46),
  I1 => R_DPATH_RET_15,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_22_RNI637G_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(6),
  I1 => R_DPATH_RET_50,
  I2 => M20_E_0_RETO_0,
  O => NN_6);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_10_RNIKESK_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(48),
  I1 => R_DPATH_RET_19,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_10_RNIKESK_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(18),
  I1 => R_DPATH_RET_9,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_52_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_14_RNIUO6G_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(22),
  I1 => R_DPATH_RET_11,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_26);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_14_RNIUO6G_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(15),
  I1 => R_DPATH_RET_12,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_32_RNIUVIQ_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(26),
  I1 => R_DPATH_RET_6,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_30);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_32_RNIUVIQ_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(16),
  I1 => R_DPATH_RET_20,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_24_RNI7T6G_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(27),
  I1 => R_DPATH_RET_16,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_31);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_24_RNI7T6G_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(28),
  I1 => R_DPATH_RET_22,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_32);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_28_RNIAT6G_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(29),
  I1 => R_DPATH_RET_18,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_33);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_28_RNIAT6G_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(30),
  I1 => R_DPATH_RET_21,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_34);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_26_RNIDUIQ_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(32),
  I1 => R_DPATH_RET_17,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_36);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_26_RNIDUIQ_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(33),
  I1 => R_DPATH_RET_8,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_37);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_16_RNIUR6G_O6: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(15),
  I1 => R_DPATH_RET_12,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_49);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RET_16_RNIUR6G_O5: LUT3 
generic map(
  INIT => X"3B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RETO(16),
  I1 => R_DPATH_RET_20,
  I2 => M20_E_0_RETO_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_50);
GRLFPC20_R_X_RDD_0_DOUT_RNICAQN_O6q0z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_R_X_RDD_0_DOUT(0),
  I1 => RqXzXRDDY_1,
  O => GRLFPC20_R_X_RDD);
GRLFPC20_R_X_RDD_0_DOUT_RNICAQN_O5q0z: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_R_X_SEQERR_0_DOUT(0),
  I1 => RqXzXRDDY_1,
  O => GRLFPC20_R_X_SEQERR);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIGH2E1_O6q2z: LUT5 
generic map(
  INIT => X"EE00EE0E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => N_6_MUX_52_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIGH2E1_O5q2z: LUT5 
generic map(
  INIT => X"EE00EE0E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(2),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(1),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_NOTABORTNULLEXC,
  I3 => GRLFPC20_FPI_LDOP,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_14(77),
  O => N_6_MUX_54_I);
GRLFPC20_FPI_START_LUT6_2_O6: LUT4 
generic map(
  INIT => X"0200"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_MK_RST,
  I2 => GRLFPC20_R_MK_RST2,
  I3 => GRLFPC20_FPOP_1,
  O => GRLFPC20_FPI_START);
GRLFPC20_FPI_START_LUT6_2_O5: LUT4 
generic map(
  INIT => X"0200"
)
port map (
  I0 => holdn,
  I1 => GRLFPC20_R_MK_RST,
  I2 => GRLFPC20_R_MK_RST2,
  I3 => GRLFPC20_FPOP_1,
  O => GRLFPC20_FPI_START_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_50_1_SUM0_0_A2_LUT6_2_O6: LUT5 
generic map(
  INIT => X"95A96A56"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2,
  I2 => N_1381_I,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6321_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_50_1_SUM0_0_A2_LUT6_2_O5: LUT5 
generic map(
  INIT => X"EAFE80A8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2,
  I2 => N_1381_I,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_50(316));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1_RNI2NP53_O6: LUT5 
generic map(
  INIT => X"95A96A56"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2,
  I2 => N_1381_I,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1_RNI2NP53_O5: LUT5 
generic map(
  INIT => X"EAFE80A8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_55_TRFWWBASICCELL_CIN_2,
  I2 => N_1381_I,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6320,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_114(56),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(58));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKJCR82_O6q93z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_CI_34_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_91(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(35));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKJCR82_O5q93z: LUT5 
generic map(
  INIT => X"EBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_20_TRFWWBASICCELL_CIN_3,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_22_TRFWWBASICCELL_CIN_3,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_CI_34_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_24_SI_91(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_23_CI_35_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(92));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN561_TEMP_RNI7RGM12_O6: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_72(41),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(16));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_40_TRFWWBASICCELL_UN561_TEMP_RNI7RGM12_O5: LUT5 
generic map(
  INIT => X"EBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_39_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_CI_15_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_72(41),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_42_CI_16_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(73));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2_RNIC8AE81_O6: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_111(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_8(55));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2_RNIC8AE81_O5: LUT5 
generic map(
  INIT => X"EBBE8228"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_2_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_CI_54_C2,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_4_SI_111(2),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_CI_55_C3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_DPATH_NEW_23(112));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKH6T51_O6q323z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_12(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_43_SI_128(41));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIKH6T51_O5q323z: LUT5 
generic map(
  INIT => X"F9F69060"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_45_TRFWWBASICCELL_CIN,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_46_CI_12_C1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_CIN_3,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_12(45),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_45_CI_13_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4O9BT_O6q336z: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_SI_25(32),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_82(31),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI4O9BT_O5q336z: LUT5 
generic map(
  INIT => X"C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_SI_25(32),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_SI_82(31),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_31_SI_140(29));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1_CO0_LUT6_2_O6: LUT5 
generic map(
  INIT => X"FEECC880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_56(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_113(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_MULLSBLOGIC_TEMP_1_CO0_LUT6_2_O5: LUT5 
generic map(
  INIT => X"C993366C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_1_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_0_TRFWWBASICCELL_CIN_1,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_2_CI_56(1),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_3_SI_56(1),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_SI_113(0),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_CO0_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIA795M_O6q9z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_SI_23(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_SI_139(30));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_MIXOIN_3_LUT6_2_RNIA795M_O5q9z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_34_TRFWWBASICCELL_CIN_2,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_35_CI_23_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_36_SI_23(34),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_CI_24_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4SO63_O6q79z: LUT4 
generic map(
  INIT => X"9000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_55_0,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_774);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI4SO63_O5q79z: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_18_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2U9HS_O6q337z: LUT5 
generic map(
  INIT => X"EDDE8448"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_SI_25(32),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C3);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNI2U9HS_O5q337z: LUT5 
generic map(
  INIT => X"96696996"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_32_TRFWWBASICCELL_CIN_1,
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_CIN_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_33_CI_25_C1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_34_SI_25(32),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_32_CI_26_C2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_30_SI_141(28));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_O6q11z: LUT5 
generic map(
  INIT => X"00CCAAF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_20,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_O5q11z: LUT4 
generic map(
  INIT => X"0A0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(54),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_0,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(7));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_O6q9z: LUT5 
generic map(
  INIT => X"00CCAAF0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_22,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(9));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_O5q9z: LUT4 
generic map(
  INIT => X"0A0C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(56),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_2,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(3),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(2),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(5));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_40_O6q84z: LUT5 
generic map(
  INIT => X"05CEFFCC"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_604);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_40_O5q84z: LUT5 
generic map(
  INIT => X"20FFFFC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_334);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN_LUT6_2_O6: LUT4 
generic map(
  INIT => X"0008"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  I3 => GRLFPC20_FPI_LDOP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN_LUT6_2_O5: LUT4 
generic map(
  INIT => X"2AAA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(3),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_RIN_DPATH_SN_N_4_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(89),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6156);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_25_TRFWWBASICCELL_UN435_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(112),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6133);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(85),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6103);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_29_TRFWWBASICCELL_UN594_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(86),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6102);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN558_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6115);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN558_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(61),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6127);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_UN150_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(108),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6251);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_6_TRFWWBASICCELL_UN150_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6289);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_UN609_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(90),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6098);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_24_TRFWWBASICCELL_UN609_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6106);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6104);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_30_TRFWWBASICCELL_UN591_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(99),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6089);
GRLFPC20_ANNULRES_0_SQMUXA_2_1_LUT6_2_O6: LUT5 
generic map(
  INIT => X"000E0000"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => GRLFPC20_R_E_FPOP,
  I3 => GRLFPC20_R_M_FPOP,
  I4 => GRLFPC20_R_A_FPOP,
  O => GRLFPC20_ANNULRES_0_SQMUXA_2_1);
GRLFPC20_ANNULRES_0_SQMUXA_2_1_LUT6_2_O5: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => GRLFPC20_R_A_FPOP,
  O => GRLFPC20_V_E_FPOP_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_UN459_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6148);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_17_TRFWWBASICCELL_UN459_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6172);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_UN87_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(87),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6272);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_27_TRFWWBASICCELL_UN87_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6291);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_UN282_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(95),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6207);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_19_TRFWWBASICCELL_UN282_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(88),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6214);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_UN105_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(93),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6266);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_21_TRFWWBASICCELL_UN105_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(64),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6295);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN588_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6105);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN588_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6126);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIQO2P1_O6q78z: LUT3 
generic map(
  INIT => X"02"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1707);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIQO2P1_O5q78z: LUT3 
generic map(
  INIT => X"02"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1762);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_O6q0z: LUT5 
generic map(
  INIT => X"00020000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(7),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(0));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_O5q0z: LUT2 
generic map(
  INIT => X"D"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0);
GRLFPC20_WRADDR_0_SQMUXA_LUT6_2_O6: LUT5 
generic map(
  INIT => X"00010000"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  I3 => GRLFPC20_R_X_AFSR,
  I4 => GRLFPC20_R_X_LD,
  O => GRLFPC20_WRADDR_0_SQMUXA);
GRLFPC20_WRADDR_0_SQMUXA_LUT6_2_O5: LUT5 
generic map(
  INIT => X"01000000"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  I3 => GRLFPC20_R_X_AFSR,
  I4 => GRLFPC20_R_X_LD,
  O => GRLFPC20_V_FSR_AEXC_1_SQMUXA_SN);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_UN132_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(102),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6257);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_12_TRFWWBASICCELL_UN132_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(59),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6300);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(98),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6147);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_16_TRFWWBASICCELL_UN462_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6183);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN198_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6235);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN198_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(68),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6234);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN417_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6162);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_31_TRFWWBASICCELL_UN417_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(70),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6175);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_0_2_LUT6_2_O6q39z: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_0_1(39));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_0_2_LUT6_2_O5q39z: LUT5 
generic map(
  INIT => X"00120000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_12_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_13_0_LUT6_2_O6q60z: LUT4 
generic map(
  INIT => X"0400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_13_0(60));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A24_13_0_LUT6_2_O5q60z: LUT5 
generic map(
  INIT => X"00004000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3793);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_44_O6q84z: LUT5 
generic map(
  INIT => X"03FBFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_860);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_44_O5q84z: LUT5 
generic map(
  INIT => X"190A0AC0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_655);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_UN213_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6230);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_42_TRFWWBASICCELL_UN213_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(97),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6205);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_9_0_LUT6_2_O6q56z: LUT4 
generic map(
  INIT => X"0001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_9_0(56));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A25_9_0_LUT6_2_O5q56z: LUT5 
generic map(
  INIT => X"40000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_22_1(11));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1V1P1_O6q78z: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1731);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNI1V1P1_O5q78z: LUT4 
generic map(
  INIT => X"0082"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1877);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_53_O6q84z: LUT3 
generic map(
  INIT => X"01"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_731);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_53_O5q84z: LUT5 
generic map(
  INIT => X"31BBB337"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1018);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(71),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6117);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_43_TRFWWBASICCELL_UN552_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(72),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6116);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE_LUT6_2_O6: LUT2 
generic map(
  INIT => X"B"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_SRONEMORE_LUT6_2_O5: LUT5 
generic map(
  INIT => X"0F040B00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_SRTOSTICKY_1,
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_0(21),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_S_1_1(22),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G0_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_O6q2z: LUT5 
generic map(
  INIT => X"00020000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(5),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(2));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_O5q2z: LUT2 
generic map(
  INIT => X"D"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_UN285_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6206);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_18_TRFWWBASICCELL_UN285_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6220);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_0_O6q79z: LUT3 
generic map(
  INIT => X"41"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_343);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_0_O5q79z: LUT3 
generic map(
  INIT => X"08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_4637);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN27_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(67),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6292);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_UN27_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(77),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6282);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN69_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6278);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN69_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(96),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(55),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_27,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6263);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(81),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6164);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_33_TRFWWBASICCELL_UN411_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(104),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(51),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_23,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6141);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_UN639_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(100),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6088);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_14_TRFWWBASICCELL_UN639_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"A959"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(105),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(49),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_51,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6083);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_UN306_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(103),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6199);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_11_TRFWWBASICCELL_UN306_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(66),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6236);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(73),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6229);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_41_TRFWWBASICCELL_UN216_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(60),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6242);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_43_O6q84z: LUT5 
generic map(
  INIT => X"04FEFFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1241_MUX);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_43_O5q84z: LUT5 
generic map(
  INIT => X"290A0A43"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_618);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_UN234_TEMP_LUT6_2_O6: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6223);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_35_TRFWWBASICCELL_UN234_TEMP_LUT6_2_O5: LUT4 
generic map(
  INIT => X"9A95"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(110),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(21),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_3,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6192);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_0_O6q78z: LUT3 
generic map(
  INIT => X"08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1705);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_0_O5q78z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6365);
GRLFPC20_R_A_LD_RNIPS8D1_O6: LUT4 
generic map(
  INIT => X"1000"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => GRLFPC20_R_A_MOV,
  I3 => GRLFPC20_R_A_FPOP,
  O => GRLFPC20_N_826);
GRLFPC20_R_A_LD_RNIPS8D1_O5: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_a_annul,
  I1 => cpi_a_trap,
  I2 => GRLFPC20_R_A_LD,
  O => GRLFPC20_V_E_LD_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_O6q1z: LUT4 
generic map(
  INIT => X"E0C0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(10),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2814);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_EXPADDERSHFT_EXPXBUS_1_LUT6_2_O5q1z: LUT3 
generic map(
  INIT => X"E0"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(30),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(29),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(34),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_2815);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_9_2_LUT6_2_O6q11z: LUT4 
generic map(
  INIT => X"1000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(79),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3021_2);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_I_A27_9_2_LUT6_2_O5q11z: LUT4 
generic map(
  INIT => X"0100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_A15_24_0(58));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_6_0_LUT6_2_O6q36z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1739);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A19_6_0_LUT6_2_O5q36z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(82),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_19_0_0_A8_0(63));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_O6q1z: LUT5 
generic map(
  INIT => X"00020000"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(6),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3(1));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLAREGXZ_XZAREGLC_3_LUT6_2_O5q1z: LUT2 
generic map(
  INIT => X"D"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_G3_0_0_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_O6q78z: LUT3 
generic map(
  INIT => X"80"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(78),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_3853_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNIOM2P1_O5q78z: LUT4 
generic map(
  INIT => X"1FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_792);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_55_O6q84z: LUT3 
generic map(
  INIT => X"08"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_57_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_55_O5q84z: LUT5 
generic map(
  INIT => X"00008143"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_368);
GRLFPC20_V_I_EXEC_0_SQMUXA_LUT6_2_O6: LUT4 
generic map(
  INIT => X"0100"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  I3 => GRLFPC20_R_X_FPOP,
  O => GRLFPC20_V_I_EXEC_0_SQMUXA);
GRLFPC20_V_I_EXEC_0_SQMUXA_LUT6_2_O5: LUT5 
generic map(
  INIT => X"01000000"
)
port map (
  I0 => cpi_flush,
  I1 => cpi_x_annul,
  I2 => cpi_x_trap,
  I3 => holdn,
  I4 => GRLFPC20_R_X_FPOP,
  O => N_453);
GRLFPC20_RS2_0_SQMUXA_LUT6_2_O6: LUT3 
generic map(
  INIT => X"10"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  I2 => GRLFPC20_MOV_0_SQMUXA_4,
  O => GRLFPC20_RS2_0_SQMUXA);
GRLFPC20_RS2_0_SQMUXA_LUT6_2_O5: LUT5 
generic map(
  INIT => X"00100000"
)
port map (
  I0 => cpi_d_inst(20),
  I1 => cpi_d_inst(22),
  I2 => GRLFPC20_MOV_0_SQMUXA_4,
  I3 => GRLFPC20_COMB_UN4_LOCK,
  I4 => holdn,
  O => GRLFPC20_RIN_MK_LDOP_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_61_O6q84z: LUT4 
generic map(
  INIT => X"0001"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_746_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_61_O5q84z: LUT5 
generic map(
  INIT => X"7FFEFA9F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1042);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_60_O6q84z: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_55_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_60_O5q84z: LUT5 
generic map(
  INIT => X"5273F256"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_340);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_42_O6q84z: LUT5 
generic map(
  INIT => X"0500C7CE"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_997);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_42_O5q84z: LUT5 
generic map(
  INIT => X"55181C00"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_986);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_12_O6q84z: LUT4 
generic map(
  INIT => X"5FFB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1113);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_12_O5q84z: LUT5 
generic map(
  INIT => X"7FEFFFDB"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1168);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_59_O6q84z: LUT4 
generic map(
  INIT => X"0004"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_70_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_59_O5q84z: LUT5 
generic map(
  INIT => X"00000020"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_56_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_47_O6q84z: LUT4 
generic map(
  INIT => X"0900"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_120_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_47_O5q84z: LUT5 
generic map(
  INIT => X"39AAA215"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_458);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIG5604_O6q323z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(323),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(50),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_SI_12(45));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIG5604_O5q323z: LUT4 
generic map(
  INIT => X"F220"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(323),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(50),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_47_TRFWWBASICCELL_CIN_1,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_47_CI_11_C1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_50_O6q84z: LUT4 
generic map(
  INIT => X"0400"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_24_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_50_O5q84z: LUT5 
generic map(
  INIT => X"77FFFF7F"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_824);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIV01B7_O6q316z: LUT4 
generic map(
  INIT => X"2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_54_SI_5(52));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH_RNIV01B7_O5q316z: LUT5 
generic map(
  INIT => X"D22D2DD2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_DPATH(316),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(0),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_CTRLXERSHFT_SUMIN_4(57),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_52_TRFWWBASICCELL_CIN,
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_REMWTAGE57_54_TRFWWBASICCELL_CIN_2,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_TRFWWRRAY_53_CI_5_AXB1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_O6q84z: LUT4 
generic map(
  INIT => X"8000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_766_I);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_O5q84z: LUT5 
generic map(
  INIT => X"12900064"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_6367);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_19_O6q84z: LUT4 
generic map(
  INIT => X"3AFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1011);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_19_O5q84z: LUT5 
generic map(
  INIT => X"2DCCD7BA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_436);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_48_O6q84z: LUT4 
generic map(
  INIT => X"0880"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1105);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_48_O5q84z: LUT5 
generic map(
  INIT => X"66557DEA"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_419);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_25_O6q84z: LUT4 
generic map(
  INIT => X"2000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_201_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_25_O5q84z: LUT5 
generic map(
  INIT => X"04000029"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_838);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_57_O6q84z: LUT4 
generic map(
  INIT => X"0020"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_699);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_57_O5q84z: LUT5 
generic map(
  INIT => X"02010890"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_559);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_51_O6q84z: LUT4 
generic map(
  INIT => X"0230"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_59_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_51_O5q84z: LUT5 
generic map(
  INIT => X"FFBF3EFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1155);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_52_O6q84z: LUT4 
generic map(
  INIT => X"0110"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_12_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_52_O5q84z: LUT5 
generic map(
  INIT => X"05060590"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_661);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_49_O6q84z: LUT4 
generic map(
  INIT => X"0810"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_841);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_49_O5q84z: LUT5 
generic map(
  INIT => X"20000004"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1134);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_7_O6q84z: LUT4 
generic map(
  INIT => X"6FFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1214);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_7_O5q84z: LUT5 
generic map(
  INIT => X"4CE01000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_583);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_56_O6q84z: LUT4 
generic map(
  INIT => X"0060"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_761);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_56_O5q84z: LUT5 
generic map(
  INIT => X"7AFB727E"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1016);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1_LUT6_2_O6: LUT4 
generic map(
  INIT => X"00EF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(65),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(71),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(72),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_UPDATE_1_LUT6_2_O5: LUT2 
generic map(
  INIT => X"2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(62),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_WAITMULXFF_NOTSAMPLEDWAIT,
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_PXS_PCTRL_NEW_18_0(74));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_LUT6_2_O6q22z: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_LUT6_2_O5q22z: LUT5 
generic map(
  INIT => X"003BC4FF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(22),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(26),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_0(22));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_LUT6_2_O6q23z: LUT5 
generic map(
  INIT => X"00C43BFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(27),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_LUT6_2_O5q23z: LUT5 
generic map(
  INIT => X"00C43BFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_SCTRL(15),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(42),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_GRFPUE(2),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(27),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_8(23),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_RIGHTSHIFTERBL_S_4_1(23));
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_17_O6q84z: LUT5 
generic map(
  INIT => X"3AEB03D2"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_912);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_17_O5q84z: LUT5 
generic map(
  INIT => X"06060490"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_626);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_54_O6q84z: LUT5 
generic map(
  INIT => X"00050720"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_797);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_54_O5q84z: LUT5 
generic map(
  INIT => X"3EA5FFFF"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_1012);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_58_O6q84z: LUT5 
generic map(
  INIT => X"00000100"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_784);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_58_O5q84z: LUT5 
generic map(
  INIT => X"00010000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_808_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_45_O6q84z: LUT5 
generic map(
  INIT => X"02000000"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_828);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_45_O5q84z: LUT5 
generic map(
  INIT => X"3900000C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_584);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_6_O6q84z: LUT5 
generic map(
  INIT => X"6836D31D"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_995);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL_RNILK3P1_6_O5q84z: LUT5 
generic map(
  INIT => X"2900000C"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(84),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(83),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(85),
  I3 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(81),
  I4 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(80),
  O => GRLFPC20_GRFPUL_GEN0_GRLFPU0_N_552);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNINQMJ3_O6q11z: LUT3 
generic map(
  INIT => X"D8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => N_29,
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(14),
  O => N_30);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNINQMJ3_O5q11z: LUT3 
generic map(
  INIT => X"27"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(11),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(13),
  O => G5_0_0);
GRLFPC20_R_MK_LDOP_RNI8VJU_2_O6: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_139);
GRLFPC20_R_MK_LDOP_RNI8VJU_2_O5: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_131_1);
GRLFPC20_R_MK_LDOP_RNI8VJU_0_O6: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_131);
GRLFPC20_R_MK_LDOP_RNI8VJU_0_O5: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_139_0);
GRLFPC20_R_MK_LDOP_RNI8VJU_O6: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_131_0);
GRLFPC20_R_MK_LDOP_RNI8VJU_O5: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_139_1);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNIAHNO1_O6q19z: LUT3 
generic map(
  INIT => X"27"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(26),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(28),
  O => G5_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4_LUT6_2_RNIAHNO1_O5q19z: LUT3 
generic map(
  INIT => X"27"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_SLCONTROL(1),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(17),
  I2 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_LEFTSHIFTERBL_S_4(19),
  O => G5_0_1);
GRLFPC20_R_MK_LDOP_RNI8VJU_1_O6: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_139_2);
GRLFPC20_R_MK_LDOP_RNI8VJU_1_O5: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_139_4);
GRLFPC20_R_MK_LDOP_RNI8VJU_3_O6: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_139_3);
GRLFPC20_R_MK_LDOP_RNI8VJU_3_O5: LUT4 
generic map(
  INIT => X"0002"
)
port map (
  I0 => rst,
  I1 => GRLFPC20_R_MK_LDOP,
  I2 => GRLFPC20_R_MK_RST,
  I3 => GRLFPC20_R_MK_RST2,
  O => N_139_5);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN_LUT6_2_RNII1LN_O6: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  O => M74_I_A3_0);
GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN_LUT6_2_RNII1LN_O5: LUT2 
generic map(
  INIT => X"8"
)
port map (
  I0 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_R_PCTRL(45),
  I1 => GRLFPC20_GRFPUL_GEN0_GRLFPU0_C_DPXX_UN11_XZAREGLOADEN,
  O => M74_I_A3_0_0);
cpo_cc(0) <= NN_1;
cpo_cc(1) <= CPO_CC_2;
cpo_restart <= NN_5;
cpo_dbg_data(0) <= NN_5;
cpo_dbg_data(1) <= NN_5;
cpo_dbg_data(2) <= NN_5;
cpo_dbg_data(3) <= NN_5;
cpo_dbg_data(4) <= NN_5;
cpo_dbg_data(5) <= NN_5;
cpo_dbg_data(6) <= NN_5;
cpo_dbg_data(7) <= NN_5;
cpo_dbg_data(8) <= NN_5;
cpo_dbg_data(9) <= NN_5;
cpo_dbg_data(10) <= NN_5;
cpo_dbg_data(11) <= NN_5;
cpo_dbg_data(12) <= NN_5;
cpo_dbg_data(13) <= NN_5;
cpo_dbg_data(14) <= NN_5;
cpo_dbg_data(15) <= NN_5;
cpo_dbg_data(16) <= NN_5;
cpo_dbg_data(17) <= NN_5;
cpo_dbg_data(18) <= NN_5;
cpo_dbg_data(19) <= NN_5;
cpo_dbg_data(20) <= NN_5;
cpo_dbg_data(21) <= NN_5;
cpo_dbg_data(22) <= NN_5;
cpo_dbg_data(23) <= NN_5;
cpo_dbg_data(24) <= NN_5;
cpo_dbg_data(25) <= NN_5;
cpo_dbg_data(26) <= NN_5;
cpo_dbg_data(27) <= NN_5;
cpo_dbg_data(28) <= NN_5;
cpo_dbg_data(29) <= NN_5;
cpo_dbg_data(30) <= NN_5;
cpo_dbg_data(31) <= NN_5;
cpo_dbg_par(0) <= NN_5;
cpo_dbg_par(1) <= NN_5;
cpo_dbg_par(2) <= NN_5;
cpo_dbg_par(3) <= NN_5;
cpo_dbg_par(4) <= NN_5;
cpo_dbg_par(5) <= NN_5;
cpo_dbg_par(6) <= NN_5;
cpo_dbg_par(7) <= NN_5;
rfi1_rd1addr(0) <= RFI2_RD1ADDR_70;
rfi1_rd1addr(1) <= RFI2_RD1ADDR_71;
rfi1_rd1addr(2) <= RFI2_RD1ADDR_72;
rfi1_rd1addr(3) <= RFI2_RD1ADDR_73;
rfi1_rd2addr(0) <= RFI2_RD2ADDR_74;
rfi1_rd2addr(1) <= RFI2_RD2ADDR_75;
rfi1_rd2addr(2) <= RFI2_RD2ADDR_76;
rfi1_rd2addr(3) <= RFI2_RD2ADDR_77;
rfi1_wraddr(0) <= RFI2_WRADDR_78;
rfi1_wraddr(1) <= RFI2_WRADDR_79;
rfi1_wraddr(2) <= RFI2_WRADDR_80;
rfi1_wraddr(3) <= RFI2_WRADDR_81;
rfi1_wecb(0) <= NN_5;
rfi1_wecb(1) <= NN_5;
rfi1_wecb(2) <= NN_5;
rfi1_wecb(3) <= NN_5;
rfi1_wecb(4) <= NN_5;
rfi1_wecb(5) <= NN_5;
rfi1_wecb(6) <= NN_5;
rfi1_wecb(7) <= NN_5;
rfi1_ren1 <= RFI1_REN1_64;
rfi1_ren2 <= RFI1_REN2_65;
rfi1_inhw1 <= NN_5;
rfi1_inhw2 <= NN_5;
rfi1_einj1 <= NN_5;
rfi1_einj2 <= NN_5;
rfi2_rd1addr(0) <= RFI2_RD1ADDR_70;
rfi2_rd1addr(1) <= RFI2_RD1ADDR_71;
rfi2_rd1addr(2) <= RFI2_RD1ADDR_72;
rfi2_rd1addr(3) <= RFI2_RD1ADDR_73;
rfi2_rd2addr(0) <= RFI2_RD2ADDR_74;
rfi2_rd2addr(1) <= RFI2_RD2ADDR_75;
rfi2_rd2addr(2) <= RFI2_RD2ADDR_76;
rfi2_rd2addr(3) <= RFI2_RD2ADDR_77;
rfi2_wraddr(0) <= RFI2_WRADDR_78;
rfi2_wraddr(1) <= RFI2_WRADDR_79;
rfi2_wraddr(2) <= RFI2_WRADDR_80;
rfi2_wraddr(3) <= RFI2_WRADDR_81;
rfi2_wecb(0) <= NN_5;
rfi2_wecb(1) <= NN_5;
rfi2_wecb(2) <= NN_5;
rfi2_wecb(3) <= NN_5;
rfi2_wecb(4) <= NN_5;
rfi2_wecb(5) <= NN_5;
rfi2_wecb(6) <= NN_5;
rfi2_wecb(7) <= NN_5;
rfi2_ren1 <= RFI2_REN1_90;
rfi2_ren2 <= RFI2_REN2_91;
rfi2_inhw1 <= NN_5;
rfi2_inhw2 <= NN_5;
rfi2_einj1 <= NN_5;
rfi2_einj2 <= NN_5;
end beh;

